""" openconfig_network_instance 

An OpenConfig description of a network\-instance. This may be
a Layer 3 forwarding construct such as a virtual routing and
forwarding (VRF) instance, or a Layer 2 instance such as a
virtual switch instance (VSI). Mixed Layer 2 and Layer 3
instances are also supported.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class NetworkInstances(_Entity_):
    """
    The L2, L3, or L2+L3 forwarding instances that are
    configured on the local system
    
    .. attribute:: network_instance
    
        Network instances configured on the local system
    
        **type**: list of    :py:class:`NetworkInstance<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance>`
    
    """
    _prefix = 'oc-netinst'
    _revision = '2017-01-13'

    def __init__(self):
        super().__init__()
        self._top_entity = None

        self.yang_name = "network-instances"
        self.yang_parent_name = "openconfig-network-instance"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("network-instance", ("network_instance", NetworkInstances.NetworkInstance))])
        self._leafs = OrderedDict()

        self.network_instance = YList(self)
        self._segment_path = lambda: "openconfig-network-instance:network-instances"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(NetworkInstances, [], name, value)

    class NetworkInstance(_Entity_):
        """
        Network instances configured on the local system
        
        .. attribute:: name  (key)
        
            A unique name identifying the network instance
        
            **type**: str
        
            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
        
        .. attribute:: fdb
        
            Operational state and configuration parameters relating to the forwarding database of the network instance
        
            **type**:  :py:class:`Fdb<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb>`
        
        .. attribute:: config
        
            Configuration parameters relating to a network instance
        
            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
        
        .. attribute:: state
        
            Operational state parameters relating to a network instance
        
            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.State>`
        
            **config**: False
        
        .. attribute:: encapsulation
        
            Configuration parameters relating to the encapsulation used for the network instance
        
            **type**:  :py:class:`Encapsulation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Encapsulation>`
        
        .. attribute:: inter_instance_policies
        
            Policies dictating how RIB or FIB entries are imported to and exported from this instance
        
            **type**:  :py:class:`InterInstancePolicies<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies>`
        
        .. attribute:: table_connections
        
            Policies dictating how RIB or FIB entries are propagated between tables
        
            **type**:  :py:class:`TableConnections<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections>`
        
        .. attribute:: interfaces
        
            The interfaces that are associated with this network instance
        
            **type**:  :py:class:`Interfaces<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces>`
        
        .. attribute:: tables
        
            The routing tables that are managed by this network instance
        
            **type**:  :py:class:`Tables<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables>`
        
        .. attribute:: connection_points
        
            The set of connection points within a forwarding instance
        
            **type**:  :py:class:`ConnectionPoints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints>`
        
        .. attribute:: mpls
        
            Anchor point for mpls configuration and operational data
        
            **type**:  :py:class:`Mpls<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls>`
        
        .. attribute:: segment_routing
        
            Configuration and operational state parameters relating to segment routing
        
            **type**:  :py:class:`SegmentRouting<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting>`
        
        .. attribute:: vlans
        
            Container for VLAN configuration and state variables
        
            **type**:  :py:class:`Vlans<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans>`
        
        .. attribute:: afts
        
            The abstract forwarding tables (AFTs) that are associated with the network instance. An AFT is instantiated per\-protocol running within the network\-instance \- such that one exists for IPv4 Unicast, IPv6 Unicast, MPLS, L2 forwarding entries, etc. A forwarding entry within the FIB has a set of next\-hops, which may be a reference to an entry within another table \- e.g., where a Layer 3 next\-hop has an associated Layer 2 forwarding entry
        
            **type**:  :py:class:`Afts<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts>`
        
        .. attribute:: protocols
        
            The routing protocols that are enabled for this network\-instance
        
            **type**:  :py:class:`Protocols<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols>`
        
        """
        _prefix = 'oc-netinst'
        _revision = '2017-01-13'

        def __init__(self):
            super().__init__()

            self.yang_name = "network-instance"
            self.yang_parent_name = "network-instances"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = ['name']
            self._child_classes = OrderedDict([("fdb", ("fdb", NetworkInstances.NetworkInstance.Fdb)), ("config", ("config", NetworkInstances.NetworkInstance.Config)), ("state", ("state", NetworkInstances.NetworkInstance.State)), ("encapsulation", ("encapsulation", NetworkInstances.NetworkInstance.Encapsulation)), ("inter-instance-policies", ("inter_instance_policies", NetworkInstances.NetworkInstance.InterInstancePolicies)), ("table-connections", ("table_connections", NetworkInstances.NetworkInstance.TableConnections)), ("interfaces", ("interfaces", NetworkInstances.NetworkInstance.Interfaces)), ("tables", ("tables", NetworkInstances.NetworkInstance.Tables)), ("connection-points", ("connection_points", NetworkInstances.NetworkInstance.ConnectionPoints)), ("mpls", ("mpls", NetworkInstances.NetworkInstance.Mpls)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.SegmentRouting)), ("vlans", ("vlans", NetworkInstances.NetworkInstance.Vlans)), ("afts", ("afts", NetworkInstances.NetworkInstance.Afts)), ("protocols", ("protocols", NetworkInstances.NetworkInstance.Protocols))])
            self._leafs = OrderedDict([
                ('name', (YLeaf(YType.str, 'name'), ['str'])),
            ])
            self.name = None

            self.fdb = NetworkInstances.NetworkInstance.Fdb()
            self.fdb.parent = self
            self._children_name_map["fdb"] = "fdb"

            self.config = NetworkInstances.NetworkInstance.Config()
            self.config.parent = self
            self._children_name_map["config"] = "config"

            self.state = NetworkInstances.NetworkInstance.State()
            self.state.parent = self
            self._children_name_map["state"] = "state"

            self.encapsulation = NetworkInstances.NetworkInstance.Encapsulation()
            self.encapsulation.parent = self
            self._children_name_map["encapsulation"] = "encapsulation"

            self.inter_instance_policies = NetworkInstances.NetworkInstance.InterInstancePolicies()
            self.inter_instance_policies.parent = self
            self._children_name_map["inter_instance_policies"] = "inter-instance-policies"

            self.table_connections = NetworkInstances.NetworkInstance.TableConnections()
            self.table_connections.parent = self
            self._children_name_map["table_connections"] = "table-connections"

            self.interfaces = NetworkInstances.NetworkInstance.Interfaces()
            self.interfaces.parent = self
            self._children_name_map["interfaces"] = "interfaces"

            self.tables = NetworkInstances.NetworkInstance.Tables()
            self.tables.parent = self
            self._children_name_map["tables"] = "tables"

            self.connection_points = NetworkInstances.NetworkInstance.ConnectionPoints()
            self.connection_points.parent = self
            self._children_name_map["connection_points"] = "connection-points"

            self.mpls = NetworkInstances.NetworkInstance.Mpls()
            self.mpls.parent = self
            self._children_name_map["mpls"] = "mpls"

            self.segment_routing = NetworkInstances.NetworkInstance.SegmentRouting()
            self.segment_routing.parent = self
            self._children_name_map["segment_routing"] = "segment-routing"

            self.vlans = NetworkInstances.NetworkInstance.Vlans()
            self.vlans.parent = self
            self._children_name_map["vlans"] = "vlans"

            self.afts = NetworkInstances.NetworkInstance.Afts()
            self.afts.parent = self
            self._children_name_map["afts"] = "afts"

            self.protocols = NetworkInstances.NetworkInstance.Protocols()
            self.protocols.parent = self
            self._children_name_map["protocols"] = "protocols"
            self._segment_path = lambda: "network-instance" + "[name='" + str(self.name) + "']"
            self._absolute_path = lambda: "openconfig-network-instance:network-instances/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(NetworkInstances.NetworkInstance, ['name'], name, value)

        class Fdb(_Entity_):
            """
            Operational state and configuration parameters relating to
            the forwarding database of the network instance
            
            .. attribute:: config
            
                Configuration parameters relating to the FDB
            
                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.Config>`
            
            .. attribute:: state
            
                Operational state parameters relating to the FDB
            
                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.State>`
            
                **config**: False
            
            .. attribute:: mac_table
            
                Table of learned or statically configured MAC addresses and corresponding VLANs in the bridge domain
            
                **type**:  :py:class:`MacTable<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "fdb"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Fdb.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Fdb.State)), ("mac-table", ("mac_table", NetworkInstances.NetworkInstance.Fdb.MacTable))])
                self._leafs = OrderedDict()

                self.config = NetworkInstances.NetworkInstance.Fdb.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.state = NetworkInstances.NetworkInstance.Fdb.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"

                self.mac_table = NetworkInstances.NetworkInstance.Fdb.MacTable()
                self.mac_table.parent = self
                self._children_name_map["mac_table"] = "mac-table"
                self._segment_path = lambda: "fdb"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Fdb, [], name, value)

            class Config(_Entity_):
                """
                Configuration parameters relating to the FDB
                
                .. attribute:: mac_learning
                
                    When this leaf is set to true, MAC learning is enabled for the network instance, such that MAC addresses are learned from ingress frames and added to the FDB
                
                    **type**: bool
                
                .. attribute:: mac_aging_time
                
                    The number of seconds of inactivity after which the entry in the local FDB is timed out
                
                    **type**: int
                
                        **range:** 0..65535
                
                    **units**: seconds
                
                .. attribute:: maximum_entries
                
                    The maximum number of MAC address entries that should be accepted into the FDB
                
                    **type**: int
                
                        **range:** 0..65535
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "fdb"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mac_learning', (YLeaf(YType.boolean, 'mac-learning'), ['bool'])),
                        ('mac_aging_time', (YLeaf(YType.uint16, 'mac-aging-time'), ['int'])),
                        ('maximum_entries', (YLeaf(YType.uint16, 'maximum-entries'), ['int'])),
                    ])
                    self.mac_learning = None
                    self.mac_aging_time = None
                    self.maximum_entries = None
                    self._segment_path = lambda: "config"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.Config, ['mac_learning', 'mac_aging_time', 'maximum_entries'], name, value)


            class State(_Entity_):
                """
                Operational state parameters relating to the FDB
                
                .. attribute:: mac_learning
                
                    When this leaf is set to true, MAC learning is enabled for the network instance, such that MAC addresses are learned from ingress frames and added to the FDB
                
                    **type**: bool
                
                    **config**: False
                
                .. attribute:: mac_aging_time
                
                    The number of seconds of inactivity after which the entry in the local FDB is timed out
                
                    **type**: int
                
                        **range:** 0..65535
                
                    **config**: False
                
                    **units**: seconds
                
                .. attribute:: maximum_entries
                
                    The maximum number of MAC address entries that should be accepted into the FDB
                
                    **type**: int
                
                        **range:** 0..65535
                
                    **config**: False
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "fdb"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('mac_learning', (YLeaf(YType.boolean, 'mac-learning'), ['bool'])),
                        ('mac_aging_time', (YLeaf(YType.uint16, 'mac-aging-time'), ['int'])),
                        ('maximum_entries', (YLeaf(YType.uint16, 'maximum-entries'), ['int'])),
                    ])
                    self.mac_learning = None
                    self.mac_aging_time = None
                    self.maximum_entries = None
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.State, ['mac_learning', 'mac_aging_time', 'maximum_entries'], name, value)


            class MacTable(_Entity_):
                """
                Table of learned or statically configured MAC addresses and
                corresponding VLANs in the bridge domain
                
                .. attribute:: entries
                
                    Enclosing container for list of MAC table entries
                
                    **type**:  :py:class:`Entries<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "mac-table"
                    self.yang_parent_name = "fdb"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("entries", ("entries", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries))])
                    self._leafs = OrderedDict()

                    self.entries = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries()
                    self.entries.parent = self
                    self._children_name_map["entries"] = "entries"
                    self._segment_path = lambda: "mac-table"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable, [], name, value)

                class Entries(_Entity_):
                    """
                    Enclosing container for list of MAC table entries
                    
                    .. attribute:: entry
                    
                        List of learned MAC addresses
                    
                        **type**: list of    :py:class:`Entry<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "entries"
                        self.yang_parent_name = "mac-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("entry", ("entry", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry))])
                        self._leafs = OrderedDict()

                        self.entry = YList(self)
                        self._segment_path = lambda: "entries"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries, [], name, value)

                    class Entry(_Entity_):
                        """
                        List of learned MAC addresses
                        
                        .. attribute:: mac_address  (key)
                        
                            Reference to mac\-address list key
                        
                            **type**: str
                        
                                **pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                            **refers to**:  :py:class:`mac_address<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config>`
                        
                        .. attribute:: config
                        
                            Configuration data for MAC table entries
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config>`
                        
                        .. attribute:: state
                        
                            Operational state data for MAC table entries
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State>`
                        
                            **config**: False
                        
                        .. attribute:: interface
                        
                            Reference to the base and/or subinterface for the MAC table entry
                        
                            **type**:  :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "entry"
                            self.yang_parent_name = "entries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['mac_address']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State)), ("interface", ("interface", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface))])
                            self._leafs = OrderedDict([
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ])
                            self.mac_address = None

                            self.config = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.interface = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"
                            self._segment_path = lambda: "entry" + "[mac-address='" + str(self.mac_address) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry, ['mac_address'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration data for MAC table entries
                            
                            .. attribute:: mac_address
                            
                                MAC address for the dynamic or static MAC table entry
                            
                                **type**: str
                            
                                    **pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: vlan
                            
                                VLAN from which this MAC address was received
                            
                                **type**: int
                            
                                    **range:** 1..4094
                            
                                **refers to**:  :py:class:`vlan_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                    ('vlan', (YLeaf(YType.str, 'vlan'), ['int'])),
                                ])
                                self.mac_address = None
                                self.vlan = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Config, ['mac_address', 'vlan'], name, value)


                        class State(_Entity_):
                            """
                            Operational state data for MAC table entries
                            
                            .. attribute:: mac_address
                            
                                MAC address for the dynamic or static MAC table entry
                            
                                **type**: str
                            
                                    **pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                                **config**: False
                            
                            .. attribute:: vlan
                            
                                VLAN from which this MAC address was received
                            
                                **type**: int
                            
                                    **range:** 1..4094
                            
                                **refers to**:  :py:class:`vlan_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                            
                                **config**: False
                            
                            .. attribute:: age
                            
                                The time in seconds since the MAC address has been in the table
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                                **units**: seconds
                            
                            .. attribute:: entry_type
                            
                                Indicates whether the entry was statically configured, or dynamically learned
                            
                                **type**:  :py:class:`EntryType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State.EntryType>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                    ('vlan', (YLeaf(YType.str, 'vlan'), ['int'])),
                                    ('age', (YLeaf(YType.uint64, 'age'), ['int'])),
                                    ('entry_type', (YLeaf(YType.enumeration, 'entry-type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Fdb.MacTable.Entries.Entry.State.EntryType')])),
                                ])
                                self.mac_address = None
                                self.vlan = None
                                self.age = None
                                self.entry_type = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.State, ['mac_address', 'vlan', 'age', 'entry_type'], name, value)

                            class EntryType(Enum):
                                """
                                EntryType (Enum Class)

                                .. data:: STATIC = 0

                                    Statically programmed MAC table entry

                                .. data:: DYNAMIC = 1

                                    Dynamically learned MAC table entry

                                """

                                STATIC = Enum.YLeaf(0, "STATIC")

                                DYNAMIC = Enum.YLeaf(1, "DYNAMIC")



                        class Interface(_Entity_):
                            """
                            Reference to the base and/or subinterface for the
                            MAC table entry
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef))])
                                self._leafs = OrderedDict()

                                self.interface_ref = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "interface"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface, [], name, value)

                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Fdb.MacTable.Entries.Entry.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)








        class Config(_Entity_):
            """
            Configuration parameters relating to a network
            instance
            
            .. attribute:: name
            
                An operator\-assigned unique name for the forwarding instance
            
                **type**: str
            
            .. attribute:: type
            
                The type of network instance. The value of this leaf indicates the type of forwarding entries that should be supported by this network instance
            
                **type**:  :py:class:`NETWORKINSTANCETYPE<ydk.models.openconfig.openconfig_network_instance_types.NETWORKINSTANCETYPE>`
            
            .. attribute:: enabled
            
                Whether the network instance should be configured to be active on the network element
            
                **type**: bool
            
            .. attribute:: description
            
                A free\-form string to be used by the network operator to describe the function of this network instance
            
                **type**: str
            
            .. attribute:: router_id
            
                A identifier for the local network instance \- typically used within associated routing protocols or signalling routing information in another network instance
            
                **type**: str
            
                    **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])
            
            .. attribute:: route_distinguisher
            
                The route distinguisher that should be used for the local VRF or VSI instance when it is signalled via BGP
            
                **type**: union of the below types:
            
                    **type**: str
            
                        **pattern:** ^(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])\:(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])$
            
                    **type**: str
            
                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\:(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])$
            
                    **type**: str
            
                        **pattern:** ^(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])\:(65[0\-5][0\-3][0\-5]\|[1\-5]{2}[0\-9]{3}\|[1\-9]{0,2}[0\-9][0\-9]\|[1\-9])$
            
            .. attribute:: enabled_address_families
            
                The address families that are to be enabled for this network instance
            
                **type**: list of   :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
            
            .. attribute:: mtu
            
                The maximum frame size which should be supported for this instance for Layer 2 frames
            
                **type**: int
            
                    **range:** 0..65535
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "config"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_network_instance_types', 'NETWORKINSTANCETYPE')])),
                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str','str','str'])),
                    ('enabled_address_families', (YLeafList(YType.identityref, 'enabled-address-families'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                ])
                self.name = None
                self.type = None
                self.enabled = None
                self.description = None
                self.router_id = None
                self.route_distinguisher = None
                self.enabled_address_families = []
                self.mtu = None
                self._segment_path = lambda: "config"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Config, ['name', 'type', 'enabled', 'description', 'router_id', 'route_distinguisher', 'enabled_address_families', 'mtu'], name, value)


        class State(_Entity_):
            """
            Operational state parameters relating to a network
            instance
            
            .. attribute:: name
            
                An operator\-assigned unique name for the forwarding instance
            
                **type**: str
            
                **config**: False
            
            .. attribute:: type
            
                The type of network instance. The value of this leaf indicates the type of forwarding entries that should be supported by this network instance
            
                **type**:  :py:class:`NETWORKINSTANCETYPE<ydk.models.openconfig.openconfig_network_instance_types.NETWORKINSTANCETYPE>`
            
                **config**: False
            
            .. attribute:: enabled
            
                Whether the network instance should be configured to be active on the network element
            
                **type**: bool
            
                **config**: False
            
            .. attribute:: description
            
                A free\-form string to be used by the network operator to describe the function of this network instance
            
                **type**: str
            
                **config**: False
            
            .. attribute:: router_id
            
                A identifier for the local network instance \- typically used within associated routing protocols or signalling routing information in another network instance
            
                **type**: str
            
                    **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])
            
                **config**: False
            
            .. attribute:: route_distinguisher
            
                The route distinguisher that should be used for the local VRF or VSI instance when it is signalled via BGP
            
                **type**: union of the below types:
            
                    **type**: str
            
                        **pattern:** ^(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])\:(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])$
            
                    **type**: str
            
                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\:(65[0\-5][0\-3][0\-5]\|[1\-5][1\-5][0\-9][0\-9][0\-9]\|[1\-9]?[1\-9]?[0\-9][0\-9]\|[1\-9])$
            
                    **type**: str
            
                        **pattern:** ^(4[0\-2][0\-9][0\-4][0\-9][0\-6][0\-7][0\-2][0\-9][0\-5]\|[0\-3][0\-9]{9}\|[1\-9][0\-9]{1,8}\|[1\-9])\:(65[0\-5][0\-3][0\-5]\|[1\-5]{2}[0\-9]{3}\|[1\-9]{0,2}[0\-9][0\-9]\|[1\-9])$
            
                **config**: False
            
            .. attribute:: enabled_address_families
            
                The address families that are to be enabled for this network instance
            
                **type**: list of   :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
            
                **config**: False
            
            .. attribute:: mtu
            
                The maximum frame size which should be supported for this instance for Layer 2 frames
            
                **type**: int
            
                    **range:** 0..65535
            
                **config**: False
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "state"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_network_instance_types', 'NETWORKINSTANCETYPE')])),
                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                    ('description', (YLeaf(YType.str, 'description'), ['str'])),
                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                    ('route_distinguisher', (YLeaf(YType.str, 'route-distinguisher'), ['str','str','str'])),
                    ('enabled_address_families', (YLeafList(YType.identityref, 'enabled-address-families'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                    ('mtu', (YLeaf(YType.uint16, 'mtu'), ['int'])),
                ])
                self.name = None
                self.type = None
                self.enabled = None
                self.description = None
                self.router_id = None
                self.route_distinguisher = None
                self.enabled_address_families = []
                self.mtu = None
                self._segment_path = lambda: "state"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.State, ['name', 'type', 'enabled', 'description', 'router_id', 'route_distinguisher', 'enabled_address_families', 'mtu'], name, value)


        class Encapsulation(_Entity_):
            """
            Configuration parameters relating to the encapsulation
            used for the network instance
            
            .. attribute:: config
            
                Configuration parameters relating to the encapsulation of the network instance
            
                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Encapsulation.Config>`
            
            .. attribute:: state
            
                State parameters relating to the encapsulation of the network instance
            
                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Encapsulation.State>`
            
                **config**: False
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "encapsulation"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Encapsulation.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Encapsulation.State))])
                self._leafs = OrderedDict()

                self.config = NetworkInstances.NetworkInstance.Encapsulation.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.state = NetworkInstances.NetworkInstance.Encapsulation.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"
                self._segment_path = lambda: "encapsulation"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Encapsulation, [], name, value)

            class Config(_Entity_):
                """
                Configuration parameters relating to the encapsulation
                of the network instance
                
                .. attribute:: encapsulation_type
                
                    The on\-the\-wire encapsulation that should be used when sending traffic from this network instance
                
                    **type**:  :py:class:`ENCAPSULATION<ydk.models.openconfig.openconfig_network_instance_types.ENCAPSULATION>`
                
                .. attribute:: label_allocation_mode
                
                    The label allocation mode to be used for L3 entries in the network instance
                
                    **type**:  :py:class:`LABELALLOCATIONMODE<ydk.models.openconfig.openconfig_network_instance_types.LABELALLOCATIONMODE>`
                
                .. attribute:: control_word
                
                    Whether the control\-word should be used for the network instance
                
                    **type**: bool
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "encapsulation"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encapsulation_type', (YLeaf(YType.identityref, 'encapsulation-type'), [('ydk.models.openconfig.openconfig_network_instance_types', 'ENCAPSULATION')])),
                        ('label_allocation_mode', (YLeaf(YType.identityref, 'label-allocation-mode'), [('ydk.models.openconfig.openconfig_network_instance_types', 'LABELALLOCATIONMODE')])),
                        ('control_word', (YLeaf(YType.boolean, 'control-word'), ['bool'])),
                    ])
                    self.encapsulation_type = None
                    self.label_allocation_mode = None
                    self.control_word = None
                    self._segment_path = lambda: "config"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Encapsulation.Config, ['encapsulation_type', 'label_allocation_mode', 'control_word'], name, value)


            class State(_Entity_):
                """
                State parameters relating to the encapsulation of
                the network instance
                
                .. attribute:: encapsulation_type
                
                    The on\-the\-wire encapsulation that should be used when sending traffic from this network instance
                
                    **type**:  :py:class:`ENCAPSULATION<ydk.models.openconfig.openconfig_network_instance_types.ENCAPSULATION>`
                
                    **config**: False
                
                .. attribute:: label_allocation_mode
                
                    The label allocation mode to be used for L3 entries in the network instance
                
                    **type**:  :py:class:`LABELALLOCATIONMODE<ydk.models.openconfig.openconfig_network_instance_types.LABELALLOCATIONMODE>`
                
                    **config**: False
                
                .. attribute:: control_word
                
                    Whether the control\-word should be used for the network instance
                
                    **type**: bool
                
                    **config**: False
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "encapsulation"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('encapsulation_type', (YLeaf(YType.identityref, 'encapsulation-type'), [('ydk.models.openconfig.openconfig_network_instance_types', 'ENCAPSULATION')])),
                        ('label_allocation_mode', (YLeaf(YType.identityref, 'label-allocation-mode'), [('ydk.models.openconfig.openconfig_network_instance_types', 'LABELALLOCATIONMODE')])),
                        ('control_word', (YLeaf(YType.boolean, 'control-word'), ['bool'])),
                    ])
                    self.encapsulation_type = None
                    self.label_allocation_mode = None
                    self.control_word = None
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Encapsulation.State, ['encapsulation_type', 'label_allocation_mode', 'control_word'], name, value)



        class InterInstancePolicies(_Entity_):
            """
            Policies dictating how RIB or FIB entries are imported
            to and exported from this instance
            
            .. attribute:: apply_policy
            
                Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
            
                **type**:  :py:class:`ApplyPolicy<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "inter-instance-policies"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy))])
                self._leafs = OrderedDict()

                self.apply_policy = NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy()
                self.apply_policy.parent = self
                self._children_name_map["apply_policy"] = "apply-policy"
                self._segment_path = lambda: "inter-instance-policies"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.InterInstancePolicies, [], name, value)

            class ApplyPolicy(_Entity_):
                """
                Anchor point for routing policies in the model.
                Import and export policies are with respect to the local
                routing table, i.e., export (send) and import (receive),
                depending on the context.
                
                .. attribute:: config
                
                    Policy configuration data
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config>`
                
                .. attribute:: state
                
                    Operational state for routing policy
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State>`
                
                    **config**: False
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "apply-policy"
                    self.yang_parent_name = "inter-instance-policies"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State))])
                    self._leafs = OrderedDict()

                    self.config = NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._segment_path = lambda: "apply-policy"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy, [], name, value)

                class Config(_Entity_):
                    """
                    Policy configuration data.
                    
                    .. attribute:: import_policy
                    
                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    
                        **type**: list of str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_import_policy
                    
                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    
                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                        **default value**: REJECT_ROUTE
                    
                    .. attribute:: export_policy
                    
                        list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    
                        **type**: list of str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_export_policy
                    
                        explicitly set a default policy if no policy definition in the export policy chain is satisfied
                    
                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                        **default value**: REJECT_ROUTE
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "apply-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                            ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                            ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                        ])
                        self.import_policy = []
                        self.default_import_policy = None
                        self.export_policy = []
                        self.default_export_policy = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                class State(_Entity_):
                    """
                    Operational state for routing policy
                    
                    .. attribute:: import_policy
                    
                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    
                        **type**: list of str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                        **config**: False
                    
                    .. attribute:: default_import_policy
                    
                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    
                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                        **config**: False
                    
                        **default value**: REJECT_ROUTE
                    
                    .. attribute:: export_policy
                    
                        list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    
                        **type**: list of str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                        **config**: False
                    
                    .. attribute:: default_export_policy
                    
                        explicitly set a default policy if no policy definition in the export policy chain is satisfied
                    
                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                        **config**: False
                    
                        **default value**: REJECT_ROUTE
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "apply-policy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                            ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                            ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                        ])
                        self.import_policy = []
                        self.default_import_policy = None
                        self.export_policy = []
                        self.default_export_policy = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.InterInstancePolicies.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)




        class TableConnections(_Entity_):
            """
            Policies dictating how RIB or FIB entries are propagated
            between tables
            
            .. attribute:: table_connection
            
                A list of connections between pairs of routing or forwarding tables, the leaking of entries between which is specified by the import policy.  A connection connecting a source table to a destination table implies that routes that match the policy specified for the connection are available for the destination protocol to advertise, or match within its policies
            
                **type**: list of    :py:class:`TableConnection<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections.TableConnection>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "table-connections"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("table-connection", ("table_connection", NetworkInstances.NetworkInstance.TableConnections.TableConnection))])
                self._leafs = OrderedDict()

                self.table_connection = YList(self)
                self._segment_path = lambda: "table-connections"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections, [], name, value)

            class TableConnection(_Entity_):
                """
                A list of connections between pairs of routing or
                forwarding tables, the leaking of entries between
                which is specified by the import policy.
                
                A connection connecting a source table to a destination
                table implies that routes that match the policy specified
                for the connection are available for the destination
                protocol to advertise, or match within its policies.
                
                .. attribute:: src_protocol  (key)
                
                    The name of the protocol associated with the table which should be utilised as the source of forwarding or routing information
                
                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: dst_protocol  (key)
                
                    The table to which routing entries should be exported
                
                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: address_family  (key)
                
                    The address family associated with the connection
                
                    **type**:  :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                
                .. attribute:: config
                
                    Configuration parameters relating to the connection between tables
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config>`
                
                .. attribute:: state
                
                    State parameters relating to the connection between tables
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.TableConnections.TableConnection.State>`
                
                    **config**: False
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "table-connection"
                    self.yang_parent_name = "table-connections"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['src_protocol','dst_protocol','address_family']
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config)), ("state", ("state", NetworkInstances.NetworkInstance.TableConnections.TableConnection.State))])
                    self._leafs = OrderedDict([
                        ('src_protocol', (YLeaf(YType.identityref, 'src-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                        ('dst_protocol', (YLeaf(YType.identityref, 'dst-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                        ('address_family', (YLeaf(YType.identityref, 'address-family'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                    ])
                    self.src_protocol = None
                    self.dst_protocol = None
                    self.address_family = None

                    self.config = NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.TableConnections.TableConnection.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._segment_path = lambda: "table-connection" + "[src-protocol='" + str(self.src_protocol) + "']" + "[dst-protocol='" + str(self.dst_protocol) + "']" + "[address-family='" + str(self.address_family) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections.TableConnection, ['src_protocol', 'dst_protocol', 'address_family'], name, value)

                class Config(_Entity_):
                    """
                    Configuration parameters relating to the connection
                    between tables
                    
                    .. attribute:: src_protocol
                    
                        The source protocol for the table connection
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: address_family
                    
                        The address family associated with the connection. This must be defined for the source protocol. The target address family is implicitly defined by the address family specified for the source protocol
                    
                        **type**:  :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    .. attribute:: dst_protocol
                    
                        The destination protocol for the table connection
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: import_policy
                    
                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    
                        **type**: list of str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                    .. attribute:: default_import_policy
                    
                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    
                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                        **default value**: REJECT_ROUTE
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "table-connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('src_protocol', (YLeaf(YType.identityref, 'src-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('address_family', (YLeaf(YType.identityref, 'address-family'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                            ('dst_protocol', (YLeaf(YType.identityref, 'dst-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                        ])
                        self.src_protocol = None
                        self.address_family = None
                        self.dst_protocol = None
                        self.import_policy = []
                        self.default_import_policy = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections.TableConnection.Config, ['src_protocol', 'address_family', 'dst_protocol', 'import_policy', 'default_import_policy'], name, value)


                class State(_Entity_):
                    """
                    State parameters relating to the connection between
                    tables
                    
                    .. attribute:: src_protocol
                    
                        The source protocol for the table connection
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                        **config**: False
                    
                    .. attribute:: address_family
                    
                        The address family associated with the connection. This must be defined for the source protocol. The target address family is implicitly defined by the address family specified for the source protocol
                    
                        **type**:  :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                        **config**: False
                    
                    .. attribute:: dst_protocol
                    
                        The destination protocol for the table connection
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                        **config**: False
                    
                    .. attribute:: import_policy
                    
                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                    
                        **type**: list of str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                    
                        **config**: False
                    
                    .. attribute:: default_import_policy
                    
                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                    
                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                    
                        **config**: False
                    
                        **default value**: REJECT_ROUTE
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "table-connection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('src_protocol', (YLeaf(YType.identityref, 'src-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('address_family', (YLeaf(YType.identityref, 'address-family'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                            ('dst_protocol', (YLeaf(YType.identityref, 'dst-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                        ])
                        self.src_protocol = None
                        self.address_family = None
                        self.dst_protocol = None
                        self.import_policy = []
                        self.default_import_policy = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.TableConnections.TableConnection.State, ['src_protocol', 'address_family', 'dst_protocol', 'import_policy', 'default_import_policy'], name, value)




        class Interfaces(_Entity_):
            """
            The interfaces that are associated with this network
            instance
            
            .. attribute:: interface
            
                An interface associated with the network instance
            
                **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "interfaces"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Interfaces.Interface))])
                self._leafs = OrderedDict()

                self.interface = YList(self)
                self._segment_path = lambda: "interfaces"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces, [], name, value)

            class Interface(_Entity_):
                """
                An interface associated with the network instance
                
                .. attribute:: id  (key)
                
                    A reference to an identifier for this interface which acts as a key for this list
                
                    **type**: str
                
                    **refers to**:  :py:class:`id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface.Config>`
                
                .. attribute:: config
                
                    Configuration parameters relating to the associated interface
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface.Config>`
                
                .. attribute:: state
                
                    Operational state parameters relating to the associated interface
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Interfaces.Interface.State>`
                
                    **config**: False
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "interface"
                    self.yang_parent_name = "interfaces"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['id']
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Interfaces.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Interfaces.Interface.State))])
                    self._leafs = OrderedDict([
                        ('id', (YLeaf(YType.str, 'id'), ['str'])),
                    ])
                    self.id = None

                    self.config = NetworkInstances.NetworkInstance.Interfaces.Interface.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.Interfaces.Interface.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._segment_path = lambda: "interface" + "[id='" + str(self.id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces.Interface, ['id'], name, value)

                class Config(_Entity_):
                    """
                    Configuration parameters relating to the associated
                    interface
                    
                    .. attribute:: id
                    
                        A unique identifier for this interface \- this is expressed as a free\-text string
                    
                        **type**: str
                    
                    .. attribute:: interface
                    
                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                    
                    .. attribute:: subinterface
                    
                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                    
                        **type**: int
                    
                            **range:** 0..4294967295
                    
                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                    
                    .. attribute:: associated_address_families
                    
                        The address families on the subinterface which are to be associated with this network instance. When this leaf\-list is empty and the network instance requires Layer 3 information the address families for which the network instance is enabled should be imported. If the value of this leaf\-list is specified then the association MUST only be made for those address families that are included in the list
                    
                        **type**: list of   :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                            ('associated_address_families', (YLeafList(YType.identityref, 'associated-address-families'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                        ])
                        self.id = None
                        self.interface = None
                        self.subinterface = None
                        self.associated_address_families = []
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces.Interface.Config, ['id', 'interface', 'subinterface', 'associated_address_families'], name, value)


                class State(_Entity_):
                    """
                    Operational state parameters relating to the
                    associated interface
                    
                    .. attribute:: id
                    
                        A unique identifier for this interface \- this is expressed as a free\-text string
                    
                        **type**: str
                    
                        **config**: False
                    
                    .. attribute:: interface
                    
                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                    
                        **config**: False
                    
                    .. attribute:: subinterface
                    
                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                    
                        **type**: int
                    
                            **range:** 0..4294967295
                    
                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                    
                        **config**: False
                    
                    .. attribute:: associated_address_families
                    
                        The address families on the subinterface which are to be associated with this network instance. When this leaf\-list is empty and the network instance requires Layer 3 information the address families for which the network instance is enabled should be imported. If the value of this leaf\-list is specified then the association MUST only be made for those address families that are included in the list
                    
                        **type**: list of   :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('id', (YLeaf(YType.str, 'id'), ['str'])),
                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                            ('associated_address_families', (YLeafList(YType.identityref, 'associated-address-families'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                        ])
                        self.id = None
                        self.interface = None
                        self.subinterface = None
                        self.associated_address_families = []
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Interfaces.Interface.State, ['id', 'interface', 'subinterface', 'associated_address_families'], name, value)




        class Tables(_Entity_):
            """
            The routing tables that are managed by this network
            instance
            
            .. attribute:: table
            
                A network instance manages one or more forwarding or routing tables. These may reflect a Layer 2 forwarding information base, a Layer 3 routing table, or an MPLS LFIB.  The table populated by a protocol within an instance is identified by the protocol identifier (e.g., BGP, IS\-IS) and the address family (e.g., IPv4, IPv6) supported by that protocol. Multiple instances of the same protocol populate a single table \-\- such that a single IS\-IS or OSPF IPv4 table exists per network instance.  An implementation is expected to create entries within this list when the relevant protocol context is enabled. i.e., when a BGP instance is created with IPv4 and IPv6 address families enabled, the protocol=BGP, address\-family=IPv4 table is created by the system
            
                **type**: list of    :py:class:`Table<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables.Table>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "tables"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("table", ("table", NetworkInstances.NetworkInstance.Tables.Table))])
                self._leafs = OrderedDict()

                self.table = YList(self)
                self._segment_path = lambda: "tables"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Tables, [], name, value)

            class Table(_Entity_):
                """
                A network instance manages one or more forwarding or
                routing tables. These may reflect a Layer 2 forwarding
                information base, a Layer 3 routing table, or an MPLS
                LFIB.
                
                The table populated by a protocol within an instance is
                identified by the protocol identifier (e.g., BGP, IS\-IS)
                and the address family (e.g., IPv4, IPv6) supported by
                that protocol. Multiple instances of the same protocol
                populate a single table \-\- such that
                a single IS\-IS or OSPF IPv4 table exists per network
                instance.
                
                An implementation is expected to create entries within
                this list when the relevant protocol context is enabled.
                i.e., when a BGP instance is created with IPv4 and IPv6
                address families enabled, the protocol=BGP,
                address\-family=IPv4 table is created by the system.
                
                .. attribute:: protocol  (key)
                
                    A reference to the protocol that populates the table
                
                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: address_family  (key)
                
                    A reference to the address\-family that the table represents
                
                    **type**:  :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                
                .. attribute:: config
                
                    Configuration parameters relating to the table
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables.Table.Config>`
                
                .. attribute:: state
                
                    State parameters related to the table
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Tables.Table.State>`
                
                    **config**: False
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "table"
                    self.yang_parent_name = "tables"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['protocol','address_family']
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Tables.Table.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Tables.Table.State))])
                    self._leafs = OrderedDict([
                        ('protocol', (YLeaf(YType.identityref, 'protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                        ('address_family', (YLeaf(YType.identityref, 'address-family'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                    ])
                    self.protocol = None
                    self.address_family = None

                    self.config = NetworkInstances.NetworkInstance.Tables.Table.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.Tables.Table.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"
                    self._segment_path = lambda: "table" + "[protocol='" + str(self.protocol) + "']" + "[address-family='" + str(self.address_family) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Tables.Table, ['protocol', 'address_family'], name, value)

                class Config(_Entity_):
                    """
                    Configuration parameters relating to the
                    table
                    
                    .. attribute:: protocol
                    
                        Reference to the protocol that the table is associated with
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: address_family
                    
                        The address family (IPv4, IPv6) of the table's entries
                    
                        **type**:  :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.identityref, 'protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('address_family', (YLeaf(YType.identityref, 'address-family'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                        ])
                        self.protocol = None
                        self.address_family = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Tables.Table.Config, ['protocol', 'address_family'], name, value)


                class State(_Entity_):
                    """
                    State parameters related to the table
                    
                    .. attribute:: protocol
                    
                        Reference to the protocol that the table is associated with
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                        **config**: False
                    
                    .. attribute:: address_family
                    
                        The address family (IPv4, IPv6) of the table's entries
                    
                        **type**:  :py:class:`ADDRESSFAMILY<ydk.models.openconfig.openconfig_types.ADDRESSFAMILY>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('protocol', (YLeaf(YType.identityref, 'protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('address_family', (YLeaf(YType.identityref, 'address-family'), [('ydk.models.openconfig.openconfig_types', 'ADDRESSFAMILY')])),
                        ])
                        self.protocol = None
                        self.address_family = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Tables.Table.State, ['protocol', 'address_family'], name, value)




        class ConnectionPoints(_Entity_):
            """
            The set of connection points within a forwarding
            instance
            
            .. attribute:: connection_point
            
                A connection point within a Layer 2 network instance. Each connection\-point consists of a set of interfaces only one of which is active at any one time. Other than the specification of whether an interface is local (i.e., exists within this network\-instance), or remote, all configuration and state parameters are common
            
                **type**: list of    :py:class:`ConnectionPoint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "connection-points"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("connection-point", ("connection_point", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint))])
                self._leafs = OrderedDict()

                self.connection_point = YList(self)
                self._segment_path = lambda: "connection-points"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints, [], name, value)

            class ConnectionPoint(_Entity_):
                """
                A connection point within a Layer 2 network instance.
                Each connection\-point consists of a set of interfaces
                only one of which is active at any one time. Other than
                the specification of whether an interface is local
                (i.e., exists within this network\-instance), or remote,
                all configuration and state parameters are common
                
                .. attribute:: connection_point_id  (key)
                
                    A locally significant reference for the connection\-point
                
                    **type**: str
                
                    **refers to**:  :py:class:`connection_point_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config>`
                
                .. attribute:: config
                
                    Configuration parameters relating to a Layer 2 network instance connection point
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config>`
                
                .. attribute:: state
                
                    Operational state parameters relating to a Layer 2 network instance connection point
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State>`
                
                    **config**: False
                
                .. attribute:: endpoints
                
                    The set of endpoints which are grouped within the connection point
                
                    **type**:  :py:class:`Endpoints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "connection-point"
                    self.yang_parent_name = "connection-points"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['connection_point_id']
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State)), ("endpoints", ("endpoints", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints))])
                    self._leafs = OrderedDict([
                        ('connection_point_id', (YLeaf(YType.str, 'connection-point-id'), ['str'])),
                    ])
                    self.connection_point_id = None

                    self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"

                    self.endpoints = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints()
                    self.endpoints.parent = self
                    self._children_name_map["endpoints"] = "endpoints"
                    self._segment_path = lambda: "connection-point" + "[connection-point-id='" + str(self.connection_point_id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint, ['connection_point_id'], name, value)

                class Config(_Entity_):
                    """
                    Configuration parameters relating to a Layer 2
                    network instance connection point
                    
                    .. attribute:: connection_point_id
                    
                        An identifier for a connection point
                    
                        **type**: str
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "connection-point"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('connection_point_id', (YLeaf(YType.str, 'connection-point-id'), ['str'])),
                        ])
                        self.connection_point_id = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Config, ['connection_point_id'], name, value)


                class State(_Entity_):
                    """
                    Operational state parameters relating to a Layer 2
                    network instance connection point
                    
                    .. attribute:: connection_point_id
                    
                        An identifier for a connection point
                    
                        **type**: str
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "connection-point"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('connection_point_id', (YLeaf(YType.str, 'connection-point-id'), ['str'])),
                        ])
                        self.connection_point_id = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.State, ['connection_point_id'], name, value)


                class Endpoints(_Entity_):
                    """
                    The set of endpoints which are grouped within the
                    connection point
                    
                    .. attribute:: endpoint
                    
                        A list of the endpoints (interfaces or remote connection points that can be used for this connection point). The active endpoint is selected based on the precedence that it is configured with
                    
                        **type**: list of    :py:class:`Endpoint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "endpoints"
                        self.yang_parent_name = "connection-point"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("endpoint", ("endpoint", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint))])
                        self._leafs = OrderedDict()

                        self.endpoint = YList(self)
                        self._segment_path = lambda: "endpoints"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints, [], name, value)

                    class Endpoint(_Entity_):
                        """
                        A list of the endpoints (interfaces or remote
                        connection points that can be used for this
                        connection point). The active endpoint is selected
                        based on the precedence that it is configured
                        with
                        
                        .. attribute:: endpoint_id  (key)
                        
                            A pointer to the configured identifier for the endpoint
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`endpoint_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config>`
                        
                        .. attribute:: config
                        
                            Configuration parameters relating to the endpoint
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config>`
                        
                        .. attribute:: state
                        
                            Operational state parameters relating to the endpoint
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State>`
                        
                            **config**: False
                        
                        .. attribute:: local
                        
                            Configuration and operational state parameters relating to a local interface
                        
                            **type**:  :py:class:`Local<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local>`
                        
                        .. attribute:: remote
                        
                            Configuration and operational state parameters relating to a remote interface
                        
                            **type**:  :py:class:`Remote<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "endpoint"
                            self.yang_parent_name = "endpoints"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['endpoint_id']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State)), ("local", ("local", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local)), ("remote", ("remote", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote))])
                            self._leafs = OrderedDict([
                                ('endpoint_id', (YLeaf(YType.str, 'endpoint-id'), ['str'])),
                            ])
                            self.endpoint_id = None

                            self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.local = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local()
                            self.local.parent = self
                            self._children_name_map["local"] = "local"

                            self.remote = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote()
                            self.remote.parent = self
                            self._children_name_map["remote"] = "remote"
                            self._segment_path = lambda: "endpoint" + "[endpoint-id='" + str(self.endpoint_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint, ['endpoint_id'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters relating to the
                            endpoint
                            
                            .. attribute:: endpoint_id
                            
                                An identifier for the endpoint
                            
                                **type**: str
                            
                            .. attribute:: precedence
                            
                                The precedence of the endpoint \- the lowest precendence viable endpoint will be utilised as the active endpoint within a connection
                            
                                **type**: int
                            
                                    **range:** 0..65535
                            
                            .. attribute:: type
                            
                                The type of endpoint that is referred to by the current endpoint
                            
                                **type**:  :py:class:`ENDPOINTTYPE<ydk.models.openconfig.openconfig_network_instance_types.ENDPOINTTYPE>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('endpoint_id', (YLeaf(YType.str, 'endpoint-id'), ['str'])),
                                    ('precedence', (YLeaf(YType.uint16, 'precedence'), ['int'])),
                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_network_instance_types', 'ENDPOINTTYPE')])),
                                ])
                                self.endpoint_id = None
                                self.precedence = None
                                self.type = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Config, ['endpoint_id', 'precedence', 'type'], name, value)


                        class State(_Entity_):
                            """
                            Operational state parameters relating to the
                            endpoint
                            
                            .. attribute:: endpoint_id
                            
                                An identifier for the endpoint
                            
                                **type**: str
                            
                                **config**: False
                            
                            .. attribute:: precedence
                            
                                The precedence of the endpoint \- the lowest precendence viable endpoint will be utilised as the active endpoint within a connection
                            
                                **type**: int
                            
                                    **range:** 0..65535
                            
                                **config**: False
                            
                            .. attribute:: type
                            
                                The type of endpoint that is referred to by the current endpoint
                            
                                **type**:  :py:class:`ENDPOINTTYPE<ydk.models.openconfig.openconfig_network_instance_types.ENDPOINTTYPE>`
                            
                                **config**: False
                            
                            .. attribute:: active
                            
                                When the backup endpoint is active, the value of this parameter is set to true
                            
                                **type**: bool
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('endpoint_id', (YLeaf(YType.str, 'endpoint-id'), ['str'])),
                                    ('precedence', (YLeaf(YType.uint16, 'precedence'), ['int'])),
                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_network_instance_types', 'ENDPOINTTYPE')])),
                                    ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                ])
                                self.endpoint_id = None
                                self.precedence = None
                                self.type = None
                                self.active = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.State, ['endpoint_id', 'precedence', 'type', 'active'], name, value)


                        class Local(_Entity_):
                            """
                            Configuration and operational state parameters
                            relating to a local interface
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to a local endpoint
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to a local endpoint
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "local"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "local"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to a local
                                endpoint
                                
                                .. attribute:: interface
                                
                                    Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                .. attribute:: subinterface
                                
                                    Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "local"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.Config, ['interface', 'subinterface'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to a
                                local endpoint
                                
                                .. attribute:: interface
                                
                                    Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                    **config**: False
                                
                                .. attribute:: subinterface
                                
                                    Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "local"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Local.State, ['interface', 'subinterface'], name, value)



                        class Remote(_Entity_):
                            """
                            Configuration and operational state parameters
                            relating to a remote interface
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to a remote endpoint
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to a remote endpoint
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "remote"
                                self.yang_parent_name = "endpoint"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config)), ("state", ("state", NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "remote"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to a remote
                                endpoint
                                
                                .. attribute:: remote_system
                                
                                    The IP address of the device which hosts the remote end\-point
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                        **type**: str
                                
                                            **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: virtual_circuit_identifier
                                
                                    The virtual\-circuit identifier that identifies the connection at the remote end\-point
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('remote_system', (YLeaf(YType.str, 'remote-system'), ['str','str'])),
                                        ('virtual_circuit_identifier', (YLeaf(YType.uint32, 'virtual-circuit-identifier'), ['int'])),
                                    ])
                                    self.remote_system = None
                                    self.virtual_circuit_identifier = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.Config, ['remote_system', 'virtual_circuit_identifier'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to
                                a remote endpoint
                                
                                .. attribute:: remote_system
                                
                                    The IP address of the device which hosts the remote end\-point
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                        **type**: str
                                
                                            **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                    **config**: False
                                
                                .. attribute:: virtual_circuit_identifier
                                
                                    The virtual\-circuit identifier that identifies the connection at the remote end\-point
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "remote"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('remote_system', (YLeaf(YType.str, 'remote-system'), ['str','str'])),
                                        ('virtual_circuit_identifier', (YLeaf(YType.uint32, 'virtual-circuit-identifier'), ['int'])),
                                    ])
                                    self.remote_system = None
                                    self.virtual_circuit_identifier = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.ConnectionPoints.ConnectionPoint.Endpoints.Endpoint.Remote.State, ['remote_system', 'virtual_circuit_identifier'], name, value)







        class Mpls(_Entity_):
            """
            Anchor point for mpls configuration and operational
            data
            
            .. attribute:: global_
            
                general mpls configuration applicable to any type of LSP and signaling protocol \- label ranges, entropy label supportmay be added here
            
                **type**:  :py:class:`Global<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global>`
            
            .. attribute:: te_global_attributes
            
                traffic\-engineering global attributes
            
                **type**:  :py:class:`TeGlobalAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes>`
            
            .. attribute:: te_interface_attributes
            
                traffic engineering attributes specific for interfaces
            
                **type**:  :py:class:`TeInterfaceAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes>`
            
            .. attribute:: signaling_protocols
            
                top\-level signaling protocol configuration
            
                **type**:  :py:class:`SignalingProtocols<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols>`
            
            .. attribute:: lsps
            
                LSP definitions and configuration
            
                **type**:  :py:class:`Lsps<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "mpls"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("global", ("global_", NetworkInstances.NetworkInstance.Mpls.Global)), ("te-global-attributes", ("te_global_attributes", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes)), ("te-interface-attributes", ("te_interface_attributes", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes)), ("signaling-protocols", ("signaling_protocols", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols)), ("lsps", ("lsps", NetworkInstances.NetworkInstance.Mpls.Lsps))])
                self._leafs = OrderedDict()

                self.global_ = NetworkInstances.NetworkInstance.Mpls.Global()
                self.global_.parent = self
                self._children_name_map["global_"] = "global"

                self.te_global_attributes = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes()
                self.te_global_attributes.parent = self
                self._children_name_map["te_global_attributes"] = "te-global-attributes"

                self.te_interface_attributes = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes()
                self.te_interface_attributes.parent = self
                self._children_name_map["te_interface_attributes"] = "te-interface-attributes"

                self.signaling_protocols = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols()
                self.signaling_protocols.parent = self
                self._children_name_map["signaling_protocols"] = "signaling-protocols"

                self.lsps = NetworkInstances.NetworkInstance.Mpls.Lsps()
                self.lsps.parent = self
                self._children_name_map["lsps"] = "lsps"
                self._segment_path = lambda: "mpls"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls, [], name, value)

            class Global(_Entity_):
                """
                general mpls configuration applicable to any
                type of LSP and signaling protocol \- label ranges,
                entropy label supportmay be added here
                
                .. attribute:: config
                
                    Top level global MPLS configuration
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.Config>`
                
                .. attribute:: state
                
                    Top level global MPLS state
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.State>`
                
                    **config**: False
                
                .. attribute:: interface_attributes
                
                    Parameters related to MPLS interfaces
                
                    **type**:  :py:class:`InterfaceAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes>`
                
                .. attribute:: reserved_label_blocks
                
                    A range of labels starting with the start\-label and up\-to and including the end label that should be allocated as reserved. These labels should not be utilised by any dynamic label allocation on the local system unless the allocating protocol is explicitly configured to specify that allocation of labels should be out of the label block specified
                
                    **type**:  :py:class:`ReservedLabelBlocks<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "global"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Global.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Global.State)), ("interface-attributes", ("interface_attributes", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes)), ("reserved-label-blocks", ("reserved_label_blocks", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks))])
                    self._leafs = OrderedDict()

                    self.config = NetworkInstances.NetworkInstance.Mpls.Global.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.Mpls.Global.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"

                    self.interface_attributes = NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes()
                    self.interface_attributes.parent = self
                    self._children_name_map["interface_attributes"] = "interface-attributes"

                    self.reserved_label_blocks = NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks()
                    self.reserved_label_blocks.parent = self
                    self._children_name_map["reserved_label_blocks"] = "reserved-label-blocks"
                    self._segment_path = lambda: "global"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global, [], name, value)

                class Config(_Entity_):
                    """
                    Top level global MPLS configuration
                    
                    .. attribute:: null_label
                    
                        The null\-label type used, implicit or explicit
                    
                        **type**:  :py:class:`NULLLABELTYPE<ydk.models.openconfig.openconfig_mpls_types.NULLLABELTYPE>`
                    
                        **default value**: oc-mplst:IMPLICIT
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('null_label', (YLeaf(YType.identityref, 'null-label'), [('ydk.models.openconfig.openconfig_mpls_types', 'NULLLABELTYPE')])),
                        ])
                        self.null_label = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.Config, ['null_label'], name, value)


                class State(_Entity_):
                    """
                    Top level global MPLS state
                    
                    .. attribute:: null_label
                    
                        The null\-label type used, implicit or explicit
                    
                        **type**:  :py:class:`NULLLABELTYPE<ydk.models.openconfig.openconfig_mpls_types.NULLLABELTYPE>`
                    
                        **config**: False
                    
                        **default value**: oc-mplst:IMPLICIT
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('null_label', (YLeaf(YType.identityref, 'null-label'), [('ydk.models.openconfig.openconfig_mpls_types', 'NULLLABELTYPE')])),
                        ])
                        self.null_label = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.State, ['null_label'], name, value)


                class InterfaceAttributes(_Entity_):
                    """
                    Parameters related to MPLS interfaces
                    
                    .. attribute:: interface
                    
                        List of TE interfaces
                    
                        **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "interface-attributes"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface))])
                        self._leafs = OrderedDict()

                        self.interface = YList(self)
                        self._segment_path = lambda: "interface-attributes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes, [], name, value)

                    class Interface(_Entity_):
                        """
                        List of TE interfaces
                        
                        .. attribute:: interface_id  (key)
                        
                            Reference to the interface id list key
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`interface_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.Config>`
                        
                        .. attribute:: config
                        
                            Configuration parameters related to MPLS interfaces\:
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.Config>`
                        
                        .. attribute:: state
                        
                            State parameters related to TE interfaces
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.State>`
                        
                            **config**: False
                        
                        .. attribute:: interface_ref
                        
                            Reference to an interface or subinterface
                        
                            **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "interface-attributes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_id']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef))])
                            self._leafs = OrderedDict([
                                ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                            ])
                            self.interface_id = None

                            self.config = NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.interface_ref = NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef()
                            self.interface_ref.parent = self
                            self._children_name_map["interface_ref"] = "interface-ref"
                            self._segment_path = lambda: "interface" + "[interface-id='" + str(self.interface_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface, ['interface_id'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters related to MPLS interfaces\:
                            
                            .. attribute:: interface_id
                            
                                Indentifier for the MPLS interface
                            
                                **type**: str
                            
                            .. attribute:: mpls_enabled
                            
                                Enable MPLS forwarding on this interface
                            
                                **type**: bool
                            
                                **default value**: false
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                    ('mpls_enabled', (YLeaf(YType.boolean, 'mpls-enabled'), ['bool'])),
                                ])
                                self.interface_id = None
                                self.mpls_enabled = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.Config, ['interface_id', 'mpls_enabled'], name, value)


                        class State(_Entity_):
                            """
                            State parameters related to TE interfaces
                            
                            .. attribute:: interface_id
                            
                                Indentifier for the MPLS interface
                            
                                **type**: str
                            
                                **config**: False
                            
                            .. attribute:: mpls_enabled
                            
                                Enable MPLS forwarding on this interface
                            
                                **type**: bool
                            
                                **config**: False
                            
                                **default value**: false
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                    ('mpls_enabled', (YLeaf(YType.boolean, 'mpls-enabled'), ['bool'])),
                                ])
                                self.interface_id = None
                                self.mpls_enabled = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.State, ['interface_id', 'mpls_enabled'], name, value)


                        class InterfaceRef(_Entity_):
                            """
                            Reference to an interface or subinterface
                            
                            .. attribute:: config
                            
                                Configured reference to interface / subinterface
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.Config>`
                            
                            .. attribute:: state
                            
                                Operational state for interface\-ref
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "interface-ref"
                                self.yang_parent_name = "interface"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "interface-ref"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef, [], name, value)

                            class Config(_Entity_):
                                """
                                Configured reference to interface / subinterface
                                
                                .. attribute:: interface
                                
                                    Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                .. attribute:: subinterface
                                
                                    Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "interface-ref"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                            class State(_Entity_):
                                """
                                Operational state for interface\-ref
                                
                                .. attribute:: interface
                                
                                    Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                    **config**: False
                                
                                .. attribute:: subinterface
                                
                                    Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface-ref"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.InterfaceAttributes.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)





                class ReservedLabelBlocks(_Entity_):
                    """
                    A range of labels starting with the start\-label and up\-to and including
                    the end label that should be allocated as reserved. These labels should
                    not be utilised by any dynamic label allocation on the local system unless
                    the allocating protocol is explicitly configured to specify that
                    allocation of labels should be out of the label block specified.
                    
                    .. attribute:: reserved_label_block
                    
                        A range of labels starting with the start\-label up to and including the end label that should be allocated for use by a specific protocol
                    
                        **type**: list of    :py:class:`ReservedLabelBlock<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "reserved-label-blocks"
                        self.yang_parent_name = "global"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("reserved-label-block", ("reserved_label_block", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock))])
                        self._leafs = OrderedDict()

                        self.reserved_label_block = YList(self)
                        self._segment_path = lambda: "reserved-label-blocks"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks, [], name, value)

                    class ReservedLabelBlock(_Entity_):
                        """
                        A range of labels starting with the start\-label up to and including
                        the end label that should be allocated for use by a specific protocol.
                        
                        .. attribute:: local_id  (key)
                        
                            A reference to a unique local identifier for this label block
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: config
                        
                            Configuration parameters relating to the label block
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: state
                        
                            State parameters relating to the label block
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "reserved-label-block"
                            self.yang_parent_name = "reserved-label-blocks"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['local_id']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.State))])
                            self._leafs = OrderedDict([
                                ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                            ])
                            self.local_id = None

                            self.config = NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "reserved-label-block" + "[local-id='" + str(self.local_id) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock, ['local_id'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters relating to the label block.
                            
                            .. attribute:: local_id
                            
                                A local identifier for the global label block allocation
                            
                                **type**: str
                            
                            .. attribute:: lower_bound
                            
                                Lower bound of the global label block. The block is defined to include this label
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 16..1048575
                            
                                    **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                            
                            .. attribute:: upper_bound
                            
                                Upper bound for the global label block. The block is defined to include this label
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 16..1048575
                            
                                    **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "reserved-label-block"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                    ('lower_bound', (YLeaf(YType.str, 'lower-bound'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ('upper_bound', (YLeaf(YType.str, 'upper-bound'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                ])
                                self.local_id = None
                                self.lower_bound = None
                                self.upper_bound = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config, ['local_id', 'lower_bound', 'upper_bound'], name, value)


                        class State(_Entity_):
                            """
                            State parameters relating to the label block.
                            
                            .. attribute:: local_id
                            
                                A local identifier for the global label block allocation
                            
                                **type**: str
                            
                                **config**: False
                            
                            .. attribute:: lower_bound
                            
                                Lower bound of the global label block. The block is defined to include this label
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 16..1048575
                            
                                    **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                            
                                **config**: False
                            
                            .. attribute:: upper_bound
                            
                                Upper bound for the global label block. The block is defined to include this label
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 16..1048575
                            
                                    **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "reserved-label-block"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                    ('lower_bound', (YLeaf(YType.str, 'lower-bound'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ('upper_bound', (YLeaf(YType.str, 'upper-bound'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                ])
                                self.local_id = None
                                self.lower_bound = None
                                self.upper_bound = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.State, ['local_id', 'lower_bound', 'upper_bound'], name, value)





            class TeGlobalAttributes(_Entity_):
                """
                traffic\-engineering global attributes
                
                .. attribute:: srlgs
                
                    Shared risk link groups attributes
                
                    **type**:  :py:class:`Srlgs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs>`
                
                .. attribute:: mpls_admin_groups
                
                    Top\-level container for admin\-groups configuration and state
                
                    **type**:  :py:class:`MplsAdminGroups<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups>`
                
                .. attribute:: te_lsp_timers
                
                    Definition for delays associated with setup and cleanup of TE LSPs
                
                    **type**:  :py:class:`TeLspTimers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers>`
                
                .. attribute:: bandwidth_measurement
                
                    Configuration and operational state parameters related to how bandwidth utilisation is measured and flooded into the IGP
                
                    **type**:  :py:class:`BandwidthMeasurement<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "te-global-attributes"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("srlgs", ("srlgs", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs)), ("mpls-admin-groups", ("mpls_admin_groups", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups)), ("te-lsp-timers", ("te_lsp_timers", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers)), ("openconfig-rsvp-sr-ext:bandwidth-measurement", ("bandwidth_measurement", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement))])
                    self._leafs = OrderedDict()

                    self.srlgs = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs()
                    self.srlgs.parent = self
                    self._children_name_map["srlgs"] = "srlgs"

                    self.mpls_admin_groups = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups()
                    self.mpls_admin_groups.parent = self
                    self._children_name_map["mpls_admin_groups"] = "mpls-admin-groups"

                    self.te_lsp_timers = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers()
                    self.te_lsp_timers.parent = self
                    self._children_name_map["te_lsp_timers"] = "te-lsp-timers"

                    self.bandwidth_measurement = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement()
                    self.bandwidth_measurement.parent = self
                    self._children_name_map["bandwidth_measurement"] = "openconfig-rsvp-sr-ext:bandwidth-measurement"
                    self._segment_path = lambda: "te-global-attributes"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes, [], name, value)

                class Srlgs(_Entity_):
                    """
                    Shared risk link groups attributes
                    
                    .. attribute:: srlg
                    
                        List of shared risk link groups
                    
                        **type**: list of    :py:class:`Srlg<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "srlgs"
                        self.yang_parent_name = "te-global-attributes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("srlg", ("srlg", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg))])
                        self._leafs = OrderedDict()

                        self.srlg = YList(self)
                        self._segment_path = lambda: "srlgs"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs, [], name, value)

                    class Srlg(_Entity_):
                        """
                        List of shared risk link groups
                        
                        .. attribute:: name  (key)
                        
                            The SRLG group identifier
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.Config>`
                        
                        .. attribute:: config
                        
                            Configuration parameters related to the SRLG
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.Config>`
                        
                        .. attribute:: state
                        
                            State parameters related to the SRLG
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.State>`
                        
                            **config**: False
                        
                        .. attribute:: static_srlg_members
                        
                            SRLG members for static (not flooded) SRLGs 
                        
                            **type**:  :py:class:`StaticSrlgMembers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "srlg"
                            self.yang_parent_name = "srlgs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.State)), ("static-srlg-members", ("static_srlg_members", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.config = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.static_srlg_members = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers()
                            self.static_srlg_members.parent = self
                            self._children_name_map["static_srlg_members"] = "static-srlg-members"
                            self._segment_path = lambda: "srlg" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg, ['name'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters related to the SRLG
                            
                            .. attribute:: name
                            
                                SRLG group identifier
                            
                                **type**: str
                            
                            .. attribute:: value
                            
                                group ID for the SRLG
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                            .. attribute:: cost
                            
                                The cost of the SRLG to the computation algorithm
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                            .. attribute:: flooding_type
                            
                                The type of SRLG, either flooded in the IGP or statically configured
                            
                                **type**:  :py:class:`MplsSrlgFloodingType<ydk.models.openconfig.openconfig_mpls.MplsSrlgFloodingType>`
                            
                                **default value**: FLOODED_SRLG
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "srlg"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('flooding_type', (YLeaf(YType.enumeration, 'flooding-type'), [('ydk.models.openconfig.openconfig_mpls', 'MplsSrlgFloodingType', '')])),
                                ])
                                self.name = None
                                self.value = None
                                self.cost = None
                                self.flooding_type = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.Config, ['name', 'value', 'cost', 'flooding_type'], name, value)


                        class State(_Entity_):
                            """
                            State parameters related to the SRLG
                            
                            .. attribute:: name
                            
                                SRLG group identifier
                            
                                **type**: str
                            
                                **config**: False
                            
                            .. attribute:: value
                            
                                group ID for the SRLG
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **config**: False
                            
                            .. attribute:: cost
                            
                                The cost of the SRLG to the computation algorithm
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **config**: False
                            
                            .. attribute:: flooding_type
                            
                                The type of SRLG, either flooded in the IGP or statically configured
                            
                                **type**:  :py:class:`MplsSrlgFloodingType<ydk.models.openconfig.openconfig_mpls.MplsSrlgFloodingType>`
                            
                                **config**: False
                            
                                **default value**: FLOODED_SRLG
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "srlg"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                    ('cost', (YLeaf(YType.uint32, 'cost'), ['int'])),
                                    ('flooding_type', (YLeaf(YType.enumeration, 'flooding-type'), [('ydk.models.openconfig.openconfig_mpls', 'MplsSrlgFloodingType', '')])),
                                ])
                                self.name = None
                                self.value = None
                                self.cost = None
                                self.flooding_type = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.State, ['name', 'value', 'cost', 'flooding_type'], name, value)


                        class StaticSrlgMembers(_Entity_):
                            """
                            SRLG members for static (not flooded) SRLGs 
                            
                            .. attribute:: members_list
                            
                                List of SRLG members, which are expressed as IP address endpoints of links contained in the SRLG
                            
                                **type**: list of    :py:class:`MembersList<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "static-srlg-members"
                                self.yang_parent_name = "srlg"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("members-list", ("members_list", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList))])
                                self._leafs = OrderedDict()

                                self.members_list = YList(self)
                                self._segment_path = lambda: "static-srlg-members"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers, [], name, value)

                            class MembersList(_Entity_):
                                """
                                List of SRLG members, which are expressed
                                as IP address endpoints of links contained in the
                                SRLG
                                
                                .. attribute:: from_address  (key)
                                
                                    The from address of the link in the SRLG
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **refers to**:  :py:class:`from_address<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.Config>`
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the SRLG members
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.Config>`
                                
                                .. attribute:: state
                                
                                    State parameters relating to the SRLG members
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "members-list"
                                    self.yang_parent_name = "static-srlg-members"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['from_address']
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.State))])
                                    self._leafs = OrderedDict([
                                        ('from_address', (YLeaf(YType.str, 'from-address'), ['str'])),
                                    ])
                                    self.from_address = None

                                    self.config = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "members-list" + "[from-address='" + str(self.from_address) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList, ['from_address'], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the
                                    SRLG members
                                    
                                    .. attribute:: from_address
                                    
                                        IP address of the a\-side of the SRLG link
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                    .. attribute:: to_address
                                    
                                        IP address of the z\-side of the SRLG link
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "members-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('from_address', (YLeaf(YType.str, 'from-address'), ['str','str'])),
                                            ('to_address', (YLeaf(YType.str, 'to-address'), ['str','str'])),
                                        ])
                                        self.from_address = None
                                        self.to_address = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.Config, ['from_address', 'to_address'], name, value)


                                class State(_Entity_):
                                    """
                                    State parameters relating to the SRLG
                                    members
                                    
                                    .. attribute:: from_address
                                    
                                        IP address of the a\-side of the SRLG link
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                        **config**: False
                                    
                                    .. attribute:: to_address
                                    
                                        IP address of the z\-side of the SRLG link
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "members-list"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('from_address', (YLeaf(YType.str, 'from-address'), ['str','str'])),
                                            ('to_address', (YLeaf(YType.str, 'to-address'), ['str','str'])),
                                        ])
                                        self.from_address = None
                                        self.to_address = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg.StaticSrlgMembers.MembersList.State, ['from_address', 'to_address'], name, value)






                class MplsAdminGroups(_Entity_):
                    """
                    Top\-level container for admin\-groups configuration
                    and state
                    
                    .. attribute:: admin_group
                    
                        configuration of value to name mapping for mpls affinities/admin\-groups
                    
                        **type**: list of    :py:class:`AdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "mpls-admin-groups"
                        self.yang_parent_name = "te-global-attributes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup))])
                        self._leafs = OrderedDict()

                        self.admin_group = YList(self)
                        self._segment_path = lambda: "mpls-admin-groups"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups, [], name, value)

                    class AdminGroup(_Entity_):
                        """
                        configuration of value to name mapping
                        for mpls affinities/admin\-groups
                        
                        .. attribute:: admin_group_name  (key)
                        
                            name for mpls admin\-group
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.Config>`
                        
                        .. attribute:: config
                        
                            Configurable items for admin\-groups
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.Config>`
                        
                        .. attribute:: state
                        
                            Operational state for admin\-groups
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "admin-group"
                            self.yang_parent_name = "mpls-admin-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['admin_group_name']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.State))])
                            self._leafs = OrderedDict([
                                ('admin_group_name', (YLeaf(YType.str, 'admin-group-name'), ['str'])),
                            ])
                            self.admin_group_name = None

                            self.config = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "admin-group" + "[admin-group-name='" + str(self.admin_group_name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup, ['admin_group_name'], name, value)

                        class Config(_Entity_):
                            """
                            Configurable items for admin\-groups
                            
                            .. attribute:: admin_group_name
                            
                                name for mpls admin\-group
                            
                                **type**: str
                            
                            .. attribute:: bit_position
                            
                                bit\-position value for mpls admin\-group. The value for the admin group is an integer that represents one of the bit positions in the admin\-group bitmask. Values between 0 and 31 are interpreted as the original limit of 32 admin groups. Values >=32 are interpreted as extended admin group values as per RFC7308
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "admin-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('admin_group_name', (YLeaf(YType.str, 'admin-group-name'), ['str'])),
                                    ('bit_position', (YLeaf(YType.uint32, 'bit-position'), ['int'])),
                                ])
                                self.admin_group_name = None
                                self.bit_position = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.Config, ['admin_group_name', 'bit_position'], name, value)


                        class State(_Entity_):
                            """
                            Operational state for admin\-groups
                            
                            .. attribute:: admin_group_name
                            
                                name for mpls admin\-group
                            
                                **type**: str
                            
                                **config**: False
                            
                            .. attribute:: bit_position
                            
                                bit\-position value for mpls admin\-group. The value for the admin group is an integer that represents one of the bit positions in the admin\-group bitmask. Values between 0 and 31 are interpreted as the original limit of 32 admin groups. Values >=32 are interpreted as extended admin group values as per RFC7308
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "admin-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('admin_group_name', (YLeaf(YType.str, 'admin-group-name'), ['str'])),
                                    ('bit_position', (YLeaf(YType.uint32, 'bit-position'), ['int'])),
                                ])
                                self.admin_group_name = None
                                self.bit_position = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup.State, ['admin_group_name', 'bit_position'], name, value)




                class TeLspTimers(_Entity_):
                    """
                    Definition for delays associated with setup
                    and cleanup of TE LSPs
                    
                    .. attribute:: config
                    
                        Configuration parameters related to timers for TE LSPs
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.Config>`
                    
                    .. attribute:: state
                    
                        State related to timers for TE LSPs
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "te-lsp-timers"
                        self.yang_parent_name = "te-global-attributes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.State))])
                        self._leafs = OrderedDict()

                        self.config = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "te-lsp-timers"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters related
                        to timers for TE LSPs
                        
                        .. attribute:: install_delay
                        
                            delay the use of newly installed te lsp for a specified amount of time
                        
                            **type**: int
                        
                                **range:** 0..3600
                        
                            **units**: seconds
                        
                        .. attribute:: cleanup_delay
                        
                            delay the removal of old te lsp for a specified amount of time
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **units**: seconds
                        
                        .. attribute:: reoptimize_timer
                        
                            frequency of reoptimization of a traffic engineered LSP
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **units**: seconds
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "te-lsp-timers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('install_delay', (YLeaf(YType.uint16, 'install-delay'), ['int'])),
                                ('cleanup_delay', (YLeaf(YType.uint16, 'cleanup-delay'), ['int'])),
                                ('reoptimize_timer', (YLeaf(YType.uint16, 'reoptimize-timer'), ['int'])),
                            ])
                            self.install_delay = None
                            self.cleanup_delay = None
                            self.reoptimize_timer = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.Config, ['install_delay', 'cleanup_delay', 'reoptimize_timer'], name, value)


                    class State(_Entity_):
                        """
                        State related to timers for TE LSPs
                        
                        .. attribute:: install_delay
                        
                            delay the use of newly installed te lsp for a specified amount of time
                        
                            **type**: int
                        
                                **range:** 0..3600
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        .. attribute:: cleanup_delay
                        
                            delay the removal of old te lsp for a specified amount of time
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        .. attribute:: reoptimize_timer
                        
                            frequency of reoptimization of a traffic engineered LSP
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "te-lsp-timers"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('install_delay', (YLeaf(YType.uint16, 'install-delay'), ['int'])),
                                ('cleanup_delay', (YLeaf(YType.uint16, 'cleanup-delay'), ['int'])),
                                ('reoptimize_timer', (YLeaf(YType.uint16, 'reoptimize-timer'), ['int'])),
                            ])
                            self.install_delay = None
                            self.cleanup_delay = None
                            self.reoptimize_timer = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.TeLspTimers.State, ['install_delay', 'cleanup_delay', 'reoptimize_timer'], name, value)



                class BandwidthMeasurement(_Entity_):
                    """
                    Configuration and operational state parameters related to
                    how bandwidth utilisation is measured and flooded into the
                    IGP.
                    
                    .. attribute:: config
                    
                        Configuration parameters relating to bandwidth measurement
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parameters relating to bandwidth measurement
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.State>`
                    
                        **config**: False
                    
                    .. attribute:: update_trigger
                    
                        Configuration and operational state parameters related to the update trigger for flooding new bandwidth information into the IGP
                    
                        **type**:  :py:class:`UpdateTrigger<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger>`
                    
                    """
                    _prefix = 'oc-sr-rsvp-ext'
                    _revision = '2017-03-06'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "bandwidth-measurement"
                        self.yang_parent_name = "te-global-attributes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.State)), ("update-trigger", ("update_trigger", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger))])
                        self._leafs = OrderedDict()

                        self.config = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.update_trigger = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger()
                        self.update_trigger.parent = self
                        self._children_name_map["update_trigger"] = "update-trigger"
                        self._segment_path = lambda: "openconfig-rsvp-sr-ext:bandwidth-measurement"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters relating to bandwidth
                        measurement.
                        
                        .. attribute:: measure_sr_traffic
                        
                            When this leaf is set to true, the local system should measure the bandwidth utilisation of SR traffic on interfaces for which TED entries are being generated.  In the case that this functionality is enabled, traffic forwarded using LFIB entries that correspond to MPLS labels which correspond to SR SIDs should be accounted for
                        
                            **type**: bool
                        
                        .. attribute:: collection_interval
                        
                            The interval at which the collection of interface statistics relating to non\-RSVP\-TE traffic should be performed
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **units**: seconds
                        
                        .. attribute:: adjustment_interval
                        
                            The interval after which an adjustment to the utilised bandwidth on the interface is made. This value must be greater than, or equal to, the collection interval for statistics.  This value is referred to as N in draft\-sitaraman\-sr\-rsvp\-coexistence\-rec\-01.  After N seconds have expired, the arithmetic mean of the samples is taken, and this is considered as the non\-RSVP\-TE utilisation of the interface. In the case that the adjustment interval is an integer >1 multiple of the collection interval, this serves to provide smoothing of the collected bandwidth statistics
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **units**: seconds
                        
                        .. attribute:: bandwidth_multiplier
                        
                            A multiplier applied to the sampled bandwidth which determines the value that is propagated to the IGP TED. By default this value is 1.0000, and hence the actual sampled value is flooded
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-922337203685477.5808..922337203685477.5807
                        
                            **default value**: 1.0000
                        
                        """
                        _prefix = 'oc-sr-rsvp-ext'
                        _revision = '2017-03-06'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "bandwidth-measurement"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('measure_sr_traffic', (YLeaf(YType.boolean, 'measure-sr-traffic'), ['bool'])),
                                ('collection_interval', (YLeaf(YType.uint32, 'collection-interval'), ['int'])),
                                ('adjustment_interval', (YLeaf(YType.uint32, 'adjustment-interval'), ['int'])),
                                ('bandwidth_multiplier', (YLeaf(YType.str, 'bandwidth-multiplier'), ['Decimal64'])),
                            ])
                            self.measure_sr_traffic = None
                            self.collection_interval = None
                            self.adjustment_interval = None
                            self.bandwidth_multiplier = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.Config, ['measure_sr_traffic', 'collection_interval', 'adjustment_interval', 'bandwidth_multiplier'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parameters relating to bandwidth
                        measurement
                        
                        .. attribute:: measure_sr_traffic
                        
                            When this leaf is set to true, the local system should measure the bandwidth utilisation of SR traffic on interfaces for which TED entries are being generated.  In the case that this functionality is enabled, traffic forwarded using LFIB entries that correspond to MPLS labels which correspond to SR SIDs should be accounted for
                        
                            **type**: bool
                        
                            **config**: False
                        
                        .. attribute:: collection_interval
                        
                            The interval at which the collection of interface statistics relating to non\-RSVP\-TE traffic should be performed
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        .. attribute:: adjustment_interval
                        
                            The interval after which an adjustment to the utilised bandwidth on the interface is made. This value must be greater than, or equal to, the collection interval for statistics.  This value is referred to as N in draft\-sitaraman\-sr\-rsvp\-coexistence\-rec\-01.  After N seconds have expired, the arithmetic mean of the samples is taken, and this is considered as the non\-RSVP\-TE utilisation of the interface. In the case that the adjustment interval is an integer >1 multiple of the collection interval, this serves to provide smoothing of the collected bandwidth statistics
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        .. attribute:: bandwidth_multiplier
                        
                            A multiplier applied to the sampled bandwidth which determines the value that is propagated to the IGP TED. By default this value is 1.0000, and hence the actual sampled value is flooded
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-922337203685477.5808..922337203685477.5807
                        
                            **config**: False
                        
                            **default value**: 1.0000
                        
                        .. attribute:: effective_adjustment_interval
                        
                            The effective adjustment interval that is being used by the system. In the case that the adjustment\-interval leaf is set to a non\-integer multiple of the collection\-interval, and the system does not support this, the value of this leaf should reflect the effective value of the adjustment interval that it has selected. In the case where no rounding of the adjustment interval has occurred, this value should have the same value as the adjustment\-inerval leaf
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **config**: False
                        
                            **units**: seconds
                        
                        """
                        _prefix = 'oc-sr-rsvp-ext'
                        _revision = '2017-03-06'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "bandwidth-measurement"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('measure_sr_traffic', (YLeaf(YType.boolean, 'measure-sr-traffic'), ['bool'])),
                                ('collection_interval', (YLeaf(YType.uint32, 'collection-interval'), ['int'])),
                                ('adjustment_interval', (YLeaf(YType.uint32, 'adjustment-interval'), ['int'])),
                                ('bandwidth_multiplier', (YLeaf(YType.str, 'bandwidth-multiplier'), ['Decimal64'])),
                                ('effective_adjustment_interval', (YLeaf(YType.uint32, 'effective-adjustment-interval'), ['int'])),
                            ])
                            self.measure_sr_traffic = None
                            self.collection_interval = None
                            self.adjustment_interval = None
                            self.bandwidth_multiplier = None
                            self.effective_adjustment_interval = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.State, ['measure_sr_traffic', 'collection_interval', 'adjustment_interval', 'bandwidth_multiplier', 'effective_adjustment_interval'], name, value)


                    class UpdateTrigger(_Entity_):
                        """
                        Configuration and operational state parameters related
                        to the update trigger for flooding new bandwidth
                        information into the IGP.
                        
                        .. attribute:: config
                        
                            Configuration parameters related to the bandwidth measurement update trigger
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.Config>`
                        
                        .. attribute:: state
                        
                            Operational state parameters related to the bandwidth measurement update trigger
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-sr-rsvp-ext'
                        _revision = '2017-03-06'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "update-trigger"
                            self.yang_parent_name = "bandwidth-measurement"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.State))])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "update-trigger"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger, [], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters related to the bandwidth
                            measurement update trigger.
                            
                            .. attribute:: update_trigger
                            
                                The trigger that should be used to determine when the IGP TED is updated with new information as to the effective maximum reservable bandwidth (adjusted\-absolute\-subscription\-bw)
                            
                                **type**:  :py:class:`UpdateTrigger_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.Config.UpdateTrigger_>`
                            
                            .. attribute:: adjusted_max_reservable_bw_pct
                            
                                The delta in the adjusted\-max\-reservable\-bandwidth that should trigger an update in the value which is flooded through the IGP TED. The delta is measured as a percentage of the current adjusted value of the maximum reservable bandwidth of the interface, as specified by the adjusted\-absolute\-subscription\-bw RSVP\-TE leaf
                            
                                **type**: int
                            
                                    **range:** 0..100
                            
                            .. attribute:: sr_traffic_pct
                            
                                The change in the calculated SR traffic on the interface that should trigger an update in the value of the maximum reservable bandwidth flooded through the IGP TED. The value is specified as a percentage of the last\-calculated\-sr\-traffic state leaf
                            
                                **type**: int
                            
                                    **range:** 0..100
                            
                            """
                            _prefix = 'oc-sr-rsvp-ext'
                            _revision = '2017-03-06'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "update-trigger"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('update_trigger', (YLeaf(YType.enumeration, 'update-trigger'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.Config.UpdateTrigger_')])),
                                    ('adjusted_max_reservable_bw_pct', (YLeaf(YType.uint8, 'adjusted-max-reservable-bw-pct'), ['int'])),
                                    ('sr_traffic_pct', (YLeaf(YType.uint8, 'sr-traffic-pct'), ['int'])),
                                ])
                                self.update_trigger = None
                                self.adjusted_max_reservable_bw_pct = None
                                self.sr_traffic_pct = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.Config, ['update_trigger', 'adjusted_max_reservable_bw_pct', 'sr_traffic_pct'], name, value)

                            class UpdateTrigger_(Enum):
                                """
                                UpdateTrigger\_ (Enum Class)

                                .. data:: ADJUSTED_MAX_RESERVABLE_PCT = 0

                                    Update of a new maximum reservable bandwidth IGP

                                    TLV is based on the value changing >= X% of

                                    the currently flooded adjusted-absolute-subscription-bw.

                                    The percentage of this value that is used is specified

                                    by the adjusted-max-reservable-bw-pct leaf.

                                .. data:: SR_TRAFFIC_PCT = 1

                                    Update of the new maximum reservable bandwidth IGP

                                    TLV is based on the value changing >= X% of the last

                                    calculated segment routing traffic utilisation for the

                                    interface. The percentage delta of this value is

                                    specified by the sr-traffic-pct leaf.

                                """

                                ADJUSTED_MAX_RESERVABLE_PCT = Enum.YLeaf(0, "ADJUSTED_MAX_RESERVABLE_PCT")

                                SR_TRAFFIC_PCT = Enum.YLeaf(1, "SR_TRAFFIC_PCT")



                        class State(_Entity_):
                            """
                            Operational state parameters related to the bandwidth
                            measurement update trigger.
                            
                            .. attribute:: update_trigger
                            
                                The trigger that should be used to determine when the IGP TED is updated with new information as to the effective maximum reservable bandwidth (adjusted\-absolute\-subscription\-bw)
                            
                                **type**:  :py:class:`UpdateTrigger_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.State.UpdateTrigger_>`
                            
                                **config**: False
                            
                            .. attribute:: adjusted_max_reservable_bw_pct
                            
                                The delta in the adjusted\-max\-reservable\-bandwidth that should trigger an update in the value which is flooded through the IGP TED. The delta is measured as a percentage of the current adjusted value of the maximum reservable bandwidth of the interface, as specified by the adjusted\-absolute\-subscription\-bw RSVP\-TE leaf
                            
                                **type**: int
                            
                                    **range:** 0..100
                            
                                **config**: False
                            
                            .. attribute:: sr_traffic_pct
                            
                                The change in the calculated SR traffic on the interface that should trigger an update in the value of the maximum reservable bandwidth flooded through the IGP TED. The value is specified as a percentage of the last\-calculated\-sr\-traffic state leaf
                            
                                **type**: int
                            
                                    **range:** 0..100
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-sr-rsvp-ext'
                            _revision = '2017-03-06'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "update-trigger"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('update_trigger', (YLeaf(YType.enumeration, 'update-trigger'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.State.UpdateTrigger_')])),
                                    ('adjusted_max_reservable_bw_pct', (YLeaf(YType.uint8, 'adjusted-max-reservable-bw-pct'), ['int'])),
                                    ('sr_traffic_pct', (YLeaf(YType.uint8, 'sr-traffic-pct'), ['int'])),
                                ])
                                self.update_trigger = None
                                self.adjusted_max_reservable_bw_pct = None
                                self.sr_traffic_pct = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.BandwidthMeasurement.UpdateTrigger.State, ['update_trigger', 'adjusted_max_reservable_bw_pct', 'sr_traffic_pct'], name, value)

                            class UpdateTrigger_(Enum):
                                """
                                UpdateTrigger\_ (Enum Class)

                                .. data:: ADJUSTED_MAX_RESERVABLE_PCT = 0

                                    Update of a new maximum reservable bandwidth IGP

                                    TLV is based on the value changing >= X% of

                                    the currently flooded adjusted-absolute-subscription-bw.

                                    The percentage of this value that is used is specified

                                    by the adjusted-max-reservable-bw-pct leaf.

                                .. data:: SR_TRAFFIC_PCT = 1

                                    Update of the new maximum reservable bandwidth IGP

                                    TLV is based on the value changing >= X% of the last

                                    calculated segment routing traffic utilisation for the

                                    interface. The percentage delta of this value is

                                    specified by the sr-traffic-pct leaf.

                                """

                                ADJUSTED_MAX_RESERVABLE_PCT = Enum.YLeaf(0, "ADJUSTED_MAX_RESERVABLE_PCT")

                                SR_TRAFFIC_PCT = Enum.YLeaf(1, "SR_TRAFFIC_PCT")






            class TeInterfaceAttributes(_Entity_):
                """
                traffic engineering attributes specific
                for interfaces
                
                .. attribute:: interface
                
                    List of TE interfaces
                
                    **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "te-interface-attributes"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface))])
                    self._leafs = OrderedDict()

                    self.interface = YList(self)
                    self._segment_path = lambda: "te-interface-attributes"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes, [], name, value)

                class Interface(_Entity_):
                    """
                    List of TE interfaces
                    
                    .. attribute:: interface_id  (key)
                    
                        Reference to the interface id list key
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`interface_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters related to TE interfaces\:
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.Config>`
                    
                    .. attribute:: state
                    
                        State parameters related to TE interfaces
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.State>`
                    
                        **config**: False
                    
                    .. attribute:: interface_ref
                    
                        Reference to an interface or subinterface
                    
                        **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef>`
                    
                    .. attribute:: igp_flooding_bandwidth
                    
                        Interface bandwidth change percentages that trigger update events into the IGP traffic engineering database (TED)
                    
                        **type**:  :py:class:`IgpFloodingBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth>`
                    
                    .. attribute:: bandwidth_measurement
                    
                        Configuration and operational state parameters relating to per\-interface bandwidth measurement. These parameters are used in the case that RSVP\-TE coexists with other MPLS signaling protocols on an interface
                    
                        **type**:  :py:class:`BandwidthMeasurement<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "te-interface-attributes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_id']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef)), ("igp-flooding-bandwidth", ("igp_flooding_bandwidth", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth)), ("openconfig-rsvp-sr-ext:bandwidth-measurement", ("bandwidth_measurement", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement))])
                        self._leafs = OrderedDict([
                            ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                        ])
                        self.interface_id = None

                        self.config = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.interface_ref = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef()
                        self.interface_ref.parent = self
                        self._children_name_map["interface_ref"] = "interface-ref"

                        self.igp_flooding_bandwidth = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth()
                        self.igp_flooding_bandwidth.parent = self
                        self._children_name_map["igp_flooding_bandwidth"] = "igp-flooding-bandwidth"

                        self.bandwidth_measurement = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement()
                        self.bandwidth_measurement.parent = self
                        self._children_name_map["bandwidth_measurement"] = "openconfig-rsvp-sr-ext:bandwidth-measurement"
                        self._segment_path = lambda: "interface" + "[interface-id='" + str(self.interface_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface, ['interface_id'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters related to TE interfaces\:
                        
                        .. attribute:: interface_id
                        
                            Id of the interface
                        
                            **type**: str
                        
                        .. attribute:: te_metric
                        
                            TE specific metric for the link
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                        .. attribute:: srlg_membership
                        
                            list of references to named shared risk link groups that the interface belongs to
                        
                            **type**: list of str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg>`
                        
                        .. attribute:: admin_group
                        
                            list of admin groups (by name) on the interface
                        
                            **type**: list of str
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                ('te_metric', (YLeaf(YType.uint32, 'te-metric'), ['int'])),
                                ('srlg_membership', (YLeafList(YType.str, 'srlg-membership'), ['str'])),
                                ('admin_group', (YLeafList(YType.str, 'admin-group'), ['str'])),
                            ])
                            self.interface_id = None
                            self.te_metric = None
                            self.srlg_membership = []
                            self.admin_group = []
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.Config, ['interface_id', 'te_metric', 'srlg_membership', 'admin_group'], name, value)


                    class State(_Entity_):
                        """
                        State parameters related to TE interfaces
                        
                        .. attribute:: interface_id
                        
                            Id of the interface
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: te_metric
                        
                            TE specific metric for the link
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **config**: False
                        
                        .. attribute:: srlg_membership
                        
                            list of references to named shared risk link groups that the interface belongs to
                        
                            **type**: list of str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.Srlgs.Srlg>`
                        
                            **config**: False
                        
                        .. attribute:: admin_group
                        
                            list of admin groups (by name) on the interface
                        
                            **type**: list of str
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                ('te_metric', (YLeaf(YType.uint32, 'te-metric'), ['int'])),
                                ('srlg_membership', (YLeafList(YType.str, 'srlg-membership'), ['str'])),
                                ('admin_group', (YLeafList(YType.str, 'admin-group'), ['str'])),
                            ])
                            self.interface_id = None
                            self.te_metric = None
                            self.srlg_membership = []
                            self.admin_group = []
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.State, ['interface_id', 'te_metric', 'srlg_membership', 'admin_group'], name, value)


                    class InterfaceRef(_Entity_):
                        """
                        Reference to an interface or subinterface
                        
                        .. attribute:: config
                        
                            Configured reference to interface / subinterface
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.Config>`
                        
                        .. attribute:: state
                        
                            Operational state for interface\-ref
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "interface-ref"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.State))])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "interface-ref"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef, [], name, value)

                        class Config(_Entity_):
                            """
                            Configured reference to interface / subinterface
                            
                            .. attribute:: interface
                            
                                Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                            
                            .. attribute:: subinterface
                            
                                Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "interface-ref"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                ])
                                self.interface = None
                                self.subinterface = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                        class State(_Entity_):
                            """
                            Operational state for interface\-ref
                            
                            .. attribute:: interface
                            
                                Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                            
                                **config**: False
                            
                            .. attribute:: subinterface
                            
                                Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "interface-ref"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                    ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                ])
                                self.interface = None
                                self.subinterface = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)



                    class IgpFloodingBandwidth(_Entity_):
                        """
                        Interface bandwidth change percentages
                        that trigger update events into the IGP traffic
                        engineering database (TED)
                        
                        .. attribute:: config
                        
                            Configuration parameters for TED update threshold 
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config>`
                        
                        .. attribute:: state
                        
                            State parameters for TED update threshold 
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "igp-flooding-bandwidth"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State))])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "igp-flooding-bandwidth"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth, [], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters for TED
                            update threshold 
                            
                            .. attribute:: threshold_type
                            
                                The type of threshold that should be used to specify the values at which bandwidth is flooded. DELTA indicates that the local system should flood IGP updates when a change in reserved bandwidth >= the specified delta occurs on the interface. Where THRESHOLD\_CROSSED is specified, the local system should trigger an update (and hence flood) the reserved bandwidth when the reserved bandwidth changes such that it crosses, or becomes equal to one of the threshold values
                            
                                **type**:  :py:class:`ThresholdType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config.ThresholdType>`
                            
                            .. attribute:: delta_percentage
                            
                                The percentage of the maximum\-reservable\-bandwidth considered as the delta that results in an IGP update being flooded
                            
                                **type**: int
                            
                                    **range:** 0..100
                            
                            .. attribute:: threshold_specification
                            
                                This value specifies whether a single set of threshold values should be used for both increasing and decreasing bandwidth when determining whether to trigger updated bandwidth values to be flooded in the IGP TE extensions. MIRRORED\-UP\-DOWN indicates that a single value (or set of values) should be used for both increasing and decreasing values, where SEPARATE\-UP\-DOWN specifies that the increasing and decreasing values will be separately specified
                            
                                **type**:  :py:class:`ThresholdSpecification<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config.ThresholdSpecification>`
                            
                            .. attribute:: up_thresholds
                            
                                The thresholds (expressed as a percentage of the maximum reservable bandwidth) at which bandwidth updates are to be triggered when the bandwidth is increasing
                            
                                **type**: list of int
                            
                                    **range:** 0..100
                            
                            .. attribute:: down_thresholds
                            
                                The thresholds (expressed as a percentage of the maximum reservable bandwidth) at which bandwidth updates are to be triggered when the bandwidth is decreasing
                            
                                **type**: list of int
                            
                                    **range:** 0..100
                            
                            .. attribute:: up_down_thresholds
                            
                                The thresholds (expressed as a percentage of the maximum reservable bandwidth of the interface) at which bandwidth updates are flooded \- used both when the bandwidth is increasing and decreasing
                            
                                **type**: list of int
                            
                                    **range:** 0..100
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "igp-flooding-bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold_type', (YLeaf(YType.enumeration, 'threshold-type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config.ThresholdType')])),
                                    ('delta_percentage', (YLeaf(YType.uint8, 'delta-percentage'), ['int'])),
                                    ('threshold_specification', (YLeaf(YType.enumeration, 'threshold-specification'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config.ThresholdSpecification')])),
                                    ('up_thresholds', (YLeafList(YType.uint8, 'up-thresholds'), ['int'])),
                                    ('down_thresholds', (YLeafList(YType.uint8, 'down-thresholds'), ['int'])),
                                    ('up_down_thresholds', (YLeafList(YType.uint8, 'up-down-thresholds'), ['int'])),
                                ])
                                self.threshold_type = None
                                self.delta_percentage = None
                                self.threshold_specification = None
                                self.up_thresholds = []
                                self.down_thresholds = []
                                self.up_down_thresholds = []
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.Config, ['threshold_type', 'delta_percentage', 'threshold_specification', 'up_thresholds', 'down_thresholds', 'up_down_thresholds'], name, value)

                            class ThresholdSpecification(Enum):
                                """
                                ThresholdSpecification (Enum Class)

                                .. data:: MIRRORED_UP_DOWN = 0

                                    MIRRORED_UP_DOWN indicates that a single set of

                                    threshold values should be used for both increasing

                                    and decreasing bandwidth when determining whether

                                    to trigger updated bandwidth values to be flooded

                                    in the IGP TE extensions.

                                .. data:: SEPARATE_UP_DOWN = 1

                                    SEPARATE_UP_DOWN indicates that a separate

                                    threshold values should be used for the increasing

                                    and decreasing bandwidth when determining whether

                                    to trigger updated bandwidth values to be flooded

                                    in the IGP TE extensions.

                                """

                                MIRRORED_UP_DOWN = Enum.YLeaf(0, "MIRRORED_UP_DOWN")

                                SEPARATE_UP_DOWN = Enum.YLeaf(1, "SEPARATE_UP_DOWN")


                            class ThresholdType(Enum):
                                """
                                ThresholdType (Enum Class)

                                .. data:: DELTA = 0

                                    DELTA indicates that the local

                                    system should flood IGP updates when a

                                    change in reserved bandwidth >= the specified

                                    delta occurs on the interface.

                                .. data:: THRESHOLD_CROSSED = 1

                                    THRESHOLD-CROSSED indicates that

                                    the local system should trigger an update (and

                                    hence flood) the reserved bandwidth when the

                                    reserved bandwidth changes such that it crosses,

                                    or becomes equal to one of the threshold values.

                                """

                                DELTA = Enum.YLeaf(0, "DELTA")

                                THRESHOLD_CROSSED = Enum.YLeaf(1, "THRESHOLD_CROSSED")



                        class State(_Entity_):
                            """
                            State parameters for TED update threshold 
                            
                            .. attribute:: threshold_type
                            
                                The type of threshold that should be used to specify the values at which bandwidth is flooded. DELTA indicates that the local system should flood IGP updates when a change in reserved bandwidth >= the specified delta occurs on the interface. Where THRESHOLD\_CROSSED is specified, the local system should trigger an update (and hence flood) the reserved bandwidth when the reserved bandwidth changes such that it crosses, or becomes equal to one of the threshold values
                            
                                **type**:  :py:class:`ThresholdType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State.ThresholdType>`
                            
                                **config**: False
                            
                            .. attribute:: delta_percentage
                            
                                The percentage of the maximum\-reservable\-bandwidth considered as the delta that results in an IGP update being flooded
                            
                                **type**: int
                            
                                    **range:** 0..100
                            
                                **config**: False
                            
                            .. attribute:: threshold_specification
                            
                                This value specifies whether a single set of threshold values should be used for both increasing and decreasing bandwidth when determining whether to trigger updated bandwidth values to be flooded in the IGP TE extensions. MIRRORED\-UP\-DOWN indicates that a single value (or set of values) should be used for both increasing and decreasing values, where SEPARATE\-UP\-DOWN specifies that the increasing and decreasing values will be separately specified
                            
                                **type**:  :py:class:`ThresholdSpecification<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State.ThresholdSpecification>`
                            
                                **config**: False
                            
                            .. attribute:: up_thresholds
                            
                                The thresholds (expressed as a percentage of the maximum reservable bandwidth) at which bandwidth updates are to be triggered when the bandwidth is increasing
                            
                                **type**: list of int
                            
                                    **range:** 0..100
                            
                                **config**: False
                            
                            .. attribute:: down_thresholds
                            
                                The thresholds (expressed as a percentage of the maximum reservable bandwidth) at which bandwidth updates are to be triggered when the bandwidth is decreasing
                            
                                **type**: list of int
                            
                                    **range:** 0..100
                            
                                **config**: False
                            
                            .. attribute:: up_down_thresholds
                            
                                The thresholds (expressed as a percentage of the maximum reservable bandwidth of the interface) at which bandwidth updates are flooded \- used both when the bandwidth is increasing and decreasing
                            
                                **type**: list of int
                            
                                    **range:** 0..100
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "igp-flooding-bandwidth"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('threshold_type', (YLeaf(YType.enumeration, 'threshold-type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State.ThresholdType')])),
                                    ('delta_percentage', (YLeaf(YType.uint8, 'delta-percentage'), ['int'])),
                                    ('threshold_specification', (YLeaf(YType.enumeration, 'threshold-specification'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State.ThresholdSpecification')])),
                                    ('up_thresholds', (YLeafList(YType.uint8, 'up-thresholds'), ['int'])),
                                    ('down_thresholds', (YLeafList(YType.uint8, 'down-thresholds'), ['int'])),
                                    ('up_down_thresholds', (YLeafList(YType.uint8, 'up-down-thresholds'), ['int'])),
                                ])
                                self.threshold_type = None
                                self.delta_percentage = None
                                self.threshold_specification = None
                                self.up_thresholds = []
                                self.down_thresholds = []
                                self.up_down_thresholds = []
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.IgpFloodingBandwidth.State, ['threshold_type', 'delta_percentage', 'threshold_specification', 'up_thresholds', 'down_thresholds', 'up_down_thresholds'], name, value)

                            class ThresholdSpecification(Enum):
                                """
                                ThresholdSpecification (Enum Class)

                                .. data:: MIRRORED_UP_DOWN = 0

                                    MIRRORED_UP_DOWN indicates that a single set of

                                    threshold values should be used for both increasing

                                    and decreasing bandwidth when determining whether

                                    to trigger updated bandwidth values to be flooded

                                    in the IGP TE extensions.

                                .. data:: SEPARATE_UP_DOWN = 1

                                    SEPARATE_UP_DOWN indicates that a separate

                                    threshold values should be used for the increasing

                                    and decreasing bandwidth when determining whether

                                    to trigger updated bandwidth values to be flooded

                                    in the IGP TE extensions.

                                """

                                MIRRORED_UP_DOWN = Enum.YLeaf(0, "MIRRORED_UP_DOWN")

                                SEPARATE_UP_DOWN = Enum.YLeaf(1, "SEPARATE_UP_DOWN")


                            class ThresholdType(Enum):
                                """
                                ThresholdType (Enum Class)

                                .. data:: DELTA = 0

                                    DELTA indicates that the local

                                    system should flood IGP updates when a

                                    change in reserved bandwidth >= the specified

                                    delta occurs on the interface.

                                .. data:: THRESHOLD_CROSSED = 1

                                    THRESHOLD-CROSSED indicates that

                                    the local system should trigger an update (and

                                    hence flood) the reserved bandwidth when the

                                    reserved bandwidth changes such that it crosses,

                                    or becomes equal to one of the threshold values.

                                """

                                DELTA = Enum.YLeaf(0, "DELTA")

                                THRESHOLD_CROSSED = Enum.YLeaf(1, "THRESHOLD_CROSSED")




                    class BandwidthMeasurement(_Entity_):
                        """
                        Configuration and operational state parameters relating to
                        per\-interface bandwidth measurement. These parameters are
                        used in the case that RSVP\-TE coexists with other MPLS
                        signaling protocols on an interface.
                        
                        .. attribute:: state
                        
                            Operational state parameters relating to the containing interface's bandwidth measurement
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-sr-rsvp-ext'
                        _revision = '2017-03-06'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "bandwidth-measurement"
                            self.yang_parent_name = "interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement.State))])
                            self._leafs = OrderedDict()

                            self.state = NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "openconfig-rsvp-sr-ext:bandwidth-measurement"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement, [], name, value)

                        class State(_Entity_):
                            """
                            Operational state parameters relating to the containing
                            interface's bandwidth measurement.
                            
                            .. attribute:: last_sample_time
                            
                                The time at which the last sample of bandwidth utilisation for both RSVP\-TE and non\-RSVP\-TE traffic was taken. This value is represented in nanoseconds since the Unix epoch
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: last_sample_measured_rsvp_util
                            
                                The measured RSVP\-TE bandwidth utilisation at the last sample (whose time is indicated in last\-sample\-time). This value is expressed as a 64\-bit unsigned integer representing the number of kilobits per second that RSVP\-TE traffic is consuming on the interface
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                                **units**: kbps
                            
                            .. attribute:: last_sample_measured_sr_util
                            
                                The measured Segment Routing bandwidth utilisation at the last sample (whose time is indicated in last\-sample\-time). This value is expressed as a 64\-bit unsigned integer representing the number of kilobits per second that Segment Routing traffic is consuming on the interface
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                                **units**: kbps
                            
                            .. attribute:: last_calculated_time
                            
                                The time at which the last calculated value for bandwidth utilisation was performed
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: last_calculated_sr_utilisation
                            
                                The last calculated value of the Segment Routing  utilisation (taken post any averaging or adjustment that occurs). This value is updated regardless of whether the value was flooded or not
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: last_flooded_time
                            
                                The time, expressed in nanoseconds since the epoch, at which the bandwidth utilisation of non\-RSVP\-TE traffic resulted in the value being flooded in the IGP. If the configuration of the local system specifies a 0% change requires flooding, this leaf will always reflect the value of the last\-calculated\-time. In systems that have suppression due to a >0% delta being required then it indicates the last time that the percentage threshold was exceeded
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-sr-rsvp-ext'
                            _revision = '2017-03-06'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "bandwidth-measurement"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('last_sample_time', (YLeaf(YType.uint64, 'last-sample-time'), ['int'])),
                                    ('last_sample_measured_rsvp_util', (YLeaf(YType.uint64, 'last-sample-measured-rsvp-util'), ['int'])),
                                    ('last_sample_measured_sr_util', (YLeaf(YType.uint64, 'last-sample-measured-sr-util'), ['int'])),
                                    ('last_calculated_time', (YLeaf(YType.uint64, 'last-calculated-time'), ['int'])),
                                    ('last_calculated_sr_utilisation', (YLeaf(YType.uint64, 'last-calculated-sr-utilisation'), ['int'])),
                                    ('last_flooded_time', (YLeaf(YType.uint64, 'last-flooded-time'), ['int'])),
                                ])
                                self.last_sample_time = None
                                self.last_sample_measured_rsvp_util = None
                                self.last_sample_measured_sr_util = None
                                self.last_calculated_time = None
                                self.last_calculated_sr_utilisation = None
                                self.last_flooded_time = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.TeInterfaceAttributes.Interface.BandwidthMeasurement.State, ['last_sample_time', 'last_sample_measured_rsvp_util', 'last_sample_measured_sr_util', 'last_calculated_time', 'last_calculated_sr_utilisation', 'last_flooded_time'], name, value)





            class SignalingProtocols(_Entity_):
                """
                top\-level signaling protocol configuration
                
                .. attribute:: rsvp_te
                
                    RSVP\-TE global signaling protocol configuration
                
                    **type**:  :py:class:`RsvpTe<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe>`
                
                .. attribute:: ldp
                
                    LDP global signaling configuration
                
                    **type**:  :py:class:`Ldp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.Ldp>`
                
                .. attribute:: segment_routing
                
                    MPLS\-specific Segment Routing configuration and operational state parameters
                
                    **type**:  :py:class:`SegmentRouting<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "signaling-protocols"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rsvp-te", ("rsvp_te", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe)), ("ldp", ("ldp", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.Ldp)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting))])
                    self._leafs = OrderedDict()

                    self.rsvp_te = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe()
                    self.rsvp_te.parent = self
                    self._children_name_map["rsvp_te"] = "rsvp-te"

                    self.ldp = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.Ldp()
                    self.ldp.parent = self
                    self._children_name_map["ldp"] = "ldp"

                    self.segment_routing = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting()
                    self.segment_routing.parent = self
                    self._children_name_map["segment_routing"] = "segment-routing"
                    self._segment_path = lambda: "signaling-protocols"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols, [], name, value)

                class RsvpTe(_Entity_):
                    """
                    RSVP\-TE global signaling protocol configuration
                    
                    .. attribute:: sessions
                    
                        Enclosing container for sessions
                    
                        **type**:  :py:class:`Sessions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions>`
                    
                    .. attribute:: neighbors
                    
                        Configuration and state for RSVP neighbors connecting to the device
                    
                        **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors>`
                    
                    .. attribute:: global_
                    
                        Platform wide RSVP configuration and state
                    
                        **type**:  :py:class:`Global<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global>`
                    
                    .. attribute:: interface_attributes
                    
                        Attributes relating to RSVP\-TE enabled interfaces
                    
                        **type**:  :py:class:`InterfaceAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "rsvp-te"
                        self.yang_parent_name = "signaling-protocols"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("sessions", ("sessions", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions)), ("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors)), ("global", ("global_", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global)), ("interface-attributes", ("interface_attributes", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes))])
                        self._leafs = OrderedDict()

                        self.sessions = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions()
                        self.sessions.parent = self
                        self._children_name_map["sessions"] = "sessions"

                        self.neighbors = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.global_ = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.interface_attributes = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes()
                        self.interface_attributes.parent = self
                        self._children_name_map["interface_attributes"] = "interface-attributes"
                        self._segment_path = lambda: "rsvp-te"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe, [], name, value)

                    class Sessions(_Entity_):
                        """
                        Enclosing container for sessions
                        
                        .. attribute:: session
                        
                            List of RSVP sessions
                        
                            **type**: list of    :py:class:`Session<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "sessions"
                            self.yang_parent_name = "rsvp-te"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("session", ("session", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session))])
                            self._leafs = OrderedDict()

                            self.session = YList(self)
                            self._segment_path = lambda: "sessions"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions, [], name, value)

                        class Session(_Entity_):
                            """
                            List of RSVP sessions
                            
                            .. attribute:: local_index  (key)
                            
                                Reference to the local index for the RSVP session
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **refers to**:  :py:class:`local_index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State>`
                            
                                **config**: False
                            
                            .. attribute:: record_route_objects
                            
                                Enclosing container for MPLS RRO objects associated with the traffic engineered tunnel
                            
                                **type**:  :py:class:`RecordRouteObjects<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects>`
                            
                                **config**: False
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the RSVP session
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "session"
                                self.yang_parent_name = "sessions"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['local_index']
                                self._child_classes = OrderedDict([("record-route-objects", ("record_route_objects", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State))])
                                self._leafs = OrderedDict([
                                    ('local_index', (YLeaf(YType.str, 'local-index'), ['int'])),
                                ])
                                self.local_index = None

                                self.record_route_objects = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects()
                                self.record_route_objects.parent = self
                                self._children_name_map["record_route_objects"] = "record-route-objects"

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "session" + "[local-index='" + str(self.local_index) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session, ['local_index'], name, value)

                            class RecordRouteObjects(_Entity_):
                                """
                                Enclosing container for MPLS RRO objects associated with the
                                traffic engineered tunnel.
                                
                                .. attribute:: record_route_object
                                
                                    Read\-only list of record route objects associated with the traffic engineered tunnel. Each entry in the list may contain a hop IP address, MPLS label allocated at the hop, and the flags associated with the entry
                                
                                    **type**: list of    :py:class:`RecordRouteObject<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "record-route-objects"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("record-route-object", ("record_route_object", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject))])
                                    self._leafs = OrderedDict()

                                    self.record_route_object = YList(self)
                                    self._segment_path = lambda: "record-route-objects"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects, [], name, value)

                                class RecordRouteObject(_Entity_):
                                    """
                                    Read\-only list of record route objects associated with the
                                    traffic engineered tunnel. Each entry in the list
                                    may contain a hop IP address, MPLS label allocated
                                    at the hop, and the flags associated with the entry.
                                    
                                    .. attribute:: index  (key)
                                    
                                        Reference to the index of the record route object. The index is used to indicate the ordering of hops in the path
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: state
                                    
                                        Information related to RRO objects. The hop, label, and optional flags are present for each entry in the list
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "record-route-object"
                                        self.yang_parent_name = "record-route-objects"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['index']
                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject.State))])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                        ])
                                        self.index = None

                                        self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "record-route-object" + "[index='" + str(self.index) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject, ['index'], name, value)

                                    class State(_Entity_):
                                        """
                                        Information related to RRO objects. The hop, label, and
                                        optional flags are present for each entry in the list.
                                        
                                        .. attribute:: index
                                        
                                            Index of object in the list. Used for ordering
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                        .. attribute:: address
                                        
                                            IP router hop for RRO entry
                                        
                                            **type**: union of the below types:
                                        
                                                **type**: str
                                        
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                        
                                                **type**: str
                                        
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                        
                                            **config**: False
                                        
                                        .. attribute:: reported_label
                                        
                                            Label reported for RRO hop
                                        
                                            **type**: union of the below types:
                                        
                                                **type**: int
                                        
                                                    **range:** 16..1048575
                                        
                                                **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: reported_flags
                                        
                                            Subobject flags for MPLS label
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "record-route-object"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                                ('reported_label', (YLeaf(YType.str, 'reported-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                                ('reported_flags', (YLeaf(YType.uint8, 'reported-flags'), ['int'])),
                                            ])
                                            self.index = None
                                            self.address = None
                                            self.reported_label = None
                                            self.reported_flags = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.RecordRouteObjects.RecordRouteObject.State, ['index', 'address', 'reported_label', 'reported_flags'], name, value)




                            class State(_Entity_):
                                """
                                Operational state parameters relating to the
                                RSVP session
                                
                                .. attribute:: local_index
                                
                                    The index used to identify the RSVP session on the local network element. This index is generated by the device and is unique only to the local network element
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: source_address
                                
                                    Origin address of RSVP session
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: destination_address
                                
                                    Destination address of RSVP session
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: tunnel_id
                                
                                    The tunnel ID is an identifier used in the RSVP session, which remains constant over the life of the tunnel
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                .. attribute:: lsp_id
                                
                                    The LSP ID distinguishes between two LSPs originated from the same headend, and is commonly used to distinguish RSVP sessions during make before break operations
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                .. attribute:: session_name
                                
                                    The signaled name of this RSVP session
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: status
                                
                                    Enumeration of RSVP session states
                                
                                    **type**:  :py:class:`Status<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.Status>`
                                
                                    **config**: False
                                
                                .. attribute:: type
                                
                                    The type/role of the RSVP session, signifing the session's role on the current device, such as a transit session vs. an ingress session
                                
                                    **type**:  :py:class:`LSPROLE<ydk.models.openconfig.openconfig_mpls_types.LSPROLE>`
                                
                                    **config**: False
                                
                                .. attribute:: protection_requested
                                
                                    The type of protection requested for the RSVP session
                                
                                    **type**:  :py:class:`PROTECTIONTYPE<ydk.models.openconfig.openconfig_mpls_types.PROTECTIONTYPE>`
                                
                                    **config**: False
                                
                                .. attribute:: label_in
                                
                                    Incoming MPLS label associated with this RSVP session
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: label_out
                                
                                    Outgoing MPLS label associated with this RSVP session
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: sender_tspec
                                
                                    Operational state statistics relating to the SENDER\_TSPEC received for the RSVP session
                                
                                    **type**:  :py:class:`SenderTspec<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.SenderTspec>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sender-tspec", ("sender_tspec", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.SenderTspec))])
                                    self._leafs = OrderedDict([
                                        ('local_index', (YLeaf(YType.uint64, 'local-index'), ['int'])),
                                        ('source_address', (YLeaf(YType.str, 'source-address'), ['str','str'])),
                                        ('destination_address', (YLeaf(YType.str, 'destination-address'), ['str','str'])),
                                        ('tunnel_id', (YLeaf(YType.uint16, 'tunnel-id'), ['int'])),
                                        ('lsp_id', (YLeaf(YType.uint16, 'lsp-id'), ['int'])),
                                        ('session_name', (YLeaf(YType.str, 'session-name'), ['str'])),
                                        ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.Status')])),
                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_mpls_types', 'LSPROLE')])),
                                        ('protection_requested', (YLeaf(YType.identityref, 'protection-requested'), [('ydk.models.openconfig.openconfig_mpls_types', 'PROTECTIONTYPE')])),
                                        ('label_in', (YLeaf(YType.str, 'label-in'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('label_out', (YLeaf(YType.str, 'label-out'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.local_index = None
                                    self.source_address = None
                                    self.destination_address = None
                                    self.tunnel_id = None
                                    self.lsp_id = None
                                    self.session_name = None
                                    self.status = None
                                    self.type = None
                                    self.protection_requested = None
                                    self.label_in = None
                                    self.label_out = None

                                    self.sender_tspec = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.SenderTspec()
                                    self.sender_tspec.parent = self
                                    self._children_name_map["sender_tspec"] = "sender-tspec"
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State, ['local_index', 'source_address', 'destination_address', 'tunnel_id', 'lsp_id', 'session_name', 'status', 'type', 'protection_requested', 'label_in', 'label_out'], name, value)

                                class Status(Enum):
                                    """
                                    Status (Enum Class)

                                    .. data:: UP = 0

                                        RSVP session is up

                                    .. data:: DOWN = 1

                                        RSVP session is down

                                    """

                                    UP = Enum.YLeaf(0, "UP")

                                    DOWN = Enum.YLeaf(1, "DOWN")


                                class SenderTspec(_Entity_):
                                    """
                                    Operational state statistics relating to the SENDER\_TSPEC
                                    received for the RSVP session
                                    
                                    .. attribute:: rate
                                    
                                        The rate at which the head\-end device generates traffic, expressed in bytes per second
                                    
                                        **type**: str
                                    
                                            **length:** 4..4
                                    
                                        **config**: False
                                    
                                        **units**: Bps
                                    
                                    .. attribute:: size
                                    
                                        The size of the token bucket that is used to determine the rate at which the head\-end device generates traffic, expressed in bytes per second
                                    
                                        **type**: str
                                    
                                            **length:** 4..4
                                    
                                        **config**: False
                                    
                                        **units**: bytes per second
                                    
                                    .. attribute:: peak_data_rate
                                    
                                        The maximum traffic generation rate that the head\-end device sends traffic at
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **length:** 4..4
                                    
                                            **type**:  :py:class:`PeakDataRate<ydk.models.openconfig.openconfig_mpls.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.SenderTspec.PeakDataRate>`
                                    
                                        **config**: False
                                    
                                        **units**: bytes per second
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "sender-tspec"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('rate', (YLeaf(YType.str, 'rate'), ['str'])),
                                            ('size', (YLeaf(YType.str, 'size'), ['str'])),
                                            ('peak_data_rate', (YLeaf(YType.str, 'peak-data-rate'), ['str',('ydk.models.openconfig.openconfig_mpls', 'Mpls', 'SignalingProtocols.RsvpTe.Sessions.Session.State.SenderTspec.PeakDataRate')])),
                                        ])
                                        self.rate = None
                                        self.size = None
                                        self.peak_data_rate = None
                                        self._segment_path = lambda: "sender-tspec"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session.State.SenderTspec, ['rate', 'size', 'peak_data_rate'], name, value)

                                    class PeakDataRate(Enum):
                                        """
                                        PeakDataRate (Enum Class)

                                        .. data:: INFINITY = 0

                                            The head-end device has no maximum data rate.

                                        """

                                        INFINITY = Enum.YLeaf(0, "INFINITY")






                    class Neighbors(_Entity_):
                        """
                        Configuration and state for RSVP neighbors connecting
                        to the device
                        
                        .. attribute:: neighbor
                        
                            List of RSVP neighbors of the local system
                        
                            **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "rsvp-te"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors, [], name, value)

                        class Neighbor(_Entity_):
                            """
                            List of RSVP neighbors of the local system
                            
                            .. attribute:: address  (key)
                            
                                Reference to the address of the RSVP neighbor
                            
                                **type**: union of the below types:
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                            
                                **refers to**:  :py:class:`address<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State>`
                            
                                **config**: False
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the RSVP neighbor
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['address']
                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State))])
                                self._leafs = OrderedDict([
                                    ('address', (YLeaf(YType.str, 'address'), ['str'])),
                                ])
                                self.address = None

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "neighbor" + "[address='" + str(self.address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor, ['address'], name, value)

                            class State(_Entity_):
                                """
                                Operational state parameters relating to the
                                RSVP neighbor
                                
                                .. attribute:: address
                                
                                    Address of RSVP neighbor
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: detected_interface
                                
                                    Interface where RSVP neighbor was detected
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: neighbor_status
                                
                                    Enumuration of possible RSVP neighbor states
                                
                                    **type**:  :py:class:`NeighborStatus<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State.NeighborStatus>`
                                
                                    **config**: False
                                
                                .. attribute:: refresh_reduction
                                
                                    Suppport of neighbor for RSVP refresh reduction
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                        ('detected_interface', (YLeaf(YType.str, 'detected-interface'), ['str'])),
                                        ('neighbor_status', (YLeaf(YType.enumeration, 'neighbor-status'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State.NeighborStatus')])),
                                        ('refresh_reduction', (YLeaf(YType.boolean, 'refresh-reduction'), ['bool'])),
                                    ])
                                    self.address = None
                                    self.detected_interface = None
                                    self.neighbor_status = None
                                    self.refresh_reduction = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Neighbors.Neighbor.State, ['address', 'detected_interface', 'neighbor_status', 'refresh_reduction'], name, value)

                                class NeighborStatus(Enum):
                                    """
                                    NeighborStatus (Enum Class)

                                    .. data:: UP = 0

                                        RSVP hello messages are detected from the neighbor

                                    .. data:: DOWN = 1

                                        RSVP neighbor not detected as up, due to a

                                        communication failure or IGP notification

                                        the neighbor is unavailable

                                    """

                                    UP = Enum.YLeaf(0, "UP")

                                    DOWN = Enum.YLeaf(1, "DOWN")





                    class Global(_Entity_):
                        """
                        Platform wide RSVP configuration and state
                        
                        .. attribute:: graceful_restart
                        
                            Operational state and configuration parameters relating to graceful\-restart for RSVP
                        
                            **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart>`
                        
                        .. attribute:: soft_preemption
                        
                            Protocol options relating to RSVP soft preemption
                        
                            **type**:  :py:class:`SoftPreemption<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption>`
                        
                        .. attribute:: hellos
                        
                            Top level container for RSVP hello parameters
                        
                            **type**:  :py:class:`Hellos<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos>`
                        
                        .. attribute:: state
                        
                            Platform wide RSVP state, including counters
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "rsvp-te"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart)), ("soft-preemption", ("soft_preemption", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption)), ("hellos", ("hellos", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State))])
                            self._leafs = OrderedDict()

                            self.graceful_restart = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.soft_preemption = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption()
                            self.soft_preemption.parent = self
                            self._children_name_map["soft_preemption"] = "soft-preemption"

                            self.hellos = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos()
                            self.hellos.parent = self
                            self._children_name_map["hellos"] = "hellos"

                            self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global, [], name, value)

                        class GracefulRestart(_Entity_):
                            """
                            Operational state and configuration parameters relating to
                            graceful\-restart for RSVP
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to graceful\-restart
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.Config>`
                            
                            .. attribute:: state
                            
                                State information associated with RSVP graceful\-restart
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to
                                graceful\-restart
                                
                                .. attribute:: enable
                                
                                    Enables graceful restart on the node
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: restart_time
                                
                                    Graceful restart time (seconds)
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                .. attribute:: recovery_time
                                
                                    RSVP state recovery time
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                    ])
                                    self.enable = None
                                    self.restart_time = None
                                    self.recovery_time = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.Config, ['enable', 'restart_time', 'recovery_time'], name, value)


                            class State(_Entity_):
                                """
                                State information associated with
                                RSVP graceful\-restart
                                
                                .. attribute:: enable
                                
                                    Enables graceful restart on the node
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: restart_time
                                
                                    Graceful restart time (seconds)
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: recovery_time
                                
                                    RSVP state recovery time
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint32, 'restart-time'), ['int'])),
                                        ('recovery_time', (YLeaf(YType.uint32, 'recovery-time'), ['int'])),
                                    ])
                                    self.enable = None
                                    self.restart_time = None
                                    self.recovery_time = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.GracefulRestart.State, ['enable', 'restart_time', 'recovery_time'], name, value)



                        class SoftPreemption(_Entity_):
                            """
                            Protocol options relating to RSVP
                            soft preemption
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to RSVP soft preemption support
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.Config>`
                            
                            .. attribute:: state
                            
                                State parameters relating to RSVP soft preemption support
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "soft-preemption"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "soft-preemption"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to RSVP
                                soft preemption support
                                
                                .. attribute:: enable
                                
                                    Enables soft preemption on a node
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: soft_preemption_timeout
                                
                                    Timeout value for soft preemption to revert to hard preemption. The default timeout for soft\-preemption is 30 seconds \- after which the local system reverts to hard pre\-emption
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **default value**: 30
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "soft-preemption"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                        ('soft_preemption_timeout', (YLeaf(YType.uint16, 'soft-preemption-timeout'), ['int'])),
                                    ])
                                    self.enable = None
                                    self.soft_preemption_timeout = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.Config, ['enable', 'soft_preemption_timeout'], name, value)


                            class State(_Entity_):
                                """
                                State parameters relating to RSVP
                                soft preemption support
                                
                                .. attribute:: enable
                                
                                    Enables soft preemption on a node
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: soft_preemption_timeout
                                
                                    Timeout value for soft preemption to revert to hard preemption. The default timeout for soft\-preemption is 30 seconds \- after which the local system reverts to hard pre\-emption
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                    **default value**: 30
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "soft-preemption"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                        ('soft_preemption_timeout', (YLeaf(YType.uint16, 'soft-preemption-timeout'), ['int'])),
                                    ])
                                    self.enable = None
                                    self.soft_preemption_timeout = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.SoftPreemption.State, ['enable', 'soft_preemption_timeout'], name, value)



                        class Hellos(_Entity_):
                            """
                            Top level container for RSVP hello parameters
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to RSVP hellos
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.Config>`
                            
                            .. attribute:: state
                            
                                State information associated with RSVP hellos
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "hellos"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "hellos"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to RSVP
                                hellos
                                
                                .. attribute:: hello_interval
                                
                                    set the interval in ms between RSVP hello messages
                                
                                    **type**: int
                                
                                        **range:** 1000..60000
                                
                                    **units**: milliseconds
                                
                                    **default value**: 9000
                                
                                .. attribute:: refresh_reduction
                                
                                    enables all RSVP refresh reduction message bundling, RSVP message ID, reliable message delivery and summary refresh
                                
                                    **type**: bool
                                
                                    **default value**: true
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "hellos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                        ('refresh_reduction', (YLeaf(YType.boolean, 'refresh-reduction'), ['bool'])),
                                    ])
                                    self.hello_interval = None
                                    self.refresh_reduction = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.Config, ['hello_interval', 'refresh_reduction'], name, value)


                            class State(_Entity_):
                                """
                                State information associated with RSVP hellos
                                
                                .. attribute:: hello_interval
                                
                                    set the interval in ms between RSVP hello messages
                                
                                    **type**: int
                                
                                        **range:** 1000..60000
                                
                                    **config**: False
                                
                                    **units**: milliseconds
                                
                                    **default value**: 9000
                                
                                .. attribute:: refresh_reduction
                                
                                    enables all RSVP refresh reduction message bundling, RSVP message ID, reliable message delivery and summary refresh
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: true
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "hellos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                        ('refresh_reduction', (YLeaf(YType.boolean, 'refresh-reduction'), ['bool'])),
                                    ])
                                    self.hello_interval = None
                                    self.refresh_reduction = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.Hellos.State, ['hello_interval', 'refresh_reduction'], name, value)



                        class State(_Entity_):
                            """
                            Platform wide RSVP state, including counters
                            
                            .. attribute:: counters
                            
                                Platform wide RSVP statistics and counters
                            
                                **type**:  :py:class:`Counters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State.Counters>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("counters", ("counters", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State.Counters))])
                                self._leafs = OrderedDict()

                                self.counters = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State.Counters()
                                self.counters.parent = self
                                self._children_name_map["counters"] = "counters"
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State, [], name, value)

                            class Counters(_Entity_):
                                """
                                Platform wide RSVP statistics and counters
                                
                                .. attribute:: path_timeouts
                                
                                    TODO
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: reservation_timeouts
                                
                                    TODO
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: rate_limited_messages
                                
                                    RSVP messages dropped due to rate limiting
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_path_messages
                                
                                    Number of received RSVP Path messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_path_error_messages
                                
                                    Number of received RSVP Path Error messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_path_tear_messages
                                
                                    Number of received RSVP Path Tear messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_reservation_messages
                                
                                    Number of received RSVP Resv messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_reservation_error_messages
                                
                                    Number of received RSVP Resv Error messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_reservation_tear_messages
                                
                                    Number of received RSVP Resv Tear messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_hello_messages
                                
                                    Number of received RSVP hello messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_srefresh_messages
                                
                                    Number of received RSVP summary refresh messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_ack_messages
                                
                                    Number of received RSVP refresh reduction ack messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_path_messages
                                
                                    Number of sent RSVP PATH messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_path_error_messages
                                
                                    Number of sent RSVP Path Error messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_path_tear_messages
                                
                                    Number of sent RSVP Path Tear messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_reservation_messages
                                
                                    Number of sent RSVP Resv messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_reservation_error_messages
                                
                                    Number of sent RSVP Resv Error messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_reservation_tear_messages
                                
                                    Number of sent RSVP Resv Tear messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_hello_messages
                                
                                    Number of sent RSVP hello messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_srefresh_messages
                                
                                    Number of sent RSVP summary refresh messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_ack_messages
                                
                                    Number of sent RSVP refresh reduction ack messages
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "counters"
                                    self.yang_parent_name = "state"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('path_timeouts', (YLeaf(YType.uint64, 'path-timeouts'), ['int'])),
                                        ('reservation_timeouts', (YLeaf(YType.uint64, 'reservation-timeouts'), ['int'])),
                                        ('rate_limited_messages', (YLeaf(YType.uint64, 'rate-limited-messages'), ['int'])),
                                        ('in_path_messages', (YLeaf(YType.uint64, 'in-path-messages'), ['int'])),
                                        ('in_path_error_messages', (YLeaf(YType.uint64, 'in-path-error-messages'), ['int'])),
                                        ('in_path_tear_messages', (YLeaf(YType.uint64, 'in-path-tear-messages'), ['int'])),
                                        ('in_reservation_messages', (YLeaf(YType.uint64, 'in-reservation-messages'), ['int'])),
                                        ('in_reservation_error_messages', (YLeaf(YType.uint64, 'in-reservation-error-messages'), ['int'])),
                                        ('in_reservation_tear_messages', (YLeaf(YType.uint64, 'in-reservation-tear-messages'), ['int'])),
                                        ('in_hello_messages', (YLeaf(YType.uint64, 'in-hello-messages'), ['int'])),
                                        ('in_srefresh_messages', (YLeaf(YType.uint64, 'in-srefresh-messages'), ['int'])),
                                        ('in_ack_messages', (YLeaf(YType.uint64, 'in-ack-messages'), ['int'])),
                                        ('out_path_messages', (YLeaf(YType.uint64, 'out-path-messages'), ['int'])),
                                        ('out_path_error_messages', (YLeaf(YType.uint64, 'out-path-error-messages'), ['int'])),
                                        ('out_path_tear_messages', (YLeaf(YType.uint64, 'out-path-tear-messages'), ['int'])),
                                        ('out_reservation_messages', (YLeaf(YType.uint64, 'out-reservation-messages'), ['int'])),
                                        ('out_reservation_error_messages', (YLeaf(YType.uint64, 'out-reservation-error-messages'), ['int'])),
                                        ('out_reservation_tear_messages', (YLeaf(YType.uint64, 'out-reservation-tear-messages'), ['int'])),
                                        ('out_hello_messages', (YLeaf(YType.uint64, 'out-hello-messages'), ['int'])),
                                        ('out_srefresh_messages', (YLeaf(YType.uint64, 'out-srefresh-messages'), ['int'])),
                                        ('out_ack_messages', (YLeaf(YType.uint64, 'out-ack-messages'), ['int'])),
                                    ])
                                    self.path_timeouts = None
                                    self.reservation_timeouts = None
                                    self.rate_limited_messages = None
                                    self.in_path_messages = None
                                    self.in_path_error_messages = None
                                    self.in_path_tear_messages = None
                                    self.in_reservation_messages = None
                                    self.in_reservation_error_messages = None
                                    self.in_reservation_tear_messages = None
                                    self.in_hello_messages = None
                                    self.in_srefresh_messages = None
                                    self.in_ack_messages = None
                                    self.out_path_messages = None
                                    self.out_path_error_messages = None
                                    self.out_path_tear_messages = None
                                    self.out_reservation_messages = None
                                    self.out_reservation_error_messages = None
                                    self.out_reservation_tear_messages = None
                                    self.out_hello_messages = None
                                    self.out_srefresh_messages = None
                                    self.out_ack_messages = None
                                    self._segment_path = lambda: "counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Global.State.Counters, ['path_timeouts', 'reservation_timeouts', 'rate_limited_messages', 'in_path_messages', 'in_path_error_messages', 'in_path_tear_messages', 'in_reservation_messages', 'in_reservation_error_messages', 'in_reservation_tear_messages', 'in_hello_messages', 'in_srefresh_messages', 'in_ack_messages', 'out_path_messages', 'out_path_error_messages', 'out_path_tear_messages', 'out_reservation_messages', 'out_reservation_error_messages', 'out_reservation_tear_messages', 'out_hello_messages', 'out_srefresh_messages', 'out_ack_messages'], name, value)




                    class InterfaceAttributes(_Entity_):
                        """
                        Attributes relating to RSVP\-TE enabled interfaces
                        
                        .. attribute:: interface
                        
                            list of per\-interface RSVP configurations
                        
                            **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "interface-attributes"
                            self.yang_parent_name = "rsvp-te"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "interface-attributes"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes, [], name, value)

                        class Interface(_Entity_):
                            """
                            list of per\-interface RSVP configurations
                            
                            .. attribute:: interface_id  (key)
                            
                                reference to the interface\-id data
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`interface_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Config>`
                            
                            .. attribute:: config
                            
                                Configuration of per\-interface RSVP parameters
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Config>`
                            
                            .. attribute:: state
                            
                                Per\-interface RSVP protocol and state information
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State>`
                            
                                **config**: False
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef>`
                            
                            .. attribute:: bandwidth_reservations
                            
                                Enclosing container for bandwidth reservation
                            
                                **type**:  :py:class:`BandwidthReservations<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations>`
                            
                            .. attribute:: hellos
                            
                                Top level container for RSVP hello parameters
                            
                                **type**:  :py:class:`Hellos<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos>`
                            
                            .. attribute:: authentication
                            
                                Configuration and state parameters relating to RSVP authentication as per RFC2747
                            
                                **type**:  :py:class:`Authentication<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication>`
                            
                            .. attribute:: subscription
                            
                                Bandwidth percentage reservable by RSVP on an interface
                            
                                **type**:  :py:class:`Subscription<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription>`
                            
                            .. attribute:: protection
                            
                                link\-protection (NHOP) related configuration
                            
                                **type**:  :py:class:`Protection<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interface-attributes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_id']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef)), ("bandwidth-reservations", ("bandwidth_reservations", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations)), ("hellos", ("hellos", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication)), ("subscription", ("subscription", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription)), ("protection", ("protection", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection))])
                                self._leafs = OrderedDict([
                                    ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                ])
                                self.interface_id = None

                                self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.interface_ref = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"

                                self.bandwidth_reservations = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations()
                                self.bandwidth_reservations.parent = self
                                self._children_name_map["bandwidth_reservations"] = "bandwidth-reservations"

                                self.hellos = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos()
                                self.hellos.parent = self
                                self._children_name_map["hellos"] = "hellos"

                                self.authentication = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.subscription = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription()
                                self.subscription.parent = self
                                self._children_name_map["subscription"] = "subscription"

                                self.protection = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection()
                                self.protection.parent = self
                                self._children_name_map["protection"] = "protection"
                                self._segment_path = lambda: "interface" + "[interface-id='" + str(self.interface_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface, ['interface_id'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration of per\-interface RSVP parameters
                                
                                .. attribute:: interface_id
                                
                                    Identifier for the interface
                                
                                    **type**: str
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                    ])
                                    self.interface_id = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Config, ['interface_id'], name, value)


                            class State(_Entity_):
                                """
                                Per\-interface RSVP protocol and state information
                                
                                .. attribute:: interface_id
                                
                                    Identifier for the interface
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: counters
                                
                                    Interface specific RSVP statistics and counters
                                
                                    **type**:  :py:class:`Counters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State.Counters>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("counters", ("counters", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State.Counters))])
                                    self._leafs = OrderedDict([
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                    ])
                                    self.interface_id = None

                                    self.counters = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State.Counters()
                                    self.counters.parent = self
                                    self._children_name_map["counters"] = "counters"
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State, ['interface_id'], name, value)

                                class Counters(_Entity_):
                                    """
                                    Interface specific RSVP statistics and counters
                                    
                                    .. attribute:: in_path_messages
                                    
                                        Number of received RSVP Path messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_path_error_messages
                                    
                                        Number of received RSVP Path Error messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_path_tear_messages
                                    
                                        Number of received RSVP Path Tear messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_reservation_messages
                                    
                                        Number of received RSVP Resv messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_reservation_error_messages
                                    
                                        Number of received RSVP Resv Error messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_reservation_tear_messages
                                    
                                        Number of received RSVP Resv Tear messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_hello_messages
                                    
                                        Number of received RSVP hello messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_srefresh_messages
                                    
                                        Number of received RSVP summary refresh messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: in_ack_messages
                                    
                                        Number of received RSVP refresh reduction ack messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_path_messages
                                    
                                        Number of sent RSVP PATH messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_path_error_messages
                                    
                                        Number of sent RSVP Path Error messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_path_tear_messages
                                    
                                        Number of sent RSVP Path Tear messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_reservation_messages
                                    
                                        Number of sent RSVP Resv messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_reservation_error_messages
                                    
                                        Number of sent RSVP Resv Error messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_reservation_tear_messages
                                    
                                        Number of sent RSVP Resv Tear messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_hello_messages
                                    
                                        Number of sent RSVP hello messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_srefresh_messages
                                    
                                        Number of sent RSVP summary refresh messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: out_ack_messages
                                    
                                        Number of sent RSVP refresh reduction ack messages
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "counters"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('in_path_messages', (YLeaf(YType.uint64, 'in-path-messages'), ['int'])),
                                            ('in_path_error_messages', (YLeaf(YType.uint64, 'in-path-error-messages'), ['int'])),
                                            ('in_path_tear_messages', (YLeaf(YType.uint64, 'in-path-tear-messages'), ['int'])),
                                            ('in_reservation_messages', (YLeaf(YType.uint64, 'in-reservation-messages'), ['int'])),
                                            ('in_reservation_error_messages', (YLeaf(YType.uint64, 'in-reservation-error-messages'), ['int'])),
                                            ('in_reservation_tear_messages', (YLeaf(YType.uint64, 'in-reservation-tear-messages'), ['int'])),
                                            ('in_hello_messages', (YLeaf(YType.uint64, 'in-hello-messages'), ['int'])),
                                            ('in_srefresh_messages', (YLeaf(YType.uint64, 'in-srefresh-messages'), ['int'])),
                                            ('in_ack_messages', (YLeaf(YType.uint64, 'in-ack-messages'), ['int'])),
                                            ('out_path_messages', (YLeaf(YType.uint64, 'out-path-messages'), ['int'])),
                                            ('out_path_error_messages', (YLeaf(YType.uint64, 'out-path-error-messages'), ['int'])),
                                            ('out_path_tear_messages', (YLeaf(YType.uint64, 'out-path-tear-messages'), ['int'])),
                                            ('out_reservation_messages', (YLeaf(YType.uint64, 'out-reservation-messages'), ['int'])),
                                            ('out_reservation_error_messages', (YLeaf(YType.uint64, 'out-reservation-error-messages'), ['int'])),
                                            ('out_reservation_tear_messages', (YLeaf(YType.uint64, 'out-reservation-tear-messages'), ['int'])),
                                            ('out_hello_messages', (YLeaf(YType.uint64, 'out-hello-messages'), ['int'])),
                                            ('out_srefresh_messages', (YLeaf(YType.uint64, 'out-srefresh-messages'), ['int'])),
                                            ('out_ack_messages', (YLeaf(YType.uint64, 'out-ack-messages'), ['int'])),
                                        ])
                                        self.in_path_messages = None
                                        self.in_path_error_messages = None
                                        self.in_path_tear_messages = None
                                        self.in_reservation_messages = None
                                        self.in_reservation_error_messages = None
                                        self.in_reservation_tear_messages = None
                                        self.in_hello_messages = None
                                        self.in_srefresh_messages = None
                                        self.in_ack_messages = None
                                        self.out_path_messages = None
                                        self.out_path_error_messages = None
                                        self.out_path_tear_messages = None
                                        self.out_reservation_messages = None
                                        self.out_reservation_error_messages = None
                                        self.out_reservation_tear_messages = None
                                        self.out_hello_messages = None
                                        self.out_srefresh_messages = None
                                        self.out_ack_messages = None
                                        self._segment_path = lambda: "counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.State.Counters, ['in_path_messages', 'in_path_error_messages', 'in_path_tear_messages', 'in_reservation_messages', 'in_reservation_error_messages', 'in_reservation_tear_messages', 'in_hello_messages', 'in_srefresh_messages', 'in_ack_messages', 'out_path_messages', 'out_path_error_messages', 'out_path_tear_messages', 'out_reservation_messages', 'out_reservation_error_messages', 'out_reservation_tear_messages', 'out_hello_messages', 'out_srefresh_messages', 'out_ack_messages'], name, value)



                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)



                            class BandwidthReservations(_Entity_):
                                """
                                Enclosing container for bandwidth reservation
                                
                                .. attribute:: bandwidth_reservation
                                
                                    Available and reserved bandwidth by priority on the interface
                                
                                    **type**: list of    :py:class:`BandwidthReservation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "bandwidth-reservations"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("bandwidth-reservation", ("bandwidth_reservation", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation))])
                                    self._leafs = OrderedDict()

                                    self.bandwidth_reservation = YList(self)
                                    self._segment_path = lambda: "bandwidth-reservations"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations, [], name, value)

                                class BandwidthReservation(_Entity_):
                                    """
                                    Available and reserved bandwidth by priority on
                                    the interface.
                                    
                                    .. attribute:: priority  (key)
                                    
                                        Reference to the RSVP priority level
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: int
                                    
                                                **range:** 0..7
                                    
                                            **type**:  :py:class:`Priority<ydk.models.openconfig.openconfig_mpls.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State.Priority>`
                                    
                                        **refers to**:  :py:class:`priority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: state
                                    
                                        Operational state parameters relating to a bandwidth reservation at a certain priority
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "bandwidth-reservation"
                                        self.yang_parent_name = "bandwidth-reservations"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['priority']
                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State))])
                                        self._leafs = OrderedDict([
                                            ('priority', (YLeaf(YType.str, 'priority'), ['str'])),
                                        ])
                                        self.priority = None

                                        self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "bandwidth-reservation" + "[priority='" + str(self.priority) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation, ['priority'], name, value)

                                    class State(_Entity_):
                                        """
                                        Operational state parameters relating to a
                                        bandwidth reservation at a certain priority
                                        
                                        .. attribute:: priority
                                        
                                            RSVP priority level for LSPs traversing the interface
                                        
                                            **type**: union of the below types:
                                        
                                                **type**: int
                                        
                                                    **range:** 0..7
                                        
                                                **type**:  :py:class:`Priority<ydk.models.openconfig.openconfig_mpls.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State.Priority>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: available_bandwidth
                                        
                                            Bandwidth currently available with the priority level, or for the entire interface when the priority is set to ALL
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: reserved_bandwidth
                                        
                                            Bandwidth currently reserved within the priority level, or the sum of all priority levels when the keyword is set to ALL
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: active_reservations_count
                                        
                                            Number of active RSVP reservations in the associated priority, or the sum of all reservations when the priority level is set to ALL
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: highwater_mark
                                        
                                            Maximum bandwidth reserved on the interface within the priority, or across all priorities in the case that the priority level is set to ALL
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "bandwidth-reservation"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('priority', (YLeaf(YType.str, 'priority'), ['int',('ydk.models.openconfig.openconfig_mpls', 'Mpls', 'SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State.Priority')])),
                                                ('available_bandwidth', (YLeaf(YType.uint64, 'available-bandwidth'), ['int'])),
                                                ('reserved_bandwidth', (YLeaf(YType.uint64, 'reserved-bandwidth'), ['int'])),
                                                ('active_reservations_count', (YLeaf(YType.uint64, 'active-reservations-count'), ['int'])),
                                                ('highwater_mark', (YLeaf(YType.uint64, 'highwater-mark'), ['int'])),
                                            ])
                                            self.priority = None
                                            self.available_bandwidth = None
                                            self.reserved_bandwidth = None
                                            self.active_reservations_count = None
                                            self.highwater_mark = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.BandwidthReservations.BandwidthReservation.State, ['priority', 'available_bandwidth', 'reserved_bandwidth', 'active_reservations_count', 'highwater_mark'], name, value)

                                        class Priority(Enum):
                                            """
                                            Priority (Enum Class)

                                            .. data:: ALL = 0

                                                The ALL keyword represents the overall

                                                state of the interface - i.e., the union

                                                of all of the priority levels

                                            """

                                            ALL = Enum.YLeaf(0, "ALL")





                            class Hellos(_Entity_):
                                """
                                Top level container for RSVP hello parameters
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to RSVP hellos
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.Config>`
                                
                                .. attribute:: state
                                
                                    State information associated with RSVP hellos
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "hellos"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "hellos"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to RSVP
                                    hellos
                                    
                                    .. attribute:: hello_interval
                                    
                                        set the interval in ms between RSVP hello messages
                                    
                                        **type**: int
                                    
                                            **range:** 1000..60000
                                    
                                        **units**: milliseconds
                                    
                                        **default value**: 9000
                                    
                                    .. attribute:: refresh_reduction
                                    
                                        enables all RSVP refresh reduction message bundling, RSVP message ID, reliable message delivery and summary refresh
                                    
                                        **type**: bool
                                    
                                        **default value**: true
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                            ('refresh_reduction', (YLeaf(YType.boolean, 'refresh-reduction'), ['bool'])),
                                        ])
                                        self.hello_interval = None
                                        self.refresh_reduction = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.Config, ['hello_interval', 'refresh_reduction'], name, value)


                                class State(_Entity_):
                                    """
                                    State information associated with RSVP hellos
                                    
                                    .. attribute:: hello_interval
                                    
                                        set the interval in ms between RSVP hello messages
                                    
                                        **type**: int
                                    
                                            **range:** 1000..60000
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                        **default value**: 9000
                                    
                                    .. attribute:: refresh_reduction
                                    
                                        enables all RSVP refresh reduction message bundling, RSVP message ID, reliable message delivery and summary refresh
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: true
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "hellos"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_interval', (YLeaf(YType.uint16, 'hello-interval'), ['int'])),
                                            ('refresh_reduction', (YLeaf(YType.boolean, 'refresh-reduction'), ['bool'])),
                                        ])
                                        self.hello_interval = None
                                        self.refresh_reduction = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Hellos.State, ['hello_interval', 'refresh_reduction'], name, value)



                            class Authentication(_Entity_):
                                """
                                Configuration and state parameters relating to RSVP
                                authentication as per RFC2747
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to authentication
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.Config>`
                                
                                .. attribute:: state
                                
                                    State information associated with authentication
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating
                                    to authentication
                                    
                                    .. attribute:: enable
                                    
                                        Enables RSVP authentication on the node
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: authentication_key
                                    
                                        authenticate RSVP signaling messages
                                    
                                        **type**: str
                                    
                                            **length:** 1..32
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('authentication_key', (YLeaf(YType.str, 'authentication-key'), ['str'])),
                                        ])
                                        self.enable = None
                                        self.authentication_key = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.Config, ['enable', 'authentication_key'], name, value)


                                class State(_Entity_):
                                    """
                                    State information associated
                                    with authentication
                                    
                                    .. attribute:: enable
                                    
                                        Enables RSVP authentication on the node
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: authentication_key
                                    
                                        authenticate RSVP signaling messages
                                    
                                        **type**: str
                                    
                                            **length:** 1..32
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enable', (YLeaf(YType.boolean, 'enable'), ['bool'])),
                                            ('authentication_key', (YLeaf(YType.str, 'authentication-key'), ['str'])),
                                        ])
                                        self.enable = None
                                        self.authentication_key = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Authentication.State, ['enable', 'authentication_key'], name, value)



                            class Subscription(_Entity_):
                                """
                                Bandwidth percentage reservable by RSVP
                                on an interface
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to RSVP subscription options
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.Config>`
                                
                                .. attribute:: state
                                
                                    State parameters relating to RSVP subscription options
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "subscription"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "subscription"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to RSVP
                                    subscription options
                                    
                                    .. attribute:: subscription
                                    
                                        percentage of the interface bandwidth that RSVP can reserve
                                    
                                        **type**: int
                                    
                                            **range:** 0..100
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "subscription"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('subscription', (YLeaf(YType.uint8, 'subscription'), ['int'])),
                                        ])
                                        self.subscription = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.Config, ['subscription'], name, value)


                                class State(_Entity_):
                                    """
                                    State parameters relating to RSVP
                                    subscription options
                                    
                                    .. attribute:: subscription
                                    
                                        percentage of the interface bandwidth that RSVP can reserve
                                    
                                        **type**: int
                                    
                                            **range:** 0..100
                                    
                                        **config**: False
                                    
                                    .. attribute:: calculated_absolute_subscription_bw
                                    
                                        The calculated absolute value of the bandwidth which is reservable to RSVP\-TE on the interface prior to any adjustments that may be made from external sources
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: kbps
                                    
                                    .. attribute:: adjusted_absolute_subscription_bw
                                    
                                        The adjusted absolute value (in kbps) of the bandwidth which is reservable to RSVP\-TE on the local system. In the case that the bandwidth\-measurement configuration does not account for non\-RSVP\-TE traffic then this value is equal to the calculated\-absolute\-subscription\-bw, in the case that non\-RSVP\-TE traffic is being accounted for, it is lower such that calculated\-absolute\-subscription\-bw \- adjusted\-absolute\-subscription\-bw = the current calculated non\-RSVP\-TE traffic.  This value reflects the last flooded value of the maximum reservable bandwidth, or subscription
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: kbps
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "subscription"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('subscription', (YLeaf(YType.uint8, 'subscription'), ['int'])),
                                            ('calculated_absolute_subscription_bw', (YLeaf(YType.uint64, 'calculated-absolute-subscription-bw'), ['int'])),
                                            ('adjusted_absolute_subscription_bw', (YLeaf(YType.uint64, 'openconfig-rsvp-sr-ext:adjusted-absolute-subscription-bw'), ['int'])),
                                        ])
                                        self.subscription = None
                                        self.calculated_absolute_subscription_bw = None
                                        self.adjusted_absolute_subscription_bw = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Subscription.State, ['subscription', 'calculated_absolute_subscription_bw', 'adjusted_absolute_subscription_bw'], name, value)



                            class Protection(_Entity_):
                                """
                                link\-protection (NHOP) related configuration
                                
                                .. attribute:: config
                                
                                    Configuration for link\-protection
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.Config>`
                                
                                .. attribute:: state
                                
                                    State for link\-protection
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "protection"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "protection"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration for link\-protection
                                    
                                    .. attribute:: link_protection_style_requested
                                    
                                        Style of mpls frr protection desired\: link, link\-node, or unprotected
                                    
                                        **type**:  :py:class:`PROTECTIONTYPE<ydk.models.openconfig.openconfig_mpls_types.PROTECTIONTYPE>`
                                    
                                        **default value**: oc-mplst:LINK_NODE_PROTECTION_REQUESTED
                                    
                                    .. attribute:: bypass_optimize_interval
                                    
                                        interval between periodic optimization of the bypass LSPs
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **units**: seconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "protection"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('link_protection_style_requested', (YLeaf(YType.identityref, 'link-protection-style-requested'), [('ydk.models.openconfig.openconfig_mpls_types', 'PROTECTIONTYPE')])),
                                            ('bypass_optimize_interval', (YLeaf(YType.uint16, 'bypass-optimize-interval'), ['int'])),
                                        ])
                                        self.link_protection_style_requested = None
                                        self.bypass_optimize_interval = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.Config, ['link_protection_style_requested', 'bypass_optimize_interval'], name, value)


                                class State(_Entity_):
                                    """
                                    State for link\-protection
                                    
                                    .. attribute:: link_protection_style_requested
                                    
                                        Style of mpls frr protection desired\: link, link\-node, or unprotected
                                    
                                        **type**:  :py:class:`PROTECTIONTYPE<ydk.models.openconfig.openconfig_mpls_types.PROTECTIONTYPE>`
                                    
                                        **config**: False
                                    
                                        **default value**: oc-mplst:LINK_NODE_PROTECTION_REQUESTED
                                    
                                    .. attribute:: bypass_optimize_interval
                                    
                                        interval between periodic optimization of the bypass LSPs
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                        **units**: seconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "protection"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('link_protection_style_requested', (YLeaf(YType.identityref, 'link-protection-style-requested'), [('ydk.models.openconfig.openconfig_mpls_types', 'PROTECTIONTYPE')])),
                                            ('bypass_optimize_interval', (YLeaf(YType.uint16, 'bypass-optimize-interval'), ['int'])),
                                        ])
                                        self.link_protection_style_requested = None
                                        self.bypass_optimize_interval = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.InterfaceAttributes.Interface.Protection.State, ['link_protection_style_requested', 'bypass_optimize_interval'], name, value)






                class Ldp(_Entity_):
                    """
                    LDP global signaling configuration
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "ldp"
                        self.yang_parent_name = "signaling-protocols"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict()
                        self._segment_path = lambda: "ldp"
                        self._is_frozen = True


                class SegmentRouting(_Entity_):
                    """
                    MPLS\-specific Segment Routing configuration and operational state
                    parameters
                    
                    .. attribute:: aggregate_sid_counters
                    
                        Per\-SID counters aggregated across all interfaces on the local system
                    
                        **type**:  :py:class:`AggregateSidCounters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters>`
                    
                    .. attribute:: interfaces
                    
                        Interface related Segment Routing parameters
                    
                        **type**:  :py:class:`Interfaces<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "segment-routing"
                        self.yang_parent_name = "signaling-protocols"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aggregate-sid-counters", ("aggregate_sid_counters", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters)), ("interfaces", ("interfaces", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces))])
                        self._leafs = OrderedDict()

                        self.aggregate_sid_counters = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters()
                        self.aggregate_sid_counters.parent = self
                        self._children_name_map["aggregate_sid_counters"] = "aggregate-sid-counters"

                        self.interfaces = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                        self._segment_path = lambda: "segment-routing"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting, [], name, value)

                    class AggregateSidCounters(_Entity_):
                        """
                        Per\-SID counters aggregated across all interfaces on the local system
                        
                        .. attribute:: aggregate_sid_counter
                        
                            Counters aggregated across all of the interfaces of the local system corresponding to traffic received or forwarded with a particular SID
                        
                            **type**: list of    :py:class:`AggregateSidCounter<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "aggregate-sid-counters"
                            self.yang_parent_name = "segment-routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("aggregate-sid-counter", ("aggregate_sid_counter", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter))])
                            self._leafs = OrderedDict()

                            self.aggregate_sid_counter = YList(self)
                            self._segment_path = lambda: "aggregate-sid-counters"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters, [], name, value)

                        class AggregateSidCounter(_Entity_):
                            """
                            Counters aggregated across all of the interfaces of the local
                            system corresponding to traffic received or forwarded with a
                            particular SID
                            
                            .. attribute:: mpls_label  (key)
                            
                                The MPLS label representing the segment identifier
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 16..1048575
                            
                                    **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                            
                                **refers to**:  :py:class:`mpls_label<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter.State>`
                            
                                **config**: False
                            
                            .. attribute:: state
                            
                                State parameters for per\-SID statistics
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "aggregate-sid-counter"
                                self.yang_parent_name = "aggregate-sid-counters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['mpls_label']
                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter.State))])
                                self._leafs = OrderedDict([
                                    ('mpls_label', (YLeaf(YType.str, 'mpls-label'), ['str'])),
                                ])
                                self.mpls_label = None

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "aggregate-sid-counter" + "[mpls-label='" + str(self.mpls_label) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter, ['mpls_label'], name, value)

                            class State(_Entity_):
                                """
                                State parameters for per\-SID statistics
                                
                                .. attribute:: mpls_label
                                
                                    The MPLS label used for the segment identifier
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: in_pkts
                                
                                    A cumulative counter of the packets received within the context which have matched a label corresponding to an SR Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_octets
                                
                                    The cumulative counter of the total bytes received within the context which have matched a label corresponding to an SR Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_pkts
                                
                                    A cumulative counter of the total number of packets transmitted by the local system within the context which have a label imposed that corresponds to an Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_octets
                                
                                    A cumulative counter of the total bytes transmitted by the local system within the context which have a label imported that corresponds to an SR Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "aggregate-sid-counter"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('mpls_label', (YLeaf(YType.str, 'mpls-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('in_pkts', (YLeaf(YType.uint64, 'in-pkts'), ['int'])),
                                        ('in_octets', (YLeaf(YType.uint64, 'in-octets'), ['int'])),
                                        ('out_pkts', (YLeaf(YType.uint64, 'out-pkts'), ['int'])),
                                        ('out_octets', (YLeaf(YType.uint64, 'out-octets'), ['int'])),
                                    ])
                                    self.mpls_label = None
                                    self.in_pkts = None
                                    self.in_octets = None
                                    self.out_pkts = None
                                    self.out_octets = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.AggregateSidCounters.AggregateSidCounter.State, ['mpls_label', 'in_pkts', 'in_octets', 'out_pkts', 'out_octets'], name, value)




                    class Interfaces(_Entity_):
                        """
                        Interface related Segment Routing parameters.
                        
                        .. attribute:: interface
                        
                            Parameters and MPLS\-specific configuration relating to Segment Routing on an interface
                        
                            **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "interfaces"
                            self.yang_parent_name = "segment-routing"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces, [], name, value)

                        class Interface(_Entity_):
                            """
                            Parameters and MPLS\-specific configuration relating to Segment
                            Routing on an interface.
                            
                            .. attribute:: interface_id  (key)
                            
                                A reference to the ID for the interface for which SR is configured
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`interface_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.Config>`
                            
                            .. attribute:: config
                            
                                MPLS\-specific Segment Routing configuration parameters related to an interface
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.Config>`
                            
                            .. attribute:: state
                            
                                MPLS\-specific Segment Routing operational state parameters related to an interface
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.State>`
                            
                                **config**: False
                            
                            .. attribute:: sid_counters
                            
                                Per\-SID statistics for MPLS
                            
                                **type**:  :py:class:`SidCounters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters>`
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_id']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.State)), ("sid-counters", ("sid_counters", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                ])
                                self.interface_id = None

                                self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.sid_counters = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters()
                                self.sid_counters.parent = self
                                self._children_name_map["sid_counters"] = "sid-counters"

                                self.interface_ref = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "interface" + "[interface-id='" + str(self.interface_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface, ['interface_id'], name, value)

                            class Config(_Entity_):
                                """
                                MPLS\-specific Segment Routing configuration parameters
                                related to an interface.
                                
                                .. attribute:: interface_id
                                
                                    A unique identifier for the interface
                                
                                    **type**: str
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                    ])
                                    self.interface_id = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.Config, ['interface_id'], name, value)


                            class State(_Entity_):
                                """
                                MPLS\-specific Segment Routing operational state parameters
                                related to an interface.
                                
                                .. attribute:: interface_id
                                
                                    A unique identifier for the interface
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: in_pkts
                                
                                    A cumulative counter of the packets received within the context which have matched a label corresponding to an SR Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: in_octets
                                
                                    The cumulative counter of the total bytes received within the context which have matched a label corresponding to an SR Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_pkts
                                
                                    A cumulative counter of the total number of packets transmitted by the local system within the context which have a label imposed that corresponds to an Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: out_octets
                                
                                    A cumulative counter of the total bytes transmitted by the local system within the context which have a label imported that corresponds to an SR Segment Identifier
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                        ('in_pkts', (YLeaf(YType.uint64, 'in-pkts'), ['int'])),
                                        ('in_octets', (YLeaf(YType.uint64, 'in-octets'), ['int'])),
                                        ('out_pkts', (YLeaf(YType.uint64, 'out-pkts'), ['int'])),
                                        ('out_octets', (YLeaf(YType.uint64, 'out-octets'), ['int'])),
                                    ])
                                    self.interface_id = None
                                    self.in_pkts = None
                                    self.in_octets = None
                                    self.out_pkts = None
                                    self.out_octets = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.State, ['interface_id', 'in_pkts', 'in_octets', 'out_pkts', 'out_octets'], name, value)


                            class SidCounters(_Entity_):
                                """
                                Per\-SID statistics for MPLS
                                
                                .. attribute:: sid_counter
                                
                                    Per segment identifier counters for the MPLS dataplane
                                
                                    **type**: list of    :py:class:`SidCounter<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "sid-counters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("sid-counter", ("sid_counter", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter))])
                                    self._leafs = OrderedDict()

                                    self.sid_counter = YList(self)
                                    self._segment_path = lambda: "sid-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters, [], name, value)

                                class SidCounter(_Entity_):
                                    """
                                    Per segment identifier counters for the MPLS dataplane.
                                    
                                    .. attribute:: mpls_label  (key)
                                    
                                        The MPLS label representing the segment identifier
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: int
                                    
                                                **range:** 16..1048575
                                    
                                            **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                    
                                        **refers to**:  :py:class:`mpls_label<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: state
                                    
                                        State parameters for per\-SID statistics
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: forwarding_classes
                                    
                                        Per\-SID per\-forwarding class counters for Segment Routing
                                    
                                        **type**:  :py:class:`ForwardingClasses<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "sid-counter"
                                        self.yang_parent_name = "sid-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['mpls_label']
                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.State)), ("forwarding-classes", ("forwarding_classes", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses))])
                                        self._leafs = OrderedDict([
                                            ('mpls_label', (YLeaf(YType.str, 'mpls-label'), ['str'])),
                                        ])
                                        self.mpls_label = None

                                        self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.forwarding_classes = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses()
                                        self.forwarding_classes.parent = self
                                        self._children_name_map["forwarding_classes"] = "forwarding-classes"
                                        self._segment_path = lambda: "sid-counter" + "[mpls-label='" + str(self.mpls_label) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter, ['mpls_label'], name, value)

                                    class State(_Entity_):
                                        """
                                        State parameters for per\-SID statistics
                                        
                                        .. attribute:: mpls_label
                                        
                                            The MPLS label used for the segment identifier
                                        
                                            **type**: union of the below types:
                                        
                                                **type**: int
                                        
                                                    **range:** 16..1048575
                                        
                                                **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: in_pkts
                                        
                                            A cumulative counter of the packets received within the context which have matched a label corresponding to an SR Segment Identifier
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: in_octets
                                        
                                            The cumulative counter of the total bytes received within the context which have matched a label corresponding to an SR Segment Identifier
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: out_pkts
                                        
                                            A cumulative counter of the total number of packets transmitted by the local system within the context which have a label imposed that corresponds to an Segment Identifier
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: out_octets
                                        
                                            A cumulative counter of the total bytes transmitted by the local system within the context which have a label imported that corresponds to an SR Segment Identifier
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "sid-counter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('mpls_label', (YLeaf(YType.str, 'mpls-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                                ('in_pkts', (YLeaf(YType.uint64, 'in-pkts'), ['int'])),
                                                ('in_octets', (YLeaf(YType.uint64, 'in-octets'), ['int'])),
                                                ('out_pkts', (YLeaf(YType.uint64, 'out-pkts'), ['int'])),
                                                ('out_octets', (YLeaf(YType.uint64, 'out-octets'), ['int'])),
                                            ])
                                            self.mpls_label = None
                                            self.in_pkts = None
                                            self.in_octets = None
                                            self.out_pkts = None
                                            self.out_octets = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.State, ['mpls_label', 'in_pkts', 'in_octets', 'out_pkts', 'out_octets'], name, value)


                                    class ForwardingClasses(_Entity_):
                                        """
                                        Per\-SID per\-forwarding class counters for Segment Routing.
                                        
                                        .. attribute:: forwarding_class
                                        
                                            SID entries for the forwarding class associated with the referenced MPLS EXP
                                        
                                            **type**: list of    :py:class:`ForwardingClass<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "forwarding-classes"
                                            self.yang_parent_name = "sid-counter"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("forwarding-class", ("forwarding_class", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass))])
                                            self._leafs = OrderedDict()

                                            self.forwarding_class = YList(self)
                                            self._segment_path = lambda: "forwarding-classes"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses, [], name, value)

                                        class ForwardingClass(_Entity_):
                                            """
                                            SID entries for the forwarding class associated with the
                                            referenced MPLS EXP.
                                            
                                            .. attribute:: exp  (key)
                                            
                                                Reference to the value of the EXP bits of the segment identifier
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **refers to**:  :py:class:`exp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass.State>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: state
                                            
                                                Per\-SID, per forwarding class counters for Segment Routing with the MPLS dataplane
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "forwarding-class"
                                                self.yang_parent_name = "forwarding-classes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['exp']
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass.State))])
                                                self._leafs = OrderedDict([
                                                    ('exp', (YLeaf(YType.str, 'exp'), ['int'])),
                                                ])
                                                self.exp = None

                                                self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "forwarding-class" + "[exp='" + str(self.exp) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass, ['exp'], name, value)

                                            class State(_Entity_):
                                                """
                                                Per\-SID, per forwarding class counters for Segment Routing
                                                with the MPLS dataplane
                                                
                                                .. attribute:: exp
                                                
                                                    The value of the MPLS EXP (experimental) or Traffic Class bits that the SID statistics relate to. Packets received with a MPLS label value equal to the SID's MPLS label and EXP bits equal to the this value should be counted towards the associated ingress statistics. Packets that are forwarded to the destination MPLS label corresponding to the SID should be counted towards this value. In the egress direction, where forwarding follows a SID value that requires PHP at the local node, packets should still be counted towards the egress counters
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..7
                                                
                                                    **config**: False
                                                
                                                .. attribute:: in_pkts
                                                
                                                    A cumulative counter of the packets received within the context which have matched a label corresponding to an SR Segment Identifier
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..18446744073709551615
                                                
                                                    **config**: False
                                                
                                                .. attribute:: in_octets
                                                
                                                    The cumulative counter of the total bytes received within the context which have matched a label corresponding to an SR Segment Identifier
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..18446744073709551615
                                                
                                                    **config**: False
                                                
                                                .. attribute:: out_pkts
                                                
                                                    A cumulative counter of the total number of packets transmitted by the local system within the context which have a label imposed that corresponds to an Segment Identifier
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..18446744073709551615
                                                
                                                    **config**: False
                                                
                                                .. attribute:: out_octets
                                                
                                                    A cumulative counter of the total bytes transmitted by the local system within the context which have a label imported that corresponds to an SR Segment Identifier
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..18446744073709551615
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "forwarding-class"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('exp', (YLeaf(YType.uint8, 'exp'), ['int'])),
                                                        ('in_pkts', (YLeaf(YType.uint64, 'in-pkts'), ['int'])),
                                                        ('in_octets', (YLeaf(YType.uint64, 'in-octets'), ['int'])),
                                                        ('out_pkts', (YLeaf(YType.uint64, 'out-pkts'), ['int'])),
                                                        ('out_octets', (YLeaf(YType.uint64, 'out-octets'), ['int'])),
                                                    ])
                                                    self.exp = None
                                                    self.in_pkts = None
                                                    self.in_octets = None
                                                    self.out_pkts = None
                                                    self.out_octets = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.SidCounters.SidCounter.ForwardingClasses.ForwardingClass.State, ['exp', 'in_pkts', 'in_octets', 'out_pkts', 'out_octets'], name, value)






                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.SegmentRouting.Interfaces.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)







            class Lsps(_Entity_):
                """
                LSP definitions and configuration
                
                .. attribute:: constrained_path
                
                    traffic\-engineered LSPs supporting different path computation and signaling methods
                
                    **type**:  :py:class:`ConstrainedPath<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath>`
                
                .. attribute:: unconstrained_path
                
                    LSPs that use the IGP\-determined path, i.e., non traffic\-engineered, or non constrained\-path
                
                    **type**:  :py:class:`UnconstrainedPath<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath>`
                
                .. attribute:: static_lsps
                
                    statically configured LSPs, without dynamic signaling
                
                    **type**:  :py:class:`StaticLsps<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "lsps"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("constrained-path", ("constrained_path", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath)), ("unconstrained-path", ("unconstrained_path", NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath)), ("static-lsps", ("static_lsps", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps))])
                    self._leafs = OrderedDict()

                    self.constrained_path = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath()
                    self.constrained_path.parent = self
                    self._children_name_map["constrained_path"] = "constrained-path"

                    self.unconstrained_path = NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath()
                    self.unconstrained_path.parent = self
                    self._children_name_map["unconstrained_path"] = "unconstrained-path"

                    self.static_lsps = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps()
                    self.static_lsps.parent = self
                    self._children_name_map["static_lsps"] = "static-lsps"
                    self._segment_path = lambda: "lsps"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps, [], name, value)

                class ConstrainedPath(_Entity_):
                    """
                    traffic\-engineered LSPs supporting different
                    path computation and signaling methods
                    
                    .. attribute:: named_explicit_paths
                    
                        Enclosing container for the named explicit paths
                    
                        **type**:  :py:class:`NamedExplicitPaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths>`
                    
                    .. attribute:: tunnels
                    
                        Enclosing container for tunnels
                    
                        **type**:  :py:class:`Tunnels<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "constrained-path"
                        self.yang_parent_name = "lsps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("named-explicit-paths", ("named_explicit_paths", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths)), ("tunnels", ("tunnels", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels))])
                        self._leafs = OrderedDict()

                        self.named_explicit_paths = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths()
                        self.named_explicit_paths.parent = self
                        self._children_name_map["named_explicit_paths"] = "named-explicit-paths"

                        self.tunnels = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels()
                        self.tunnels.parent = self
                        self._children_name_map["tunnels"] = "tunnels"
                        self._segment_path = lambda: "constrained-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath, [], name, value)

                    class NamedExplicitPaths(_Entity_):
                        """
                        Enclosing container for the named explicit paths
                        
                        .. attribute:: named_explicit_path
                        
                            A list of explicit paths
                        
                            **type**: list of    :py:class:`NamedExplicitPath<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "named-explicit-paths"
                            self.yang_parent_name = "constrained-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("named-explicit-path", ("named_explicit_path", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath))])
                            self._leafs = OrderedDict()

                            self.named_explicit_path = YList(self)
                            self._segment_path = lambda: "named-explicit-paths"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths, [], name, value)

                        class NamedExplicitPath(_Entity_):
                            """
                            A list of explicit paths
                            
                            .. attribute:: name  (key)
                            
                                A string name that uniquely identifies an explicit path
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to named explicit paths
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the named explicit paths
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.State>`
                            
                                **config**: False
                            
                            .. attribute:: explicit_route_objects
                            
                                Enclosing container for EROs
                            
                                **type**:  :py:class:`ExplicitRouteObjects<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "named-explicit-path"
                                self.yang_parent_name = "named-explicit-paths"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.State)), ("explicit-route-objects", ("explicit_route_objects", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.explicit_route_objects = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects()
                                self.explicit_route_objects.parent = self
                                self._children_name_map["explicit_route_objects"] = "explicit-route-objects"
                                self._segment_path = lambda: "named-explicit-path" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath, ['name'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to named explicit
                                paths
                                
                                .. attribute:: name
                                
                                    A string name that uniquely identifies an explicit path
                                
                                    **type**: str
                                
                                .. attribute:: sid_selection_mode
                                
                                    The restrictions placed on the SIDs to be selected by the calculation method for the explicit path when it is instantiated for a SR\-TE LSP
                                
                                    **type**:  :py:class:`SidSelectionMode<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config.SidSelectionMode>`
                                
                                    **default value**: MIXED_MODE
                                
                                .. attribute:: sid_protection_required
                                
                                    When this value is set to true, only SIDs that are protected are to be selected by the calculating method when the explicit path is instantiated by a SR\-TE LSP
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "named-explicit-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('sid_selection_mode', (YLeaf(YType.enumeration, 'sid-selection-mode'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config.SidSelectionMode')])),
                                        ('sid_protection_required', (YLeaf(YType.boolean, 'sid-protection-required'), ['bool'])),
                                    ])
                                    self.name = None
                                    self.sid_selection_mode = None
                                    self.sid_protection_required = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config, ['name', 'sid_selection_mode', 'sid_protection_required'], name, value)

                                class SidSelectionMode(Enum):
                                    """
                                    SidSelectionMode (Enum Class)

                                    .. data:: ADJ_SID_ONLY = 0

                                        The SR-TE tunnel should only use adjacency SIDs

                                        to build the SID stack to be pushed for the LSP

                                    .. data:: MIXED_MODE = 1

                                        The SR-TE tunnel can use a mix of adjacency

                                        and prefix SIDs to build the SID stack to be pushed

                                        to the LSP

                                    """

                                    ADJ_SID_ONLY = Enum.YLeaf(0, "ADJ_SID_ONLY")

                                    MIXED_MODE = Enum.YLeaf(1, "MIXED_MODE")



                            class State(_Entity_):
                                """
                                Operational state parameters relating to the named
                                explicit paths
                                
                                .. attribute:: name
                                
                                    A string name that uniquely identifies an explicit path
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: sid_selection_mode
                                
                                    The restrictions placed on the SIDs to be selected by the calculation method for the explicit path when it is instantiated for a SR\-TE LSP
                                
                                    **type**:  :py:class:`SidSelectionMode<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.State.SidSelectionMode>`
                                
                                    **config**: False
                                
                                    **default value**: MIXED_MODE
                                
                                .. attribute:: sid_protection_required
                                
                                    When this value is set to true, only SIDs that are protected are to be selected by the calculating method when the explicit path is instantiated by a SR\-TE LSP
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "named-explicit-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('sid_selection_mode', (YLeaf(YType.enumeration, 'sid-selection-mode'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.State.SidSelectionMode')])),
                                        ('sid_protection_required', (YLeaf(YType.boolean, 'sid-protection-required'), ['bool'])),
                                    ])
                                    self.name = None
                                    self.sid_selection_mode = None
                                    self.sid_protection_required = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.State, ['name', 'sid_selection_mode', 'sid_protection_required'], name, value)

                                class SidSelectionMode(Enum):
                                    """
                                    SidSelectionMode (Enum Class)

                                    .. data:: ADJ_SID_ONLY = 0

                                        The SR-TE tunnel should only use adjacency SIDs

                                        to build the SID stack to be pushed for the LSP

                                    .. data:: MIXED_MODE = 1

                                        The SR-TE tunnel can use a mix of adjacency

                                        and prefix SIDs to build the SID stack to be pushed

                                        to the LSP

                                    """

                                    ADJ_SID_ONLY = Enum.YLeaf(0, "ADJ_SID_ONLY")

                                    MIXED_MODE = Enum.YLeaf(1, "MIXED_MODE")



                            class ExplicitRouteObjects(_Entity_):
                                """
                                Enclosing container for EROs
                                
                                .. attribute:: explicit_route_object
                                
                                    List of explicit route objects
                                
                                    **type**: list of    :py:class:`ExplicitRouteObject<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "explicit-route-objects"
                                    self.yang_parent_name = "named-explicit-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("explicit-route-object", ("explicit_route_object", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject))])
                                    self._leafs = OrderedDict()

                                    self.explicit_route_object = YList(self)
                                    self._segment_path = lambda: "explicit-route-objects"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects, [], name, value)

                                class ExplicitRouteObject(_Entity_):
                                    """
                                    List of explicit route objects
                                    
                                    .. attribute:: index  (key)
                                    
                                        Index of this explicit route object, to express the order of hops in path
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.Config>`
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to an explicit route
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State parameters relating to an explicit route
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "explicit-route-object"
                                        self.yang_parent_name = "explicit-route-objects"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['index']
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.State))])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                        ])
                                        self.index = None

                                        self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "explicit-route-object" + "[index='" + str(self.index) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject, ['index'], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to an explicit
                                        route
                                        
                                        .. attribute:: address
                                        
                                            router hop for the LSP path
                                        
                                            **type**: union of the below types:
                                        
                                                **type**: str
                                        
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                        
                                                **type**: str
                                        
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                        
                                        .. attribute:: hop_type
                                        
                                            strict or loose hop
                                        
                                            **type**:  :py:class:`MplsHopType<ydk.models.openconfig.openconfig_mpls.MplsHopType>`
                                        
                                        .. attribute:: index
                                        
                                            Index of this explicit route object to express the order of hops in the path
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "explicit-route-object"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                                ('hop_type', (YLeaf(YType.enumeration, 'hop-type'), [('ydk.models.openconfig.openconfig_mpls', 'MplsHopType', '')])),
                                                ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                            ])
                                            self.address = None
                                            self.hop_type = None
                                            self.index = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.Config, ['address', 'hop_type', 'index'], name, value)


                                    class State(_Entity_):
                                        """
                                        State parameters relating to an explicit route
                                        
                                        .. attribute:: address
                                        
                                            router hop for the LSP path
                                        
                                            **type**: union of the below types:
                                        
                                                **type**: str
                                        
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                        
                                                **type**: str
                                        
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                        
                                            **config**: False
                                        
                                        .. attribute:: hop_type
                                        
                                            strict or loose hop
                                        
                                            **type**:  :py:class:`MplsHopType<ydk.models.openconfig.openconfig_mpls.MplsHopType>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: index
                                        
                                            Index of this explicit route object to express the order of hops in the path
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "explicit-route-object"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('address', (YLeaf(YType.str, 'address'), ['str','str'])),
                                                ('hop_type', (YLeaf(YType.enumeration, 'hop-type'), [('ydk.models.openconfig.openconfig_mpls', 'MplsHopType', '')])),
                                                ('index', (YLeaf(YType.uint8, 'index'), ['int'])),
                                            ])
                                            self.address = None
                                            self.hop_type = None
                                            self.index = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.ExplicitRouteObjects.ExplicitRouteObject.State, ['address', 'hop_type', 'index'], name, value)






                    class Tunnels(_Entity_):
                        """
                        Enclosing container for tunnels
                        
                        .. attribute:: tunnel
                        
                            List of TE tunnels. This list contains only the LSPs that the current device originates (i.e., for which it is the head\-end). Where the signaling protocol utilised for an LSP allows a mid\-point or tail device to be aware of the LSP (e.g., RSVP\-TE), then the associated sessions are maintained per protocol
                        
                            **type**: list of    :py:class:`Tunnel<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "tunnels"
                            self.yang_parent_name = "constrained-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("tunnel", ("tunnel", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel))])
                            self._leafs = OrderedDict()

                            self.tunnel = YList(self)
                            self._segment_path = lambda: "tunnels"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels, [], name, value)

                        class Tunnel(_Entity_):
                            """
                            List of TE tunnels. This list contains only the LSPs that the
                            current device originates (i.e., for which it is the head\-end).
                            Where the signaling protocol utilised for an LSP allows a mid\-point
                            or tail device to be aware of the LSP (e.g., RSVP\-TE), then the
                            associated sessions are maintained per protocol
                            
                            .. attribute:: name  (key)
                            
                                The tunnel name
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters related to TE tunnels\:
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Config>`
                            
                            .. attribute:: state
                            
                                State parameters related to TE tunnels
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State>`
                            
                                **config**: False
                            
                            .. attribute:: bandwidth
                            
                                Bandwidth configuration for TE LSPs
                            
                                **type**:  :py:class:`Bandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth>`
                            
                            .. attribute:: p2p_tunnel_attributes
                            
                                Parameters related to LSPs of type P2P
                            
                                **type**:  :py:class:`P2pTunnelAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "tunnel"
                                self.yang_parent_name = "tunnels"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['name']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State)), ("bandwidth", ("bandwidth", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth)), ("p2p-tunnel-attributes", ("p2p_tunnel_attributes", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes))])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None

                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.bandwidth = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth()
                                self.bandwidth.parent = self
                                self._children_name_map["bandwidth"] = "bandwidth"

                                self.p2p_tunnel_attributes = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes()
                                self.p2p_tunnel_attributes.parent = self
                                self._children_name_map["p2p_tunnel_attributes"] = "p2p-tunnel-attributes"
                                self._segment_path = lambda: "tunnel" + "[name='" + str(self.name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel, ['name'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters related to TE tunnels\:
                                
                                .. attribute:: name
                                
                                    The tunnel name
                                
                                    **type**: str
                                
                                .. attribute:: type
                                
                                    Tunnel type, p2p or p2mp
                                
                                    **type**:  :py:class:`TUNNELTYPE<ydk.models.openconfig.openconfig_mpls_types.TUNNELTYPE>`
                                
                                .. attribute:: signaling_protocol
                                
                                    Signaling protocol used to set up this tunnel
                                
                                    **type**:  :py:class:`PATHSETUPPROTOCOL<ydk.models.openconfig.openconfig_mpls_types.PATHSETUPPROTOCOL>`
                                
                                .. attribute:: description
                                
                                    optional text description for the tunnel
                                
                                    **type**: str
                                
                                .. attribute:: admin_status
                                
                                    TE tunnel administrative state
                                
                                    **type**:  :py:class:`TUNNELADMINSTATUS<ydk.models.openconfig.openconfig_mpls_types.TUNNELADMINSTATUS>`
                                
                                    **default value**: oc-mplst:ADMIN_UP
                                
                                .. attribute:: preference
                                
                                    Specifies a preference for this tunnel. A lower number signifies a better preference
                                
                                    **type**: int
                                
                                        **range:** 1..255
                                
                                .. attribute:: metric_type
                                
                                    The type of metric specification that should be used to set the LSP(s) metric
                                
                                    **type**:  :py:class:`LSPMETRICTYPE<ydk.models.openconfig.openconfig_mpls_types.LSPMETRICTYPE>`
                                
                                    **default value**: oc-mplst:LSP_METRIC_INHERITED
                                
                                .. attribute:: metric
                                
                                    The value of the metric that should be specified. The value supplied in this leaf is used in conjunction with the metric type to determine the value of the metric used by the system. Where the metric\-type is set to LSP\_METRIC\_ABSOLUTE \- the value of this leaf is used directly; where it is set to LSP\_METRIC\_RELATIVE, the relevant (positive or negative) offset is used to formulate the metric; where metric\-type is LSP\_METRIC\_INHERITED, the value of this leaf is not utilised
                                
                                    **type**: int
                                
                                        **range:** \-2147483648..2147483647
                                
                                .. attribute:: shortcut_eligible
                                
                                    Whether this LSP is considered to be eligible for us as a shortcut in the IGP. In the case that this leaf is set to true, the IGP SPF calculation uses the metric specified to determine whether traffic should be carried over this LSP
                                
                                    **type**: bool
                                
                                    **default value**: true
                                
                                .. attribute:: protection_style_requested
                                
                                    style of mpls frr protection desired\: can be link, link\-node or unprotected
                                
                                    **type**:  :py:class:`PROTECTIONTYPE<ydk.models.openconfig.openconfig_mpls_types.PROTECTIONTYPE>`
                                
                                    **default value**: oc-mplst:UNPROTECTED
                                
                                .. attribute:: reoptimize_timer
                                
                                    frequency of reoptimization of a traffic engineered LSP
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **units**: seconds
                                
                                .. attribute:: source
                                
                                    RSVP\-TE tunnel source address
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                .. attribute:: soft_preemption
                                
                                    Enables RSVP soft\-preemption on this LSP
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: setup_priority
                                
                                    RSVP\-TE preemption priority during LSP setup, lower is higher priority; default 7 indicates that LSP will not preempt established LSPs during setup
                                
                                    **type**: int
                                
                                        **range:** 0..7
                                
                                    **default value**: 7
                                
                                .. attribute:: hold_priority
                                
                                    preemption priority once the LSP is established, lower is higher priority; default 0 indicates other LSPs will not preempt the LSPs once established
                                
                                    **type**: int
                                
                                        **range:** 0..7
                                
                                    **default value**: 0
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "tunnel"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_mpls_types', 'TUNNELTYPE')])),
                                        ('signaling_protocol', (YLeaf(YType.identityref, 'signaling-protocol'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPPROTOCOL')])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('admin_status', (YLeaf(YType.identityref, 'admin-status'), [('ydk.models.openconfig.openconfig_mpls_types', 'TUNNELADMINSTATUS')])),
                                        ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                                        ('metric_type', (YLeaf(YType.identityref, 'metric-type'), [('ydk.models.openconfig.openconfig_mpls_types', 'LSPMETRICTYPE')])),
                                        ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                        ('shortcut_eligible', (YLeaf(YType.boolean, 'shortcut-eligible'), ['bool'])),
                                        ('protection_style_requested', (YLeaf(YType.identityref, 'protection-style-requested'), [('ydk.models.openconfig.openconfig_mpls_types', 'PROTECTIONTYPE')])),
                                        ('reoptimize_timer', (YLeaf(YType.uint16, 'reoptimize-timer'), ['int'])),
                                        ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                                        ('soft_preemption', (YLeaf(YType.boolean, 'soft-preemption'), ['bool'])),
                                        ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                        ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                    ])
                                    self.name = None
                                    self.type = None
                                    self.signaling_protocol = None
                                    self.description = None
                                    self.admin_status = None
                                    self.preference = None
                                    self.metric_type = None
                                    self.metric = None
                                    self.shortcut_eligible = None
                                    self.protection_style_requested = None
                                    self.reoptimize_timer = None
                                    self.source = None
                                    self.soft_preemption = None
                                    self.setup_priority = None
                                    self.hold_priority = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Config, ['name', 'type', 'signaling_protocol', 'description', 'admin_status', 'preference', 'metric_type', 'metric', 'shortcut_eligible', 'protection_style_requested', 'reoptimize_timer', 'source', 'soft_preemption', 'setup_priority', 'hold_priority'], name, value)


                            class State(_Entity_):
                                """
                                State parameters related to TE tunnels
                                
                                .. attribute:: name
                                
                                    The tunnel name
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: type
                                
                                    Tunnel type, p2p or p2mp
                                
                                    **type**:  :py:class:`TUNNELTYPE<ydk.models.openconfig.openconfig_mpls_types.TUNNELTYPE>`
                                
                                    **config**: False
                                
                                .. attribute:: signaling_protocol
                                
                                    Signaling protocol used to set up this tunnel
                                
                                    **type**:  :py:class:`PATHSETUPPROTOCOL<ydk.models.openconfig.openconfig_mpls_types.PATHSETUPPROTOCOL>`
                                
                                    **config**: False
                                
                                .. attribute:: description
                                
                                    optional text description for the tunnel
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: admin_status
                                
                                    TE tunnel administrative state
                                
                                    **type**:  :py:class:`TUNNELADMINSTATUS<ydk.models.openconfig.openconfig_mpls_types.TUNNELADMINSTATUS>`
                                
                                    **config**: False
                                
                                    **default value**: oc-mplst:ADMIN_UP
                                
                                .. attribute:: preference
                                
                                    Specifies a preference for this tunnel. A lower number signifies a better preference
                                
                                    **type**: int
                                
                                        **range:** 1..255
                                
                                    **config**: False
                                
                                .. attribute:: metric_type
                                
                                    The type of metric specification that should be used to set the LSP(s) metric
                                
                                    **type**:  :py:class:`LSPMETRICTYPE<ydk.models.openconfig.openconfig_mpls_types.LSPMETRICTYPE>`
                                
                                    **config**: False
                                
                                    **default value**: oc-mplst:LSP_METRIC_INHERITED
                                
                                .. attribute:: metric
                                
                                    The value of the metric that should be specified. The value supplied in this leaf is used in conjunction with the metric type to determine the value of the metric used by the system. Where the metric\-type is set to LSP\_METRIC\_ABSOLUTE \- the value of this leaf is used directly; where it is set to LSP\_METRIC\_RELATIVE, the relevant (positive or negative) offset is used to formulate the metric; where metric\-type is LSP\_METRIC\_INHERITED, the value of this leaf is not utilised
                                
                                    **type**: int
                                
                                        **range:** \-2147483648..2147483647
                                
                                    **config**: False
                                
                                .. attribute:: shortcut_eligible
                                
                                    Whether this LSP is considered to be eligible for us as a shortcut in the IGP. In the case that this leaf is set to true, the IGP SPF calculation uses the metric specified to determine whether traffic should be carried over this LSP
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: true
                                
                                .. attribute:: protection_style_requested
                                
                                    style of mpls frr protection desired\: can be link, link\-node or unprotected
                                
                                    **type**:  :py:class:`PROTECTIONTYPE<ydk.models.openconfig.openconfig_mpls_types.PROTECTIONTYPE>`
                                
                                    **config**: False
                                
                                    **default value**: oc-mplst:UNPROTECTED
                                
                                .. attribute:: reoptimize_timer
                                
                                    frequency of reoptimization of a traffic engineered LSP
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                    **units**: seconds
                                
                                .. attribute:: source
                                
                                    RSVP\-TE tunnel source address
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: soft_preemption
                                
                                    Enables RSVP soft\-preemption on this LSP
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: setup_priority
                                
                                    RSVP\-TE preemption priority during LSP setup, lower is higher priority; default 7 indicates that LSP will not preempt established LSPs during setup
                                
                                    **type**: int
                                
                                        **range:** 0..7
                                
                                    **config**: False
                                
                                    **default value**: 7
                                
                                .. attribute:: hold_priority
                                
                                    preemption priority once the LSP is established, lower is higher priority; default 0 indicates other LSPs will not preempt the LSPs once established
                                
                                    **type**: int
                                
                                        **range:** 0..7
                                
                                    **config**: False
                                
                                    **default value**: 0
                                
                                .. attribute:: oper_status
                                
                                    The operational status of the TE tunnel
                                
                                    **type**:  :py:class:`LSPOPERSTATUS<ydk.models.openconfig.openconfig_mpls_types.LSPOPERSTATUS>`
                                
                                    **config**: False
                                
                                .. attribute:: role
                                
                                    The lsp role at the current node, whether it is headend, transit or tailend
                                
                                    **type**:  :py:class:`LSPROLE<ydk.models.openconfig.openconfig_mpls_types.LSPROLE>`
                                
                                    **config**: False
                                
                                .. attribute:: counters
                                
                                    State data for MPLS label switched paths. This state data is specific to a single label switched path
                                
                                    **type**:  :py:class:`Counters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State.Counters>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "tunnel"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("counters", ("counters", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State.Counters))])
                                    self._leafs = OrderedDict([
                                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_mpls_types', 'TUNNELTYPE')])),
                                        ('signaling_protocol', (YLeaf(YType.identityref, 'signaling-protocol'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPPROTOCOL')])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('admin_status', (YLeaf(YType.identityref, 'admin-status'), [('ydk.models.openconfig.openconfig_mpls_types', 'TUNNELADMINSTATUS')])),
                                        ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                                        ('metric_type', (YLeaf(YType.identityref, 'metric-type'), [('ydk.models.openconfig.openconfig_mpls_types', 'LSPMETRICTYPE')])),
                                        ('metric', (YLeaf(YType.int32, 'metric'), ['int'])),
                                        ('shortcut_eligible', (YLeaf(YType.boolean, 'shortcut-eligible'), ['bool'])),
                                        ('protection_style_requested', (YLeaf(YType.identityref, 'protection-style-requested'), [('ydk.models.openconfig.openconfig_mpls_types', 'PROTECTIONTYPE')])),
                                        ('reoptimize_timer', (YLeaf(YType.uint16, 'reoptimize-timer'), ['int'])),
                                        ('source', (YLeaf(YType.str, 'source'), ['str','str'])),
                                        ('soft_preemption', (YLeaf(YType.boolean, 'soft-preemption'), ['bool'])),
                                        ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                        ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                        ('oper_status', (YLeaf(YType.identityref, 'oper-status'), [('ydk.models.openconfig.openconfig_mpls_types', 'LSPOPERSTATUS')])),
                                        ('role', (YLeaf(YType.identityref, 'role'), [('ydk.models.openconfig.openconfig_mpls_types', 'LSPROLE')])),
                                    ])
                                    self.name = None
                                    self.type = None
                                    self.signaling_protocol = None
                                    self.description = None
                                    self.admin_status = None
                                    self.preference = None
                                    self.metric_type = None
                                    self.metric = None
                                    self.shortcut_eligible = None
                                    self.protection_style_requested = None
                                    self.reoptimize_timer = None
                                    self.source = None
                                    self.soft_preemption = None
                                    self.setup_priority = None
                                    self.hold_priority = None
                                    self.oper_status = None
                                    self.role = None

                                    self.counters = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State.Counters()
                                    self.counters.parent = self
                                    self._children_name_map["counters"] = "counters"
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State, ['name', 'type', 'signaling_protocol', 'description', 'admin_status', 'preference', 'metric_type', 'metric', 'shortcut_eligible', 'protection_style_requested', 'reoptimize_timer', 'source', 'soft_preemption', 'setup_priority', 'hold_priority', 'oper_status', 'role'], name, value)

                                class Counters(_Entity_):
                                    """
                                    State data for MPLS label switched paths. This state
                                    data is specific to a single label switched path.
                                    
                                    .. attribute:: bytes
                                    
                                        Number of bytes that have been forwarded over the label switched path
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: packets
                                    
                                        Number of pacets that have been forwarded over the label switched path
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: path_changes
                                    
                                        Number of path changes for the label switched path
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: state_changes
                                    
                                        Number of state changes for the label switched path
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: online_time
                                    
                                        Indication of the time the label switched path transitioned to an Oper Up or in\-service state
                                    
                                        **type**: str
                                    
                                            **pattern:** ^[0\-9]{4}\\\-[0\-9]{2}\\\-[0\-9]{2}T[0\-9]{2}\:[0\-9]{2}\:[0\-9]{2}(\\.[0\-9]+)?Z[+\-][0\-9]{2}\:[0\-9]{2}$
                                    
                                        **config**: False
                                    
                                    .. attribute:: current_path_time
                                    
                                        Indicates the time the LSP switched onto its current path. This is reset upon a LSP path change
                                    
                                        **type**: str
                                    
                                            **pattern:** ^[0\-9]{4}\\\-[0\-9]{2}\\\-[0\-9]{2}T[0\-9]{2}\:[0\-9]{2}\:[0\-9]{2}(\\.[0\-9]+)?Z[+\-][0\-9]{2}\:[0\-9]{2}$
                                    
                                        **config**: False
                                    
                                    .. attribute:: next_reoptimization_time
                                    
                                        Indicates the next scheduled time the LSP will be reoptimized
                                    
                                        **type**: str
                                    
                                            **pattern:** ^[0\-9]{4}\\\-[0\-9]{2}\\\-[0\-9]{2}T[0\-9]{2}\:[0\-9]{2}\:[0\-9]{2}(\\.[0\-9]+)?Z[+\-][0\-9]{2}\:[0\-9]{2}$
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "counters"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bytes', (YLeaf(YType.uint64, 'bytes'), ['int'])),
                                            ('packets', (YLeaf(YType.uint64, 'packets'), ['int'])),
                                            ('path_changes', (YLeaf(YType.uint64, 'path-changes'), ['int'])),
                                            ('state_changes', (YLeaf(YType.uint64, 'state-changes'), ['int'])),
                                            ('online_time', (YLeaf(YType.str, 'online-time'), ['str'])),
                                            ('current_path_time', (YLeaf(YType.str, 'current-path-time'), ['str'])),
                                            ('next_reoptimization_time', (YLeaf(YType.str, 'next-reoptimization-time'), ['str'])),
                                        ])
                                        self.bytes = None
                                        self.packets = None
                                        self.path_changes = None
                                        self.state_changes = None
                                        self.online_time = None
                                        self.current_path_time = None
                                        self.next_reoptimization_time = None
                                        self._segment_path = lambda: "counters"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.State.Counters, ['bytes', 'packets', 'path_changes', 'state_changes', 'online_time', 'current_path_time', 'next_reoptimization_time'], name, value)



                            class Bandwidth(_Entity_):
                                """
                                Bandwidth configuration for TE LSPs
                                
                                .. attribute:: config
                                
                                    Configuration parameters related to bandwidth on TE tunnels\:
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.Config>`
                                
                                .. attribute:: state
                                
                                    State parameters related to bandwidth configuration of TE tunnels
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.State>`
                                
                                    **config**: False
                                
                                .. attribute:: auto_bandwidth
                                
                                    Parameters related to auto\-bandwidth
                                
                                    **type**:  :py:class:`AutoBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "bandwidth"
                                    self.yang_parent_name = "tunnel"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.State)), ("auto-bandwidth", ("auto_bandwidth", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.auto_bandwidth = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth()
                                    self.auto_bandwidth.parent = self
                                    self._children_name_map["auto_bandwidth"] = "auto-bandwidth"
                                    self._segment_path = lambda: "bandwidth"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters related to bandwidth on TE
                                    tunnels\:
                                    
                                    .. attribute:: specification_type
                                    
                                        The method used for settign the bandwidth, either explicitly specified or configured
                                    
                                        **type**:  :py:class:`TeBandwidthType<ydk.models.openconfig.openconfig_mpls.TeBandwidthType>`
                                    
                                        **default value**: SPECIFIED
                                    
                                    .. attribute:: set_bandwidth
                                    
                                        set bandwidth explicitly, e.g., using offline calculation
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "bandwidth"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('specification_type', (YLeaf(YType.enumeration, 'specification-type'), [('ydk.models.openconfig.openconfig_mpls', 'TeBandwidthType', '')])),
                                            ('set_bandwidth', (YLeaf(YType.uint64, 'set-bandwidth'), ['int'])),
                                        ])
                                        self.specification_type = None
                                        self.set_bandwidth = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.Config, ['specification_type', 'set_bandwidth'], name, value)


                                class State(_Entity_):
                                    """
                                    State parameters related to bandwidth
                                    configuration of TE tunnels
                                    
                                    .. attribute:: specification_type
                                    
                                        The method used for settign the bandwidth, either explicitly specified or configured
                                    
                                        **type**:  :py:class:`TeBandwidthType<ydk.models.openconfig.openconfig_mpls.TeBandwidthType>`
                                    
                                        **config**: False
                                    
                                        **default value**: SPECIFIED
                                    
                                    .. attribute:: set_bandwidth
                                    
                                        set bandwidth explicitly, e.g., using offline calculation
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    .. attribute:: signaled_bandwidth
                                    
                                        The currently signaled bandwidth of the LSP. In the case where the bandwidth is specified explicitly, then this will match the value of the set\-bandwidth leaf; in cases where the bandwidth is dynamically computed by the system, the current value of the bandwidth should be reflected
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "bandwidth"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('specification_type', (YLeaf(YType.enumeration, 'specification-type'), [('ydk.models.openconfig.openconfig_mpls', 'TeBandwidthType', '')])),
                                            ('set_bandwidth', (YLeaf(YType.uint64, 'set-bandwidth'), ['int'])),
                                            ('signaled_bandwidth', (YLeaf(YType.uint64, 'signaled-bandwidth'), ['int'])),
                                        ])
                                        self.specification_type = None
                                        self.set_bandwidth = None
                                        self.signaled_bandwidth = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.State, ['specification_type', 'set_bandwidth', 'signaled_bandwidth'], name, value)


                                class AutoBandwidth(_Entity_):
                                    """
                                    Parameters related to auto\-bandwidth
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to MPLS auto\-bandwidth on the tunnel
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State parameters relating to MPLS auto\-bandwidth on the tunnel
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: overflow
                                    
                                        configuration of MPLS overflow bandwidth adjustement for the LSP
                                    
                                        **type**:  :py:class:`Overflow<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow>`
                                    
                                    .. attribute:: underflow
                                    
                                        configuration of MPLS underflow bandwidth adjustement for the LSP
                                    
                                        **type**:  :py:class:`Underflow<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "auto-bandwidth"
                                        self.yang_parent_name = "bandwidth"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.State)), ("overflow", ("overflow", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow)), ("underflow", ("underflow", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.overflow = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow()
                                        self.overflow.parent = self
                                        self._children_name_map["overflow"] = "overflow"

                                        self.underflow = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow()
                                        self.underflow.parent = self
                                        self._children_name_map["underflow"] = "underflow"
                                        self._segment_path = lambda: "auto-bandwidth"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to MPLS
                                        auto\-bandwidth on the tunnel.
                                        
                                        .. attribute:: enabled
                                        
                                            enables mpls auto\-bandwidth on the lsp
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: min_bw
                                        
                                            set the minimum bandwidth in Kbps for an auto\-bandwidth LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                        .. attribute:: max_bw
                                        
                                            set the maximum bandwidth in Kbps for an auto\-bandwidth LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                        .. attribute:: adjust_interval
                                        
                                            time in seconds between adjustments to LSP bandwidth
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                        .. attribute:: adjust_threshold
                                        
                                            percentage difference between the LSP's specified bandwidth and its current bandwidth allocation \-\- if the difference is greater than the specified percentage, auto\-bandwidth adjustment is triggered
                                        
                                            **type**: int
                                        
                                                **range:** 0..100
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "auto-bandwidth"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ('min_bw', (YLeaf(YType.uint64, 'min-bw'), ['int'])),
                                                ('max_bw', (YLeaf(YType.uint64, 'max-bw'), ['int'])),
                                                ('adjust_interval', (YLeaf(YType.uint32, 'adjust-interval'), ['int'])),
                                                ('adjust_threshold', (YLeaf(YType.uint8, 'adjust-threshold'), ['int'])),
                                            ])
                                            self.enabled = None
                                            self.min_bw = None
                                            self.max_bw = None
                                            self.adjust_interval = None
                                            self.adjust_threshold = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Config, ['enabled', 'min_bw', 'max_bw', 'adjust_interval', 'adjust_threshold'], name, value)


                                    class State(_Entity_):
                                        """
                                        State parameters relating to MPLS
                                        auto\-bandwidth on the tunnel.
                                        
                                        .. attribute:: enabled
                                        
                                            enables mpls auto\-bandwidth on the lsp
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: min_bw
                                        
                                            set the minimum bandwidth in Kbps for an auto\-bandwidth LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: max_bw
                                        
                                            set the maximum bandwidth in Kbps for an auto\-bandwidth LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: adjust_interval
                                        
                                            time in seconds between adjustments to LSP bandwidth
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **config**: False
                                        
                                        .. attribute:: adjust_threshold
                                        
                                            percentage difference between the LSP's specified bandwidth and its current bandwidth allocation \-\- if the difference is greater than the specified percentage, auto\-bandwidth adjustment is triggered
                                        
                                            **type**: int
                                        
                                                **range:** 0..100
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "auto-bandwidth"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ('min_bw', (YLeaf(YType.uint64, 'min-bw'), ['int'])),
                                                ('max_bw', (YLeaf(YType.uint64, 'max-bw'), ['int'])),
                                                ('adjust_interval', (YLeaf(YType.uint32, 'adjust-interval'), ['int'])),
                                                ('adjust_threshold', (YLeaf(YType.uint8, 'adjust-threshold'), ['int'])),
                                            ])
                                            self.enabled = None
                                            self.min_bw = None
                                            self.max_bw = None
                                            self.adjust_interval = None
                                            self.adjust_threshold = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.State, ['enabled', 'min_bw', 'max_bw', 'adjust_interval', 'adjust_threshold'], name, value)


                                    class Overflow(_Entity_):
                                        """
                                        configuration of MPLS overflow bandwidth
                                        adjustement for the LSP
                                        
                                        .. attribute:: config
                                        
                                            Config information for MPLS overflow bandwidth adjustment
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.Config>`
                                        
                                        .. attribute:: state
                                        
                                            Config information for MPLS overflow bandwidth adjustment
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "overflow"
                                            self.yang_parent_name = "auto-bandwidth"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "overflow"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Config information for MPLS overflow bandwidth
                                            adjustment
                                            
                                            .. attribute:: enabled
                                            
                                                enables mpls lsp bandwidth overflow adjustment on the lsp
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: overflow_threshold
                                            
                                                bandwidth percentage change to trigger an overflow event
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: trigger_event_count
                                            
                                                number of consecutive overflow sample events needed to trigger an overflow adjustment
                                            
                                                **type**: int
                                            
                                                    **range:** 0..65535
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "overflow"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ('overflow_threshold', (YLeaf(YType.uint8, 'overflow-threshold'), ['int'])),
                                                    ('trigger_event_count', (YLeaf(YType.uint16, 'trigger-event-count'), ['int'])),
                                                ])
                                                self.enabled = None
                                                self.overflow_threshold = None
                                                self.trigger_event_count = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.Config, ['enabled', 'overflow_threshold', 'trigger_event_count'], name, value)


                                        class State(_Entity_):
                                            """
                                            Config information for MPLS overflow bandwidth
                                            adjustment
                                            
                                            .. attribute:: enabled
                                            
                                                enables mpls lsp bandwidth overflow adjustment on the lsp
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: overflow_threshold
                                            
                                                bandwidth percentage change to trigger an overflow event
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: trigger_event_count
                                            
                                                number of consecutive overflow sample events needed to trigger an overflow adjustment
                                            
                                                **type**: int
                                            
                                                    **range:** 0..65535
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "overflow"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ('overflow_threshold', (YLeaf(YType.uint8, 'overflow-threshold'), ['int'])),
                                                    ('trigger_event_count', (YLeaf(YType.uint16, 'trigger-event-count'), ['int'])),
                                                ])
                                                self.enabled = None
                                                self.overflow_threshold = None
                                                self.trigger_event_count = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Overflow.State, ['enabled', 'overflow_threshold', 'trigger_event_count'], name, value)



                                    class Underflow(_Entity_):
                                        """
                                        configuration of MPLS underflow bandwidth
                                        adjustement for the LSP
                                        
                                        .. attribute:: config
                                        
                                            Config information for MPLS underflow bandwidth adjustment
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for MPLS underflow bandwidth adjustment
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "underflow"
                                            self.yang_parent_name = "auto-bandwidth"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "underflow"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Config information for MPLS underflow bandwidth
                                            adjustment
                                            
                                            .. attribute:: enabled
                                            
                                                enables bandwidth underflow adjustment on the lsp
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: underflow_threshold
                                            
                                                bandwidth percentage change to trigger and underflow event
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: trigger_event_count
                                            
                                                number of consecutive underflow sample events needed to trigger an underflow adjustment
                                            
                                                **type**: int
                                            
                                                    **range:** 0..65535
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "underflow"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ('underflow_threshold', (YLeaf(YType.uint8, 'underflow-threshold'), ['int'])),
                                                    ('trigger_event_count', (YLeaf(YType.uint16, 'trigger-event-count'), ['int'])),
                                                ])
                                                self.enabled = None
                                                self.underflow_threshold = None
                                                self.trigger_event_count = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.Config, ['enabled', 'underflow_threshold', 'trigger_event_count'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for MPLS underflow bandwidth
                                            adjustment
                                            
                                            .. attribute:: enabled
                                            
                                                enables bandwidth underflow adjustment on the lsp
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: underflow_threshold
                                            
                                                bandwidth percentage change to trigger and underflow event
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: trigger_event_count
                                            
                                                number of consecutive underflow sample events needed to trigger an underflow adjustment
                                            
                                                **type**: int
                                            
                                                    **range:** 0..65535
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "underflow"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ('underflow_threshold', (YLeaf(YType.uint8, 'underflow-threshold'), ['int'])),
                                                    ('trigger_event_count', (YLeaf(YType.uint16, 'trigger-event-count'), ['int'])),
                                                ])
                                                self.enabled = None
                                                self.underflow_threshold = None
                                                self.trigger_event_count = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.Bandwidth.AutoBandwidth.Underflow.State, ['enabled', 'underflow_threshold', 'trigger_event_count'], name, value)





                            class P2pTunnelAttributes(_Entity_):
                                """
                                Parameters related to LSPs of type P2P
                                
                                .. attribute:: config
                                
                                    Configuration parameters for P2P LSPs
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.Config>`
                                
                                .. attribute:: state
                                
                                    State parameters for P2P LSPs
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.State>`
                                
                                    **config**: False
                                
                                .. attribute:: p2p_primary_path
                                
                                    Primary paths associated with the LSP
                                
                                    **type**:  :py:class:`P2pPrimaryPath<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath>`
                                
                                .. attribute:: p2p_secondary_paths
                                
                                    Secondary paths for the LSP
                                
                                    **type**:  :py:class:`P2pSecondaryPaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "p2p-tunnel-attributes"
                                    self.yang_parent_name = "tunnel"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.State)), ("p2p-primary-path", ("p2p_primary_path", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath)), ("p2p-secondary-paths", ("p2p_secondary_paths", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.p2p_primary_path = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath()
                                    self.p2p_primary_path.parent = self
                                    self._children_name_map["p2p_primary_path"] = "p2p-primary-path"

                                    self.p2p_secondary_paths = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths()
                                    self.p2p_secondary_paths.parent = self
                                    self._children_name_map["p2p_secondary_paths"] = "p2p-secondary-paths"
                                    self._segment_path = lambda: "p2p-tunnel-attributes"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters for P2P LSPs
                                    
                                    .. attribute:: destination
                                    
                                        P2P tunnel destination address
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "p2p-tunnel-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('destination', (YLeaf(YType.str, 'destination'), ['str','str'])),
                                        ])
                                        self.destination = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.Config, ['destination'], name, value)


                                class State(_Entity_):
                                    """
                                    State parameters for P2P LSPs
                                    
                                    .. attribute:: destination
                                    
                                        P2P tunnel destination address
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "p2p-tunnel-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('destination', (YLeaf(YType.str, 'destination'), ['str','str'])),
                                        ])
                                        self.destination = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.State, ['destination'], name, value)


                                class P2pPrimaryPath(_Entity_):
                                    """
                                    Primary paths associated with the LSP
                                    
                                    .. attribute:: p2p_primary_path
                                    
                                        List of p2p primary paths for a tunnel
                                    
                                        **type**: list of    :py:class:`P2pPrimaryPath_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "p2p-primary-path"
                                        self.yang_parent_name = "p2p-tunnel-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("p2p-primary-path", ("p2p_primary_path", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_))])
                                        self._leafs = OrderedDict()

                                        self.p2p_primary_path = YList(self)
                                        self._segment_path = lambda: "p2p-primary-path"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath, [], name, value)

                                    class P2pPrimaryPath_(_Entity_):
                                        """
                                        List of p2p primary paths for a tunnel
                                        
                                        .. attribute:: name  (key)
                                        
                                            Path name
                                        
                                            **type**: str
                                        
                                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.Config>`
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters related to paths
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State parameters related to paths
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.State>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: candidate_secondary_paths
                                        
                                            The set of candidate secondary paths which may be used for this primary path. When secondary paths are specified in the list the path of the secondary LSP in use must be restricted to those path options referenced. The priority of the secondary paths is specified within the list. Higher priority values are less preferred \- that is to say that a path with priority 0 is the most preferred path. In the case that the list is empty, any secondary path option may be utilised when the current primary path is in use
                                        
                                            **type**:  :py:class:`CandidateSecondaryPaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths>`
                                        
                                        .. attribute:: admin_groups
                                        
                                            Top\-level container for include/exclude constraints for link affinities
                                        
                                            **type**:  :py:class:`AdminGroups<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "p2p-primary-path"
                                            self.yang_parent_name = "p2p-primary-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.State)), ("candidate-secondary-paths", ("candidate_secondary_paths", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths)), ("admin-groups", ("admin_groups", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"

                                            self.candidate_secondary_paths = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths()
                                            self.candidate_secondary_paths.parent = self
                                            self._children_name_map["candidate_secondary_paths"] = "candidate-secondary-paths"

                                            self.admin_groups = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups()
                                            self.admin_groups.parent = self
                                            self._children_name_map["admin_groups"] = "admin-groups"
                                            self._segment_path = lambda: "p2p-primary-path" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_, ['name'], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters related to paths
                                            
                                            .. attribute:: name
                                            
                                                Path name
                                            
                                                **type**: str
                                            
                                            .. attribute:: path_computation_method
                                            
                                                The method used for computing the path, either locally computed, queried from a server or not computed at all (explicitly configured)
                                            
                                                **type**:  :py:class:`PATHCOMPUTATIONMETHOD<ydk.models.openconfig.openconfig_mpls_types.PATHCOMPUTATIONMETHOD>`
                                            
                                                **default value**: oc-mplst:LOCALLY_COMPUTED
                                            
                                            .. attribute:: use_cspf
                                            
                                                Flag to enable CSPF for locally computed LSPs
                                            
                                                **type**: bool
                                            
                                            .. attribute:: cspf_tiebreaker
                                            
                                                Determine the tie\-breaking method to choose between equally desirable paths during CSFP computation
                                            
                                                **type**:  :py:class:`CspfTieBreaking<ydk.models.openconfig.openconfig_mpls.CspfTieBreaking>`
                                            
                                            .. attribute:: path_computation_server
                                            
                                                Address of the external path computation server
                                            
                                                **type**: union of the below types:
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                            
                                            .. attribute:: explicit_path_name
                                            
                                                reference to a defined path
                                            
                                                **type**: str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config>`
                                            
                                            .. attribute:: preference
                                            
                                                Specifies a preference for this path. The lower the number higher the preference
                                            
                                                **type**: int
                                            
                                                    **range:** 1..255
                                            
                                            .. attribute:: setup_priority
                                            
                                                RSVP\-TE preemption priority during LSP setup, lower is higher priority; default 7 indicates that LSP will not preempt established LSPs during setup
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **default value**: 7
                                            
                                            .. attribute:: hold_priority
                                            
                                                preemption priority once the LSP is established, lower is higher priority; default 0 indicates other LSPs will not preempt the LSPs once established
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **default value**: 0
                                            
                                            .. attribute:: retry_timer
                                            
                                                sets the time between attempts to establish the LSP
                                            
                                                **type**: int
                                            
                                                    **range:** 1..600
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "p2p-primary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('path_computation_method', (YLeaf(YType.identityref, 'path-computation-method'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHCOMPUTATIONMETHOD')])),
                                                    ('use_cspf', (YLeaf(YType.boolean, 'use-cspf'), ['bool'])),
                                                    ('cspf_tiebreaker', (YLeaf(YType.enumeration, 'cspf-tiebreaker'), [('ydk.models.openconfig.openconfig_mpls', 'CspfTieBreaking', '')])),
                                                    ('path_computation_server', (YLeaf(YType.str, 'path-computation-server'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                                    ('retry_timer', (YLeaf(YType.uint16, 'retry-timer'), ['int'])),
                                                ])
                                                self.name = None
                                                self.path_computation_method = None
                                                self.use_cspf = None
                                                self.cspf_tiebreaker = None
                                                self.path_computation_server = None
                                                self.explicit_path_name = None
                                                self.preference = None
                                                self.setup_priority = None
                                                self.hold_priority = None
                                                self.retry_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.Config, ['name', 'path_computation_method', 'use_cspf', 'cspf_tiebreaker', 'path_computation_server', 'explicit_path_name', 'preference', 'setup_priority', 'hold_priority', 'retry_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State parameters related to paths
                                            
                                            .. attribute:: name
                                            
                                                Path name
                                            
                                                **type**: str
                                            
                                                **config**: False
                                            
                                            .. attribute:: path_computation_method
                                            
                                                The method used for computing the path, either locally computed, queried from a server or not computed at all (explicitly configured)
                                            
                                                **type**:  :py:class:`PATHCOMPUTATIONMETHOD<ydk.models.openconfig.openconfig_mpls_types.PATHCOMPUTATIONMETHOD>`
                                            
                                                **config**: False
                                            
                                                **default value**: oc-mplst:LOCALLY_COMPUTED
                                            
                                            .. attribute:: use_cspf
                                            
                                                Flag to enable CSPF for locally computed LSPs
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                            .. attribute:: cspf_tiebreaker
                                            
                                                Determine the tie\-breaking method to choose between equally desirable paths during CSFP computation
                                            
                                                **type**:  :py:class:`CspfTieBreaking<ydk.models.openconfig.openconfig_mpls.CspfTieBreaking>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: path_computation_server
                                            
                                                Address of the external path computation server
                                            
                                                **type**: union of the below types:
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                            
                                                **config**: False
                                            
                                            .. attribute:: explicit_path_name
                                            
                                                reference to a defined path
                                            
                                                **type**: str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: preference
                                            
                                                Specifies a preference for this path. The lower the number higher the preference
                                            
                                                **type**: int
                                            
                                                    **range:** 1..255
                                            
                                                **config**: False
                                            
                                            .. attribute:: setup_priority
                                            
                                                RSVP\-TE preemption priority during LSP setup, lower is higher priority; default 7 indicates that LSP will not preempt established LSPs during setup
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **config**: False
                                            
                                                **default value**: 7
                                            
                                            .. attribute:: hold_priority
                                            
                                                preemption priority once the LSP is established, lower is higher priority; default 0 indicates other LSPs will not preempt the LSPs once established
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **config**: False
                                            
                                                **default value**: 0
                                            
                                            .. attribute:: retry_timer
                                            
                                                sets the time between attempts to establish the LSP
                                            
                                                **type**: int
                                            
                                                    **range:** 1..600
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            .. attribute:: associated_rsvp_session
                                            
                                                If the signalling protocol specified for this path is RSVP\-TE, this leaf provides a reference to the associated session within the RSVP\-TE protocol sessions list, such that details of the signaling can be retrieved
                                            
                                                **type**: int
                                            
                                                    **range:** 0..18446744073709551615
                                            
                                                **refers to**:  :py:class:`local_index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "p2p-primary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('path_computation_method', (YLeaf(YType.identityref, 'path-computation-method'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHCOMPUTATIONMETHOD')])),
                                                    ('use_cspf', (YLeaf(YType.boolean, 'use-cspf'), ['bool'])),
                                                    ('cspf_tiebreaker', (YLeaf(YType.enumeration, 'cspf-tiebreaker'), [('ydk.models.openconfig.openconfig_mpls', 'CspfTieBreaking', '')])),
                                                    ('path_computation_server', (YLeaf(YType.str, 'path-computation-server'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                                    ('retry_timer', (YLeaf(YType.uint16, 'retry-timer'), ['int'])),
                                                    ('associated_rsvp_session', (YLeaf(YType.str, 'associated-rsvp-session'), ['int'])),
                                                ])
                                                self.name = None
                                                self.path_computation_method = None
                                                self.use_cspf = None
                                                self.cspf_tiebreaker = None
                                                self.path_computation_server = None
                                                self.explicit_path_name = None
                                                self.preference = None
                                                self.setup_priority = None
                                                self.hold_priority = None
                                                self.retry_timer = None
                                                self.associated_rsvp_session = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.State, ['name', 'path_computation_method', 'use_cspf', 'cspf_tiebreaker', 'path_computation_server', 'explicit_path_name', 'preference', 'setup_priority', 'hold_priority', 'retry_timer', 'associated_rsvp_session'], name, value)


                                        class CandidateSecondaryPaths(_Entity_):
                                            """
                                            The set of candidate secondary paths which may be used
                                            for this primary path. When secondary paths are specified
                                            in the list the path of the secondary LSP in use must be
                                            restricted to those path options referenced. The
                                            priority of the secondary paths is specified within the
                                            list. Higher priority values are less preferred \- that is
                                            to say that a path with priority 0 is the most preferred
                                            path. In the case that the list is empty, any secondary
                                            path option may be utilised when the current primary path
                                            is in use.
                                            
                                            .. attribute:: candidate_secondary_path
                                            
                                                List of secondary paths which may be utilised when the current primary path is in use
                                            
                                                **type**: list of    :py:class:`CandidateSecondaryPath<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath>`
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "candidate-secondary-paths"
                                                self.yang_parent_name = "p2p-primary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("candidate-secondary-path", ("candidate_secondary_path", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath))])
                                                self._leafs = OrderedDict()

                                                self.candidate_secondary_path = YList(self)
                                                self._segment_path = lambda: "candidate-secondary-paths"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths, [], name, value)

                                            class CandidateSecondaryPath(_Entity_):
                                                """
                                                List of secondary paths which may be utilised when the
                                                current primary path is in use
                                                
                                                .. attribute:: secondary_path  (key)
                                                
                                                    A reference to the secondary path option reference which acts as the key of the candidate\-secondary\-path list
                                                
                                                    **type**: str
                                                
                                                    **refers to**:  :py:class:`secondary_path<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.Config>`
                                                
                                                .. attribute:: config
                                                
                                                    Configuration parameters relating to the candidate secondary path
                                                
                                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.Config>`
                                                
                                                .. attribute:: state
                                                
                                                    Operational state parameters relating to the candidate secondary path
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "candidate-secondary-path"
                                                    self.yang_parent_name = "candidate-secondary-paths"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = ['secondary_path']
                                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.State))])
                                                    self._leafs = OrderedDict([
                                                        ('secondary_path', (YLeaf(YType.str, 'secondary-path'), ['str'])),
                                                    ])
                                                    self.secondary_path = None

                                                    self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.Config()
                                                    self.config.parent = self
                                                    self._children_name_map["config"] = "config"

                                                    self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "candidate-secondary-path" + "[secondary-path='" + str(self.secondary_path) + "']"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath, ['secondary_path'], name, value)

                                                class Config(_Entity_):
                                                    """
                                                    Configuration parameters relating to the candidate
                                                    secondary path
                                                    
                                                    .. attribute:: secondary_path
                                                    
                                                        A reference to the secondary path that should be utilised when the containing primary path option is in use
                                                    
                                                        **type**: str
                                                    
                                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config>`
                                                    
                                                    .. attribute:: priority
                                                    
                                                        The priority of the specified secondary path option. Higher priority options are less preferable \- such that a secondary path reference with a priority of 0 is the most preferred
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..65535
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "config"
                                                        self.yang_parent_name = "candidate-secondary-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('secondary_path', (YLeaf(YType.str, 'secondary-path'), ['str'])),
                                                            ('priority', (YLeaf(YType.uint16, 'priority'), ['int'])),
                                                        ])
                                                        self.secondary_path = None
                                                        self.priority = None
                                                        self._segment_path = lambda: "config"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.Config, ['secondary_path', 'priority'], name, value)


                                                class State(_Entity_):
                                                    """
                                                    Operational state parameters relating to the candidate
                                                    secondary path
                                                    
                                                    .. attribute:: secondary_path
                                                    
                                                        A reference to the secondary path that should be utilised when the containing primary path option is in use
                                                    
                                                        **type**: str
                                                    
                                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: priority
                                                    
                                                        The priority of the specified secondary path option. Higher priority options are less preferable \- such that a secondary path reference with a priority of 0 is the most preferred
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..65535
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: active
                                                    
                                                        Indicates the current active path option that has been selected of the candidate secondary paths
                                                    
                                                        **type**: bool
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "candidate-secondary-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('secondary_path', (YLeaf(YType.str, 'secondary-path'), ['str'])),
                                                            ('priority', (YLeaf(YType.uint16, 'priority'), ['int'])),
                                                            ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                                        ])
                                                        self.secondary_path = None
                                                        self.priority = None
                                                        self.active = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.CandidateSecondaryPaths.CandidateSecondaryPath.State, ['secondary_path', 'priority', 'active'], name, value)




                                        class AdminGroups(_Entity_):
                                            """
                                            Top\-level container for include/exclude constraints for
                                            link affinities
                                            
                                            .. attribute:: config
                                            
                                                Configuration data 
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.Config>`
                                            
                                            .. attribute:: state
                                            
                                                Operational state data 
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "admin-groups"
                                                self.yang_parent_name = "p2p-primary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "admin-groups"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration data 
                                                
                                                .. attribute:: exclude_group
                                                
                                                    list of references to named admin\-groups to exclude in path calculation
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                .. attribute:: include_all_group
                                                
                                                    list of references to named admin\-groups of which all must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                .. attribute:: include_any_group
                                                
                                                    list of references to named admin\-groups of which one must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "admin-groups"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('exclude_group', (YLeafList(YType.str, 'exclude-group'), ['str'])),
                                                        ('include_all_group', (YLeafList(YType.str, 'include-all-group'), ['str'])),
                                                        ('include_any_group', (YLeafList(YType.str, 'include-any-group'), ['str'])),
                                                    ])
                                                    self.exclude_group = []
                                                    self.include_all_group = []
                                                    self.include_any_group = []
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.Config, ['exclude_group', 'include_all_group', 'include_any_group'], name, value)


                                            class State(_Entity_):
                                                """
                                                Operational state data 
                                                
                                                .. attribute:: exclude_group
                                                
                                                    list of references to named admin\-groups to exclude in path calculation
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: include_all_group
                                                
                                                    list of references to named admin\-groups of which all must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: include_any_group
                                                
                                                    list of references to named admin\-groups of which one must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "admin-groups"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('exclude_group', (YLeafList(YType.str, 'exclude-group'), ['str'])),
                                                        ('include_all_group', (YLeafList(YType.str, 'include-all-group'), ['str'])),
                                                        ('include_any_group', (YLeafList(YType.str, 'include-any-group'), ['str'])),
                                                    ])
                                                    self.exclude_group = []
                                                    self.include_all_group = []
                                                    self.include_any_group = []
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pPrimaryPath.P2pPrimaryPath_.AdminGroups.State, ['exclude_group', 'include_all_group', 'include_any_group'], name, value)





                                class P2pSecondaryPaths(_Entity_):
                                    """
                                    Secondary paths for the LSP
                                    
                                    .. attribute:: p2p_secondary_path
                                    
                                        List of p2p primary paths for a tunnel
                                    
                                        **type**: list of    :py:class:`P2pSecondaryPath<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "p2p-secondary-paths"
                                        self.yang_parent_name = "p2p-tunnel-attributes"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("p2p-secondary-path", ("p2p_secondary_path", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath))])
                                        self._leafs = OrderedDict()

                                        self.p2p_secondary_path = YList(self)
                                        self._segment_path = lambda: "p2p-secondary-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths, [], name, value)

                                    class P2pSecondaryPath(_Entity_):
                                        """
                                        List of p2p primary paths for a tunnel
                                        
                                        .. attribute:: name  (key)
                                        
                                            Path name
                                        
                                            **type**: str
                                        
                                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config>`
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters related to paths
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State parameters related to paths
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.State>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: admin_groups
                                        
                                            Top\-level container for include/exclude constraints for link affinities
                                        
                                            **type**:  :py:class:`AdminGroups<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "p2p-secondary-path"
                                            self.yang_parent_name = "p2p-secondary-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['name']
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.State)), ("admin-groups", ("admin_groups", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups))])
                                            self._leafs = OrderedDict([
                                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                            ])
                                            self.name = None

                                            self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"

                                            self.admin_groups = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups()
                                            self.admin_groups.parent = self
                                            self._children_name_map["admin_groups"] = "admin-groups"
                                            self._segment_path = lambda: "p2p-secondary-path" + "[name='" + str(self.name) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath, ['name'], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters related to paths
                                            
                                            .. attribute:: name
                                            
                                                Path name
                                            
                                                **type**: str
                                            
                                            .. attribute:: path_computation_method
                                            
                                                The method used for computing the path, either locally computed, queried from a server or not computed at all (explicitly configured)
                                            
                                                **type**:  :py:class:`PATHCOMPUTATIONMETHOD<ydk.models.openconfig.openconfig_mpls_types.PATHCOMPUTATIONMETHOD>`
                                            
                                                **default value**: oc-mplst:LOCALLY_COMPUTED
                                            
                                            .. attribute:: use_cspf
                                            
                                                Flag to enable CSPF for locally computed LSPs
                                            
                                                **type**: bool
                                            
                                            .. attribute:: cspf_tiebreaker
                                            
                                                Determine the tie\-breaking method to choose between equally desirable paths during CSFP computation
                                            
                                                **type**:  :py:class:`CspfTieBreaking<ydk.models.openconfig.openconfig_mpls.CspfTieBreaking>`
                                            
                                            .. attribute:: path_computation_server
                                            
                                                Address of the external path computation server
                                            
                                                **type**: union of the below types:
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                            
                                            .. attribute:: explicit_path_name
                                            
                                                reference to a defined path
                                            
                                                **type**: str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config>`
                                            
                                            .. attribute:: preference
                                            
                                                Specifies a preference for this path. The lower the number higher the preference
                                            
                                                **type**: int
                                            
                                                    **range:** 1..255
                                            
                                            .. attribute:: setup_priority
                                            
                                                RSVP\-TE preemption priority during LSP setup, lower is higher priority; default 7 indicates that LSP will not preempt established LSPs during setup
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **default value**: 7
                                            
                                            .. attribute:: hold_priority
                                            
                                                preemption priority once the LSP is established, lower is higher priority; default 0 indicates other LSPs will not preempt the LSPs once established
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **default value**: 0
                                            
                                            .. attribute:: retry_timer
                                            
                                                sets the time between attempts to establish the LSP
                                            
                                                **type**: int
                                            
                                                    **range:** 1..600
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "p2p-secondary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('path_computation_method', (YLeaf(YType.identityref, 'path-computation-method'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHCOMPUTATIONMETHOD')])),
                                                    ('use_cspf', (YLeaf(YType.boolean, 'use-cspf'), ['bool'])),
                                                    ('cspf_tiebreaker', (YLeaf(YType.enumeration, 'cspf-tiebreaker'), [('ydk.models.openconfig.openconfig_mpls', 'CspfTieBreaking', '')])),
                                                    ('path_computation_server', (YLeaf(YType.str, 'path-computation-server'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                                    ('retry_timer', (YLeaf(YType.uint16, 'retry-timer'), ['int'])),
                                                ])
                                                self.name = None
                                                self.path_computation_method = None
                                                self.use_cspf = None
                                                self.cspf_tiebreaker = None
                                                self.path_computation_server = None
                                                self.explicit_path_name = None
                                                self.preference = None
                                                self.setup_priority = None
                                                self.hold_priority = None
                                                self.retry_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.Config, ['name', 'path_computation_method', 'use_cspf', 'cspf_tiebreaker', 'path_computation_server', 'explicit_path_name', 'preference', 'setup_priority', 'hold_priority', 'retry_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State parameters related to paths
                                            
                                            .. attribute:: name
                                            
                                                Path name
                                            
                                                **type**: str
                                            
                                                **config**: False
                                            
                                            .. attribute:: path_computation_method
                                            
                                                The method used for computing the path, either locally computed, queried from a server or not computed at all (explicitly configured)
                                            
                                                **type**:  :py:class:`PATHCOMPUTATIONMETHOD<ydk.models.openconfig.openconfig_mpls_types.PATHCOMPUTATIONMETHOD>`
                                            
                                                **config**: False
                                            
                                                **default value**: oc-mplst:LOCALLY_COMPUTED
                                            
                                            .. attribute:: use_cspf
                                            
                                                Flag to enable CSPF for locally computed LSPs
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                            .. attribute:: cspf_tiebreaker
                                            
                                                Determine the tie\-breaking method to choose between equally desirable paths during CSFP computation
                                            
                                                **type**:  :py:class:`CspfTieBreaking<ydk.models.openconfig.openconfig_mpls.CspfTieBreaking>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: path_computation_server
                                            
                                                Address of the external path computation server
                                            
                                                **type**: union of the below types:
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                            
                                                    **type**: str
                                            
                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                            
                                                **config**: False
                                            
                                            .. attribute:: explicit_path_name
                                            
                                                reference to a defined path
                                            
                                                **type**: str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.NamedExplicitPaths.NamedExplicitPath.Config>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: preference
                                            
                                                Specifies a preference for this path. The lower the number higher the preference
                                            
                                                **type**: int
                                            
                                                    **range:** 1..255
                                            
                                                **config**: False
                                            
                                            .. attribute:: setup_priority
                                            
                                                RSVP\-TE preemption priority during LSP setup, lower is higher priority; default 7 indicates that LSP will not preempt established LSPs during setup
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **config**: False
                                            
                                                **default value**: 7
                                            
                                            .. attribute:: hold_priority
                                            
                                                preemption priority once the LSP is established, lower is higher priority; default 0 indicates other LSPs will not preempt the LSPs once established
                                            
                                                **type**: int
                                            
                                                    **range:** 0..7
                                            
                                                **config**: False
                                            
                                                **default value**: 0
                                            
                                            .. attribute:: retry_timer
                                            
                                                sets the time between attempts to establish the LSP
                                            
                                                **type**: int
                                            
                                                    **range:** 1..600
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            .. attribute:: associated_rsvp_session
                                            
                                                If the signalling protocol specified for this path is RSVP\-TE, this leaf provides a reference to the associated session within the RSVP\-TE protocol sessions list, such that details of the signaling can be retrieved
                                            
                                                **type**: int
                                            
                                                    **range:** 0..18446744073709551615
                                            
                                                **refers to**:  :py:class:`local_index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.SignalingProtocols.RsvpTe.Sessions.Session>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "p2p-secondary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                                    ('path_computation_method', (YLeaf(YType.identityref, 'path-computation-method'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHCOMPUTATIONMETHOD')])),
                                                    ('use_cspf', (YLeaf(YType.boolean, 'use-cspf'), ['bool'])),
                                                    ('cspf_tiebreaker', (YLeaf(YType.enumeration, 'cspf-tiebreaker'), [('ydk.models.openconfig.openconfig_mpls', 'CspfTieBreaking', '')])),
                                                    ('path_computation_server', (YLeaf(YType.str, 'path-computation-server'), ['str','str'])),
                                                    ('explicit_path_name', (YLeaf(YType.str, 'explicit-path-name'), ['str'])),
                                                    ('preference', (YLeaf(YType.uint8, 'preference'), ['int'])),
                                                    ('setup_priority', (YLeaf(YType.uint8, 'setup-priority'), ['int'])),
                                                    ('hold_priority', (YLeaf(YType.uint8, 'hold-priority'), ['int'])),
                                                    ('retry_timer', (YLeaf(YType.uint16, 'retry-timer'), ['int'])),
                                                    ('associated_rsvp_session', (YLeaf(YType.str, 'associated-rsvp-session'), ['int'])),
                                                ])
                                                self.name = None
                                                self.path_computation_method = None
                                                self.use_cspf = None
                                                self.cspf_tiebreaker = None
                                                self.path_computation_server = None
                                                self.explicit_path_name = None
                                                self.preference = None
                                                self.setup_priority = None
                                                self.hold_priority = None
                                                self.retry_timer = None
                                                self.associated_rsvp_session = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.State, ['name', 'path_computation_method', 'use_cspf', 'cspf_tiebreaker', 'path_computation_server', 'explicit_path_name', 'preference', 'setup_priority', 'hold_priority', 'retry_timer', 'associated_rsvp_session'], name, value)


                                        class AdminGroups(_Entity_):
                                            """
                                            Top\-level container for include/exclude constraints for
                                            link affinities
                                            
                                            .. attribute:: config
                                            
                                                Configuration data 
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.Config>`
                                            
                                            .. attribute:: state
                                            
                                                Operational state data 
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "admin-groups"
                                                self.yang_parent_name = "p2p-secondary-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "admin-groups"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration data 
                                                
                                                .. attribute:: exclude_group
                                                
                                                    list of references to named admin\-groups to exclude in path calculation
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                .. attribute:: include_all_group
                                                
                                                    list of references to named admin\-groups of which all must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                .. attribute:: include_any_group
                                                
                                                    list of references to named admin\-groups of which one must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "admin-groups"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('exclude_group', (YLeafList(YType.str, 'exclude-group'), ['str'])),
                                                        ('include_all_group', (YLeafList(YType.str, 'include-all-group'), ['str'])),
                                                        ('include_any_group', (YLeafList(YType.str, 'include-any-group'), ['str'])),
                                                    ])
                                                    self.exclude_group = []
                                                    self.include_all_group = []
                                                    self.include_any_group = []
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.Config, ['exclude_group', 'include_all_group', 'include_any_group'], name, value)


                                            class State(_Entity_):
                                                """
                                                Operational state data 
                                                
                                                .. attribute:: exclude_group
                                                
                                                    list of references to named admin\-groups to exclude in path calculation
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: include_all_group
                                                
                                                    list of references to named admin\-groups of which all must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: include_any_group
                                                
                                                    list of references to named admin\-groups of which one must be included
                                                
                                                    **type**: list of str
                                                
                                                    **refers to**:  :py:class:`admin_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.TeGlobalAttributes.MplsAdminGroups.AdminGroup>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "admin-groups"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('exclude_group', (YLeafList(YType.str, 'exclude-group'), ['str'])),
                                                        ('include_all_group', (YLeafList(YType.str, 'include-all-group'), ['str'])),
                                                        ('include_any_group', (YLeafList(YType.str, 'include-any-group'), ['str'])),
                                                    ])
                                                    self.exclude_group = []
                                                    self.include_all_group = []
                                                    self.include_any_group = []
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.ConstrainedPath.Tunnels.Tunnel.P2pTunnelAttributes.P2pSecondaryPaths.P2pSecondaryPath.AdminGroups.State, ['exclude_group', 'include_all_group', 'include_any_group'], name, value)









                class UnconstrainedPath(_Entity_):
                    """
                    LSPs that use the IGP\-determined path, i.e., non
                    traffic\-engineered, or non constrained\-path
                    
                    .. attribute:: path_setup_protocol
                    
                        select and configure the signaling method for  the LSP
                    
                        **type**:  :py:class:`PathSetupProtocol<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "unconstrained-path"
                        self.yang_parent_name = "lsps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("path-setup-protocol", ("path_setup_protocol", NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol))])
                        self._leafs = OrderedDict()

                        self.path_setup_protocol = NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol()
                        self.path_setup_protocol.parent = self
                        self._children_name_map["path_setup_protocol"] = "path-setup-protocol"
                        self._segment_path = lambda: "unconstrained-path"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath, [], name, value)

                    class PathSetupProtocol(_Entity_):
                        """
                        select and configure the signaling method for
                         the LSP
                        
                        .. attribute:: ldp
                        
                            LDP signaling setup for IGP\-congruent LSPs
                        
                            **type**:  :py:class:`Ldp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol.Ldp>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "path-setup-protocol"
                            self.yang_parent_name = "unconstrained-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ldp", ("ldp", NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol.Ldp))])
                            self._leafs = OrderedDict()

                            self.ldp = NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol.Ldp()
                            self.ldp.parent = self
                            self._children_name_map["ldp"] = "ldp"
                            self._segment_path = lambda: "path-setup-protocol"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.UnconstrainedPath.PathSetupProtocol, [], name, value)

                        class Ldp(_Entity_):
                            """
                            LDP signaling setup for IGP\-congruent LSPs
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "ldp"
                                self.yang_parent_name = "path-setup-protocol"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "ldp"
                                self._is_frozen = True




                class StaticLsps(_Entity_):
                    """
                    statically configured LSPs, without dynamic
                    signaling
                    
                    .. attribute:: static_lsp
                    
                        list of defined static LSPs
                    
                        **type**: list of    :py:class:`StaticLsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "static-lsps"
                        self.yang_parent_name = "lsps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static-lsp", ("static_lsp", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp))])
                        self._leafs = OrderedDict()

                        self.static_lsp = YList(self)
                        self._segment_path = lambda: "static-lsps"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps, [], name, value)

                    class StaticLsp(_Entity_):
                        """
                        list of defined static LSPs
                        
                        .. attribute:: name  (key)
                        
                            Reference the name list key
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Config>`
                        
                        .. attribute:: config
                        
                            Configuration data for the static lsp
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Config>`
                        
                        .. attribute:: state
                        
                            Operational state data for the static lsp
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.State>`
                        
                            **config**: False
                        
                        .. attribute:: ingress
                        
                            Static LSPs for which the router is an  ingress node
                        
                            **type**:  :py:class:`Ingress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress>`
                        
                        .. attribute:: transit
                        
                            Static LSPs for which the router is an  transit node
                        
                            **type**:  :py:class:`Transit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit>`
                        
                        .. attribute:: egress
                        
                            Static LSPs for which the router is an  egress node
                        
                            **type**:  :py:class:`Egress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "static-lsp"
                            self.yang_parent_name = "static-lsps"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['name']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.State)), ("ingress", ("ingress", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress)), ("transit", ("transit", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit)), ("egress", ("egress", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress))])
                            self._leafs = OrderedDict([
                                ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ])
                            self.name = None

                            self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.ingress = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress()
                            self.ingress.parent = self
                            self._children_name_map["ingress"] = "ingress"

                            self.transit = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit()
                            self.transit.parent = self
                            self._children_name_map["transit"] = "transit"

                            self.egress = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress()
                            self.egress.parent = self
                            self._children_name_map["egress"] = "egress"
                            self._segment_path = lambda: "static-lsp" + "[name='" + str(self.name) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp, ['name'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration data for the static lsp
                            
                            .. attribute:: name
                            
                                name to identify the LSP
                            
                                **type**: str
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "static-lsp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Config, ['name'], name, value)


                        class State(_Entity_):
                            """
                            Operational state data for the static lsp
                            
                            .. attribute:: name
                            
                                name to identify the LSP
                            
                                **type**: str
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "static-lsp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                                ])
                                self.name = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.State, ['name'], name, value)


                        class Ingress(_Entity_):
                            """
                            Static LSPs for which the router is an
                             ingress node
                            
                            .. attribute:: config
                            
                                Configuration data for ingress LSPs
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.Config>`
                            
                            .. attribute:: state
                            
                                Operational state data for ingress LSPs
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "ingress"
                                self.yang_parent_name = "static-lsp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "ingress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration data for ingress LSPs
                                
                                .. attribute:: next_hop
                                
                                    next hop IP address for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                .. attribute:: incoming_label
                                
                                    label value on the incoming packet
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                .. attribute:: push_label
                                
                                    label value to push at the current hop for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str'])),
                                        ('incoming_label', (YLeaf(YType.str, 'incoming-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('push_label', (YLeaf(YType.str, 'push-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.next_hop = None
                                    self.incoming_label = None
                                    self.push_label = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.Config, ['next_hop', 'incoming_label', 'push_label'], name, value)


                            class State(_Entity_):
                                """
                                Operational state data for ingress LSPs
                                
                                .. attribute:: next_hop
                                
                                    next hop IP address for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: incoming_label
                                
                                    label value on the incoming packet
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: push_label
                                
                                    label value to push at the current hop for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "ingress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str'])),
                                        ('incoming_label', (YLeaf(YType.str, 'incoming-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('push_label', (YLeaf(YType.str, 'push-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.next_hop = None
                                    self.incoming_label = None
                                    self.push_label = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Ingress.State, ['next_hop', 'incoming_label', 'push_label'], name, value)



                        class Transit(_Entity_):
                            """
                            Static LSPs for which the router is an
                             transit node
                            
                            .. attribute:: config
                            
                                Configuration data for transit LSPs
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.Config>`
                            
                            .. attribute:: state
                            
                                Operational state data for transit LSPs
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "transit"
                                self.yang_parent_name = "static-lsp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "transit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration data for transit LSPs
                                
                                .. attribute:: next_hop
                                
                                    next hop IP address for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                .. attribute:: incoming_label
                                
                                    label value on the incoming packet
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                .. attribute:: push_label
                                
                                    label value to push at the current hop for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "transit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str'])),
                                        ('incoming_label', (YLeaf(YType.str, 'incoming-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('push_label', (YLeaf(YType.str, 'push-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.next_hop = None
                                    self.incoming_label = None
                                    self.push_label = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.Config, ['next_hop', 'incoming_label', 'push_label'], name, value)


                            class State(_Entity_):
                                """
                                Operational state data for transit LSPs
                                
                                .. attribute:: next_hop
                                
                                    next hop IP address for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: incoming_label
                                
                                    label value on the incoming packet
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: push_label
                                
                                    label value to push at the current hop for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "transit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str'])),
                                        ('incoming_label', (YLeaf(YType.str, 'incoming-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('push_label', (YLeaf(YType.str, 'push-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.next_hop = None
                                    self.incoming_label = None
                                    self.push_label = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Transit.State, ['next_hop', 'incoming_label', 'push_label'], name, value)



                        class Egress(_Entity_):
                            """
                            Static LSPs for which the router is an
                             egress node
                            
                            .. attribute:: config
                            
                                Configuration data for egress LSPs
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.Config>`
                            
                            .. attribute:: state
                            
                                Operational state data for egress LSPs
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "egress"
                                self.yang_parent_name = "static-lsp"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "egress"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration data for egress LSPs
                                
                                .. attribute:: next_hop
                                
                                    next hop IP address for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                .. attribute:: incoming_label
                                
                                    label value on the incoming packet
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                .. attribute:: push_label
                                
                                    label value to push at the current hop for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "egress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str'])),
                                        ('incoming_label', (YLeaf(YType.str, 'incoming-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('push_label', (YLeaf(YType.str, 'push-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.next_hop = None
                                    self.incoming_label = None
                                    self.push_label = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.Config, ['next_hop', 'incoming_label', 'push_label'], name, value)


                            class State(_Entity_):
                                """
                                Operational state data for egress LSPs
                                
                                .. attribute:: next_hop
                                
                                    next hop IP address for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: incoming_label
                                
                                    label value on the incoming packet
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: push_label
                                
                                    label value to push at the current hop for the LSP
                                
                                    **type**: union of the below types:
                                
                                        **type**: int
                                
                                            **range:** 16..1048575
                                
                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "egress"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str'])),
                                        ('incoming_label', (YLeaf(YType.str, 'incoming-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('push_label', (YLeaf(YType.str, 'push-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                    ])
                                    self.next_hop = None
                                    self.incoming_label = None
                                    self.push_label = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Mpls.Lsps.StaticLsps.StaticLsp.Egress.State, ['next_hop', 'incoming_label', 'push_label'], name, value)







        class SegmentRouting(_Entity_):
            """
            Configuration and operational state parameters relating to
            segment routing.
            
            .. attribute:: srgbs
            
                Configuration and operational state parameters relating to the SRGBs defined for the system
            
                **type**:  :py:class:`Srgbs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs>`
            
            .. attribute:: srlbs
            
                Configuration and operational state parameters relating to the Segment Routing Local Blocks (SRLBs) defined for the system
            
                **type**:  :py:class:`Srlbs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "segment-routing"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("srgbs", ("srgbs", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs)), ("srlbs", ("srlbs", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs))])
                self._leafs = OrderedDict()

                self.srgbs = NetworkInstances.NetworkInstance.SegmentRouting.Srgbs()
                self.srgbs.parent = self
                self._children_name_map["srgbs"] = "srgbs"

                self.srlbs = NetworkInstances.NetworkInstance.SegmentRouting.Srlbs()
                self.srlbs.parent = self
                self._children_name_map["srlbs"] = "srlbs"
                self._segment_path = lambda: "segment-routing"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting, [], name, value)

            class Srgbs(_Entity_):
                """
                Configuration and operational state parameters relating to the
                SRGBs defined for the system.
                
                .. attribute:: srgb
                
                    A single definition of an SRGB which may comprise of multiple sets of dataplane addresses (IPv6 addresses, or MPLS labels)
                
                    **type**: list of    :py:class:`Srgb<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "srgbs"
                    self.yang_parent_name = "segment-routing"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("srgb", ("srgb", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb))])
                    self._leafs = OrderedDict()

                    self.srgb = YList(self)
                    self._segment_path = lambda: "srgbs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs, [], name, value)

                class Srgb(_Entity_):
                    """
                    A single definition of an SRGB which may comprise of multiple
                    sets of dataplane addresses (IPv6 addresses, or MPLS labels).
                    
                    .. attribute:: local_id  (key)
                    
                        A reference to the identifier for the SRGB
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters relating to the SRGB
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                    
                    .. attribute:: state
                    
                        State parameters relating to the SRGB
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "srgb"
                        self.yang_parent_name = "srgbs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['local_id']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config)), ("state", ("state", NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State))])
                        self._leafs = OrderedDict([
                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                        ])
                        self.local_id = None

                        self.config = NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "srgb" + "[local-id='" + str(self.local_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb, ['local_id'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters relating to the SRGB.
                        
                        .. attribute:: local_id
                        
                            Unique identifier for the segment routing global block on the local system
                        
                            **type**: str
                        
                        .. attribute:: dataplane_type
                        
                            The dataplane being used to instantiate the SRGB. When MPLS is specified the set of MPLS label blocks that are defined in the mpls\-label\-blocks list are used to make up the SRGB. When IPv6 is specified, the set of IPv6 prefixes specified in the ipv6\-prefixes list are used
                        
                            **type**:  :py:class:`SrDataplaneType<ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                        .. attribute:: mpls_label_blocks
                        
                            A list of refences to the label blocks that are used to make up the SRGB
                        
                            **type**: list of str
                        
                            **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: ipv6_prefixes
                        
                            A list of IPv6 prefixes which are to be used for segment routing using the IPv6 dataplane
                        
                            **type**: list of str
                        
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "srgb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                ('dataplane_type', (YLeaf(YType.enumeration, 'dataplane-type'), [('ydk.models.openconfig.openconfig_segment_routing', 'SrDataplaneType', '')])),
                                ('mpls_label_blocks', (YLeafList(YType.str, 'mpls-label-blocks'), ['str'])),
                                ('ipv6_prefixes', (YLeafList(YType.str, 'ipv6-prefixes'), ['str'])),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_blocks = []
                            self.ipv6_prefixes = []
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config, ['local_id', 'dataplane_type', 'mpls_label_blocks', 'ipv6_prefixes'], name, value)


                    class State(_Entity_):
                        """
                        State parameters relating to the SRGB.
                        
                        .. attribute:: local_id
                        
                            Unique identifier for the segment routing global block on the local system
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: dataplane_type
                        
                            The dataplane being used to instantiate the SRGB. When MPLS is specified the set of MPLS label blocks that are defined in the mpls\-label\-blocks list are used to make up the SRGB. When IPv6 is specified, the set of IPv6 prefixes specified in the ipv6\-prefixes list are used
                        
                            **type**:  :py:class:`SrDataplaneType<ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                            **config**: False
                        
                        .. attribute:: mpls_label_blocks
                        
                            A list of refences to the label blocks that are used to make up the SRGB
                        
                            **type**: list of str
                        
                            **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                            **config**: False
                        
                        .. attribute:: ipv6_prefixes
                        
                            A list of IPv6 prefixes which are to be used for segment routing using the IPv6 dataplane
                        
                            **type**: list of str
                        
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                            **config**: False
                        
                        .. attribute:: size
                        
                            The total number of SRGB entries that are available within the SRGB
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **config**: False
                        
                        .. attribute:: used
                        
                            The total number of SRGB entries that have already been alocated by protocols referencing the SRGB
                        
                            **type**: int
                        
                                **range:** 0..4294967295
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "srgb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                ('dataplane_type', (YLeaf(YType.enumeration, 'dataplane-type'), [('ydk.models.openconfig.openconfig_segment_routing', 'SrDataplaneType', '')])),
                                ('mpls_label_blocks', (YLeafList(YType.str, 'mpls-label-blocks'), ['str'])),
                                ('ipv6_prefixes', (YLeafList(YType.str, 'ipv6-prefixes'), ['str'])),
                                ('size', (YLeaf(YType.uint32, 'size'), ['int'])),
                                ('used', (YLeaf(YType.uint32, 'used'), ['int'])),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_blocks = []
                            self.ipv6_prefixes = []
                            self.size = None
                            self.used = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.State, ['local_id', 'dataplane_type', 'mpls_label_blocks', 'ipv6_prefixes', 'size', 'used'], name, value)




            class Srlbs(_Entity_):
                """
                Configuration and operational state parameters relating to the
                Segment Routing Local Blocks (SRLBs) defined for the system.
                
                .. attribute:: srlb
                
                    A definition of a Segment Routing Local Block, defined to be a set of Segment Identifiers (specified as MPLS labels or IPv6 addreses) that are defined for local allocation by the system. A block may optionally be advertised into an IGP
                
                    **type**: list of    :py:class:`Srlb<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "srlbs"
                    self.yang_parent_name = "segment-routing"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("srlb", ("srlb", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb))])
                    self._leafs = OrderedDict()

                    self.srlb = YList(self)
                    self._segment_path = lambda: "srlbs"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs, [], name, value)

                class Srlb(_Entity_):
                    """
                    A definition of a Segment Routing Local Block, defined to be
                    a set of Segment Identifiers (specified as MPLS labels or
                    IPv6 addreses) that are defined for local allocation by the
                    system. A block may optionally be advertised into an IGP.
                    
                    .. attribute:: local_id  (key)
                    
                        Reference to the local identifier used for the SRLB
                    
                        **type**: str
                    
                        **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters relating to the SRLB
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parmeters relating to the SRLB
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "srlb"
                        self.yang_parent_name = "srlbs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['local_id']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config)), ("state", ("state", NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State))])
                        self._leafs = OrderedDict([
                            ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                        ])
                        self.local_id = None

                        self.config = NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "srlb" + "[local-id='" + str(self.local_id) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb, ['local_id'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters relating to the SRLB.
                        
                        .. attribute:: local_id
                        
                            A unique local identifier used for the Segment Routing Local Block. The identifier is used when referencing the SRLB within other contexts
                        
                            **type**: str
                        
                        .. attribute:: dataplane_type
                        
                            The dataplane that is to be used for the Segment Routing Local Block. When MPLS is specified, the local block corresponds to a block of MPLS labels; when IPv6 is specified it corresponds to an IPv6 prefix
                        
                            **type**:  :py:class:`SrDataplaneType<ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                        .. attribute:: mpls_label_block
                        
                            A reference to the MPLS label block that is used to contain the SIDs of the SRLB
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                        .. attribute:: ipv6_prefix
                        
                            The IPv6 prefix that is used for the SRLB
                        
                            **type**: str
                        
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "srlb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                ('dataplane_type', (YLeaf(YType.enumeration, 'dataplane-type'), [('ydk.models.openconfig.openconfig_segment_routing', 'SrDataplaneType', '')])),
                                ('mpls_label_block', (YLeaf(YType.str, 'mpls-label-block'), ['str'])),
                                ('ipv6_prefix', (YLeaf(YType.str, 'ipv6-prefix'), ['str'])),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_block = None
                            self.ipv6_prefix = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config, ['local_id', 'dataplane_type', 'mpls_label_block', 'ipv6_prefix'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parmeters relating to the SRLB.
                        
                        .. attribute:: local_id
                        
                            A unique local identifier used for the Segment Routing Local Block. The identifier is used when referencing the SRLB within other contexts
                        
                            **type**: str
                        
                            **config**: False
                        
                        .. attribute:: dataplane_type
                        
                            The dataplane that is to be used for the Segment Routing Local Block. When MPLS is specified, the local block corresponds to a block of MPLS labels; when IPv6 is specified it corresponds to an IPv6 prefix
                        
                            **type**:  :py:class:`SrDataplaneType<ydk.models.openconfig.openconfig_segment_routing.SrDataplaneType>`
                        
                            **config**: False
                        
                        .. attribute:: mpls_label_block
                        
                            A reference to the MPLS label block that is used to contain the SIDs of the SRLB
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Mpls.Global.ReservedLabelBlocks.ReservedLabelBlock.Config>`
                        
                            **config**: False
                        
                        .. attribute:: ipv6_prefix
                        
                            The IPv6 prefix that is used for the SRLB
                        
                            **type**: str
                        
                                **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "srlb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_id', (YLeaf(YType.str, 'local-id'), ['str'])),
                                ('dataplane_type', (YLeaf(YType.enumeration, 'dataplane-type'), [('ydk.models.openconfig.openconfig_segment_routing', 'SrDataplaneType', '')])),
                                ('mpls_label_block', (YLeaf(YType.str, 'mpls-label-block'), ['str'])),
                                ('ipv6_prefix', (YLeaf(YType.str, 'ipv6-prefix'), ['str'])),
                            ])
                            self.local_id = None
                            self.dataplane_type = None
                            self.mpls_label_block = None
                            self.ipv6_prefix = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.State, ['local_id', 'dataplane_type', 'mpls_label_block', 'ipv6_prefix'], name, value)





        class Vlans(_Entity_):
            """
            Container for VLAN configuration and state
            variables
            
            .. attribute:: vlan
            
                Configured VLANs keyed by id
            
                **type**: list of    :py:class:`Vlan<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "vlans"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("vlan", ("vlan", NetworkInstances.NetworkInstance.Vlans.Vlan))])
                self._leafs = OrderedDict()

                self.vlan = YList(self)
                self._segment_path = lambda: "vlans"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Vlans, [], name, value)

            class Vlan(_Entity_):
                """
                Configured VLANs keyed by id
                
                .. attribute:: vlan_id  (key)
                
                    references the configured vlan\-id
                
                    **type**: int
                
                        **range:** 1..4094
                
                    **refers to**:  :py:class:`vlan_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                
                .. attribute:: config
                
                    Configuration parameters for VLANs
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config>`
                
                .. attribute:: state
                
                    State variables for VLANs
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.State>`
                
                    **config**: False
                
                .. attribute:: members
                
                    Enclosing container for list of member interfaces
                
                    **type**:  :py:class:`Members<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "vlan"
                    self.yang_parent_name = "vlans"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['vlan_id']
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Vlans.Vlan.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Vlans.Vlan.State)), ("members", ("members", NetworkInstances.NetworkInstance.Vlans.Vlan.Members))])
                    self._leafs = OrderedDict([
                        ('vlan_id', (YLeaf(YType.str, 'vlan-id'), ['int'])),
                    ])
                    self.vlan_id = None

                    self.config = NetworkInstances.NetworkInstance.Vlans.Vlan.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.Vlans.Vlan.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"

                    self.members = NetworkInstances.NetworkInstance.Vlans.Vlan.Members()
                    self.members.parent = self
                    self._children_name_map["members"] = "members"
                    self._segment_path = lambda: "vlan" + "[vlan-id='" + str(self.vlan_id) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan, ['vlan_id'], name, value)

                class Config(_Entity_):
                    """
                    Configuration parameters for VLANs
                    
                    .. attribute:: vlan_id
                    
                        Interface VLAN id
                    
                        **type**: int
                    
                            **range:** 1..4094
                    
                    .. attribute:: name
                    
                        Interface VLAN name
                    
                        **type**: str
                    
                    .. attribute:: status
                    
                        Admin state of the VLAN
                    
                        **type**:  :py:class:`Status<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Config.Status>`
                    
                        **default value**: ACTIVE
                    
                    .. attribute:: tpid
                    
                        Optionally set the tag protocol identifier field (TPID) that is accepted on the VLAN
                    
                        **type**:  :py:class:`TPIDTYPES<ydk.models.openconfig.openconfig_vlan_types.TPIDTYPES>`
                    
                        **default value**: oc-vlan-types:TPID_0x8100
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Vlans.Vlan.Config.Status')])),
                            ('tpid', (YLeaf(YType.identityref, 'tpid'), [('ydk.models.openconfig.openconfig_vlan_types', 'TPIDTYPES')])),
                        ])
                        self.vlan_id = None
                        self.name = None
                        self.status = None
                        self.tpid = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Config, ['vlan_id', 'name', 'status', 'tpid'], name, value)

                    class Status(Enum):
                        """
                        Status (Enum Class)

                        .. data:: ACTIVE = 0

                            VLAN is active

                        .. data:: SUSPENDED = 1

                            VLAN is inactive / suspended

                        """

                        ACTIVE = Enum.YLeaf(0, "ACTIVE")

                        SUSPENDED = Enum.YLeaf(1, "SUSPENDED")



                class State(_Entity_):
                    """
                    State variables for VLANs
                    
                    .. attribute:: vlan_id
                    
                        Interface VLAN id
                    
                        **type**: int
                    
                            **range:** 1..4094
                    
                        **config**: False
                    
                    .. attribute:: name
                    
                        Interface VLAN name
                    
                        **type**: str
                    
                        **config**: False
                    
                    .. attribute:: status
                    
                        Admin state of the VLAN
                    
                        **type**:  :py:class:`Status<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.State.Status>`
                    
                        **config**: False
                    
                        **default value**: ACTIVE
                    
                    .. attribute:: tpid
                    
                        Optionally set the tag protocol identifier field (TPID) that is accepted on the VLAN
                    
                        **type**:  :py:class:`TPIDTYPES<ydk.models.openconfig.openconfig_vlan_types.TPIDTYPES>`
                    
                        **config**: False
                    
                        **default value**: oc-vlan-types:TPID_0x8100
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('vlan_id', (YLeaf(YType.uint16, 'vlan-id'), ['int'])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('status', (YLeaf(YType.enumeration, 'status'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Vlans.Vlan.State.Status')])),
                            ('tpid', (YLeaf(YType.identityref, 'tpid'), [('ydk.models.openconfig.openconfig_vlan_types', 'TPIDTYPES')])),
                        ])
                        self.vlan_id = None
                        self.name = None
                        self.status = None
                        self.tpid = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.State, ['vlan_id', 'name', 'status', 'tpid'], name, value)

                    class Status(Enum):
                        """
                        Status (Enum Class)

                        .. data:: ACTIVE = 0

                            VLAN is active

                        .. data:: SUSPENDED = 1

                            VLAN is inactive / suspended

                        """

                        ACTIVE = Enum.YLeaf(0, "ACTIVE")

                        SUSPENDED = Enum.YLeaf(1, "SUSPENDED")



                class Members(_Entity_):
                    """
                    Enclosing container for list of member interfaces
                    
                    .. attribute:: member
                    
                        List of references to interfaces / subinterfaces associated with the VLAN
                    
                        **type**: list of    :py:class:`Member<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "members"
                        self.yang_parent_name = "vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("member", ("member", NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member))])
                        self._leafs = OrderedDict()

                        self.member = YList(self)
                        self._segment_path = lambda: "members"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Members, [], name, value)

                    class Member(_Entity_):
                        """
                        List of references to interfaces / subinterfaces
                        associated with the VLAN.
                        
                        .. attribute:: interface_ref
                        
                            Reference to an interface or subinterface
                        
                            **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "member"
                            self.yang_parent_name = "members"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef))])
                            self._leafs = OrderedDict()

                            self.interface_ref = NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef()
                            self.interface_ref.parent = self
                            self._children_name_map["interface_ref"] = "interface-ref"
                            self._segment_path = lambda: "member"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member, [], name, value)

                        class InterfaceRef(_Entity_):
                            """
                            Reference to an interface or subinterface
                            
                            .. attribute:: state
                            
                                Operational state for interface\-ref
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "interface-ref"
                                self.yang_parent_name = "member"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State))])
                                self._leafs = OrderedDict()

                                self.state = NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "interface-ref"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef, [], name, value)

                            class State(_Entity_):
                                """
                                Operational state for interface\-ref
                                
                                .. attribute:: interface
                                
                                    Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                
                                    **config**: False
                                
                                .. attribute:: subinterface
                                
                                    Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface-ref"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                        ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                    ])
                                    self.interface = None
                                    self.subinterface = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Vlans.Vlan.Members.Member.InterfaceRef.State, ['interface', 'subinterface'], name, value)







        class Afts(_Entity_):
            """
            The abstract forwarding tables (AFTs) that are associated
            with the network instance. An AFT is instantiated per\-protocol
            running within the network\-instance \- such that one exists for
            IPv4 Unicast, IPv6 Unicast, MPLS, L2 forwarding entries, etc.
            A forwarding entry within the FIB has a set of next\-hops,
            which may be a reference to an entry within another table \-
            e.g., where a Layer 3 next\-hop has an associated Layer 2
            forwarding entry.
            
            .. attribute:: ipv4_unicast
            
                The abstract forwarding table for IPv4 unicast. Entries within this table are uniquely keyed on the IPv4 unicast destination prefix which is matched by ingress packets.  The data set represented by the IPv4 Unicast AFT is the set of entries from the IPv4 unicast RIB that have been selected for installation into the FIB of the device exporting the data structure
            
                **type**:  :py:class:`Ipv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast>`
            
            .. attribute:: ipv6_unicast
            
                The abstract forwarding table for IPv6 unicast. Entries within this table are uniquely keyed on the IPv6 unicast destination prefix which is matched by ingress packets.  The data set represented by the IPv6 Unicast AFTis the set of entries within the IPv6 RIB that 
            
                **type**:  :py:class:`Ipv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast>`
            
            .. attribute:: policy_forwarding
            
                The abstract forwarding table for policy\-based forwarding entries. Since multiple match criteria can be utilised within a policy\-based forwarding rule, this AFT provides a flexible match criteria, and is indexed based on an arbitrary 64\-bit index. Entries within the AFT may match on multiple field types (e.g., L4 header fields, as well as L2 fields).  Examples of entries within this table are\:  \- IPv4 policy\-based routing based on DSCP.  \- MPLS policy\-based forwarding entries
            
                **type**:  :py:class:`PolicyForwarding<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding>`
            
            .. attribute:: mpls
            
                The abstract forwarding table for MPLS label based forwarding entries. Entries within the table are keyed based on the top\-most MPLS label in the stack on the ingress packet
            
                **type**:  :py:class:`Mpls<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls>`
            
            .. attribute:: ethernet
            
                The abstract forwarding table for Ethernet based forwarding entries. Entries within the table are keyed based on the destination MAC address on the ingress packet
            
                **type**:  :py:class:`Ethernet<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "afts"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast)), ("policy-forwarding", ("policy_forwarding", NetworkInstances.NetworkInstance.Afts.PolicyForwarding)), ("mpls", ("mpls", NetworkInstances.NetworkInstance.Afts.Mpls)), ("ethernet", ("ethernet", NetworkInstances.NetworkInstance.Afts.Ethernet))])
                self._leafs = OrderedDict()

                self.ipv4_unicast = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast()
                self.ipv4_unicast.parent = self
                self._children_name_map["ipv4_unicast"] = "ipv4-unicast"

                self.ipv6_unicast = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast()
                self.ipv6_unicast.parent = self
                self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                self.policy_forwarding = NetworkInstances.NetworkInstance.Afts.PolicyForwarding()
                self.policy_forwarding.parent = self
                self._children_name_map["policy_forwarding"] = "policy-forwarding"

                self.mpls = NetworkInstances.NetworkInstance.Afts.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"

                self.ethernet = NetworkInstances.NetworkInstance.Afts.Ethernet()
                self.ethernet.parent = self
                self._children_name_map["ethernet"] = "ethernet"
                self._segment_path = lambda: "afts"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Afts, [], name, value)

            class Ipv4Unicast(_Entity_):
                """
                The abstract forwarding table for IPv4 unicast. Entries
                within this table are uniquely keyed on the IPv4 unicast
                destination prefix which is matched by ingress packets.
                
                The data set represented by the IPv4 Unicast AFT is the set
                of entries from the IPv4 unicast RIB that have been selected
                for installation into the FIB of the device exporting the
                data structure.
                
                .. attribute:: ipv4_entry
                
                    List of the IPv4 unicast entries within the abstract forwarding table. This list is keyed by the destination IPv4 prefix
                
                    **type**: list of    :py:class:`Ipv4Entry<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "ipv4-unicast"
                    self.yang_parent_name = "afts"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv4-entry", ("ipv4_entry", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry))])
                    self._leafs = OrderedDict()

                    self.ipv4_entry = YList(self)
                    self._segment_path = lambda: "ipv4-unicast"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast, [], name, value)

                class Ipv4Entry(_Entity_):
                    """
                    List of the IPv4 unicast entries within the abstract
                    forwarding table. This list is keyed by the destination IPv4
                    prefix.
                    
                    .. attribute:: prefix  (key)
                    
                        Reference to the IPv4 unicast destination prefix which must be matched to utilise the AFT entry
                    
                        **type**: str
                    
                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                    
                        **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters for the IPv4 unicast AFT entry
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parameters for the IPv4 unicast AFT entry
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.State>`
                    
                        **config**: False
                    
                    .. attribute:: next_hops
                    
                        The list of next\-hops that are to be used for entry within the AFT table. The structure of each next\-hop is address family independent, such that it is possible to resolve fully how the next\-hop is treated. For example\:  \- Where ingress IPv4 unicast packets are to be forwarded via  an MPLS LSP, the next\-hop list should indicate the MPLS  label stack that is used to the next\-hop. \- Where ingress MPLS labelled packets are to be forwarded to  an IPv6 nexthop (for example, a CE within a VPN, then the  popped label stack, and IPv6 next\-hop address should be  indicated)
                    
                        **type**:  :py:class:`NextHops<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "ipv4-entry"
                        self.yang_parent_name = "ipv4-unicast"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None

                        self.config = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.next_hops = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops()
                        self.next_hops.parent = self
                        self._children_name_map["next_hops"] = "next-hops"
                        self._segment_path = lambda: "ipv4-entry" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry, ['prefix'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters for the IPv4 unicast AFT entry.
                        
                        .. attribute:: prefix
                        
                            The IPv4 destination prefix that should be matched to utilise the AFT entry
                        
                            **type**: str
                        
                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "ipv4-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.Config, ['prefix'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parameters for the IPv4 unicast AFT
                        entry.
                        
                        .. attribute:: prefix
                        
                            The IPv4 destination prefix that should be matched to utilise the AFT entry
                        
                            **type**: str
                        
                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                        
                            **config**: False
                        
                        .. attribute:: packets_forwarded
                        
                            The number of packets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: octets_forwarded
                        
                            The number of octets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: origin_network_instance
                        
                            If the AFT entry was imported from another network instance (e.g., it corresponds to a L3 forwarding entry which was learned within another network\-instance), the value of this leaf reflects the network\-instance from which it was learned.  For example, if the local network\-instance corresponds to a L3VRF, and routes are imported from the VPNv4 address\-family of the BGP instance in the DEFAULT\_INSTANCE, then this value would reflect the DEFAULT\_INSTANCE as the origin\-network\-instance
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "ipv4-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('packets_forwarded', (YLeaf(YType.uint64, 'packets-forwarded'), ['int'])),
                                ('octets_forwarded', (YLeaf(YType.uint64, 'octets-forwarded'), ['int'])),
                                ('origin_network_instance', (YLeaf(YType.str, 'openconfig-aft-network-instance:origin-network-instance'), ['str'])),
                            ])
                            self.prefix = None
                            self.packets_forwarded = None
                            self.octets_forwarded = None
                            self.origin_network_instance = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.State, ['prefix', 'packets_forwarded', 'octets_forwarded', 'origin_network_instance'], name, value)


                    class NextHops(_Entity_):
                        """
                        The list of next\-hops that are to be used for entry within
                        the AFT table. The structure of each next\-hop is address
                        family independent, such that it is possible to resolve fully
                        how the next\-hop is treated. For example\:
                        
                        \- Where ingress IPv4 unicast packets are to be forwarded via
                         an MPLS LSP, the next\-hop list should indicate the MPLS
                         label stack that is used to the next\-hop.
                        \- Where ingress MPLS labelled packets are to be forwarded to
                         an IPv6 nexthop (for example, a CE within a VPN, then the
                         popped label stack, and IPv6 next\-hop address should be
                         indicated).
                        
                        .. attribute:: next_hop
                        
                            A next\-hop associated with the forwarding instance. The entries within the next\-hop list should only reflect next\-hops that are actively used by the local system. That is to say inactive, backup or FRR next\-hops should not be included within this list
                        
                            **type**: list of    :py:class:`NextHop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "next-hops"
                            self.yang_parent_name = "ipv4-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = YList(self)
                            self._segment_path = lambda: "next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops, [], name, value)

                        class NextHop(_Entity_):
                            """
                            A next\-hop associated with the forwarding instance. The
                            entries within the next\-hop list should only reflect
                            next\-hops that are actively used by the local system.
                            That is to say inactive, backup or FRR next\-hops should
                            not be included within this list.
                            
                            .. attribute:: index  (key)
                            
                                A unique index identifying the next\-hop entry for the AFT entry
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.State>`
                            
                                **config**: False
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['index']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                ])
                                self.index = None

                                self.config = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.interface_ref = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop, ['index'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the AFT next\-hop
                                entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                    ])
                                    self.index = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.Config, ['index'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to the AFT
                                next\-hop entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: weight
                                
                                    The weight of the next\-hop. Traffic is balanced according to the ratio described by the relative weights of the next hops that exist for the AFT entry. Note that all next\-hops that are specified are assumed to be active next\-hops and therefore eligible (and selected) to be installed in the FIB, and hence used for packet forwarding
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: ip_address
                                
                                    The IP address of the next\-hop system
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: mac_address
                                
                                    The MAC address of the next\-hop if resolved by the local network instance
                                
                                    **type**: str
                                
                                        **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                                
                                    **config**: False
                                
                                .. attribute:: popped_mpls_label_stack
                                
                                    The MPLS label stack to be popped from the packet when switched by the system. The stack is encoded as a leaf\-list such that the first entry is the label that is outer\-most (i.e., furthest from the bottom of the stack) label stack to be popped.  If the local system pops the outer\-most label 400, then the value of this list is [400,]. If the local system removes two labels, the outer\-most being 500, and the second of which is 400, then the value of the list is [500, 400].  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: pushed_mpls_label_stack
                                
                                    The MPLS label stack imposed when forwarding packets to the next\-hop \- the stack is encoded as a leaf list whereby the order of the  entries is such that the first entry in the list is the  label at the bottom of the stack to be pushed.  To this end, a packet which is to forwarded to a device using a service label of 42, and a transport label of 8072 will be represented with a label stack list of [42, 8072].  The MPLS label stack list is ordered by the user, such that no system re\-ordering of leaves is permitted by the system.  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: decapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop, the local system performs a decapsulation of the packet \- removing the specified header type. In the case that no next\-hop is specified, the packet header is removed, and a subsequent forwarding lookup is performed on the packet encapsulated within the header, matched within the relevant AFT within the specified network\-instance
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: encapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop the local system performs an encapsulation of the packet \- adding the specified header type
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: origin_protocol
                                
                                    The protocol from which the AFT entry was learned
                                
                                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                                
                                    **config**: False
                                
                                .. attribute:: network_instance
                                
                                    The network\-instance within which the next\-hop should be resolved. When this leaf is unspecified, the next\-hop is resolved within the local instance
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('decapsulate_header', (YLeaf(YType.enumeration, 'decapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('encapsulate_header', (YLeaf(YType.enumeration, 'encapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('origin_protocol', (YLeaf(YType.identityref, 'origin-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                                        ('network_instance', (YLeaf(YType.str, 'openconfig-aft-network-instance:network-instance'), ['str'])),
                                    ])
                                    self.index = None
                                    self.weight = None
                                    self.ip_address = None
                                    self.mac_address = None
                                    self.popped_mpls_label_stack = []
                                    self.pushed_mpls_label_stack = []
                                    self.decapsulate_header = None
                                    self.encapsulate_header = None
                                    self.origin_protocol = None
                                    self.network_instance = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.State, ['index', 'weight', 'ip_address', 'mac_address', 'popped_mpls_label_stack', 'pushed_mpls_label_stack', 'decapsulate_header', 'encapsulate_header', 'origin_protocol', 'network_instance'], name, value)


                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv4Unicast.Ipv4Entry.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)







            class Ipv6Unicast(_Entity_):
                """
                The abstract forwarding table for IPv6 unicast. Entries
                within this table are uniquely keyed on the IPv6 unicast
                destination prefix which is matched by ingress packets.
                
                The data set represented by the IPv6 Unicast AFTis the set
                of entries within the IPv6 RIB that 
                
                .. attribute:: ipv6_entry
                
                    List of the IPv6 unicast entries within the abstract forwarding table. This list is keyed by the destination IPv6 prefix
                
                    **type**: list of    :py:class:`Ipv6Entry<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "ipv6-unicast"
                    self.yang_parent_name = "afts"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ipv6-entry", ("ipv6_entry", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry))])
                    self._leafs = OrderedDict()

                    self.ipv6_entry = YList(self)
                    self._segment_path = lambda: "ipv6-unicast"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast, [], name, value)

                class Ipv6Entry(_Entity_):
                    """
                    List of the IPv6 unicast entries within the abstract
                    forwarding table. This list is keyed by the destination IPv6
                    prefix.
                    
                    .. attribute:: prefix  (key)
                    
                        Reference to the IPv6 unicast destination prefix which must be matched to utilise the AFT entry
                    
                        **type**: str
                    
                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                    
                        **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters for the IPv6 unicast AFT entry
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parameters for the IPv6 unicast AFT entry
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.State>`
                    
                        **config**: False
                    
                    .. attribute:: next_hops
                    
                        The list of next\-hops that are to be used for entry within the AFT table. The structure of each next\-hop is address family independent, such that it is possible to resolve fully how the next\-hop is treated. For example\:  \- Where ingress IPv4 unicast packets are to be forwarded via  an MPLS LSP, the next\-hop list should indicate the MPLS  label stack that is used to the next\-hop. \- Where ingress MPLS labelled packets are to be forwarded to  an IPv6 nexthop (for example, a CE within a VPN, then the  popped label stack, and IPv6 next\-hop address should be  indicated)
                    
                        **type**:  :py:class:`NextHops<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "ipv6-entry"
                        self.yang_parent_name = "ipv6-unicast"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['prefix']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops))])
                        self._leafs = OrderedDict([
                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                        ])
                        self.prefix = None

                        self.config = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.next_hops = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops()
                        self.next_hops.parent = self
                        self._children_name_map["next_hops"] = "next-hops"
                        self._segment_path = lambda: "ipv6-entry" + "[prefix='" + str(self.prefix) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry, ['prefix'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters for the IPv6 unicast AFT entry.
                        
                        .. attribute:: prefix
                        
                            The IPv6 destination prefix that should be matched to utilise the AFT entry
                        
                            **type**: str
                        
                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "ipv6-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.Config, ['prefix'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parameters for the IPv6 unicast AFT
                        entry.
                        
                        .. attribute:: prefix
                        
                            The IPv6 destination prefix that should be matched to utilise the AFT entry
                        
                            **type**: str
                        
                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                        
                            **config**: False
                        
                        .. attribute:: packets_forwarded
                        
                            The number of packets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: octets_forwarded
                        
                            The number of octets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: origin_network_instance
                        
                            If the AFT entry was imported from another network instance (e.g., it corresponds to a L3 forwarding entry which was learned within another network\-instance), the value of this leaf reflects the network\-instance from which it was learned.  For example, if the local network\-instance corresponds to a L3VRF, and routes are imported from the VPNv4 address\-family of the BGP instance in the DEFAULT\_INSTANCE, then this value would reflect the DEFAULT\_INSTANCE as the origin\-network\-instance
                        
                            **type**: str
                        
                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "ipv6-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                ('packets_forwarded', (YLeaf(YType.uint64, 'packets-forwarded'), ['int'])),
                                ('octets_forwarded', (YLeaf(YType.uint64, 'octets-forwarded'), ['int'])),
                                ('origin_network_instance', (YLeaf(YType.str, 'openconfig-aft-network-instance:origin-network-instance'), ['str'])),
                            ])
                            self.prefix = None
                            self.packets_forwarded = None
                            self.octets_forwarded = None
                            self.origin_network_instance = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.State, ['prefix', 'packets_forwarded', 'octets_forwarded', 'origin_network_instance'], name, value)


                    class NextHops(_Entity_):
                        """
                        The list of next\-hops that are to be used for entry within
                        the AFT table. The structure of each next\-hop is address
                        family independent, such that it is possible to resolve fully
                        how the next\-hop is treated. For example\:
                        
                        \- Where ingress IPv4 unicast packets are to be forwarded via
                         an MPLS LSP, the next\-hop list should indicate the MPLS
                         label stack that is used to the next\-hop.
                        \- Where ingress MPLS labelled packets are to be forwarded to
                         an IPv6 nexthop (for example, a CE within a VPN, then the
                         popped label stack, and IPv6 next\-hop address should be
                         indicated).
                        
                        .. attribute:: next_hop
                        
                            A next\-hop associated with the forwarding instance. The entries within the next\-hop list should only reflect next\-hops that are actively used by the local system. That is to say inactive, backup or FRR next\-hops should not be included within this list
                        
                            **type**: list of    :py:class:`NextHop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "next-hops"
                            self.yang_parent_name = "ipv6-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = YList(self)
                            self._segment_path = lambda: "next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops, [], name, value)

                        class NextHop(_Entity_):
                            """
                            A next\-hop associated with the forwarding instance. The
                            entries within the next\-hop list should only reflect
                            next\-hops that are actively used by the local system.
                            That is to say inactive, backup or FRR next\-hops should
                            not be included within this list.
                            
                            .. attribute:: index  (key)
                            
                                A unique index identifying the next\-hop entry for the AFT entry
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.State>`
                            
                                **config**: False
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['index']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                ])
                                self.index = None

                                self.config = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.interface_ref = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop, ['index'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the AFT next\-hop
                                entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                    ])
                                    self.index = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.Config, ['index'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to the AFT
                                next\-hop entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: weight
                                
                                    The weight of the next\-hop. Traffic is balanced according to the ratio described by the relative weights of the next hops that exist for the AFT entry. Note that all next\-hops that are specified are assumed to be active next\-hops and therefore eligible (and selected) to be installed in the FIB, and hence used for packet forwarding
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: ip_address
                                
                                    The IP address of the next\-hop system
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: mac_address
                                
                                    The MAC address of the next\-hop if resolved by the local network instance
                                
                                    **type**: str
                                
                                        **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                                
                                    **config**: False
                                
                                .. attribute:: popped_mpls_label_stack
                                
                                    The MPLS label stack to be popped from the packet when switched by the system. The stack is encoded as a leaf\-list such that the first entry is the label that is outer\-most (i.e., furthest from the bottom of the stack) label stack to be popped.  If the local system pops the outer\-most label 400, then the value of this list is [400,]. If the local system removes two labels, the outer\-most being 500, and the second of which is 400, then the value of the list is [500, 400].  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: pushed_mpls_label_stack
                                
                                    The MPLS label stack imposed when forwarding packets to the next\-hop \- the stack is encoded as a leaf list whereby the order of the  entries is such that the first entry in the list is the  label at the bottom of the stack to be pushed.  To this end, a packet which is to forwarded to a device using a service label of 42, and a transport label of 8072 will be represented with a label stack list of [42, 8072].  The MPLS label stack list is ordered by the user, such that no system re\-ordering of leaves is permitted by the system.  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: decapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop, the local system performs a decapsulation of the packet \- removing the specified header type. In the case that no next\-hop is specified, the packet header is removed, and a subsequent forwarding lookup is performed on the packet encapsulated within the header, matched within the relevant AFT within the specified network\-instance
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: encapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop the local system performs an encapsulation of the packet \- adding the specified header type
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: origin_protocol
                                
                                    The protocol from which the AFT entry was learned
                                
                                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                                
                                    **config**: False
                                
                                .. attribute:: network_instance
                                
                                    The network\-instance within which the next\-hop should be resolved. When this leaf is unspecified, the next\-hop is resolved within the local instance
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Config>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('decapsulate_header', (YLeaf(YType.enumeration, 'decapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('encapsulate_header', (YLeaf(YType.enumeration, 'encapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('origin_protocol', (YLeaf(YType.identityref, 'origin-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                                        ('network_instance', (YLeaf(YType.str, 'openconfig-aft-network-instance:network-instance'), ['str'])),
                                    ])
                                    self.index = None
                                    self.weight = None
                                    self.ip_address = None
                                    self.mac_address = None
                                    self.popped_mpls_label_stack = []
                                    self.pushed_mpls_label_stack = []
                                    self.decapsulate_header = None
                                    self.encapsulate_header = None
                                    self.origin_protocol = None
                                    self.network_instance = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.State, ['index', 'weight', 'ip_address', 'mac_address', 'popped_mpls_label_stack', 'pushed_mpls_label_stack', 'decapsulate_header', 'encapsulate_header', 'origin_protocol', 'network_instance'], name, value)


                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ipv6Unicast.Ipv6Entry.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)







            class PolicyForwarding(_Entity_):
                """
                The abstract forwarding table for policy\-based forwarding
                entries. Since multiple match criteria can be utilised
                within a policy\-based forwarding rule, this AFT provides a
                flexible match criteria, and is indexed based on an
                arbitrary 64\-bit index. Entries within the AFT may match on
                multiple field types (e.g., L4 header fields, as well as L2
                fields).
                
                Examples of entries within this table are\:
                 \- IPv4 policy\-based routing based on DSCP.
                 \- MPLS policy\-based forwarding entries.
                
                .. attribute:: policy_forwarding_entry
                
                    List of the policy forwarding entries within the abstract forwarding table. Each entry is uniquely identified by an index on the system, due to the arbitrary match conditions that may be implemented within the policy forwarding AFT. The index may change upon changes of the entry if, and only if, the device exporting the AFT replaces the entire entry by removing the previous entry and replacing it with a subsequent updated version
                
                    **type**: list of    :py:class:`PolicyForwardingEntry<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "policy-forwarding"
                    self.yang_parent_name = "afts"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("policy-forwarding-entry", ("policy_forwarding_entry", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry))])
                    self._leafs = OrderedDict()

                    self.policy_forwarding_entry = YList(self)
                    self._segment_path = lambda: "policy-forwarding"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding, [], name, value)

                class PolicyForwardingEntry(_Entity_):
                    """
                    List of the policy forwarding entries within the abstract
                    forwarding table. Each entry is uniquely identified by an
                    index on the system, due to the arbitrary match conditions
                    that may be implemented within the policy forwarding AFT.
                    The index may change upon changes of the entry if, and only
                    if, the device exporting the AFT replaces the entire entry
                    by removing the previous entry and replacing it with a
                    subsequent updated version.
                    
                    .. attribute:: index  (key)
                    
                        Reference to the arbitary index for the policy forwarding AFT entry
                    
                        **type**: int
                    
                            **range:** 0..18446744073709551615
                    
                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters for the Policy forwarding AFT entry
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parameters for the Policy Forwarding AFT entry
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.State>`
                    
                        **config**: False
                    
                    .. attribute:: next_hops
                    
                        The list of next\-hops that are to be used for entry within the AFT table. The structure of each next\-hop is address family independent, such that it is possible to resolve fully how the next\-hop is treated. For example\:  \- Where ingress IPv4 unicast packets are to be forwarded via  an MPLS LSP, the next\-hop list should indicate the MPLS  label stack that is used to the next\-hop. \- Where ingress MPLS labelled packets are to be forwarded to  an IPv6 nexthop (for example, a CE within a VPN, then the  popped label stack, and IPv6 next\-hop address should be  indicated)
                    
                        **type**:  :py:class:`NextHops<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "policy-forwarding-entry"
                        self.yang_parent_name = "policy-forwarding"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['index']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops))])
                        self._leafs = OrderedDict([
                            ('index', (YLeaf(YType.str, 'index'), ['int'])),
                        ])
                        self.index = None

                        self.config = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.next_hops = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops()
                        self.next_hops.parent = self
                        self._children_name_map["next_hops"] = "next-hops"
                        self._segment_path = lambda: "policy-forwarding-entry" + "[index='" + str(self.index) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry, ['index'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters for the Policy forwarding
                        AFT entry.
                        
                        .. attribute:: index
                        
                            An arbitrary 64\-bit index identifying the policy forwarding AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                        .. attribute:: ip_prefix
                        
                            The IP prefix that the forwarding entry matches
                        
                            **type**: union of the below types:
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                        
                        .. attribute:: mac_address
                        
                            The MAC address that the forwarding entry matches. Used for Layer 2 forwarding entries, e.g., within a VSI instance
                        
                            **type**: str
                        
                                **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                        
                        .. attribute:: mpls_label
                        
                            The MPLS label that the forwarding entry matches. Used for MPLS forwarding entries, whereby the local device acts as an LSR
                        
                            **type**: union of the below types:
                        
                                **type**: int
                        
                                    **range:** 16..1048575
                        
                                **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                        
                        .. attribute:: mpls_tc
                        
                            The value of the MPLS Traffic Class bits (formerly known as the MPLS experimental bits) that are to be matched by the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..7
                        
                        .. attribute:: ip_dscp
                        
                            The value of the differentiated services code point (DSCP) to be matched for the forwarding entry. The value is specified in cases where specific class\-based forwarding based on IP is implemented by the device
                        
                            **type**: int
                        
                                **range:** 0..63
                        
                        .. attribute:: ip_protocol
                        
                            The value of the IP protocol field of an IPv4 packet, or the next\-header field of an IPv6 packet which is to be matched by the AFT entry. This field is utilised where forwarding is performed based on L4 information
                        
                            **type**: union of the below types:
                        
                                **type**: int
                        
                                    **range:** 0..254
                        
                                **type**:  :py:class:`IPPROTOCOL<ydk.models.openconfig.openconfig_packet_match_types.IPPROTOCOL>`
                        
                        .. attribute:: l4_src_port
                        
                            The value of the source port field of the transport header that is to be matched by the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                        .. attribute:: l4_dst_port
                        
                            The value of the destination port field of the transport header that is to be matched by the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "policy-forwarding-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                ('ip_prefix', (YLeaf(YType.str, 'ip-prefix'), ['str','str'])),
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                ('mpls_label', (YLeaf(YType.str, 'mpls-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                ('mpls_tc', (YLeaf(YType.uint8, 'mpls-tc'), ['int'])),
                                ('ip_dscp', (YLeaf(YType.uint8, 'ip-dscp'), ['int'])),
                                ('ip_protocol', (YLeaf(YType.str, 'ip-protocol'), ['int',('ydk.models.openconfig.openconfig_packet_match_types', 'IPPROTOCOL')])),
                                ('l4_src_port', (YLeaf(YType.uint16, 'l4-src-port'), ['int'])),
                                ('l4_dst_port', (YLeaf(YType.uint16, 'l4-dst-port'), ['int'])),
                            ])
                            self.index = None
                            self.ip_prefix = None
                            self.mac_address = None
                            self.mpls_label = None
                            self.mpls_tc = None
                            self.ip_dscp = None
                            self.ip_protocol = None
                            self.l4_src_port = None
                            self.l4_dst_port = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.Config, ['index', 'ip_prefix', 'mac_address', 'mpls_label', 'mpls_tc', 'ip_dscp', 'ip_protocol', 'l4_src_port', 'l4_dst_port'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parameters for the Policy Forwarding
                        AFT entry.
                        
                        .. attribute:: index
                        
                            An arbitrary 64\-bit index identifying the policy forwarding AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: ip_prefix
                        
                            The IP prefix that the forwarding entry matches
                        
                            **type**: union of the below types:
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                        
                            **config**: False
                        
                        .. attribute:: mac_address
                        
                            The MAC address that the forwarding entry matches. Used for Layer 2 forwarding entries, e.g., within a VSI instance
                        
                            **type**: str
                        
                                **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                        
                            **config**: False
                        
                        .. attribute:: mpls_label
                        
                            The MPLS label that the forwarding entry matches. Used for MPLS forwarding entries, whereby the local device acts as an LSR
                        
                            **type**: union of the below types:
                        
                                **type**: int
                        
                                    **range:** 16..1048575
                        
                                **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                        
                            **config**: False
                        
                        .. attribute:: mpls_tc
                        
                            The value of the MPLS Traffic Class bits (formerly known as the MPLS experimental bits) that are to be matched by the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..7
                        
                            **config**: False
                        
                        .. attribute:: ip_dscp
                        
                            The value of the differentiated services code point (DSCP) to be matched for the forwarding entry. The value is specified in cases where specific class\-based forwarding based on IP is implemented by the device
                        
                            **type**: int
                        
                                **range:** 0..63
                        
                            **config**: False
                        
                        .. attribute:: ip_protocol
                        
                            The value of the IP protocol field of an IPv4 packet, or the next\-header field of an IPv6 packet which is to be matched by the AFT entry. This field is utilised where forwarding is performed based on L4 information
                        
                            **type**: union of the below types:
                        
                                **type**: int
                        
                                    **range:** 0..254
                        
                                **type**:  :py:class:`IPPROTOCOL<ydk.models.openconfig.openconfig_packet_match_types.IPPROTOCOL>`
                        
                            **config**: False
                        
                        .. attribute:: l4_src_port
                        
                            The value of the source port field of the transport header that is to be matched by the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **config**: False
                        
                        .. attribute:: l4_dst_port
                        
                            The value of the destination port field of the transport header that is to be matched by the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..65535
                        
                            **config**: False
                        
                        .. attribute:: packets_forwarded
                        
                            The number of packets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: octets_forwarded
                        
                            The number of octets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "policy-forwarding-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                ('ip_prefix', (YLeaf(YType.str, 'ip-prefix'), ['str','str'])),
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                ('mpls_label', (YLeaf(YType.str, 'mpls-label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                ('mpls_tc', (YLeaf(YType.uint8, 'mpls-tc'), ['int'])),
                                ('ip_dscp', (YLeaf(YType.uint8, 'ip-dscp'), ['int'])),
                                ('ip_protocol', (YLeaf(YType.str, 'ip-protocol'), ['int',('ydk.models.openconfig.openconfig_packet_match_types', 'IPPROTOCOL')])),
                                ('l4_src_port', (YLeaf(YType.uint16, 'l4-src-port'), ['int'])),
                                ('l4_dst_port', (YLeaf(YType.uint16, 'l4-dst-port'), ['int'])),
                                ('packets_forwarded', (YLeaf(YType.uint64, 'packets-forwarded'), ['int'])),
                                ('octets_forwarded', (YLeaf(YType.uint64, 'octets-forwarded'), ['int'])),
                            ])
                            self.index = None
                            self.ip_prefix = None
                            self.mac_address = None
                            self.mpls_label = None
                            self.mpls_tc = None
                            self.ip_dscp = None
                            self.ip_protocol = None
                            self.l4_src_port = None
                            self.l4_dst_port = None
                            self.packets_forwarded = None
                            self.octets_forwarded = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.State, ['index', 'ip_prefix', 'mac_address', 'mpls_label', 'mpls_tc', 'ip_dscp', 'ip_protocol', 'l4_src_port', 'l4_dst_port', 'packets_forwarded', 'octets_forwarded'], name, value)


                    class NextHops(_Entity_):
                        """
                        The list of next\-hops that are to be used for entry within
                        the AFT table. The structure of each next\-hop is address
                        family independent, such that it is possible to resolve fully
                        how the next\-hop is treated. For example\:
                        
                        \- Where ingress IPv4 unicast packets are to be forwarded via
                         an MPLS LSP, the next\-hop list should indicate the MPLS
                         label stack that is used to the next\-hop.
                        \- Where ingress MPLS labelled packets are to be forwarded to
                         an IPv6 nexthop (for example, a CE within a VPN, then the
                         popped label stack, and IPv6 next\-hop address should be
                         indicated).
                        
                        .. attribute:: next_hop
                        
                            A next\-hop associated with the forwarding instance. The entries within the next\-hop list should only reflect next\-hops that are actively used by the local system. That is to say inactive, backup or FRR next\-hops should not be included within this list
                        
                            **type**: list of    :py:class:`NextHop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "next-hops"
                            self.yang_parent_name = "policy-forwarding-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = YList(self)
                            self._segment_path = lambda: "next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops, [], name, value)

                        class NextHop(_Entity_):
                            """
                            A next\-hop associated with the forwarding instance. The
                            entries within the next\-hop list should only reflect
                            next\-hops that are actively used by the local system.
                            That is to say inactive, backup or FRR next\-hops should
                            not be included within this list.
                            
                            .. attribute:: index  (key)
                            
                                A unique index identifying the next\-hop entry for the AFT entry
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.State>`
                            
                                **config**: False
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['index']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                ])
                                self.index = None

                                self.config = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.interface_ref = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop, ['index'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the AFT next\-hop
                                entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                    ])
                                    self.index = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.Config, ['index'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to the AFT
                                next\-hop entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: weight
                                
                                    The weight of the next\-hop. Traffic is balanced according to the ratio described by the relative weights of the next hops that exist for the AFT entry. Note that all next\-hops that are specified are assumed to be active next\-hops and therefore eligible (and selected) to be installed in the FIB, and hence used for packet forwarding
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: ip_address
                                
                                    The IP address of the next\-hop system
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: mac_address
                                
                                    The MAC address of the next\-hop if resolved by the local network instance
                                
                                    **type**: str
                                
                                        **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                                
                                    **config**: False
                                
                                .. attribute:: popped_mpls_label_stack
                                
                                    The MPLS label stack to be popped from the packet when switched by the system. The stack is encoded as a leaf\-list such that the first entry is the label that is outer\-most (i.e., furthest from the bottom of the stack) label stack to be popped.  If the local system pops the outer\-most label 400, then the value of this list is [400,]. If the local system removes two labels, the outer\-most being 500, and the second of which is 400, then the value of the list is [500, 400].  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: pushed_mpls_label_stack
                                
                                    The MPLS label stack imposed when forwarding packets to the next\-hop \- the stack is encoded as a leaf list whereby the order of the  entries is such that the first entry in the list is the  label at the bottom of the stack to be pushed.  To this end, a packet which is to forwarded to a device using a service label of 42, and a transport label of 8072 will be represented with a label stack list of [42, 8072].  The MPLS label stack list is ordered by the user, such that no system re\-ordering of leaves is permitted by the system.  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: decapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop, the local system performs a decapsulation of the packet \- removing the specified header type. In the case that no next\-hop is specified, the packet header is removed, and a subsequent forwarding lookup is performed on the packet encapsulated within the header, matched within the relevant AFT within the specified network\-instance
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: encapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop the local system performs an encapsulation of the packet \- adding the specified header type
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: origin_protocol
                                
                                    The protocol from which the AFT entry was learned
                                
                                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('decapsulate_header', (YLeaf(YType.enumeration, 'decapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('encapsulate_header', (YLeaf(YType.enumeration, 'encapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('origin_protocol', (YLeaf(YType.identityref, 'origin-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                                    ])
                                    self.index = None
                                    self.weight = None
                                    self.ip_address = None
                                    self.mac_address = None
                                    self.popped_mpls_label_stack = []
                                    self.pushed_mpls_label_stack = []
                                    self.decapsulate_header = None
                                    self.encapsulate_header = None
                                    self.origin_protocol = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.State, ['index', 'weight', 'ip_address', 'mac_address', 'popped_mpls_label_stack', 'pushed_mpls_label_stack', 'decapsulate_header', 'encapsulate_header', 'origin_protocol'], name, value)


                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.PolicyForwarding.PolicyForwardingEntry.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)







            class Mpls(_Entity_):
                """
                The abstract forwarding table for MPLS label based
                forwarding entries. Entries within the table are keyed based
                on the top\-most MPLS label in the stack on the ingress
                packet.
                
                .. attribute:: label_entry
                
                    List of the MPLS entries within the abstract forwarding table. This list is keyed by the top\-most MPLS label
                
                    **type**: list of    :py:class:`LabelEntry<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "afts"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("label-entry", ("label_entry", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry))])
                    self._leafs = OrderedDict()

                    self.label_entry = YList(self)
                    self._segment_path = lambda: "mpls"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls, [], name, value)

                class LabelEntry(_Entity_):
                    """
                    List of the MPLS entries within the abstract
                    forwarding table. This list is keyed by the top\-most MPLS
                    label.
                    
                    .. attribute:: label  (key)
                    
                        Reference to the top\-most MPLS label matched by the entry
                    
                        **type**: union of the below types:
                    
                            **type**: int
                    
                                **range:** 16..1048575
                    
                            **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                    
                        **refers to**:  :py:class:`label<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters for the MPLS AFT entry
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parameters for the MPLS AFT entry
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.State>`
                    
                        **config**: False
                    
                    .. attribute:: next_hops
                    
                        The list of next\-hops that are to be used for entry within the AFT table. The structure of each next\-hop is address family independent, such that it is possible to resolve fully how the next\-hop is treated. For example\:  \- Where ingress IPv4 unicast packets are to be forwarded via  an MPLS LSP, the next\-hop list should indicate the MPLS  label stack that is used to the next\-hop. \- Where ingress MPLS labelled packets are to be forwarded to  an IPv6 nexthop (for example, a CE within a VPN, then the  popped label stack, and IPv6 next\-hop address should be  indicated)
                    
                        **type**:  :py:class:`NextHops<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "label-entry"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['label']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops))])
                        self._leafs = OrderedDict([
                            ('label', (YLeaf(YType.str, 'label'), ['str'])),
                        ])
                        self.label = None

                        self.config = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.next_hops = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops()
                        self.next_hops.parent = self
                        self._children_name_map["next_hops"] = "next-hops"
                        self._segment_path = lambda: "label-entry" + "[label='" + str(self.label) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry, ['label'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters for the MPLS AFT entry.
                        
                        .. attribute:: label
                        
                            The top\-most MPLS label that should be matched to utilise the AFT entry
                        
                            **type**: union of the below types:
                        
                                **type**: int
                        
                                    **range:** 16..1048575
                        
                                **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "label-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('label', (YLeaf(YType.str, 'label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                            ])
                            self.label = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.Config, ['label'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parameters for the MPLS AFT
                        entry.
                        
                        .. attribute:: label
                        
                            The top\-most MPLS label that should be matched to utilise the AFT entry
                        
                            **type**: union of the below types:
                        
                                **type**: int
                        
                                    **range:** 16..1048575
                        
                                **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                        
                            **config**: False
                        
                        .. attribute:: packets_forwarded
                        
                            The number of packets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: octets_forwarded
                        
                            The number of octets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "label-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('label', (YLeaf(YType.str, 'label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                ('packets_forwarded', (YLeaf(YType.uint64, 'packets-forwarded'), ['int'])),
                                ('octets_forwarded', (YLeaf(YType.uint64, 'octets-forwarded'), ['int'])),
                            ])
                            self.label = None
                            self.packets_forwarded = None
                            self.octets_forwarded = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.State, ['label', 'packets_forwarded', 'octets_forwarded'], name, value)


                    class NextHops(_Entity_):
                        """
                        The list of next\-hops that are to be used for entry within
                        the AFT table. The structure of each next\-hop is address
                        family independent, such that it is possible to resolve fully
                        how the next\-hop is treated. For example\:
                        
                        \- Where ingress IPv4 unicast packets are to be forwarded via
                         an MPLS LSP, the next\-hop list should indicate the MPLS
                         label stack that is used to the next\-hop.
                        \- Where ingress MPLS labelled packets are to be forwarded to
                         an IPv6 nexthop (for example, a CE within a VPN, then the
                         popped label stack, and IPv6 next\-hop address should be
                         indicated).
                        
                        .. attribute:: next_hop
                        
                            A next\-hop associated with the forwarding instance. The entries within the next\-hop list should only reflect next\-hops that are actively used by the local system. That is to say inactive, backup or FRR next\-hops should not be included within this list
                        
                            **type**: list of    :py:class:`NextHop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "next-hops"
                            self.yang_parent_name = "label-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = YList(self)
                            self._segment_path = lambda: "next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops, [], name, value)

                        class NextHop(_Entity_):
                            """
                            A next\-hop associated with the forwarding instance. The
                            entries within the next\-hop list should only reflect
                            next\-hops that are actively used by the local system.
                            That is to say inactive, backup or FRR next\-hops should
                            not be included within this list.
                            
                            .. attribute:: index  (key)
                            
                                A unique index identifying the next\-hop entry for the AFT entry
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.State>`
                            
                                **config**: False
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['index']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                ])
                                self.index = None

                                self.config = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.interface_ref = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop, ['index'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the AFT next\-hop
                                entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                    ])
                                    self.index = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.Config, ['index'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to the AFT
                                next\-hop entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: weight
                                
                                    The weight of the next\-hop. Traffic is balanced according to the ratio described by the relative weights of the next hops that exist for the AFT entry. Note that all next\-hops that are specified are assumed to be active next\-hops and therefore eligible (and selected) to be installed in the FIB, and hence used for packet forwarding
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: ip_address
                                
                                    The IP address of the next\-hop system
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: mac_address
                                
                                    The MAC address of the next\-hop if resolved by the local network instance
                                
                                    **type**: str
                                
                                        **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                                
                                    **config**: False
                                
                                .. attribute:: popped_mpls_label_stack
                                
                                    The MPLS label stack to be popped from the packet when switched by the system. The stack is encoded as a leaf\-list such that the first entry is the label that is outer\-most (i.e., furthest from the bottom of the stack) label stack to be popped.  If the local system pops the outer\-most label 400, then the value of this list is [400,]. If the local system removes two labels, the outer\-most being 500, and the second of which is 400, then the value of the list is [500, 400].  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: pushed_mpls_label_stack
                                
                                    The MPLS label stack imposed when forwarding packets to the next\-hop \- the stack is encoded as a leaf list whereby the order of the  entries is such that the first entry in the list is the  label at the bottom of the stack to be pushed.  To this end, a packet which is to forwarded to a device using a service label of 42, and a transport label of 8072 will be represented with a label stack list of [42, 8072].  The MPLS label stack list is ordered by the user, such that no system re\-ordering of leaves is permitted by the system.  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: decapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop, the local system performs a decapsulation of the packet \- removing the specified header type. In the case that no next\-hop is specified, the packet header is removed, and a subsequent forwarding lookup is performed on the packet encapsulated within the header, matched within the relevant AFT within the specified network\-instance
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: encapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop the local system performs an encapsulation of the packet \- adding the specified header type
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: origin_protocol
                                
                                    The protocol from which the AFT entry was learned
                                
                                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('decapsulate_header', (YLeaf(YType.enumeration, 'decapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('encapsulate_header', (YLeaf(YType.enumeration, 'encapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('origin_protocol', (YLeaf(YType.identityref, 'origin-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                                    ])
                                    self.index = None
                                    self.weight = None
                                    self.ip_address = None
                                    self.mac_address = None
                                    self.popped_mpls_label_stack = []
                                    self.pushed_mpls_label_stack = []
                                    self.decapsulate_header = None
                                    self.encapsulate_header = None
                                    self.origin_protocol = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.State, ['index', 'weight', 'ip_address', 'mac_address', 'popped_mpls_label_stack', 'pushed_mpls_label_stack', 'decapsulate_header', 'encapsulate_header', 'origin_protocol'], name, value)


                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Mpls.LabelEntry.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)







            class Ethernet(_Entity_):
                """
                The abstract forwarding table for Ethernet based forwarding
                entries. Entries within the table are keyed based on the
                destination MAC address on the ingress packet.
                
                .. attribute:: mac_entry
                
                    List of the Ethernet entries within the abstract forwarding table. This list is keyed by the outer MAC address of the Ethernet frame
                
                    **type**: list of    :py:class:`MacEntry<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "ethernet"
                    self.yang_parent_name = "afts"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mac-entry", ("mac_entry", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry))])
                    self._leafs = OrderedDict()

                    self.mac_entry = YList(self)
                    self._segment_path = lambda: "ethernet"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet, [], name, value)

                class MacEntry(_Entity_):
                    """
                    List of the Ethernet entries within the abstract
                    forwarding table. This list is keyed by the outer MAC address
                    of the Ethernet frame.
                    
                    .. attribute:: mac_address  (key)
                    
                        Reference to the outer MAC address matched by the entry
                    
                        **type**: str
                    
                            **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                    
                        **refers to**:  :py:class:`mac_address<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.Config>`
                    
                    .. attribute:: config
                    
                        Configuration parameters for the Ethernet AFT entry
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.Config>`
                    
                    .. attribute:: state
                    
                        Operational state parameters for the Ethernet AFT entry
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.State>`
                    
                        **config**: False
                    
                    .. attribute:: next_hops
                    
                        The list of next\-hops that are to be used for entry within the AFT table. The structure of each next\-hop is address family independent, such that it is possible to resolve fully how the next\-hop is treated. For example\:  \- Where ingress IPv4 unicast packets are to be forwarded via  an MPLS LSP, the next\-hop list should indicate the MPLS  label stack that is used to the next\-hop. \- Where ingress MPLS labelled packets are to be forwarded to  an IPv6 nexthop (for example, a CE within a VPN, then the  popped label stack, and IPv6 next\-hop address should be  indicated)
                    
                        **type**:  :py:class:`NextHops<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "mac-entry"
                        self.yang_parent_name = "ethernet"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['mac_address']
                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops))])
                        self._leafs = OrderedDict([
                            ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                        ])
                        self.mac_address = None

                        self.config = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"

                        self.next_hops = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops()
                        self.next_hops.parent = self
                        self._children_name_map["next_hops"] = "next-hops"
                        self._segment_path = lambda: "mac-entry" + "[mac-address='" + str(self.mac_address) + "']"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry, ['mac_address'], name, value)

                    class Config(_Entity_):
                        """
                        Configuration parameters for the Ethernet AFT entry.
                        
                        .. attribute:: mac_address
                        
                            The outer MAC address of the Ethernet frame that must be matched for the AFT entry to be utilised
                        
                            **type**: str
                        
                                **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "mac-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                            ])
                            self.mac_address = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.Config, ['mac_address'], name, value)


                    class State(_Entity_):
                        """
                        Operational state parameters for the Ethernet AFT
                        entry.
                        
                        .. attribute:: mac_address
                        
                            The outer MAC address of the Ethernet frame that must be matched for the AFT entry to be utilised
                        
                            **type**: str
                        
                                **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                        
                            **config**: False
                        
                        .. attribute:: packets_forwarded
                        
                            The number of packets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        .. attribute:: octets_forwarded
                        
                            The number of octets which have matched, and been forwarded, based on the AFT entry
                        
                            **type**: int
                        
                                **range:** 0..18446744073709551615
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "mac-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                ('packets_forwarded', (YLeaf(YType.uint64, 'packets-forwarded'), ['int'])),
                                ('octets_forwarded', (YLeaf(YType.uint64, 'octets-forwarded'), ['int'])),
                            ])
                            self.mac_address = None
                            self.packets_forwarded = None
                            self.octets_forwarded = None
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.State, ['mac_address', 'packets_forwarded', 'octets_forwarded'], name, value)


                    class NextHops(_Entity_):
                        """
                        The list of next\-hops that are to be used for entry within
                        the AFT table. The structure of each next\-hop is address
                        family independent, such that it is possible to resolve fully
                        how the next\-hop is treated. For example\:
                        
                        \- Where ingress IPv4 unicast packets are to be forwarded via
                         an MPLS LSP, the next\-hop list should indicate the MPLS
                         label stack that is used to the next\-hop.
                        \- Where ingress MPLS labelled packets are to be forwarded to
                         an IPv6 nexthop (for example, a CE within a VPN, then the
                         popped label stack, and IPv6 next\-hop address should be
                         indicated).
                        
                        .. attribute:: next_hop
                        
                            A next\-hop associated with the forwarding instance. The entries within the next\-hop list should only reflect next\-hops that are actively used by the local system. That is to say inactive, backup or FRR next\-hops should not be included within this list
                        
                            **type**: list of    :py:class:`NextHop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "next-hops"
                            self.yang_parent_name = "mac-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop))])
                            self._leafs = OrderedDict()

                            self.next_hop = YList(self)
                            self._segment_path = lambda: "next-hops"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops, [], name, value)

                        class NextHop(_Entity_):
                            """
                            A next\-hop associated with the forwarding instance. The
                            entries within the next\-hop list should only reflect
                            next\-hops that are actively used by the local system.
                            That is to say inactive, backup or FRR next\-hops should
                            not be included within this list.
                            
                            .. attribute:: index  (key)
                            
                                A unique index identifying the next\-hop entry for the AFT entry
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to the AFT next\-hop entry
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.State>`
                            
                                **config**: False
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "next-hop"
                                self.yang_parent_name = "next-hops"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['index']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('index', (YLeaf(YType.str, 'index'), ['int'])),
                                ])
                                self.index = None

                                self.config = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.interface_ref = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop, ['index'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the AFT next\-hop
                                entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                    ])
                                    self.index = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.Config, ['index'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to the AFT
                                next\-hop entry
                                
                                .. attribute:: index
                                
                                    A unique entry for the next\-hop
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: weight
                                
                                    The weight of the next\-hop. Traffic is balanced according to the ratio described by the relative weights of the next hops that exist for the AFT entry. Note that all next\-hops that are specified are assumed to be active next\-hops and therefore eligible (and selected) to be installed in the FIB, and hence used for packet forwarding
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: ip_address
                                
                                    The IP address of the next\-hop system
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: mac_address
                                
                                    The MAC address of the next\-hop if resolved by the local network instance
                                
                                    **type**: str
                                
                                        **pattern:** ^[0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}$
                                
                                    **config**: False
                                
                                .. attribute:: popped_mpls_label_stack
                                
                                    The MPLS label stack to be popped from the packet when switched by the system. The stack is encoded as a leaf\-list such that the first entry is the label that is outer\-most (i.e., furthest from the bottom of the stack) label stack to be popped.  If the local system pops the outer\-most label 400, then the value of this list is [400,]. If the local system removes two labels, the outer\-most being 500, and the second of which is 400, then the value of the list is [500, 400].  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: pushed_mpls_label_stack
                                
                                    The MPLS label stack imposed when forwarding packets to the next\-hop \- the stack is encoded as a leaf list whereby the order of the  entries is such that the first entry in the list is the  label at the bottom of the stack to be pushed.  To this end, a packet which is to forwarded to a device using a service label of 42, and a transport label of 8072 will be represented with a label stack list of [42, 8072].  The MPLS label stack list is ordered by the user, such that no system re\-ordering of leaves is permitted by the system.  A swap operation is reflected by entries in the popped\-mpls\-label\-stack and pushed\-mpls\-label\-stack nodes
                                
                                    **type**: union of the below types:
                                
                                        **type**: list of int
                                
                                            **range:** 16..1048575
                                
                                        **type**: list of   :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                
                                    **config**: False
                                
                                .. attribute:: decapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop, the local system performs a decapsulation of the packet \- removing the specified header type. In the case that no next\-hop is specified, the packet header is removed, and a subsequent forwarding lookup is performed on the packet encapsulated within the header, matched within the relevant AFT within the specified network\-instance
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: encapsulate_header
                                
                                    When forwarding a packet to the specified next\-hop the local system performs an encapsulation of the packet \- adding the specified header type
                                
                                    **type**:  :py:class:`EncapsulationHeaderType<ydk.models.openconfig.openconfig_aft_types.EncapsulationHeaderType>`
                                
                                    **config**: False
                                
                                .. attribute:: origin_protocol
                                
                                    The protocol from which the AFT entry was learned
                                
                                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.uint64, 'index'), ['int'])),
                                        ('weight', (YLeaf(YType.uint32, 'weight'), ['int'])),
                                        ('ip_address', (YLeaf(YType.str, 'ip-address'), ['str','str'])),
                                        ('mac_address', (YLeaf(YType.str, 'mac-address'), ['str'])),
                                        ('popped_mpls_label_stack', (YLeafList(YType.str, 'popped-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('pushed_mpls_label_stack', (YLeafList(YType.str, 'pushed-mpls-label-stack'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                        ('decapsulate_header', (YLeaf(YType.enumeration, 'decapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('encapsulate_header', (YLeaf(YType.enumeration, 'encapsulate-header'), [('ydk.models.openconfig.openconfig_aft_types', 'EncapsulationHeaderType', '')])),
                                        ('origin_protocol', (YLeaf(YType.identityref, 'origin-protocol'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                                    ])
                                    self.index = None
                                    self.weight = None
                                    self.ip_address = None
                                    self.mac_address = None
                                    self.popped_mpls_label_stack = []
                                    self.pushed_mpls_label_stack = []
                                    self.decapsulate_header = None
                                    self.encapsulate_header = None
                                    self.origin_protocol = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.State, ['index', 'weight', 'ip_address', 'mac_address', 'popped_mpls_label_stack', 'pushed_mpls_label_stack', 'decapsulate_header', 'encapsulate_header', 'origin_protocol'], name, value)


                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Afts.Ethernet.MacEntry.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)








        class Protocols(_Entity_):
            """
            The routing protocols that are enabled for this
            network\-instance.
            
            .. attribute:: protocol
            
                A process (instance) of a routing protocol. Some systems may not support more than one instance of a particular routing protocol
            
                **type**: list of    :py:class:`Protocol<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol>`
            
            """
            _prefix = 'oc-netinst'
            _revision = '2017-01-13'

            def __init__(self):
                super().__init__()

                self.yang_name = "protocols"
                self.yang_parent_name = "network-instance"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("protocol", ("protocol", NetworkInstances.NetworkInstance.Protocols.Protocol))])
                self._leafs = OrderedDict()

                self.protocol = YList(self)
                self._segment_path = lambda: "protocols"
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols, [], name, value)

            class Protocol(_Entity_):
                """
                A process (instance) of a routing protocol. Some
                systems may not support more than one instance of
                a particular routing protocol
                
                .. attribute:: identifier  (key)
                
                    The protocol name for the routing or forwarding protocol to be instantiated
                
                    **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                
                .. attribute:: name  (key)
                
                    An operator\-assigned identifier for the routing or forwarding protocol. For some processes this leaf may be system defined
                
                    **type**: str
                
                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Config>`
                
                .. attribute:: config
                
                    Configuration parameters relating to the routing protocol instance
                
                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Config>`
                
                .. attribute:: state
                
                    State parameters relating to the routing protocol instance
                
                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.State>`
                
                    **config**: False
                
                .. attribute:: static_routes
                
                    Enclosing container for the list of static routes
                
                    **type**:  :py:class:`StaticRoutes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes>`
                
                .. attribute:: local_aggregates
                
                    Enclosing container for locally\-defined aggregate routes
                
                    **type**:  :py:class:`LocalAggregates<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates>`
                
                .. attribute:: bgp
                
                    Top\-level configuration and state for the BGP router
                
                    **type**:  :py:class:`Bgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp>`
                
                .. attribute:: isis
                
                    This container defines top\-level ISIS configuration and state information
                
                    **type**:  :py:class:`Isis<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis>`
                
                """
                _prefix = 'oc-netinst'
                _revision = '2017-01-13'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "protocol"
                    self.yang_parent_name = "protocols"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = ['identifier','name']
                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.State)), ("static-routes", ("static_routes", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes)), ("local-aggregates", ("local_aggregates", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates)), ("bgp", ("bgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp)), ("isis", ("isis", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis))])
                    self._leafs = OrderedDict([
                        ('identifier', (YLeaf(YType.identityref, 'identifier'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                    ])
                    self.identifier = None
                    self.name = None

                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Config()
                    self.config.parent = self
                    self._children_name_map["config"] = "config"

                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.State()
                    self.state.parent = self
                    self._children_name_map["state"] = "state"

                    self.static_routes = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes()
                    self.static_routes.parent = self
                    self._children_name_map["static_routes"] = "static-routes"

                    self.local_aggregates = NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates()
                    self.local_aggregates.parent = self
                    self._children_name_map["local_aggregates"] = "local-aggregates"

                    self.bgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp()
                    self.bgp.parent = self
                    self._children_name_map["bgp"] = "bgp"

                    self.isis = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis()
                    self.isis.parent = self
                    self._children_name_map["isis"] = "isis"
                    self._segment_path = lambda: "protocol" + "[identifier='" + str(self.identifier) + "']" + "[name='" + str(self.name) + "']"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol, ['identifier', 'name'], name, value)

                class Config(_Entity_):
                    """
                    Configuration parameters relating to the routing
                    protocol instance
                    
                    .. attribute:: identifier
                    
                        The protocol identifier for the instance
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                    .. attribute:: name
                    
                        A unique name for the protocol instance
                    
                        **type**: str
                    
                    .. attribute:: enabled
                    
                        A boolean value indicating whether the local protocol instance is enabled
                    
                        **type**: bool
                    
                    .. attribute:: default_metric
                    
                        The default metric within the RIB for entries that are installed by this protocol instance. This value may be overridden by protocol specific configuration options. The lower the metric specified the more preferable the RIB entry is to be selected for use within the network instance. Where multiple entries have the same metric value then these equal cost paths should be treated according to the specified ECMP path selection behaviour for the instance
                    
                        **type**: int
                    
                            **range:** 0..4294967295
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "config"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('identifier', (YLeaf(YType.identityref, 'identifier'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                        ])
                        self.identifier = None
                        self.name = None
                        self.enabled = None
                        self.default_metric = None
                        self._segment_path = lambda: "config"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Config, ['identifier', 'name', 'enabled', 'default_metric'], name, value)


                class State(_Entity_):
                    """
                    State parameters relating to the routing protocol
                    instance
                    
                    .. attribute:: identifier
                    
                        The protocol identifier for the instance
                    
                        **type**:  :py:class:`INSTALLPROTOCOLTYPE<ydk.models.openconfig.openconfig_policy_types.INSTALLPROTOCOLTYPE>`
                    
                        **config**: False
                    
                    .. attribute:: name
                    
                        A unique name for the protocol instance
                    
                        **type**: str
                    
                        **config**: False
                    
                    .. attribute:: enabled
                    
                        A boolean value indicating whether the local protocol instance is enabled
                    
                        **type**: bool
                    
                        **config**: False
                    
                    .. attribute:: default_metric
                    
                        The default metric within the RIB for entries that are installed by this protocol instance. This value may be overridden by protocol specific configuration options. The lower the metric specified the more preferable the RIB entry is to be selected for use within the network instance. Where multiple entries have the same metric value then these equal cost paths should be treated according to the specified ECMP path selection behaviour for the instance
                    
                        **type**: int
                    
                            **range:** 0..4294967295
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "state"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('identifier', (YLeaf(YType.identityref, 'identifier'), [('ydk.models.openconfig.openconfig_policy_types', 'INSTALLPROTOCOLTYPE')])),
                            ('name', (YLeaf(YType.str, 'name'), ['str'])),
                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                            ('default_metric', (YLeaf(YType.uint32, 'default-metric'), ['int'])),
                        ])
                        self.identifier = None
                        self.name = None
                        self.enabled = None
                        self.default_metric = None
                        self._segment_path = lambda: "state"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.State, ['identifier', 'name', 'enabled', 'default_metric'], name, value)


                class StaticRoutes(_Entity_):
                    """
                    Enclosing container for the list of static routes
                    
                    .. attribute:: static
                    
                        List of locally configured static routes
                    
                        **type**: list of    :py:class:`Static<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "static-routes"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("static", ("static", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static))])
                        self._leafs = OrderedDict()

                        self.static = YList(self)
                        self._segment_path = lambda: "static-routes"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes, [], name, value)

                    class Static(_Entity_):
                        """
                        List of locally configured static routes
                        
                        .. attribute:: prefix  (key)
                        
                            Reference to the destination prefix list key
                        
                            **type**: union of the below types:
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                        
                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config>`
                        
                        .. attribute:: config
                        
                            Configuration data for static routes
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config>`
                        
                        .. attribute:: state
                        
                            Operational state data for static routes
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State>`
                        
                            **config**: False
                        
                        .. attribute:: next_hops
                        
                            Configuration and state parameters relating to the next\-hops that are to be utilised for the static route being specified
                        
                            **type**:  :py:class:`NextHops<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "static"
                            self.yang_parent_name = "static-routes"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State)), ("next-hops", ("next_hops", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.next_hops = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops()
                            self.next_hops.parent = self
                            self._children_name_map["next_hops"] = "next-hops"
                            self._segment_path = lambda: "static" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static, ['prefix'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration data for static routes
                            
                            .. attribute:: prefix
                            
                                Destination prefix for the static route, either IPv4 or IPv6
                            
                                **type**: union of the below types:
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                            
                            .. attribute:: set_tag
                            
                                Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 0..4294967295
                            
                                    **type**: str
                            
                                        **pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('set_tag', (YLeaf(YType.str, 'set-tag'), ['int','str'])),
                                ])
                                self.prefix = None
                                self.set_tag = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.Config, ['prefix', 'set_tag'], name, value)


                        class State(_Entity_):
                            """
                            Operational state data for static routes
                            
                            .. attribute:: prefix
                            
                                Destination prefix for the static route, either IPv4 or IPv6
                            
                                **type**: union of the below types:
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                            
                                **config**: False
                            
                            .. attribute:: set_tag
                            
                                Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 0..4294967295
                            
                                    **type**: str
                            
                                        **pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('set_tag', (YLeaf(YType.str, 'set-tag'), ['int','str'])),
                                ])
                                self.prefix = None
                                self.set_tag = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.State, ['prefix', 'set_tag'], name, value)


                        class NextHops(_Entity_):
                            """
                            Configuration and state parameters relating to the
                            next\-hops that are to be utilised for the static
                            route being specified
                            
                            .. attribute:: next_hop
                            
                                A list of next\-hops to be utilised for the static route being specified
                            
                                **type**: list of    :py:class:`NextHop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "next-hops"
                                self.yang_parent_name = "static"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("next-hop", ("next_hop", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop))])
                                self._leafs = OrderedDict()

                                self.next_hop = YList(self)
                                self._segment_path = lambda: "next-hops"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops, [], name, value)

                            class NextHop(_Entity_):
                                """
                                A list of next\-hops to be utilised for the static
                                route being specified.
                                
                                .. attribute:: index  (key)
                                
                                    A reference to the index of the current next\-hop. The index is intended to be a user\-specified value which can be used to reference the next\-hop in question, without any other semantics being assigned to it
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config>`
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the next\-hop entry
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state parameters relating to the next\-hop entry
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State>`
                                
                                    **config**: False
                                
                                .. attribute:: interface_ref
                                
                                    Reference to an interface or subinterface
                                
                                    **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef>`
                                
                                .. attribute:: enable_bfd
                                
                                    Enable BFD for liveliness detection to the next\-hop or neighbour
                                
                                    **type**:  :py:class:`EnableBfd<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "next-hops"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['index']
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef)), ("openconfig-bfd:enable-bfd", ("enable_bfd", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd))])
                                    self._leafs = OrderedDict([
                                        ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                    ])
                                    self.index = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.interface_ref = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef()
                                    self.interface_ref.parent = self
                                    self._children_name_map["interface_ref"] = "interface-ref"

                                    self.enable_bfd = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd()
                                    self.enable_bfd.parent = self
                                    self._children_name_map["enable_bfd"] = "openconfig-bfd:enable-bfd"
                                    self._segment_path = lambda: "next-hop" + "[index='" + str(self.index) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop, ['index'], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the next\-hop
                                    entry
                                    
                                    .. attribute:: index
                                    
                                        An user\-specified identifier utilised to uniquely reference the next\-hop entry in the next\-hop list. The value of this index has no semantic meaning other than for referencing the entry
                                    
                                        **type**: str
                                    
                                    .. attribute:: next_hop
                                    
                                        The next\-hop that is to be used for the static route \- this may be specified as an IP address, an interface or a pre\-defined next\-hop type \- for instance, DROP or LOCAL\_LINK. When this leaf is not set, and the interface\-ref value is specified for the next\-hop, then the system should treat the prefix as though it is directly connected to the interface
                                    
                                        **type**: union of the below types:
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                            **type**:  :py:class:`LOCALDEFINEDNEXTHOP<ydk.models.openconfig.openconfig_local_routing.LOCALDEFINEDNEXTHOP>`
                                    
                                    .. attribute:: metric
                                    
                                        A metric which is utilised to specify the preference of the next\-hop entry when it is injected into the RIB. The lower the metric, the more preferable the prefix is. When this value is not specified the metric is inherited from the default metric utilised for static routes within the network instance that the static routes are being instantiated. When multiple next\-hops are specified for a static route, the metric is utilised to determine which of the next\-hops is to be installed in the RIB. When multiple next\-hops have the same metric (be it specified, or simply the default) then these next\-hops should all be installed in the RIB
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                    .. attribute:: recurse
                                    
                                        Determines whether the next\-hop should be allowed to be looked up recursively \- i.e., via a RIB entry which has been installed by a routing protocol, or another static route \- rather than needing to be connected directly to an interface of the local system within the current network instance. When the interface reference specified within the next\-hop entry is set (i.e., is not null) then forwarding is restricted to being via the interface specified \- and recursion is hence disabled
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str',('ydk.models.openconfig.openconfig_local_routing', 'LOCALDEFINEDNEXTHOP')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('recurse', (YLeaf(YType.boolean, 'recurse'), ['bool'])),
                                        ])
                                        self.index = None
                                        self.next_hop = None
                                        self.metric = None
                                        self.recurse = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.Config, ['index', 'next_hop', 'metric', 'recurse'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state parameters relating to the
                                    next\-hop entry
                                    
                                    .. attribute:: index
                                    
                                        An user\-specified identifier utilised to uniquely reference the next\-hop entry in the next\-hop list. The value of this index has no semantic meaning other than for referencing the entry
                                    
                                        **type**: str
                                    
                                        **config**: False
                                    
                                    .. attribute:: next_hop
                                    
                                        The next\-hop that is to be used for the static route \- this may be specified as an IP address, an interface or a pre\-defined next\-hop type \- for instance, DROP or LOCAL\_LINK. When this leaf is not set, and the interface\-ref value is specified for the next\-hop, then the system should treat the prefix as though it is directly connected to the interface
                                    
                                        **type**: union of the below types:
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                            **type**:  :py:class:`LOCALDEFINEDNEXTHOP<ydk.models.openconfig.openconfig_local_routing.LOCALDEFINEDNEXTHOP>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: metric
                                    
                                        A metric which is utilised to specify the preference of the next\-hop entry when it is injected into the RIB. The lower the metric, the more preferable the prefix is. When this value is not specified the metric is inherited from the default metric utilised for static routes within the network instance that the static routes are being instantiated. When multiple next\-hops are specified for a static route, the metric is utilised to determine which of the next\-hops is to be installed in the RIB. When multiple next\-hops have the same metric (be it specified, or simply the default) then these next\-hops should all be installed in the RIB
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: recurse
                                    
                                        Determines whether the next\-hop should be allowed to be looked up recursively \- i.e., via a RIB entry which has been installed by a routing protocol, or another static route \- rather than needing to be connected directly to an interface of the local system within the current network instance. When the interface reference specified within the next\-hop entry is set (i.e., is not null) then forwarding is restricted to being via the interface specified \- and recursion is hence disabled
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('index', (YLeaf(YType.str, 'index'), ['str'])),
                                            ('next_hop', (YLeaf(YType.str, 'next-hop'), ['str','str',('ydk.models.openconfig.openconfig_local_routing', 'LOCALDEFINEDNEXTHOP')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('recurse', (YLeaf(YType.boolean, 'recurse'), ['bool'])),
                                        ])
                                        self.index = None
                                        self.next_hop = None
                                        self.metric = None
                                        self.recurse = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.State, ['index', 'next_hop', 'metric', 'recurse'], name, value)


                                class InterfaceRef(_Entity_):
                                    """
                                    Reference to an interface or subinterface
                                    
                                    .. attribute:: config
                                    
                                        Configured reference to interface / subinterface
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config>`
                                    
                                    .. attribute:: state
                                    
                                        Operational state for interface\-ref
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "interface-ref"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "interface-ref"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configured reference to interface / subinterface
                                        
                                        .. attribute:: interface
                                        
                                            Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                        
                                            **type**: str
                                        
                                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                        
                                        .. attribute:: subinterface
                                        
                                            Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                    class State(_Entity_):
                                        """
                                        Operational state for interface\-ref
                                        
                                        .. attribute:: interface
                                        
                                            Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                        
                                            **type**: str
                                        
                                            **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: subinterface
                                        
                                            Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "interface-ref"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                                ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                            ])
                                            self.interface = None
                                            self.subinterface = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.InterfaceRef.State, ['interface', 'subinterface'], name, value)



                                class EnableBfd(_Entity_):
                                    """
                                    Enable BFD for liveliness detection to the next\-hop or
                                    neighbour.
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to enabling BFD
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.Config>`
                                    
                                    .. attribute:: state
                                    
                                        Operational state parameters relating to enabing BFD
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-bfd'
                                    _revision = '2018-11-21'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "enable-bfd"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "openconfig-bfd:enable-bfd"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to enabling BFD.
                                        
                                        .. attribute:: enabled
                                        
                                            When this leaf is set to true, BFD is used to detect the liveliness of the remote peer or next\-hop
                                        
                                            **type**: bool
                                        
                                        """
                                        _prefix = 'oc-bfd'
                                        _revision = '2018-11-21'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "enable-bfd"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.Config, ['enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        Operational state parameters relating to enabing BFD.
                                        
                                        .. attribute:: enabled
                                        
                                            When this leaf is set to true, BFD is used to detect the liveliness of the remote peer or next\-hop
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                        .. attribute:: associated_session
                                        
                                            A reference to the BFD session that is tracking the liveliness of the remote entity
                                        
                                            **type**: str
                                        
                                            **refers to**:  :py:class:`local_discriminator<ydk.models.openconfig.openconfig_bfd.Bfd.Interfaces.Interface.Peers.Peer>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-bfd'
                                        _revision = '2018-11-21'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "enable-bfd"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ('associated_session', (YLeaf(YType.str, 'associated-session'), ['str'])),
                                            ])
                                            self.enabled = None
                                            self.associated_session = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.StaticRoutes.Static.NextHops.NextHop.EnableBfd.State, ['enabled', 'associated_session'], name, value)







                class LocalAggregates(_Entity_):
                    """
                    Enclosing container for locally\-defined aggregate
                    routes
                    
                    .. attribute:: aggregate
                    
                        List of aggregates
                    
                        **type**: list of    :py:class:`Aggregate<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "local-aggregates"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("aggregate", ("aggregate", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate))])
                        self._leafs = OrderedDict()

                        self.aggregate = YList(self)
                        self._segment_path = lambda: "local-aggregates"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates, [], name, value)

                    class Aggregate(_Entity_):
                        """
                        List of aggregates
                        
                        .. attribute:: prefix  (key)
                        
                            Reference to the configured prefix for this aggregate
                        
                            **type**: union of the below types:
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                        
                                **type**: str
                        
                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                        
                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config>`
                        
                        .. attribute:: config
                        
                            Configuration data for aggregate advertisements
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config>`
                        
                        .. attribute:: state
                        
                            Operational state data for aggregate advertisements
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "aggregate"
                            self.yang_parent_name = "local-aggregates"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['prefix']
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State))])
                            self._leafs = OrderedDict([
                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                            ])
                            self.prefix = None

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"
                            self._segment_path = lambda: "aggregate" + "[prefix='" + str(self.prefix) + "']"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate, ['prefix'], name, value)

                        class Config(_Entity_):
                            """
                            Configuration data for aggregate advertisements
                            
                            .. attribute:: prefix
                            
                                Aggregate prefix to be advertised
                            
                                **type**: union of the below types:
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                            
                            .. attribute:: discard
                            
                                When true, install the aggregate route with a discard next\-hop \-\- traffic destined to the aggregate will be discarded with no ICMP message generated.  When false, traffic destined to an aggregate address when no constituent routes are present will generate an ICMP unreachable message
                            
                                **type**: bool
                            
                                **default value**: false
                            
                            .. attribute:: set_tag
                            
                                Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 0..4294967295
                            
                                    **type**: str
                            
                                        **pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "aggregate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('discard', (YLeaf(YType.boolean, 'discard'), ['bool'])),
                                    ('set_tag', (YLeaf(YType.str, 'set-tag'), ['int','str'])),
                                ])
                                self.prefix = None
                                self.discard = None
                                self.set_tag = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.Config, ['prefix', 'discard', 'set_tag'], name, value)


                        class State(_Entity_):
                            """
                            Operational state data for aggregate
                            advertisements
                            
                            .. attribute:: prefix
                            
                                Aggregate prefix to be advertised
                            
                                **type**: union of the below types:
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                            
                                **config**: False
                            
                            .. attribute:: discard
                            
                                When true, install the aggregate route with a discard next\-hop \-\- traffic destined to the aggregate will be discarded with no ICMP message generated.  When false, traffic destined to an aggregate address when no constituent routes are present will generate an ICMP unreachable message
                            
                                **type**: bool
                            
                                **config**: False
                            
                                **default value**: false
                            
                            .. attribute:: set_tag
                            
                                Set a generic tag value on the route. This tag can be used for filtering routes that are distributed to other routing protocols
                            
                                **type**: union of the below types:
                            
                                    **type**: int
                            
                                        **range:** 0..4294967295
                            
                                    **type**: str
                            
                                        **pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "aggregate"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                    ('discard', (YLeaf(YType.boolean, 'discard'), ['bool'])),
                                    ('set_tag', (YLeaf(YType.str, 'set-tag'), ['int','str'])),
                                ])
                                self.prefix = None
                                self.discard = None
                                self.set_tag = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.LocalAggregates.Aggregate.State, ['prefix', 'discard', 'set_tag'], name, value)




                class Bgp(_Entity_):
                    """
                    Top\-level configuration and state for the BGP router
                    
                    .. attribute:: global_
                    
                        Global configuration for the BGP router
                    
                        **type**:  :py:class:`Global<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global>`
                    
                    .. attribute:: neighbors
                    
                        Configuration for BGP neighbors
                    
                        **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors>`
                    
                    .. attribute:: peer_groups
                    
                        Configuration for BGP peer\-groups
                    
                        **type**:  :py:class:`PeerGroups<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "bgp"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("global", ("global_", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global)), ("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors)), ("peer-groups", ("peer_groups", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups))])
                        self._leafs = OrderedDict()

                        self.global_ = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors()
                        self.neighbors.parent = self
                        self._children_name_map["neighbors"] = "neighbors"

                        self.peer_groups = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups()
                        self.peer_groups.parent = self
                        self._children_name_map["peer_groups"] = "peer-groups"
                        self._segment_path = lambda: "bgp"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp, [], name, value)

                    class Global(_Entity_):
                        """
                        Global configuration for the BGP router
                        
                        .. attribute:: config
                        
                            Configuration parameters relating to the global BGP router
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config>`
                        
                        .. attribute:: state
                        
                            State information relating to the global BGP router
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State>`
                        
                            **config**: False
                        
                        .. attribute:: default_route_distance
                        
                            Administrative distance (or preference) assigned to routes received from different sources (external, internal, and local)
                        
                            **type**:  :py:class:`DefaultRouteDistance<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance>`
                        
                        .. attribute:: confederation
                        
                            Parameters indicating whether the local system acts as part of a BGP confederation
                        
                            **type**:  :py:class:`Confederation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation>`
                        
                        .. attribute:: graceful_restart
                        
                            Parameters relating the graceful restart mechanism for BGP
                        
                            **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart>`
                        
                        .. attribute:: use_multiple_paths
                        
                            Parameters related to the use of multiple paths for the same NLRI
                        
                            **type**:  :py:class:`UseMultiplePaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths>`
                        
                        .. attribute:: route_selection_options
                        
                            Parameters relating to options for route selection
                        
                            **type**:  :py:class:`RouteSelectionOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions>`
                        
                        .. attribute:: afi_safis
                        
                            Address family specific configuration
                        
                            **type**:  :py:class:`AfiSafis<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis>`
                        
                        .. attribute:: dynamic_neighbor_prefixes
                        
                            A list of IP prefixes from which the system should\:  \- Accept connections to the BGP daemon  \- Dynamically configure a BGP neighbor corresponding to the    source address of the remote system, using the parameters    of the specified peer\-group. For such neighbors, an entry within the neighbor list should be created, indicating that the peer was dynamically configured, and referencing the peer\-group from which the configuration was derived
                        
                            **type**:  :py:class:`DynamicNeighborPrefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State)), ("default-route-distance", ("default_route_distance", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance)), ("confederation", ("confederation", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths)), ("route-selection-options", ("route_selection_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions)), ("afi-safis", ("afi_safis", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis)), ("dynamic-neighbor-prefixes", ("dynamic_neighbor_prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes))])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.default_route_distance = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance()
                            self.default_route_distance.parent = self
                            self._children_name_map["default_route_distance"] = "default-route-distance"

                            self.confederation = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation()
                            self.confederation.parent = self
                            self._children_name_map["confederation"] = "confederation"

                            self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths()
                            self.use_multiple_paths.parent = self
                            self._children_name_map["use_multiple_paths"] = "use-multiple-paths"

                            self.route_selection_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions()
                            self.route_selection_options.parent = self
                            self._children_name_map["route_selection_options"] = "route-selection-options"

                            self.afi_safis = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis()
                            self.afi_safis.parent = self
                            self._children_name_map["afi_safis"] = "afi-safis"

                            self.dynamic_neighbor_prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes()
                            self.dynamic_neighbor_prefixes.parent = self
                            self._children_name_map["dynamic_neighbor_prefixes"] = "dynamic-neighbor-prefixes"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global, [], name, value)

                        class Config(_Entity_):
                            """
                            Configuration parameters relating to the global BGP router
                            
                            .. attribute:: as_
                            
                                Local autonomous system number of the router.  Uses the 32\-bit as\-number type from the model in RFC 6991
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **mandatory**: True
                            
                            .. attribute:: router_id
                            
                                Router id of the router \- an unsigned 32\-bit integer expressed in dotted quad notation
                            
                                **type**: str
                            
                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_', (YLeaf(YType.uint32, 'as'), ['int'])),
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                ])
                                self.as_ = None
                                self.router_id = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Config, ['as_', 'router_id'], name, value)


                        class State(_Entity_):
                            """
                            State information relating to the global BGP router
                            
                            .. attribute:: as_
                            
                                Local autonomous system number of the router.  Uses the 32\-bit as\-number type from the model in RFC 6991
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **mandatory**: True
                            
                                **config**: False
                            
                            .. attribute:: router_id
                            
                                Router id of the router \- an unsigned 32\-bit integer expressed in dotted quad notation
                            
                                **type**: str
                            
                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                            
                                **config**: False
                            
                            .. attribute:: total_paths
                            
                                Total number of BGP paths within the context
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **config**: False
                            
                            .. attribute:: total_prefixes
                            
                                Total number of BGP prefixes received within the context
                            
                                **type**: int
                            
                                    **range:** 0..4294967295
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('as_', (YLeaf(YType.uint32, 'as'), ['int'])),
                                    ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                    ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                    ('total_prefixes', (YLeaf(YType.uint32, 'total-prefixes'), ['int'])),
                                ])
                                self.as_ = None
                                self.router_id = None
                                self.total_paths = None
                                self.total_prefixes = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.State, ['as_', 'router_id', 'total_paths', 'total_prefixes'], name, value)


                        class DefaultRouteDistance(_Entity_):
                            """
                            Administrative distance (or preference) assigned to
                            routes received from different sources
                            (external, internal, and local).
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the default route distance
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config>`
                            
                            .. attribute:: state
                            
                                State information relating to the default route distance
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "default-route-distance"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "default-route-distance"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the default route
                                distance
                                
                                .. attribute:: external_route_distance
                                
                                    Administrative distance for routes learned from external BGP (eBGP)
                                
                                    **type**: int
                                
                                        **range:** 1..255
                                
                                .. attribute:: internal_route_distance
                                
                                    Administrative distance for routes learned from internal BGP (iBGP)
                                
                                    **type**: int
                                
                                        **range:** 1..255
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "default-route-distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external_route_distance', (YLeaf(YType.uint8, 'external-route-distance'), ['int'])),
                                        ('internal_route_distance', (YLeaf(YType.uint8, 'internal-route-distance'), ['int'])),
                                    ])
                                    self.external_route_distance = None
                                    self.internal_route_distance = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.Config, ['external_route_distance', 'internal_route_distance'], name, value)


                            class State(_Entity_):
                                """
                                State information relating to the default route distance
                                
                                .. attribute:: external_route_distance
                                
                                    Administrative distance for routes learned from external BGP (eBGP)
                                
                                    **type**: int
                                
                                        **range:** 1..255
                                
                                    **config**: False
                                
                                .. attribute:: internal_route_distance
                                
                                    Administrative distance for routes learned from internal BGP (iBGP)
                                
                                    **type**: int
                                
                                        **range:** 1..255
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "default-route-distance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('external_route_distance', (YLeaf(YType.uint8, 'external-route-distance'), ['int'])),
                                        ('internal_route_distance', (YLeaf(YType.uint8, 'internal-route-distance'), ['int'])),
                                    ])
                                    self.external_route_distance = None
                                    self.internal_route_distance = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DefaultRouteDistance.State, ['external_route_distance', 'internal_route_distance'], name, value)



                        class Confederation(_Entity_):
                            """
                            Parameters indicating whether the local system acts as part
                            of a BGP confederation
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to BGP confederations
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config>`
                            
                            .. attribute:: state
                            
                                State information relating to the BGP confederations
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "confederation"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "confederation"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to BGP confederations
                                
                                .. attribute:: enabled
                                
                                    When this leaf is set to true it indicates that the local\-AS is part of a BGP confederation
                                
                                    **type**: bool
                                
                                .. attribute:: identifier
                                
                                    Confederation identifier for the autonomous system
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                .. attribute:: member_as
                                
                                    Remote autonomous systems that are to be treated as part of the local confederation
                                
                                    **type**: list of int
                                
                                        **range:** 0..4294967295
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "confederation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('identifier', (YLeaf(YType.uint32, 'identifier'), ['int'])),
                                        ('member_as', (YLeafList(YType.uint32, 'member-as'), ['int'])),
                                    ])
                                    self.enabled = None
                                    self.identifier = None
                                    self.member_as = []
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.Config, ['enabled', 'identifier', 'member_as'], name, value)


                            class State(_Entity_):
                                """
                                State information relating to the BGP confederations
                                
                                .. attribute:: enabled
                                
                                    When this leaf is set to true it indicates that the local\-AS is part of a BGP confederation
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                .. attribute:: identifier
                                
                                    Confederation identifier for the autonomous system
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: member_as
                                
                                    Remote autonomous systems that are to be treated as part of the local confederation
                                
                                    **type**: list of int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "confederation"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('identifier', (YLeaf(YType.uint32, 'identifier'), ['int'])),
                                        ('member_as', (YLeafList(YType.uint32, 'member-as'), ['int'])),
                                    ])
                                    self.enabled = None
                                    self.identifier = None
                                    self.member_as = []
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.Confederation.State, ['enabled', 'identifier', 'member_as'], name, value)



                        class GracefulRestart(_Entity_):
                            """
                            Parameters relating the graceful restart mechanism for BGP
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to graceful\-restart
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config>`
                            
                            .. attribute:: state
                            
                                State information associated with graceful\-restart
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to graceful\-restart
                                
                                .. attribute:: enabled
                                
                                    Enable or disable the graceful\-restart capability
                                
                                    **type**: bool
                                
                                .. attribute:: restart_time
                                
                                    Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                
                                    **type**: int
                                
                                        **range:** 0..4096
                                
                                .. attribute:: stale_routes_time
                                
                                    An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                
                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                
                                        **range:** \-92233720368547758.08..92233720368547758.07
                                
                                .. attribute:: helper_only
                                
                                    Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                
                                    **type**: bool
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                                        ('stale_routes_time', (YLeaf(YType.str, 'stale-routes-time'), ['Decimal64'])),
                                        ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self.restart_time = None
                                    self.stale_routes_time = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.Config, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                            class State(_Entity_):
                                """
                                State information associated with graceful\-restart
                                
                                .. attribute:: enabled
                                
                                    Enable or disable the graceful\-restart capability
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                .. attribute:: restart_time
                                
                                    Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                
                                    **type**: int
                                
                                        **range:** 0..4096
                                
                                    **config**: False
                                
                                .. attribute:: stale_routes_time
                                
                                    An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                
                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                
                                        **range:** \-92233720368547758.08..92233720368547758.07
                                
                                    **config**: False
                                
                                .. attribute:: helper_only
                                
                                    Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                                        ('stale_routes_time', (YLeaf(YType.str, 'stale-routes-time'), ['Decimal64'])),
                                        ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self.restart_time = None
                                    self.stale_routes_time = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.GracefulRestart.State, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)



                        class UseMultiplePaths(_Entity_):
                            """
                            Parameters related to the use of multiple paths for the
                            same NLRI
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to multipath
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config>`
                            
                            .. attribute:: state
                            
                                State parameters relating to multipath
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State>`
                            
                                **config**: False
                            
                            .. attribute:: ebgp
                            
                                Multipath parameters for eBGP
                            
                                **type**:  :py:class:`Ebgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp>`
                            
                            .. attribute:: ibgp
                            
                                Multipath parameters for iBGP
                            
                                **type**:  :py:class:`Ibgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "use-multiple-paths"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp()
                                self.ebgp.parent = self
                                self._children_name_map["ebgp"] = "ebgp"

                                self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp()
                                self.ibgp.parent = self
                                self._children_name_map["ibgp"] = "ibgp"
                                self._segment_path = lambda: "use-multiple-paths"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to multipath
                                
                                .. attribute:: enabled
                                
                                    Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Config, ['enabled'], name, value)


                            class State(_Entity_):
                                """
                                State parameters relating to multipath
                                
                                .. attribute:: enabled
                                
                                    Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.State, ['enabled'], name, value)


                            class Ebgp(_Entity_):
                                """
                                Multipath parameters for eBGP
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to eBGP multipath
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to eBGP multipath
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "ebgp"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "ebgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to eBGP multipath
                                    
                                    .. attribute:: allow_multiple_as
                                    
                                        Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: maximum_paths
                                    
                                        Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **default value**: 1
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ebgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                            ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                        ])
                                        self.allow_multiple_as = None
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to eBGP multipath
                                    
                                    .. attribute:: allow_multiple_as
                                    
                                        Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: maximum_paths
                                    
                                        Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                        **default value**: 1
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ebgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                            ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                        ])
                                        self.allow_multiple_as = None
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)



                            class Ibgp(_Entity_):
                                """
                                Multipath parameters for iBGP
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to iBGP multipath
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to iBGP multipath
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "ibgp"
                                    self.yang_parent_name = "use-multiple-paths"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "ibgp"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to iBGP multipath
                                    
                                    .. attribute:: maximum_paths
                                    
                                        Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **default value**: 1
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ibgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                        ])
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to iBGP multipath
                                    
                                    .. attribute:: maximum_paths
                                    
                                        Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                        **default value**: 1
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ibgp"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                        ])
                                        self.maximum_paths = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)




                        class RouteSelectionOptions(_Entity_):
                            """
                            Parameters relating to options for route selection
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to route selection options
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config>`
                            
                            .. attribute:: state
                            
                                State information for the route selection options
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "route-selection-options"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "route-selection-options"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to route selection
                                options
                                
                                .. attribute:: always_compare_med
                                
                                    Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: ignore_as_path_length
                                
                                    Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: external_compare_router_id
                                
                                    When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                
                                    **type**: bool
                                
                                    **default value**: true
                                
                                .. attribute:: advertise_inactive_routes
                                
                                    Advertise inactive routes to external peers.  The default is to only advertise active routes
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: enable_aigp
                                
                                    Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: ignore_next_hop_igp_metric
                                
                                    Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "route-selection-options"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('always_compare_med', (YLeaf(YType.boolean, 'always-compare-med'), ['bool'])),
                                        ('ignore_as_path_length', (YLeaf(YType.boolean, 'ignore-as-path-length'), ['bool'])),
                                        ('external_compare_router_id', (YLeaf(YType.boolean, 'external-compare-router-id'), ['bool'])),
                                        ('advertise_inactive_routes', (YLeaf(YType.boolean, 'advertise-inactive-routes'), ['bool'])),
                                        ('enable_aigp', (YLeaf(YType.boolean, 'enable-aigp'), ['bool'])),
                                        ('ignore_next_hop_igp_metric', (YLeaf(YType.boolean, 'ignore-next-hop-igp-metric'), ['bool'])),
                                    ])
                                    self.always_compare_med = None
                                    self.ignore_as_path_length = None
                                    self.external_compare_router_id = None
                                    self.advertise_inactive_routes = None
                                    self.enable_aigp = None
                                    self.ignore_next_hop_igp_metric = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.Config, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                            class State(_Entity_):
                                """
                                State information for the route selection options
                                
                                .. attribute:: always_compare_med
                                
                                    Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: ignore_as_path_length
                                
                                    Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: external_compare_router_id
                                
                                    When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: true
                                
                                .. attribute:: advertise_inactive_routes
                                
                                    Advertise inactive routes to external peers.  The default is to only advertise active routes
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: enable_aigp
                                
                                    Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: ignore_next_hop_igp_metric
                                
                                    Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "route-selection-options"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('always_compare_med', (YLeaf(YType.boolean, 'always-compare-med'), ['bool'])),
                                        ('ignore_as_path_length', (YLeaf(YType.boolean, 'ignore-as-path-length'), ['bool'])),
                                        ('external_compare_router_id', (YLeaf(YType.boolean, 'external-compare-router-id'), ['bool'])),
                                        ('advertise_inactive_routes', (YLeaf(YType.boolean, 'advertise-inactive-routes'), ['bool'])),
                                        ('enable_aigp', (YLeaf(YType.boolean, 'enable-aigp'), ['bool'])),
                                        ('ignore_next_hop_igp_metric', (YLeaf(YType.boolean, 'ignore-next-hop-igp-metric'), ['bool'])),
                                    ])
                                    self.always_compare_med = None
                                    self.ignore_as_path_length = None
                                    self.external_compare_router_id = None
                                    self.advertise_inactive_routes = None
                                    self.enable_aigp = None
                                    self.ignore_next_hop_igp_metric = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.RouteSelectionOptions.State, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)



                        class AfiSafis(_Entity_):
                            """
                            Address family specific configuration
                            
                            .. attribute:: afi_safi
                            
                                AFI,SAFI configuration available for the neighbour or group
                            
                                **type**: list of    :py:class:`AfiSafi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "afi-safis"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi))])
                                self._leafs = OrderedDict()

                                self.afi_safi = YList(self)
                                self._segment_path = lambda: "afi-safis"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis, [], name, value)

                            class AfiSafi(_Entity_):
                                """
                                AFI,SAFI configuration available for the
                                neighbour or group
                                
                                .. attribute:: afi_safi_name  (key)
                                
                                    Reference to the AFI\-SAFI name used as a key for the AFI\-SAFI list
                                
                                    **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                
                                .. attribute:: config
                                
                                    Configuration parameters for the AFI\-SAFI
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the AFI\-SAFI
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State>`
                                
                                    **config**: False
                                
                                .. attribute:: graceful_restart
                                
                                    Parameters relating to BGP graceful\-restart
                                
                                    **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart>`
                                
                                .. attribute:: route_selection_options
                                
                                    Parameters relating to options for route selection
                                
                                    **type**:  :py:class:`RouteSelectionOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions>`
                                
                                .. attribute:: use_multiple_paths
                                
                                    Parameters related to the use of multiple paths for the same NLRI
                                
                                    **type**:  :py:class:`UseMultiplePaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths>`
                                
                                .. attribute:: ipv4_unicast
                                
                                    IPv4 unicast configuration options
                                
                                    **type**:  :py:class:`Ipv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast>`
                                
                                .. attribute:: ipv6_unicast
                                
                                    IPv6 unicast configuration options
                                
                                    **type**:  :py:class:`Ipv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast>`
                                
                                .. attribute:: ipv4_labeled_unicast
                                
                                    IPv4 Labeled Unicast configuration options
                                
                                    **type**:  :py:class:`Ipv4LabeledUnicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast>`
                                
                                .. attribute:: ipv6_labeled_unicast
                                
                                    IPv6 Labeled Unicast configuration options
                                
                                    **type**:  :py:class:`Ipv6LabeledUnicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast>`
                                
                                .. attribute:: l3vpn_ipv4_unicast
                                
                                    Unicast IPv4 L3VPN configuration options
                                
                                    **type**:  :py:class:`L3vpnIpv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast>`
                                
                                .. attribute:: l3vpn_ipv6_unicast
                                
                                    Unicast IPv6 L3VPN configuration options
                                
                                    **type**:  :py:class:`L3vpnIpv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast>`
                                
                                .. attribute:: l3vpn_ipv4_multicast
                                
                                    Multicast IPv4 L3VPN configuration options
                                
                                    **type**:  :py:class:`L3vpnIpv4Multicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast>`
                                
                                .. attribute:: l3vpn_ipv6_multicast
                                
                                    Multicast IPv6 L3VPN configuration options
                                
                                    **type**:  :py:class:`L3vpnIpv6Multicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast>`
                                
                                .. attribute:: l2vpn_vpls
                                
                                    BGP\-signalled VPLS configuration options
                                
                                    **type**:  :py:class:`L2vpnVpls<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls>`
                                
                                .. attribute:: l2vpn_evpn
                                
                                    BGP EVPN configuration options
                                
                                    **type**:  :py:class:`L2vpnEvpn<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "afi-safi"
                                    self.yang_parent_name = "afi-safis"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['afi_safi_name']
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart)), ("route-selection-options", ("route_selection_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths)), ("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast)), ("ipv4-labeled-unicast", ("ipv4_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast)), ("ipv6-labeled-unicast", ("ipv6_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast)), ("l3vpn-ipv4-unicast", ("l3vpn_ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast)), ("l3vpn-ipv6-unicast", ("l3vpn_ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast)), ("l3vpn-ipv4-multicast", ("l3vpn_ipv4_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast)), ("l3vpn-ipv6-multicast", ("l3vpn_ipv6_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast)), ("l2vpn-vpls", ("l2vpn_vpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls)), ("l2vpn-evpn", ("l2vpn_evpn", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn))])
                                    self._leafs = OrderedDict([
                                        ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                    ])
                                    self.afi_safi_name = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart()
                                    self.graceful_restart.parent = self
                                    self._children_name_map["graceful_restart"] = "graceful-restart"

                                    self.route_selection_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions()
                                    self.route_selection_options.parent = self
                                    self._children_name_map["route_selection_options"] = "route-selection-options"

                                    self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths()
                                    self.use_multiple_paths.parent = self
                                    self._children_name_map["use_multiple_paths"] = "use-multiple-paths"

                                    self.ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast()
                                    self.ipv4_unicast.parent = self
                                    self._children_name_map["ipv4_unicast"] = "ipv4-unicast"

                                    self.ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast()
                                    self.ipv6_unicast.parent = self
                                    self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                                    self.ipv4_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast()
                                    self.ipv4_labeled_unicast.parent = self
                                    self._children_name_map["ipv4_labeled_unicast"] = "ipv4-labeled-unicast"

                                    self.ipv6_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast()
                                    self.ipv6_labeled_unicast.parent = self
                                    self._children_name_map["ipv6_labeled_unicast"] = "ipv6-labeled-unicast"

                                    self.l3vpn_ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast()
                                    self.l3vpn_ipv4_unicast.parent = self
                                    self._children_name_map["l3vpn_ipv4_unicast"] = "l3vpn-ipv4-unicast"

                                    self.l3vpn_ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast()
                                    self.l3vpn_ipv6_unicast.parent = self
                                    self._children_name_map["l3vpn_ipv6_unicast"] = "l3vpn-ipv6-unicast"

                                    self.l3vpn_ipv4_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast()
                                    self.l3vpn_ipv4_multicast.parent = self
                                    self._children_name_map["l3vpn_ipv4_multicast"] = "l3vpn-ipv4-multicast"

                                    self.l3vpn_ipv6_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast()
                                    self.l3vpn_ipv6_multicast.parent = self
                                    self._children_name_map["l3vpn_ipv6_multicast"] = "l3vpn-ipv6-multicast"

                                    self.l2vpn_vpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls()
                                    self.l2vpn_vpls.parent = self
                                    self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"

                                    self.l2vpn_evpn = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn()
                                    self.l2vpn_evpn.parent = self
                                    self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"
                                    self._segment_path = lambda: "afi-safi" + "[afi-safi-name='" + str(self.afi_safi_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi, ['afi_safi_name'], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters for the AFI\-SAFI
                                    
                                    .. attribute:: afi_safi_name
                                    
                                        AFI,SAFI
                                    
                                        **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: enabled
                                    
                                        This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.afi_safi_name = None
                                        self.enabled = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Config, ['afi_safi_name', 'enabled'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the AFI\-SAFI
                                    
                                    .. attribute:: afi_safi_name
                                    
                                        AFI,SAFI
                                    
                                        **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: enabled
                                    
                                        This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: total_paths
                                    
                                        Total number of BGP paths within the context
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: total_prefixes
                                    
                                        Total number of BGP prefixes received within the context
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                            ('total_prefixes', (YLeaf(YType.uint32, 'total-prefixes'), ['int'])),
                                        ])
                                        self.afi_safi_name = None
                                        self.enabled = None
                                        self.total_paths = None
                                        self.total_prefixes = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.State, ['afi_safi_name', 'enabled', 'total_paths', 'total_prefixes'], name, value)


                                class GracefulRestart(_Entity_):
                                    """
                                    Parameters relating to BGP graceful\-restart
                                    
                                    .. attribute:: config
                                    
                                        Configuration options for BGP graceful\-restart
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information for BGP graceful\-restart
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "graceful-restart"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "graceful-restart"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration options for BGP graceful\-restart
                                        
                                        .. attribute:: enabled
                                        
                                            This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "graceful-restart"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.Config, ['enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information for BGP graceful\-restart
                                        
                                        .. attribute:: enabled
                                        
                                            This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "graceful-restart"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.GracefulRestart.State, ['enabled'], name, value)



                                class RouteSelectionOptions(_Entity_):
                                    """
                                    Parameters relating to options for route selection
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to route selection options
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information for the route selection options
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "route-selection-options"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "route-selection-options"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to route selection
                                        options
                                        
                                        .. attribute:: always_compare_med
                                        
                                            Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: ignore_as_path_length
                                        
                                            Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: external_compare_router_id
                                        
                                            When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                        
                                            **type**: bool
                                        
                                            **default value**: true
                                        
                                        .. attribute:: advertise_inactive_routes
                                        
                                            Advertise inactive routes to external peers.  The default is to only advertise active routes
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: enable_aigp
                                        
                                            Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: ignore_next_hop_igp_metric
                                        
                                            Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "route-selection-options"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always_compare_med', (YLeaf(YType.boolean, 'always-compare-med'), ['bool'])),
                                                ('ignore_as_path_length', (YLeaf(YType.boolean, 'ignore-as-path-length'), ['bool'])),
                                                ('external_compare_router_id', (YLeaf(YType.boolean, 'external-compare-router-id'), ['bool'])),
                                                ('advertise_inactive_routes', (YLeaf(YType.boolean, 'advertise-inactive-routes'), ['bool'])),
                                                ('enable_aigp', (YLeaf(YType.boolean, 'enable-aigp'), ['bool'])),
                                                ('ignore_next_hop_igp_metric', (YLeaf(YType.boolean, 'ignore-next-hop-igp-metric'), ['bool'])),
                                            ])
                                            self.always_compare_med = None
                                            self.ignore_as_path_length = None
                                            self.external_compare_router_id = None
                                            self.advertise_inactive_routes = None
                                            self.enable_aigp = None
                                            self.ignore_next_hop_igp_metric = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.Config, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information for the route selection options
                                        
                                        .. attribute:: always_compare_med
                                        
                                            Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: ignore_as_path_length
                                        
                                            Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: external_compare_router_id
                                        
                                            When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: true
                                        
                                        .. attribute:: advertise_inactive_routes
                                        
                                            Advertise inactive routes to external peers.  The default is to only advertise active routes
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: enable_aigp
                                        
                                            Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: ignore_next_hop_igp_metric
                                        
                                            Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "route-selection-options"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('always_compare_med', (YLeaf(YType.boolean, 'always-compare-med'), ['bool'])),
                                                ('ignore_as_path_length', (YLeaf(YType.boolean, 'ignore-as-path-length'), ['bool'])),
                                                ('external_compare_router_id', (YLeaf(YType.boolean, 'external-compare-router-id'), ['bool'])),
                                                ('advertise_inactive_routes', (YLeaf(YType.boolean, 'advertise-inactive-routes'), ['bool'])),
                                                ('enable_aigp', (YLeaf(YType.boolean, 'enable-aigp'), ['bool'])),
                                                ('ignore_next_hop_igp_metric', (YLeaf(YType.boolean, 'ignore-next-hop-igp-metric'), ['bool'])),
                                            ])
                                            self.always_compare_med = None
                                            self.ignore_as_path_length = None
                                            self.external_compare_router_id = None
                                            self.advertise_inactive_routes = None
                                            self.enable_aigp = None
                                            self.ignore_next_hop_igp_metric = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.RouteSelectionOptions.State, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)



                                class UseMultiplePaths(_Entity_):
                                    """
                                    Parameters related to the use of multiple paths for the
                                    same NLRI
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to multipath
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State parameters relating to multipath
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: ebgp
                                    
                                        Multipath parameters for eBGP
                                    
                                        **type**:  :py:class:`Ebgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp>`
                                    
                                    .. attribute:: ibgp
                                    
                                        Multipath parameters for iBGP
                                    
                                        **type**:  :py:class:`Ibgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "use-multiple-paths"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp()
                                        self.ebgp.parent = self
                                        self._children_name_map["ebgp"] = "ebgp"

                                        self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp()
                                        self.ibgp.parent = self
                                        self._children_name_map["ibgp"] = "ibgp"
                                        self._segment_path = lambda: "use-multiple-paths"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to multipath
                                        
                                        .. attribute:: enabled
                                        
                                            Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Config, ['enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        State parameters relating to multipath
                                        
                                        .. attribute:: enabled
                                        
                                            Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.State, ['enabled'], name, value)


                                    class Ebgp(_Entity_):
                                        """
                                        Multipath parameters for eBGP
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to eBGP multipath
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to eBGP multipath
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ebgp"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "ebgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to eBGP multipath
                                            
                                            .. attribute:: allow_multiple_as
                                            
                                                Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: maximum_paths
                                            
                                                Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **default value**: 1
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ebgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                ])
                                                self.allow_multiple_as = None
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to eBGP multipath
                                            
                                            .. attribute:: allow_multiple_as
                                            
                                                Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: maximum_paths
                                            
                                                Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                                **default value**: 1
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ebgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                ])
                                                self.allow_multiple_as = None
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)



                                    class Ibgp(_Entity_):
                                        """
                                        Multipath parameters for iBGP
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to iBGP multipath
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to iBGP multipath
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ibgp"
                                            self.yang_parent_name = "use-multiple-paths"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "ibgp"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to iBGP multipath
                                            
                                            .. attribute:: maximum_paths
                                            
                                                Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **default value**: 1
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ibgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                ])
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to iBGP multipath
                                            
                                            .. attribute:: maximum_paths
                                            
                                                Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                                **default value**: 1
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ibgp"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                ])
                                                self.maximum_paths = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)




                                class Ipv4Unicast(_Entity_):
                                    """
                                    IPv4 unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit>`
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information for common IPv4 and IPv6 unicast parameters
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ipv4-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "ipv4-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)



                                    class Config(_Entity_):
                                        """
                                        Configuration parameters for common IPv4 and IPv6 unicast
                                        AFI\-SAFI options
                                        
                                        .. attribute:: send_default_route
                                        
                                            If set to true, send the default\-route to the neighbour(s)
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.Config, ['send_default_route'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information for common IPv4 and IPv6 unicast
                                        parameters
                                        
                                        .. attribute:: send_default_route
                                        
                                            If set to true, send the default\-route to the neighbour(s)
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4Unicast.State, ['send_default_route'], name, value)



                                class Ipv6Unicast(_Entity_):
                                    """
                                    IPv6 unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit>`
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information for common IPv4 and IPv6 unicast parameters
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ipv6-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "ipv6-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)



                                    class Config(_Entity_):
                                        """
                                        Configuration parameters for common IPv4 and IPv6 unicast
                                        AFI\-SAFI options
                                        
                                        .. attribute:: send_default_route
                                        
                                            If set to true, send the default\-route to the neighbour(s)
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.Config, ['send_default_route'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information for common IPv4 and IPv6 unicast
                                        parameters
                                        
                                        .. attribute:: send_default_route
                                        
                                            If set to true, send the default\-route to the neighbour(s)
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                            ])
                                            self.send_default_route = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6Unicast.State, ['send_default_route'], name, value)



                                class Ipv4LabeledUnicast(_Entity_):
                                    """
                                    IPv4 Labeled Unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ipv4-labeled-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "ipv4-labeled-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv4-labeled-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class Ipv6LabeledUnicast(_Entity_):
                                    """
                                    IPv6 Labeled Unicast configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ipv6-labeled-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "ipv6-labeled-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "ipv6-labeled-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class L3vpnIpv4Unicast(_Entity_):
                                    """
                                    Unicast IPv4 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "l3vpn-ipv4-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "l3vpn-ipv4-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv4-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class L3vpnIpv6Unicast(_Entity_):
                                    """
                                    Unicast IPv6 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "l3vpn-ipv6-unicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "l3vpn-ipv6-unicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv6-unicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class L3vpnIpv4Multicast(_Entity_):
                                    """
                                    Multicast IPv4 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "l3vpn-ipv4-multicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "l3vpn-ipv4-multicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv4-multicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class L3vpnIpv6Multicast(_Entity_):
                                    """
                                    Multicast IPv6 L3VPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "l3vpn-ipv6-multicast"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "l3vpn-ipv6-multicast"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l3vpn-ipv6-multicast"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class L2vpnVpls(_Entity_):
                                    """
                                    BGP\-signalled VPLS configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "l2vpn-vpls"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "l2vpn-vpls"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l2vpn-vpls"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                class L2vpnEvpn(_Entity_):
                                    """
                                    BGP EVPN configuration options
                                    
                                    .. attribute:: prefix_limit
                                    
                                        Configure the maximum number of prefixes that will be accepted from a peer
                                    
                                        **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "l2vpn-evpn"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit))])
                                        self._leafs = OrderedDict()

                                        self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit()
                                        self.prefix_limit.parent = self
                                        self._children_name_map["prefix_limit"] = "prefix-limit"
                                        self._segment_path = lambda: "l2vpn-evpn"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn, [], name, value)

                                    class PrefixLimit(_Entity_):
                                        """
                                        Configure the maximum number of prefixes that will be
                                        accepted from a peer
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information relating to the prefix\-limit for the AFI\-SAFI
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "prefix-limit"
                                            self.yang_parent_name = "l2vpn-evpn"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "prefix-limit"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to the prefix
                                            limit for the AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information relating to the prefix\-limit for the
                                            AFI\-SAFI
                                            
                                            .. attribute:: max_prefixes
                                            
                                                Maximum number of prefixes that will be accepted from the neighbour
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: prevent_teardown
                                            
                                                Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: shutdown_threshold_pct
                                            
                                                Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                            
                                                **type**: int
                                            
                                                    **range:** 0..100
                                            
                                                **config**: False
                                            
                                            .. attribute:: restart_timer
                                            
                                                Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                            
                                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                            
                                                    **range:** \-92233720368547758.08..92233720368547758.07
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "prefix-limit"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                    ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                    ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                    ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                ])
                                                self.max_prefixes = None
                                                self.prevent_teardown = None
                                                self.shutdown_threshold_pct = None
                                                self.restart_timer = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)






                        class DynamicNeighborPrefixes(_Entity_):
                            """
                            A list of IP prefixes from which the system should\:
                             \- Accept connections to the BGP daemon
                             \- Dynamically configure a BGP neighbor corresponding to the
                               source address of the remote system, using the parameters
                               of the specified peer\-group.
                            For such neighbors, an entry within the neighbor list should
                            be created, indicating that the peer was dynamically
                            configured, and referencing the peer\-group from which the
                            configuration was derived.
                            
                            .. attribute:: dynamic_neighbor_prefix
                            
                                An individual prefix from which dynamic neighbor connections are allowed
                            
                                **type**: list of    :py:class:`DynamicNeighborPrefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "dynamic-neighbor-prefixes"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("dynamic-neighbor-prefix", ("dynamic_neighbor_prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix))])
                                self._leafs = OrderedDict()

                                self.dynamic_neighbor_prefix = YList(self)
                                self._segment_path = lambda: "dynamic-neighbor-prefixes"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes, [], name, value)

                            class DynamicNeighborPrefix(_Entity_):
                                """
                                An individual prefix from which dynamic neighbor
                                connections are allowed.
                                
                                .. attribute:: prefix  (key)
                                
                                    Reference to the IP prefix from which source connections are allowed for the dynamic neighbor group
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                
                                    **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.Config>`
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the source prefix for the dynamic BGP neighbor connections
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state parameters relating to the source prefix for the dynamic BGP neighbor connections
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "dynamic-neighbor-prefix"
                                    self.yang_parent_name = "dynamic-neighbor-prefixes"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['prefix']
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.State))])
                                    self._leafs = OrderedDict([
                                        ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                    ])
                                    self.prefix = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "dynamic-neighbor-prefix" + "[prefix='" + str(self.prefix) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix, ['prefix'], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the source prefix
                                    for the dynamic BGP neighbor connections.
                                    
                                    .. attribute:: prefix
                                    
                                        The IP prefix within which the source address of the remote BGP speaker must fall to be considered eligible to the dynamically configured
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                    
                                    .. attribute:: peer_group
                                    
                                        The peer\-group within which the dynamic neighbor will be configured.  The configuration parameters used for the dynamic neighbor are those specified within the referenced peer group
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`peer_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "dynamic-neighbor-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('peer_group', (YLeaf(YType.str, 'peer-group'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self.peer_group = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.Config, ['prefix', 'peer_group'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state parameters relating to the source
                                    prefix for the dynamic BGP neighbor connections.
                                    
                                    .. attribute:: prefix
                                    
                                        The IP prefix within which the source address of the remote BGP speaker must fall to be considered eligible to the dynamically configured
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                    
                                        **config**: False
                                    
                                    .. attribute:: peer_group
                                    
                                        The peer\-group within which the dynamic neighbor will be configured.  The configuration parameters used for the dynamic neighbor are those specified within the referenced peer group
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`peer_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "dynamic-neighbor-prefix"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                            ('peer_group', (YLeaf(YType.str, 'peer-group'), ['str'])),
                                        ])
                                        self.prefix = None
                                        self.peer_group = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Global.DynamicNeighborPrefixes.DynamicNeighborPrefix.State, ['prefix', 'peer_group'], name, value)





                    class Neighbors(_Entity_):
                        """
                        Configuration for BGP neighbors
                        
                        .. attribute:: neighbor
                        
                            List of BGP neighbors configured on the local system, uniquely identified by peer IPv[46] address
                        
                            **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "neighbors"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor))])
                            self._leafs = OrderedDict()

                            self.neighbor = YList(self)
                            self._segment_path = lambda: "neighbors"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors, [], name, value)

                        class Neighbor(_Entity_):
                            """
                            List of BGP neighbors configured on the local system,
                            uniquely identified by peer IPv[46] address
                            
                            .. attribute:: neighbor_address  (key)
                            
                                Reference to the address of the BGP neighbor used as a key in the neighbor list
                            
                                **type**: union of the below types:
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                            
                                    **type**: str
                            
                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                            
                                **refers to**:  :py:class:`neighbor_address<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the BGP neighbor or group
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config>`
                            
                            .. attribute:: state
                            
                                State information relating to the BGP neighbor
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State>`
                            
                                **config**: False
                            
                            .. attribute:: timers
                            
                                Timers related to a BGP neighbor
                            
                                **type**:  :py:class:`Timers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers>`
                            
                            .. attribute:: transport
                            
                                Transport session parameters for the BGP neighbor
                            
                                **type**:  :py:class:`Transport<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport>`
                            
                            .. attribute:: error_handling
                            
                                Error handling parameters used for the BGP neighbor or group
                            
                                **type**:  :py:class:`ErrorHandling<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling>`
                            
                            .. attribute:: graceful_restart
                            
                                Parameters relating the graceful restart mechanism for BGP
                            
                                **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart>`
                            
                            .. attribute:: logging_options
                            
                                Logging options for events related to the BGP neighbor or group
                            
                                **type**:  :py:class:`LoggingOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions>`
                            
                            .. attribute:: ebgp_multihop
                            
                                eBGP multi\-hop parameters for the BGPgroup
                            
                                **type**:  :py:class:`EbgpMultihop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop>`
                            
                            .. attribute:: route_reflector
                            
                                Route reflector parameters for the BGPgroup
                            
                                **type**:  :py:class:`RouteReflector<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector>`
                            
                            .. attribute:: as_path_options
                            
                                AS\_PATH manipulation parameters for the BGP neighbor or group
                            
                                **type**:  :py:class:`AsPathOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions>`
                            
                            .. attribute:: add_paths
                            
                                Parameters relating to the advertisement and receipt of multiple paths for a single NLRI (add\-paths)
                            
                                **type**:  :py:class:`AddPaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths>`
                            
                            .. attribute:: use_multiple_paths
                            
                                Parameters related to the use of multiple\-paths for the same NLRI when they are received only from this neighbor
                            
                                **type**:  :py:class:`UseMultiplePaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths>`
                            
                            .. attribute:: apply_policy
                            
                                Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                            
                                **type**:  :py:class:`ApplyPolicy<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy>`
                            
                            .. attribute:: afi_safis
                            
                                Per\-address\-family configuration parameters associated with the neighbor
                            
                                **type**:  :py:class:`AfiSafis<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis>`
                            
                            .. attribute:: enable_bfd
                            
                                Enable BFD for liveliness detection to the next\-hop or neighbour
                            
                                **type**:  :py:class:`EnableBfd<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "neighbor"
                                self.yang_parent_name = "neighbors"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['neighbor_address']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers)), ("transport", ("transport", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport)), ("error-handling", ("error_handling", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart)), ("logging-options", ("logging_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions)), ("ebgp-multihop", ("ebgp_multihop", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop)), ("route-reflector", ("route_reflector", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector)), ("as-path-options", ("as_path_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions)), ("add-paths", ("add_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy)), ("afi-safis", ("afi_safis", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis)), ("openconfig-bfd:enable-bfd", ("enable_bfd", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd))])
                                self._leafs = OrderedDict([
                                    ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str'])),
                                ])
                                self.neighbor_address = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.transport = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"

                                self.error_handling = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling()
                                self.error_handling.parent = self
                                self._children_name_map["error_handling"] = "error-handling"

                                self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart()
                                self.graceful_restart.parent = self
                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                self.logging_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions()
                                self.logging_options.parent = self
                                self._children_name_map["logging_options"] = "logging-options"

                                self.ebgp_multihop = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop()
                                self.ebgp_multihop.parent = self
                                self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                self.route_reflector = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector()
                                self.route_reflector.parent = self
                                self._children_name_map["route_reflector"] = "route-reflector"

                                self.as_path_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions()
                                self.as_path_options.parent = self
                                self._children_name_map["as_path_options"] = "as-path-options"

                                self.add_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths()
                                self.add_paths.parent = self
                                self._children_name_map["add_paths"] = "add-paths"

                                self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths()
                                self.use_multiple_paths.parent = self
                                self._children_name_map["use_multiple_paths"] = "use-multiple-paths"

                                self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy()
                                self.apply_policy.parent = self
                                self._children_name_map["apply_policy"] = "apply-policy"

                                self.afi_safis = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis()
                                self.afi_safis.parent = self
                                self._children_name_map["afi_safis"] = "afi-safis"

                                self.enable_bfd = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd()
                                self.enable_bfd.parent = self
                                self._children_name_map["enable_bfd"] = "openconfig-bfd:enable-bfd"
                                self._segment_path = lambda: "neighbor" + "[neighbor-address='" + str(self.neighbor_address) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor, ['neighbor_address'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the BGP neighbor or
                                group
                                
                                .. attribute:: peer_group
                                
                                    The peer\-group with which this neighbor is associated
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`peer_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup>`
                                
                                .. attribute:: neighbor_address
                                
                                    Address of the BGP peer, either in IPv4 or IPv6
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                .. attribute:: enabled
                                
                                    Whether the BGP peer is enabled. In cases where the enabled leaf is set to false, the local system should not initiate connections to the neighbor, and should not respond to TCP connections attempts from the neighbor. If the state of the BGP session is ESTABLISHED at the time that this leaf is set to false, the BGP session should be ceased
                                
                                    **type**: bool
                                
                                    **default value**: true
                                
                                .. attribute:: peer_as
                                
                                    AS number of the peer
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                .. attribute:: local_as
                                
                                    The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                .. attribute:: peer_type
                                
                                    Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                
                                    **type**:  :py:class:`PeerType<ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                .. attribute:: auth_password
                                
                                    Configures an MD5 authentication password for use with neighboring devices
                                
                                    **type**: str
                                
                                .. attribute:: remove_private_as
                                
                                    Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                
                                    **type**:  :py:class:`REMOVEPRIVATEASOPTION<ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                .. attribute:: route_flap_damping
                                
                                    Enable route flap damping
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: send_community
                                
                                    Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                
                                    **type**:  :py:class:`CommunityType<ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                    **default value**: NONE
                                
                                .. attribute:: description
                                
                                    An optional textual description (intended primarily for use with a peer or group
                                
                                    **type**: str
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group', (YLeaf(YType.str, 'peer-group'), ['str'])),
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('peer_as', (YLeaf(YType.uint32, 'peer-as'), ['int'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('peer_type', (YLeaf(YType.enumeration, 'peer-type'), [('ydk.models.openconfig.openconfig_bgp_types', 'PeerType', '')])),
                                        ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                        ('remove_private_as', (YLeaf(YType.identityref, 'remove-private-as'), [('ydk.models.openconfig.openconfig_bgp_types', 'REMOVEPRIVATEASOPTION')])),
                                        ('route_flap_damping', (YLeaf(YType.boolean, 'route-flap-damping'), ['bool'])),
                                        ('send_community', (YLeaf(YType.enumeration, 'send-community'), [('ydk.models.openconfig.openconfig_bgp_types', 'CommunityType', '')])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ])
                                    self.peer_group = None
                                    self.neighbor_address = None
                                    self.enabled = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Config, ['peer_group', 'neighbor_address', 'enabled', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description'], name, value)


                            class State(_Entity_):
                                """
                                State information relating to the BGP neighbor
                                
                                .. attribute:: peer_group
                                
                                    The peer\-group with which this neighbor is associated
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`peer_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup>`
                                
                                    **config**: False
                                
                                .. attribute:: neighbor_address
                                
                                    Address of the BGP peer, either in IPv4 or IPv6
                                
                                    **type**: union of the below types:
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                
                                        **type**: str
                                
                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                
                                    **config**: False
                                
                                .. attribute:: enabled
                                
                                    Whether the BGP peer is enabled. In cases where the enabled leaf is set to false, the local system should not initiate connections to the neighbor, and should not respond to TCP connections attempts from the neighbor. If the state of the BGP session is ESTABLISHED at the time that this leaf is set to false, the BGP session should be ceased
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: true
                                
                                .. attribute:: peer_as
                                
                                    AS number of the peer
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: local_as
                                
                                    The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: peer_type
                                
                                    Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                
                                    **type**:  :py:class:`PeerType<ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                    **config**: False
                                
                                .. attribute:: auth_password
                                
                                    Configures an MD5 authentication password for use with neighboring devices
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: remove_private_as
                                
                                    Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                
                                    **type**:  :py:class:`REMOVEPRIVATEASOPTION<ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                    **config**: False
                                
                                .. attribute:: route_flap_damping
                                
                                    Enable route flap damping
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: send_community
                                
                                    Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                
                                    **type**:  :py:class:`CommunityType<ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                    **config**: False
                                
                                    **default value**: NONE
                                
                                .. attribute:: description
                                
                                    An optional textual description (intended primarily for use with a peer or group
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: session_state
                                
                                    Operational state of the BGP peer
                                
                                    **type**:  :py:class:`SessionState<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.SessionState>`
                                
                                    **config**: False
                                
                                .. attribute:: last_established
                                
                                    This timestamp indicates the time that the BGP session last transitioned in or out of the Established state.  The value is the timestamp in seconds relative to the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC).  The BGP session uptime can be computed by clients as the difference between this value and the current time in UTC (assuming the session is in the ESTABLISHED state, per the session\-state leaf)
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: established_transitions
                                
                                    Number of transitions to the Established state for the neighbor session.  This value is analogous to the bgpPeerFsmEstablishedTransitions object from the standard BGP\-4 MIB
                                
                                    **type**: int
                                
                                        **range:** 0..18446744073709551615
                                
                                    **config**: False
                                
                                .. attribute:: supported_capabilities
                                
                                    BGP capabilities negotiated as supported with the peer
                                
                                    **type**: list of   :py:class:`BGPCAPABILITY<ydk.models.openconfig.openconfig_bgp_types.BGPCAPABILITY>`
                                
                                    **config**: False
                                
                                .. attribute:: messages
                                
                                    Counters for BGP messages sent and received from the neighbor
                                
                                    **type**:  :py:class:`Messages<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages>`
                                
                                    **config**: False
                                
                                .. attribute:: queues
                                
                                    Counters related to queued messages associated with the BGP neighbor
                                
                                    **type**:  :py:class:`Queues<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues>`
                                
                                    **config**: False
                                
                                .. attribute:: dynamically_configured
                                
                                    When this leaf is set to true, the peer was configured dynamically due to an inbound connection request from a specified source prefix within a dynamic\-neighbor\-prefix
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("messages", ("messages", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages)), ("queues", ("queues", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues))])
                                    self._leafs = OrderedDict([
                                        ('peer_group', (YLeaf(YType.str, 'peer-group'), ['str'])),
                                        ('neighbor_address', (YLeaf(YType.str, 'neighbor-address'), ['str','str'])),
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('peer_as', (YLeaf(YType.uint32, 'peer-as'), ['int'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('peer_type', (YLeaf(YType.enumeration, 'peer-type'), [('ydk.models.openconfig.openconfig_bgp_types', 'PeerType', '')])),
                                        ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                        ('remove_private_as', (YLeaf(YType.identityref, 'remove-private-as'), [('ydk.models.openconfig.openconfig_bgp_types', 'REMOVEPRIVATEASOPTION')])),
                                        ('route_flap_damping', (YLeaf(YType.boolean, 'route-flap-damping'), ['bool'])),
                                        ('send_community', (YLeaf(YType.enumeration, 'send-community'), [('ydk.models.openconfig.openconfig_bgp_types', 'CommunityType', '')])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('session_state', (YLeaf(YType.enumeration, 'session-state'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.SessionState')])),
                                        ('last_established', (YLeaf(YType.uint64, 'last-established'), ['int'])),
                                        ('established_transitions', (YLeaf(YType.uint64, 'established-transitions'), ['int'])),
                                        ('supported_capabilities', (YLeafList(YType.identityref, 'supported-capabilities'), [('ydk.models.openconfig.openconfig_bgp_types', 'BGPCAPABILITY')])),
                                        ('dynamically_configured', (YLeaf(YType.boolean, 'dynamically-configured'), ['bool'])),
                                    ])
                                    self.peer_group = None
                                    self.neighbor_address = None
                                    self.enabled = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self.session_state = None
                                    self.last_established = None
                                    self.established_transitions = None
                                    self.supported_capabilities = []
                                    self.dynamically_configured = None

                                    self.messages = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages()
                                    self.messages.parent = self
                                    self._children_name_map["messages"] = "messages"

                                    self.queues = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues()
                                    self.queues.parent = self
                                    self._children_name_map["queues"] = "queues"
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State, ['peer_group', 'neighbor_address', 'enabled', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description', 'session_state', 'last_established', 'established_transitions', 'supported_capabilities', 'dynamically_configured'], name, value)

                                class SessionState(Enum):
                                    """
                                    SessionState (Enum Class)

                                    .. data:: IDLE = 0

                                        neighbor is down, and in the Idle state of the

                                        FSM

                                    .. data:: CONNECT = 1

                                        neighbor is down, and the session is waiting for

                                        the underlying transport session to be established

                                    .. data:: ACTIVE = 2

                                        neighbor is down, and the local system is awaiting

                                        a conncetion from the remote peer

                                    .. data:: OPENSENT = 3

                                        neighbor is in the process of being established.

                                        The local system has sent an OPEN message

                                    .. data:: OPENCONFIRM = 4

                                        neighbor is in the process of being established.

                                        The local system is awaiting a NOTIFICATION or

                                        KEEPALIVE message

                                    .. data:: ESTABLISHED = 5

                                        neighbor is up - the BGP session with the peer is

                                        established

                                    """

                                    IDLE = Enum.YLeaf(0, "IDLE")

                                    CONNECT = Enum.YLeaf(1, "CONNECT")

                                    ACTIVE = Enum.YLeaf(2, "ACTIVE")

                                    OPENSENT = Enum.YLeaf(3, "OPENSENT")

                                    OPENCONFIRM = Enum.YLeaf(4, "OPENCONFIRM")

                                    ESTABLISHED = Enum.YLeaf(5, "ESTABLISHED")


                                class Messages(_Entity_):
                                    """
                                    Counters for BGP messages sent and received from the
                                    neighbor
                                    
                                    .. attribute:: sent
                                    
                                        Counters relating to BGP messages sent to the neighbor
                                    
                                        **type**:  :py:class:`Sent<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: received
                                    
                                        Counters for BGP messages received from the neighbor
                                    
                                        **type**:  :py:class:`Received<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "messages"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("sent", ("sent", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent)), ("received", ("received", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received))])
                                        self._leafs = OrderedDict()

                                        self.sent = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent()
                                        self.sent.parent = self
                                        self._children_name_map["sent"] = "sent"

                                        self.received = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received()
                                        self.received.parent = self
                                        self._children_name_map["received"] = "received"
                                        self._segment_path = lambda: "messages"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages, [], name, value)

                                    class Sent(_Entity_):
                                        """
                                        Counters relating to BGP messages sent to the neighbor
                                        
                                        .. attribute:: update
                                        
                                            Number of BGP UPDATE messages announcing, withdrawing or modifying paths exchanged
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: notification
                                        
                                            Number of BGP NOTIFICATION messages indicating an error condition has occurred exchanged
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "sent"
                                            self.yang_parent_name = "messages"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update', (YLeaf(YType.uint64, 'UPDATE'), ['int'])),
                                                ('notification', (YLeaf(YType.uint64, 'NOTIFICATION'), ['int'])),
                                            ])
                                            self.update = None
                                            self.notification = None
                                            self._segment_path = lambda: "sent"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Sent, ['update', 'notification'], name, value)


                                    class Received(_Entity_):
                                        """
                                        Counters for BGP messages received from the neighbor
                                        
                                        .. attribute:: update
                                        
                                            Number of BGP UPDATE messages announcing, withdrawing or modifying paths exchanged
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        .. attribute:: notification
                                        
                                            Number of BGP NOTIFICATION messages indicating an error condition has occurred exchanged
                                        
                                            **type**: int
                                        
                                                **range:** 0..18446744073709551615
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "received"
                                            self.yang_parent_name = "messages"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('update', (YLeaf(YType.uint64, 'UPDATE'), ['int'])),
                                                ('notification', (YLeaf(YType.uint64, 'NOTIFICATION'), ['int'])),
                                            ])
                                            self.update = None
                                            self.notification = None
                                            self._segment_path = lambda: "received"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Messages.Received, ['update', 'notification'], name, value)



                                class Queues(_Entity_):
                                    """
                                    Counters related to queued messages associated with the
                                    BGP neighbor
                                    
                                    .. attribute:: input
                                    
                                        The number of messages received from the peer currently queued
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: output
                                    
                                        The number of messages queued to be sent to the peer
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "queues"
                                        self.yang_parent_name = "state"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('input', (YLeaf(YType.uint32, 'input'), ['int'])),
                                            ('output', (YLeaf(YType.uint32, 'output'), ['int'])),
                                        ])
                                        self.input = None
                                        self.output = None
                                        self._segment_path = lambda: "queues"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.State.Queues, ['input', 'output'], name, value)



                            class Timers(_Entity_):
                                """
                                Timers related to a BGP neighbor
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to timers used for the BGP neighbor
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the timers used for the BGP neighbor
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to timers used for the
                                    BGP neighbor
                                    
                                    .. attribute:: connect_retry
                                    
                                        Time interval in seconds between attempts to establish a session with the peer
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: hold_time
                                    
                                        Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                        Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                        Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 30
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', (YLeaf(YType.str, 'connect-retry'), ['Decimal64'])),
                                            ('hold_time', (YLeaf(YType.str, 'hold-time'), ['Decimal64'])),
                                            ('keepalive_interval', (YLeaf(YType.str, 'keepalive-interval'), ['Decimal64'])),
                                            ('minimum_advertisement_interval', (YLeaf(YType.str, 'minimum-advertisement-interval'), ['Decimal64'])),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.Config, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the timers used for the BGP
                                    neighbor
                                    
                                    .. attribute:: connect_retry
                                    
                                        Time interval in seconds between attempts to establish a session with the peer
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: hold_time
                                    
                                        Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                        Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                        Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: negotiated_hold_time
                                    
                                        The negotiated hold\-time for the BGP session
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', (YLeaf(YType.str, 'connect-retry'), ['Decimal64'])),
                                            ('hold_time', (YLeaf(YType.str, 'hold-time'), ['Decimal64'])),
                                            ('keepalive_interval', (YLeaf(YType.str, 'keepalive-interval'), ['Decimal64'])),
                                            ('minimum_advertisement_interval', (YLeaf(YType.str, 'minimum-advertisement-interval'), ['Decimal64'])),
                                            ('negotiated_hold_time', (YLeaf(YType.str, 'negotiated-hold-time'), ['Decimal64'])),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self.negotiated_hold_time = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Timers.State, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval', 'negotiated_hold_time'], name, value)



                            class Transport(_Entity_):
                                """
                                Transport session parameters for the BGP neighbor
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the transport session(s) used for the BGP neighbor
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the transport session(s) used for the BGP neighbor
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the transport
                                    session(s) used for the BGP neighbor
                                    
                                    .. attribute:: tcp_mss
                                    
                                        Sets the max segment size for BGP TCP sessions
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                    .. attribute:: mtu_discovery
                                    
                                        Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: passive_mode
                                    
                                        Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: local_address
                                    
                                        Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    
                                        **type**: union of the below types:
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                            **type**: str
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', (YLeaf(YType.uint16, 'tcp-mss'), ['int'])),
                                            ('mtu_discovery', (YLeaf(YType.boolean, 'mtu-discovery'), ['bool'])),
                                            ('passive_mode', (YLeaf(YType.boolean, 'passive-mode'), ['bool'])),
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str','str'])),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.Config, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the transport session(s)
                                    used for the BGP neighbor
                                    
                                    .. attribute:: tcp_mss
                                    
                                        Sets the max segment size for BGP TCP sessions
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                    .. attribute:: mtu_discovery
                                    
                                        Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: passive_mode
                                    
                                        Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: local_address
                                    
                                        Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    
                                        **type**: union of the below types:
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                            **type**: str
                                    
                                        **config**: False
                                    
                                    .. attribute:: local_port
                                    
                                        Local TCP port being used for the TCP session supporting the BGP session
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                    .. attribute:: remote_address
                                    
                                        Remote address to which the BGP session has been established
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                        **config**: False
                                    
                                    .. attribute:: remote_port
                                    
                                        Remote port being used by the peer for the TCP session supporting the BGP session
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', (YLeaf(YType.uint16, 'tcp-mss'), ['int'])),
                                            ('mtu_discovery', (YLeaf(YType.boolean, 'mtu-discovery'), ['bool'])),
                                            ('passive_mode', (YLeaf(YType.boolean, 'passive-mode'), ['bool'])),
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str','str'])),
                                            ('local_port', (YLeaf(YType.uint16, 'local-port'), ['int'])),
                                            ('remote_address', (YLeaf(YType.str, 'remote-address'), ['str','str'])),
                                            ('remote_port', (YLeaf(YType.uint16, 'remote-port'), ['int'])),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self.local_port = None
                                        self.remote_address = None
                                        self.remote_port = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.Transport.State, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address', 'local_port', 'remote_address', 'remote_port'], name, value)



                            class ErrorHandling(_Entity_):
                                """
                                Error handling parameters used for the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                    Configuration parameters enabling or modifying the behavior or enhanced error handling mechanisms for the BGP neighbor
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to enhanced error handling mechanisms for the BGP neighbor
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "error-handling"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "error-handling"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters enabling or modifying the
                                    behavior or enhanced error handling mechanisms for the BGP
                                    neighbor
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                        Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', (YLeaf(YType.boolean, 'treat-as-withdraw'), ['bool'])),
                                        ])
                                        self.treat_as_withdraw = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.Config, ['treat_as_withdraw'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to enhanced error handling
                                    mechanisms for the BGP neighbor
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                        Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: erroneous_update_messages
                                    
                                        The number of BGP UPDATE messages for which the treat\-as\-withdraw mechanism has been applied based on erroneous message contents
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', (YLeaf(YType.boolean, 'treat-as-withdraw'), ['bool'])),
                                            ('erroneous_update_messages', (YLeaf(YType.uint32, 'erroneous-update-messages'), ['int'])),
                                        ])
                                        self.treat_as_withdraw = None
                                        self.erroneous_update_messages = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ErrorHandling.State, ['treat_as_withdraw', 'erroneous_update_messages'], name, value)



                            class GracefulRestart(_Entity_):
                                """
                                Parameters relating the graceful restart mechanism for BGP
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to graceful\-restart
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config>`
                                
                                .. attribute:: state
                                
                                    State information associated with graceful\-restart
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "graceful-restart"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "graceful-restart"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                        Enable or disable the graceful\-restart capability
                                    
                                        **type**: bool
                                    
                                    .. attribute:: restart_time
                                    
                                        Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    
                                        **type**: int
                                    
                                            **range:** 0..4096
                                    
                                    .. attribute:: stale_routes_time
                                    
                                        An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    .. attribute:: helper_only
                                    
                                        Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    
                                        **type**: bool
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                                            ('stale_routes_time', (YLeaf(YType.str, 'stale-routes-time'), ['Decimal64'])),
                                            ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.Config, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                                class State(_Entity_):
                                    """
                                    State information associated with graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                        Enable or disable the graceful\-restart capability
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: restart_time
                                    
                                        Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    
                                        **type**: int
                                    
                                            **range:** 0..4096
                                    
                                        **config**: False
                                    
                                    .. attribute:: stale_routes_time
                                    
                                        An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                    .. attribute:: helper_only
                                    
                                        Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: peer_restart_time
                                    
                                        The period of time (advertised by the peer) that the peer expects a restart of a BGP session to take
                                    
                                        **type**: int
                                    
                                            **range:** 0..4096
                                    
                                        **config**: False
                                    
                                    .. attribute:: peer_restarting
                                    
                                        This flag indicates whether the remote neighbor is currently in the process of restarting, and hence received routes are currently stale
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: local_restarting
                                    
                                        This flag indicates whether the local neighbor is currently restarting. The flag is unset after all NLRI have been advertised to the peer, and the End\-of\-RIB (EOR) marker has been unset
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: mode
                                    
                                        Ths leaf indicates the mode of operation of BGP graceful restart with the peer
                                    
                                        **type**:  :py:class:`Mode<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State.Mode>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                                            ('stale_routes_time', (YLeaf(YType.str, 'stale-routes-time'), ['Decimal64'])),
                                            ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                            ('peer_restart_time', (YLeaf(YType.uint16, 'peer-restart-time'), ['int'])),
                                            ('peer_restarting', (YLeaf(YType.boolean, 'peer-restarting'), ['bool'])),
                                            ('local_restarting', (YLeaf(YType.boolean, 'local-restarting'), ['bool'])),
                                            ('mode', (YLeaf(YType.enumeration, 'mode'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State.Mode')])),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self.peer_restart_time = None
                                        self.peer_restarting = None
                                        self.local_restarting = None
                                        self.mode = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.GracefulRestart.State, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only', 'peer_restart_time', 'peer_restarting', 'local_restarting', 'mode'], name, value)

                                    class Mode(Enum):
                                        """
                                        Mode (Enum Class)

                                        .. data:: HELPER_ONLY = 0

                                            The local router is operating in helper-only mode, and

                                            hence will not retain forwarding state during a local

                                            session restart, but will do so during a restart of the

                                            remote peer

                                        .. data:: BILATERAL = 1

                                            The local router is operating in both helper mode, and

                                            hence retains forwarding state during a remote restart,

                                            and also maintains forwarding state during local session

                                            restart

                                        .. data:: REMOTE_HELPER = 2

                                            The local system is able to retain routes during restart

                                            but the remote system is only able to act as a helper

                                        """

                                        HELPER_ONLY = Enum.YLeaf(0, "HELPER_ONLY")

                                        BILATERAL = Enum.YLeaf(1, "BILATERAL")

                                        REMOTE_HELPER = Enum.YLeaf(2, "REMOTE_HELPER")




                            class LoggingOptions(_Entity_):
                                """
                                Logging options for events related to the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                    Configuration parameters enabling or modifying logging for events relating to the BGPgroup
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to logging for the BGP neighbor or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "logging-options"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "logging-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters enabling or modifying logging
                                    for events relating to the BGPgroup
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                        Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    
                                        **type**: bool
                                    
                                        **default value**: true
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', (YLeaf(YType.boolean, 'log-neighbor-state-changes'), ['bool'])),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.Config, ['log_neighbor_state_changes'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to logging for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                        Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: true
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', (YLeaf(YType.boolean, 'log-neighbor-state-changes'), ['bool'])),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.LoggingOptions.State, ['log_neighbor_state_changes'], name, value)



                            class EbgpMultihop(_Entity_):
                                """
                                eBGP multi\-hop parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to eBGP multihop for the BGP group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config>`
                                
                                .. attribute:: state
                                
                                    State information for eBGP multihop, for the BGP neighbor or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "ebgp-multihop"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "ebgp-multihop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to eBGP multihop for the
                                    BGP group
                                    
                                    .. attribute:: enabled
                                    
                                        When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                        Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('multihop_ttl', (YLeaf(YType.uint8, 'multihop-ttl'), ['int'])),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.Config, ['enabled', 'multihop_ttl'], name, value)


                                class State(_Entity_):
                                    """
                                    State information for eBGP multihop, for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: enabled
                                    
                                        When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                        Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('multihop_ttl', (YLeaf(YType.uint8, 'multihop-ttl'), ['int'])),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EbgpMultihop.State, ['enabled', 'multihop_ttl'], name, value)



                            class RouteReflector(_Entity_):
                                """
                                Route reflector parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                    Configuraton parameters relating to route reflection for the BGPgroup
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to route reflection for the BGPgroup
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "route-reflector"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "route-reflector"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuraton parameters relating to route reflection
                                    for the BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                        route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: int
                                    
                                                **range:** 0..4294967295
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                    .. attribute:: route_reflector_client
                                    
                                        Configure the neighbor as a route reflector client
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', (YLeaf(YType.str, 'route-reflector-cluster-id'), ['int','str'])),
                                            ('route_reflector_client', (YLeaf(YType.boolean, 'route-reflector-client'), ['bool'])),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.Config, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to route reflection for the
                                    BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                        route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: int
                                    
                                                **range:** 0..4294967295
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                        **config**: False
                                    
                                    .. attribute:: route_reflector_client
                                    
                                        Configure the neighbor as a route reflector client
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', (YLeaf(YType.str, 'route-reflector-cluster-id'), ['int','str'])),
                                            ('route_reflector_client', (YLeaf(YType.boolean, 'route-reflector-client'), ['bool'])),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.RouteReflector.State, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)



                            class AsPathOptions(_Entity_):
                                """
                                AS\_PATH manipulation parameters for the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to AS\_PATH manipulation for the BGP peer or group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the AS\_PATH manipulation mechanisms for the BGP peer or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "as-path-options"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "as-path-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to AS\_PATH manipulation
                                    for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                        Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **default value**: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                        Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', (YLeaf(YType.uint8, 'allow-own-as'), ['int'])),
                                            ('replace_peer_as', (YLeaf(YType.boolean, 'replace-peer-as'), ['bool'])),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.Config, ['allow_own_as', 'replace_peer_as'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the AS\_PATH manipulation
                                    mechanisms for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                        Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **config**: False
                                    
                                        **default value**: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                        Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', (YLeaf(YType.uint8, 'allow-own-as'), ['int'])),
                                            ('replace_peer_as', (YLeaf(YType.boolean, 'replace-peer-as'), ['bool'])),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AsPathOptions.State, ['allow_own_as', 'replace_peer_as'], name, value)



                            class AddPaths(_Entity_):
                                """
                                Parameters relating to the advertisement and receipt of
                                multiple paths for a single NLRI (add\-paths)
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to ADD\_PATHS
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config>`
                                
                                .. attribute:: state
                                
                                    State information associated with ADD\_PATHS
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "add-paths"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "add-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                        Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: send_max
                                    
                                        The maximum number of paths to advertise to neighbors for a single NLRI
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                        A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                                            ('send_max', (YLeaf(YType.uint8, 'send-max'), ['int'])),
                                            ('eligible_prefix_policy', (YLeaf(YType.str, 'eligible-prefix-policy'), ['str'])),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.Config, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)


                                class State(_Entity_):
                                    """
                                    State information associated with ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                        Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: send_max
                                    
                                        The maximum number of paths to advertise to neighbors for a single NLRI
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **config**: False
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                        A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                                            ('send_max', (YLeaf(YType.uint8, 'send-max'), ['int'])),
                                            ('eligible_prefix_policy', (YLeaf(YType.str, 'eligible-prefix-policy'), ['str'])),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AddPaths.State, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)



                            class UseMultiplePaths(_Entity_):
                                """
                                Parameters related to the use of multiple\-paths for the same
                                NLRI when they are received only from this neighbor
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to multipath
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config>`
                                
                                .. attribute:: state
                                
                                    State parameters relating to multipath
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State>`
                                
                                    **config**: False
                                
                                .. attribute:: ebgp
                                
                                    Multipath configuration for eBGP
                                
                                    **type**:  :py:class:`Ebgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "use-multiple-paths"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp()
                                    self.ebgp.parent = self
                                    self._children_name_map["ebgp"] = "ebgp"
                                    self._segment_path = lambda: "use-multiple-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                        Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Config, ['enabled'], name, value)


                                class State(_Entity_):
                                    """
                                    State parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                        Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.State, ['enabled'], name, value)


                                class Ebgp(_Entity_):
                                    """
                                    Multipath configuration for eBGP
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to eBGP multipath
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information relating to eBGP multipath
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ebgp"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "ebgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                            Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                            ])
                                            self.allow_multiple_as = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                            Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                            ])
                                            self.allow_multiple_as = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.UseMultiplePaths.Ebgp.State, ['allow_multiple_as'], name, value)




                            class ApplyPolicy(_Entity_):
                                """
                                Anchor point for routing policies in the model.
                                Import and export policies are with respect to the local
                                routing table, i.e., export (send) and import (receive),
                                depending on the context.
                                
                                .. attribute:: config
                                
                                    Policy configuration data
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for routing policy
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "apply-policy"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "apply-policy"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Policy configuration data.
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                        list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_export_policy
                                    
                                        explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                            ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                            ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for routing policy
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **config**: False
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                        list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: default_export_policy
                                    
                                        explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **config**: False
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                            ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                            ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)



                            class AfiSafis(_Entity_):
                                """
                                Per\-address\-family configuration parameters associated with
                                the neighbor
                                
                                .. attribute:: afi_safi
                                
                                    AFI,SAFI configuration available for the neighbour or group
                                
                                    **type**: list of    :py:class:`AfiSafi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "afi-safis"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi))])
                                    self._leafs = OrderedDict()

                                    self.afi_safi = YList(self)
                                    self._segment_path = lambda: "afi-safis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis, [], name, value)

                                class AfiSafi(_Entity_):
                                    """
                                    AFI,SAFI configuration available for the
                                    neighbour or group
                                    
                                    .. attribute:: afi_safi_name  (key)
                                    
                                        Reference to the AFI\-SAFI name used as a key for the AFI\-SAFI list
                                    
                                        **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters for the AFI\-SAFI
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information relating to the AFI\-SAFI
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: graceful_restart
                                    
                                        Parameters relating to BGP graceful\-restart
                                    
                                        **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart>`
                                    
                                    .. attribute:: apply_policy
                                    
                                        Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                                    
                                        **type**:  :py:class:`ApplyPolicy<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy>`
                                    
                                    .. attribute:: ipv4_unicast
                                    
                                        IPv4 unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast>`
                                    
                                    .. attribute:: ipv6_unicast
                                    
                                        IPv6 unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast>`
                                    
                                    .. attribute:: ipv4_labeled_unicast
                                    
                                        IPv4 Labeled Unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv4LabeledUnicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast>`
                                    
                                    .. attribute:: ipv6_labeled_unicast
                                    
                                        IPv6 Labeled Unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv6LabeledUnicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_unicast
                                    
                                        Unicast IPv4 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_unicast
                                    
                                        Unicast IPv6 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_multicast
                                    
                                        Multicast IPv4 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv4Multicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_multicast
                                    
                                        Multicast IPv6 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv6Multicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast>`
                                    
                                    .. attribute:: l2vpn_vpls
                                    
                                        BGP\-signalled VPLS configuration options
                                    
                                        **type**:  :py:class:`L2vpnVpls<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls>`
                                    
                                    .. attribute:: l2vpn_evpn
                                    
                                        BGP EVPN configuration options
                                    
                                        **type**:  :py:class:`L2vpnEvpn<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn>`
                                    
                                    .. attribute:: use_multiple_paths
                                    
                                        Parameters related to the use of multiple\-paths for the same NLRI when they are received only from this neighbor
                                    
                                        **type**:  :py:class:`UseMultiplePaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "afi-safi"
                                        self.yang_parent_name = "afi-safis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['afi_safi_name']
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy)), ("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast)), ("ipv4-labeled-unicast", ("ipv4_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast)), ("ipv6-labeled-unicast", ("ipv6_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast)), ("l3vpn-ipv4-unicast", ("l3vpn_ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast)), ("l3vpn-ipv6-unicast", ("l3vpn_ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast)), ("l3vpn-ipv4-multicast", ("l3vpn_ipv4_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast)), ("l3vpn-ipv6-multicast", ("l3vpn_ipv6_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast)), ("l2vpn-vpls", ("l2vpn_vpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls)), ("l2vpn-evpn", ("l2vpn_evpn", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths))])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                        ])
                                        self.afi_safi_name = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart()
                                        self.graceful_restart.parent = self
                                        self._children_name_map["graceful_restart"] = "graceful-restart"

                                        self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy()
                                        self.apply_policy.parent = self
                                        self._children_name_map["apply_policy"] = "apply-policy"

                                        self.ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast()
                                        self.ipv4_unicast.parent = self
                                        self._children_name_map["ipv4_unicast"] = "ipv4-unicast"

                                        self.ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast()
                                        self.ipv6_unicast.parent = self
                                        self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                                        self.ipv4_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast()
                                        self.ipv4_labeled_unicast.parent = self
                                        self._children_name_map["ipv4_labeled_unicast"] = "ipv4-labeled-unicast"

                                        self.ipv6_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast()
                                        self.ipv6_labeled_unicast.parent = self
                                        self._children_name_map["ipv6_labeled_unicast"] = "ipv6-labeled-unicast"

                                        self.l3vpn_ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast()
                                        self.l3vpn_ipv4_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_unicast"] = "l3vpn-ipv4-unicast"

                                        self.l3vpn_ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast()
                                        self.l3vpn_ipv6_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_unicast"] = "l3vpn-ipv6-unicast"

                                        self.l3vpn_ipv4_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast()
                                        self.l3vpn_ipv4_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_multicast"] = "l3vpn-ipv4-multicast"

                                        self.l3vpn_ipv6_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast()
                                        self.l3vpn_ipv6_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_multicast"] = "l3vpn-ipv6-multicast"

                                        self.l2vpn_vpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls()
                                        self.l2vpn_vpls.parent = self
                                        self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"

                                        self.l2vpn_evpn = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn()
                                        self.l2vpn_evpn.parent = self
                                        self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"

                                        self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths()
                                        self.use_multiple_paths.parent = self
                                        self._children_name_map["use_multiple_paths"] = "use-multiple-paths"
                                        self._segment_path = lambda: "afi-safi" + "[afi-safi-name='" + str(self.afi_safi_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi, ['afi_safi_name'], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters for the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                            AFI,SAFI
                                        
                                            **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                            This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Config, ['afi_safi_name', 'enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information relating to the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                            AFI,SAFI
                                        
                                            **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: enabled
                                        
                                            This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: active
                                        
                                            This value indicates whether a particular AFI\-SAFI has been succesfully negotiated with the peer. An AFI\-SAFI may be enabled in the current running configuration, but a session restart may be required in order to negotiate the new capability
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                        .. attribute:: prefixes
                                        
                                            Prefix counters for the BGP session
                                        
                                            **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes))])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ('active', (YLeaf(YType.boolean, 'active'), ['bool'])),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self.active = None

                                            self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes()
                                            self.prefixes.parent = self
                                            self._children_name_map["prefixes"] = "prefixes"
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State, ['afi_safi_name', 'enabled', 'active'], name, value)

                                        class Prefixes(_Entity_):
                                            """
                                            Prefix counters for the BGP session
                                            
                                            .. attribute:: received
                                            
                                                The number of prefixes received from the neighbor
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: sent
                                            
                                                The number of prefixes advertised to the neighbor
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: installed
                                            
                                                The number of advertised prefixes installed in the Loc\-RIB
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefixes"
                                                self.yang_parent_name = "state"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                    ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                    ('installed', (YLeaf(YType.uint32, 'installed'), ['int'])),
                                                ])
                                                self.received = None
                                                self.sent = None
                                                self.installed = None
                                                self._segment_path = lambda: "prefixes"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.State.Prefixes, ['received', 'sent', 'installed'], name, value)



                                    class GracefulRestart(_Entity_):
                                        """
                                        Parameters relating to BGP graceful\-restart
                                        
                                        .. attribute:: config
                                        
                                            Configuration options for BGP graceful\-restart
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for BGP graceful\-restart
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "graceful-restart"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "graceful-restart"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration options for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                                This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.Config, ['enabled'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                                This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: received
                                            
                                                This leaf indicates whether the neighbor advertised the ability to support graceful\-restart for this AFI\-SAFI
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                            .. attribute:: advertised
                                            
                                                This leaf indicates whether the ability to support graceful\-restart has been advertised to the peer
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ('received', (YLeaf(YType.boolean, 'received'), ['bool'])),
                                                    ('advertised', (YLeaf(YType.boolean, 'advertised'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self.received = None
                                                self.advertised = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.GracefulRestart.State, ['enabled', 'received', 'advertised'], name, value)



                                    class ApplyPolicy(_Entity_):
                                        """
                                        Anchor point for routing policies in the model.
                                        Import and export policies are with respect to the local
                                        routing table, i.e., export (send) and import (receive),
                                        depending on the context.
                                        
                                        .. attribute:: config
                                        
                                            Policy configuration data
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config>`
                                        
                                        .. attribute:: state
                                        
                                            Operational state for routing policy
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "apply-policy"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "apply-policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Policy configuration data.
                                            
                                            .. attribute:: import_policy
                                            
                                                list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_import_policy
                                            
                                                explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                                list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_export_policy
                                            
                                                explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                                    ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                    ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                                    ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                        class State(_Entity_):
                                            """
                                            Operational state for routing policy
                                            
                                            .. attribute:: import_policy
                                            
                                                list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: default_import_policy
                                            
                                                explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **config**: False
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                                list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: default_export_policy
                                            
                                                explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **config**: False
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                                    ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                    ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                                    ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)



                                    class Ipv4Unicast(_Entity_):
                                        """
                                        IPv4 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for common IPv4 and IPv6 unicast parameters
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "ipv4-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)



                                        class Config(_Entity_):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.Config, ['send_default_route'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4Unicast.State, ['send_default_route'], name, value)



                                    class Ipv6Unicast(_Entity_):
                                        """
                                        IPv6 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for common IPv4 and IPv6 unicast parameters
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "ipv6-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)



                                        class Config(_Entity_):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.Config, ['send_default_route'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6Unicast.State, ['send_default_route'], name, value)



                                    class Ipv4LabeledUnicast(_Entity_):
                                        """
                                        IPv4 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv4-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "ipv4-labeled-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class Ipv6LabeledUnicast(_Entity_):
                                        """
                                        IPv6 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv6-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "ipv6-labeled-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv4Unicast(_Entity_):
                                        """
                                        Unicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv4-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv6Unicast(_Entity_):
                                        """
                                        Unicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv6-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv4Multicast(_Entity_):
                                        """
                                        Multicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv4-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv4-multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv6Multicast(_Entity_):
                                        """
                                        Multicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv6-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv6-multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L2vpnVpls(_Entity_):
                                        """
                                        BGP\-signalled VPLS configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l2vpn-vpls"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l2vpn-vpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-vpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L2vpnEvpn(_Entity_):
                                        """
                                        BGP EVPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l2vpn-evpn"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l2vpn-evpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-evpn"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class UseMultiplePaths(_Entity_):
                                        """
                                        Parameters related to the use of multiple\-paths for the same
                                        NLRI when they are received only from this neighbor
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to multipath
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State parameters relating to multipath
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: ebgp
                                        
                                            Multipath configuration for eBGP
                                        
                                            **type**:  :py:class:`Ebgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "use-multiple-paths"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"

                                            self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp()
                                            self.ebgp.parent = self
                                            self._children_name_map["ebgp"] = "ebgp"
                                            self._segment_path = lambda: "use-multiple-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                                Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Config, ['enabled'], name, value)


                                        class State(_Entity_):
                                            """
                                            State parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                                Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.State, ['enabled'], name, value)


                                        class Ebgp(_Entity_):
                                            """
                                            Multipath configuration for eBGP
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to eBGP multipath
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to eBGP multipath
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "ebgp"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "ebgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                    Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                    Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, ['allow_multiple_as'], name, value)






                            class EnableBfd(_Entity_):
                                """
                                Enable BFD for liveliness detection to the next\-hop or
                                neighbour.
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to enabling BFD
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state parameters relating to enabing BFD
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-bfd'
                                _revision = '2018-11-21'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "enable-bfd"
                                    self.yang_parent_name = "neighbor"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "openconfig-bfd:enable-bfd"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to enabling BFD.
                                    
                                    .. attribute:: enabled
                                    
                                        When this leaf is set to true, BFD is used to detect the liveliness of the remote peer or next\-hop
                                    
                                        **type**: bool
                                    
                                    """
                                    _prefix = 'oc-bfd'
                                    _revision = '2018-11-21'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "enable-bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.Config, ['enabled'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state parameters relating to enabing BFD.
                                    
                                    .. attribute:: enabled
                                    
                                        When this leaf is set to true, BFD is used to detect the liveliness of the remote peer or next\-hop
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: associated_session
                                    
                                        A reference to the BFD session that is tracking the liveliness of the remote entity
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`local_discriminator<ydk.models.openconfig.openconfig_bfd.Bfd.Interfaces.Interface.Peers.Peer>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-bfd'
                                    _revision = '2018-11-21'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "enable-bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('associated_session', (YLeaf(YType.str, 'associated-session'), ['str'])),
                                        ])
                                        self.enabled = None
                                        self.associated_session = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.Neighbors.Neighbor.EnableBfd.State, ['enabled', 'associated_session'], name, value)





                    class PeerGroups(_Entity_):
                        """
                        Configuration for BGP peer\-groups
                        
                        .. attribute:: peer_group
                        
                            List of BGP peer\-groups configured on the local system \- uniquely identified by peer\-group name
                        
                            **type**: list of    :py:class:`PeerGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "peer-groups"
                            self.yang_parent_name = "bgp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-group", ("peer_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup))])
                            self._leafs = OrderedDict()

                            self.peer_group = YList(self)
                            self._segment_path = lambda: "peer-groups"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups, [], name, value)

                        class PeerGroup(_Entity_):
                            """
                            List of BGP peer\-groups configured on the local system \-
                            uniquely identified by peer\-group name
                            
                            .. attribute:: peer_group_name  (key)
                            
                                Reference to the name of the BGP peer\-group used as a key in the peer\-group list
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`peer_group_name<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config>`
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the BGP neighbor or group
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config>`
                            
                            .. attribute:: state
                            
                                State information relating to the BGP peer\-group
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State>`
                            
                                **config**: False
                            
                            .. attribute:: timers
                            
                                Timers related to a BGP peer\-group
                            
                                **type**:  :py:class:`Timers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers>`
                            
                            .. attribute:: transport
                            
                                Transport session parameters for the BGP peer\-group
                            
                                **type**:  :py:class:`Transport<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport>`
                            
                            .. attribute:: error_handling
                            
                                Error handling parameters used for the BGP peer\-group
                            
                                **type**:  :py:class:`ErrorHandling<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling>`
                            
                            .. attribute:: graceful_restart
                            
                                Parameters relating the graceful restart mechanism for BGP
                            
                                **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart>`
                            
                            .. attribute:: logging_options
                            
                                Logging options for events related to the BGP neighbor or group
                            
                                **type**:  :py:class:`LoggingOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions>`
                            
                            .. attribute:: ebgp_multihop
                            
                                eBGP multi\-hop parameters for the BGPgroup
                            
                                **type**:  :py:class:`EbgpMultihop<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop>`
                            
                            .. attribute:: route_reflector
                            
                                Route reflector parameters for the BGPgroup
                            
                                **type**:  :py:class:`RouteReflector<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector>`
                            
                            .. attribute:: as_path_options
                            
                                AS\_PATH manipulation parameters for the BGP neighbor or group
                            
                                **type**:  :py:class:`AsPathOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions>`
                            
                            .. attribute:: add_paths
                            
                                Parameters relating to the advertisement and receipt of multiple paths for a single NLRI (add\-paths)
                            
                                **type**:  :py:class:`AddPaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths>`
                            
                            .. attribute:: use_multiple_paths
                            
                                Parameters related to the use of multiple paths for the same NLRI
                            
                                **type**:  :py:class:`UseMultiplePaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths>`
                            
                            .. attribute:: apply_policy
                            
                                Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                            
                                **type**:  :py:class:`ApplyPolicy<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy>`
                            
                            .. attribute:: afi_safis
                            
                                Per\-address\-family configuration parameters associated with thegroup
                            
                                **type**:  :py:class:`AfiSafis<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis>`
                            
                            .. attribute:: enable_bfd
                            
                                Enable BFD for liveliness detection to the next\-hop or neighbour
                            
                                **type**:  :py:class:`EnableBfd<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "peer-group"
                                self.yang_parent_name = "peer-groups"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['peer_group_name']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers)), ("transport", ("transport", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport)), ("error-handling", ("error_handling", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart)), ("logging-options", ("logging_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions)), ("ebgp-multihop", ("ebgp_multihop", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop)), ("route-reflector", ("route_reflector", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector)), ("as-path-options", ("as_path_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions)), ("add-paths", ("add_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy)), ("afi-safis", ("afi_safis", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis)), ("openconfig-bfd:enable-bfd", ("enable_bfd", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd))])
                                self._leafs = OrderedDict([
                                    ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                ])
                                self.peer_group_name = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.transport = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport()
                                self.transport.parent = self
                                self._children_name_map["transport"] = "transport"

                                self.error_handling = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling()
                                self.error_handling.parent = self
                                self._children_name_map["error_handling"] = "error-handling"

                                self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart()
                                self.graceful_restart.parent = self
                                self._children_name_map["graceful_restart"] = "graceful-restart"

                                self.logging_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions()
                                self.logging_options.parent = self
                                self._children_name_map["logging_options"] = "logging-options"

                                self.ebgp_multihop = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop()
                                self.ebgp_multihop.parent = self
                                self._children_name_map["ebgp_multihop"] = "ebgp-multihop"

                                self.route_reflector = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector()
                                self.route_reflector.parent = self
                                self._children_name_map["route_reflector"] = "route-reflector"

                                self.as_path_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions()
                                self.as_path_options.parent = self
                                self._children_name_map["as_path_options"] = "as-path-options"

                                self.add_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths()
                                self.add_paths.parent = self
                                self._children_name_map["add_paths"] = "add-paths"

                                self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths()
                                self.use_multiple_paths.parent = self
                                self._children_name_map["use_multiple_paths"] = "use-multiple-paths"

                                self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy()
                                self.apply_policy.parent = self
                                self._children_name_map["apply_policy"] = "apply-policy"

                                self.afi_safis = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis()
                                self.afi_safis.parent = self
                                self._children_name_map["afi_safis"] = "afi-safis"

                                self.enable_bfd = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd()
                                self.enable_bfd.parent = self
                                self._children_name_map["enable_bfd"] = "openconfig-bfd:enable-bfd"
                                self._segment_path = lambda: "peer-group" + "[peer-group-name='" + str(self.peer_group_name) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup, ['peer_group_name'], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the BGP neighbor or
                                group
                                
                                .. attribute:: peer_group_name
                                
                                    Name of the BGP peer\-group
                                
                                    **type**: str
                                
                                .. attribute:: peer_as
                                
                                    AS number of the peer
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                .. attribute:: local_as
                                
                                    The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                .. attribute:: peer_type
                                
                                    Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                
                                    **type**:  :py:class:`PeerType<ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                .. attribute:: auth_password
                                
                                    Configures an MD5 authentication password for use with neighboring devices
                                
                                    **type**: str
                                
                                .. attribute:: remove_private_as
                                
                                    Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                
                                    **type**:  :py:class:`REMOVEPRIVATEASOPTION<ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                .. attribute:: route_flap_damping
                                
                                    Enable route flap damping
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: send_community
                                
                                    Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                
                                    **type**:  :py:class:`CommunityType<ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                    **default value**: NONE
                                
                                .. attribute:: description
                                
                                    An optional textual description (intended primarily for use with a peer or group
                                
                                    **type**: str
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                        ('peer_as', (YLeaf(YType.uint32, 'peer-as'), ['int'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('peer_type', (YLeaf(YType.enumeration, 'peer-type'), [('ydk.models.openconfig.openconfig_bgp_types', 'PeerType', '')])),
                                        ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                        ('remove_private_as', (YLeaf(YType.identityref, 'remove-private-as'), [('ydk.models.openconfig.openconfig_bgp_types', 'REMOVEPRIVATEASOPTION')])),
                                        ('route_flap_damping', (YLeaf(YType.boolean, 'route-flap-damping'), ['bool'])),
                                        ('send_community', (YLeaf(YType.enumeration, 'send-community'), [('ydk.models.openconfig.openconfig_bgp_types', 'CommunityType', '')])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                    ])
                                    self.peer_group_name = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Config, ['peer_group_name', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description'], name, value)


                            class State(_Entity_):
                                """
                                State information relating to the BGP peer\-group
                                
                                .. attribute:: peer_group_name
                                
                                    Name of the BGP peer\-group
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: peer_as
                                
                                    AS number of the peer
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: local_as
                                
                                    The local autonomous system number that is to be used when establishing sessions with the remote peer or peer group, if this differs from the global BGP router autonomous system number
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: peer_type
                                
                                    Explicitly designate the peer or peer group as internal (iBGP) or external (eBGP)
                                
                                    **type**:  :py:class:`PeerType<ydk.models.openconfig.openconfig_bgp_types.PeerType>`
                                
                                    **config**: False
                                
                                .. attribute:: auth_password
                                
                                    Configures an MD5 authentication password for use with neighboring devices
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: remove_private_as
                                
                                    Remove private AS numbers from updates sent to peers \- when this leaf is not specified, the AS\_PATH attribute should be sent to the peer unchanged
                                
                                    **type**:  :py:class:`REMOVEPRIVATEASOPTION<ydk.models.openconfig.openconfig_bgp_types.REMOVEPRIVATEASOPTION>`
                                
                                    **config**: False
                                
                                .. attribute:: route_flap_damping
                                
                                    Enable route flap damping
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: send_community
                                
                                    Specify which types of community should be sent to the neighbor or group. The default is to not send the community attribute
                                
                                    **type**:  :py:class:`CommunityType<ydk.models.openconfig.openconfig_bgp_types.CommunityType>`
                                
                                    **config**: False
                                
                                    **default value**: NONE
                                
                                .. attribute:: description
                                
                                    An optional textual description (intended primarily for use with a peer or group
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: total_paths
                                
                                    Total number of BGP paths within the context
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                .. attribute:: total_prefixes
                                
                                    Total number of BGP prefixes received within the context
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('peer_group_name', (YLeaf(YType.str, 'peer-group-name'), ['str'])),
                                        ('peer_as', (YLeaf(YType.uint32, 'peer-as'), ['int'])),
                                        ('local_as', (YLeaf(YType.uint32, 'local-as'), ['int'])),
                                        ('peer_type', (YLeaf(YType.enumeration, 'peer-type'), [('ydk.models.openconfig.openconfig_bgp_types', 'PeerType', '')])),
                                        ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                        ('remove_private_as', (YLeaf(YType.identityref, 'remove-private-as'), [('ydk.models.openconfig.openconfig_bgp_types', 'REMOVEPRIVATEASOPTION')])),
                                        ('route_flap_damping', (YLeaf(YType.boolean, 'route-flap-damping'), ['bool'])),
                                        ('send_community', (YLeaf(YType.enumeration, 'send-community'), [('ydk.models.openconfig.openconfig_bgp_types', 'CommunityType', '')])),
                                        ('description', (YLeaf(YType.str, 'description'), ['str'])),
                                        ('total_paths', (YLeaf(YType.uint32, 'total-paths'), ['int'])),
                                        ('total_prefixes', (YLeaf(YType.uint32, 'total-prefixes'), ['int'])),
                                    ])
                                    self.peer_group_name = None
                                    self.peer_as = None
                                    self.local_as = None
                                    self.peer_type = None
                                    self.auth_password = None
                                    self.remove_private_as = None
                                    self.route_flap_damping = None
                                    self.send_community = None
                                    self.description = None
                                    self.total_paths = None
                                    self.total_prefixes = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.State, ['peer_group_name', 'peer_as', 'local_as', 'peer_type', 'auth_password', 'remove_private_as', 'route_flap_damping', 'send_community', 'description', 'total_paths', 'total_prefixes'], name, value)


                            class Timers(_Entity_):
                                """
                                Timers related to a BGP peer\-group
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to timers used for the BGP neighbor or peer group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the timers used for the BGP group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to timers used for the
                                    BGP neighbor or peer group
                                    
                                    .. attribute:: connect_retry
                                    
                                        Time interval in seconds between attempts to establish a session with the peer
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: hold_time
                                    
                                        Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                        Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                        Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **default value**: 30
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', (YLeaf(YType.str, 'connect-retry'), ['Decimal64'])),
                                            ('hold_time', (YLeaf(YType.str, 'hold-time'), ['Decimal64'])),
                                            ('keepalive_interval', (YLeaf(YType.str, 'keepalive-interval'), ['Decimal64'])),
                                            ('minimum_advertisement_interval', (YLeaf(YType.str, 'minimum-advertisement-interval'), ['Decimal64'])),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.Config, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the timers used for the BGP
                                    group
                                    
                                    .. attribute:: connect_retry
                                    
                                        Time interval in seconds between attempts to establish a session with the peer
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: hold_time
                                    
                                        Time interval in seconds that a BGP session will be considered active in the absence of keepalive or other messages from the peer.  The hold\-time is typically set to 3x the keepalive\-interval
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 90
                                    
                                    .. attribute:: keepalive_interval
                                    
                                        Time interval in seconds between transmission of keepalive messages to the neighbor.  Typically set to 1/3 the hold\-time
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 30
                                    
                                    .. attribute:: minimum_advertisement_interval
                                    
                                        Minimum time which must elapse between subsequent UPDATE messages relating to a common set of NLRI being transmitted to a peer. This timer is referred to as MinRouteAdvertisementIntervalTimer by RFC 4721 and serves to reduce the number of UPDATE messages transmitted when a particular set of NLRI exhibit instability
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                        **default value**: 30
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('connect_retry', (YLeaf(YType.str, 'connect-retry'), ['Decimal64'])),
                                            ('hold_time', (YLeaf(YType.str, 'hold-time'), ['Decimal64'])),
                                            ('keepalive_interval', (YLeaf(YType.str, 'keepalive-interval'), ['Decimal64'])),
                                            ('minimum_advertisement_interval', (YLeaf(YType.str, 'minimum-advertisement-interval'), ['Decimal64'])),
                                        ])
                                        self.connect_retry = None
                                        self.hold_time = None
                                        self.keepalive_interval = None
                                        self.minimum_advertisement_interval = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Timers.State, ['connect_retry', 'hold_time', 'keepalive_interval', 'minimum_advertisement_interval'], name, value)



                            class Transport(_Entity_):
                                """
                                Transport session parameters for the BGP peer\-group
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the transport session(s) used for the BGP neighbor or group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the transport session(s) used for the BGP neighbor or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "transport"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "transport"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the transport
                                    session(s) used for the BGP neighbor or group
                                    
                                    .. attribute:: tcp_mss
                                    
                                        Sets the max segment size for BGP TCP sessions
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                    .. attribute:: mtu_discovery
                                    
                                        Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: passive_mode
                                    
                                        Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: local_address
                                    
                                        Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    
                                        **type**: union of the below types:
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                            **type**: str
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', (YLeaf(YType.uint16, 'tcp-mss'), ['int'])),
                                            ('mtu_discovery', (YLeaf(YType.boolean, 'mtu-discovery'), ['bool'])),
                                            ('passive_mode', (YLeaf(YType.boolean, 'passive-mode'), ['bool'])),
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str','str'])),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.Config, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the transport session(s)
                                    used for the BGP neighbor or group
                                    
                                    .. attribute:: tcp_mss
                                    
                                        Sets the max segment size for BGP TCP sessions
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                    .. attribute:: mtu_discovery
                                    
                                        Turns path mtu discovery for BGP TCP sessions on (true) or off (false)
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: passive_mode
                                    
                                        Wait for peers to issue requests to open a BGP session, rather than initiating sessions from the local router
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: local_address
                                    
                                        Set the local IP (either IPv4 or IPv6) address to use for the session when sending BGP update messages.  This may be expressed as either an IP address or reference to the name of an interface
                                    
                                        **type**: union of the below types:
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                                **type**: str
                                    
                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                    
                                            **type**: str
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "transport"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('tcp_mss', (YLeaf(YType.uint16, 'tcp-mss'), ['int'])),
                                            ('mtu_discovery', (YLeaf(YType.boolean, 'mtu-discovery'), ['bool'])),
                                            ('passive_mode', (YLeaf(YType.boolean, 'passive-mode'), ['bool'])),
                                            ('local_address', (YLeaf(YType.str, 'local-address'), ['str','str','str'])),
                                        ])
                                        self.tcp_mss = None
                                        self.mtu_discovery = None
                                        self.passive_mode = None
                                        self.local_address = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.Transport.State, ['tcp_mss', 'mtu_discovery', 'passive_mode', 'local_address'], name, value)



                            class ErrorHandling(_Entity_):
                                """
                                Error handling parameters used for the BGP peer\-group
                                
                                .. attribute:: config
                                
                                    Configuration parameters enabling or modifying the behavior or enhanced error handling mechanisms for the BGP group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to enhanced error handling mechanisms for the BGP group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "error-handling"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "error-handling"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters enabling or modifying the
                                    behavior or enhanced error handling mechanisms for the BGP
                                    group
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                        Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', (YLeaf(YType.boolean, 'treat-as-withdraw'), ['bool'])),
                                        ])
                                        self.treat_as_withdraw = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.Config, ['treat_as_withdraw'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to enhanced error handling
                                    mechanisms for the BGP group
                                    
                                    .. attribute:: treat_as_withdraw
                                    
                                        Specify whether erroneous UPDATE messages for which the NLRI can be extracted are reated as though the NLRI is withdrawn \- avoiding session reset
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "error-handling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('treat_as_withdraw', (YLeaf(YType.boolean, 'treat-as-withdraw'), ['bool'])),
                                        ])
                                        self.treat_as_withdraw = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ErrorHandling.State, ['treat_as_withdraw'], name, value)



                            class GracefulRestart(_Entity_):
                                """
                                Parameters relating the graceful restart mechanism for BGP
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to graceful\-restart
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config>`
                                
                                .. attribute:: state
                                
                                    State information associated with graceful\-restart
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "graceful-restart"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "graceful-restart"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                        Enable or disable the graceful\-restart capability
                                    
                                        **type**: bool
                                    
                                    .. attribute:: restart_time
                                    
                                        Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    
                                        **type**: int
                                    
                                            **range:** 0..4096
                                    
                                    .. attribute:: stale_routes_time
                                    
                                        An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                    .. attribute:: helper_only
                                    
                                        Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    
                                        **type**: bool
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                                            ('stale_routes_time', (YLeaf(YType.str, 'stale-routes-time'), ['Decimal64'])),
                                            ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.Config, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)


                                class State(_Entity_):
                                    """
                                    State information associated with graceful\-restart
                                    
                                    .. attribute:: enabled
                                    
                                        Enable or disable the graceful\-restart capability
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: restart_time
                                    
                                        Estimated time (in seconds) for the local BGP speaker to restart a session. This value is advertise in the graceful restart BGP capability.  This is a 12\-bit value, referred to as Restart Time in RFC4724.  Per RFC4724, the suggested default value is <= the hold\-time value
                                    
                                        **type**: int
                                    
                                            **range:** 0..4096
                                    
                                        **config**: False
                                    
                                    .. attribute:: stale_routes_time
                                    
                                        An upper\-bound on the time thate stale routes will be retained by a router after a session is restarted. If an End\-of\-RIB (EOR) marker is received prior to this timer expiring stale\-routes will be flushed upon its receipt \- if no EOR is received, then when this timer expires stale paths will be purged. This timer is referred to as the Selection\_Deferral\_Timer in RFC4724
                                    
                                        **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                    
                                            **range:** \-92233720368547758.08..92233720368547758.07
                                    
                                        **config**: False
                                    
                                    .. attribute:: helper_only
                                    
                                        Enable graceful\-restart in helper mode only. When this leaf is set, the local system does not retain forwarding its own state during a restart, but supports procedures for the receiving speaker, as defined in RFC4724
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "graceful-restart"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('restart_time', (YLeaf(YType.uint16, 'restart-time'), ['int'])),
                                            ('stale_routes_time', (YLeaf(YType.str, 'stale-routes-time'), ['Decimal64'])),
                                            ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self.restart_time = None
                                        self.stale_routes_time = None
                                        self.helper_only = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.GracefulRestart.State, ['enabled', 'restart_time', 'stale_routes_time', 'helper_only'], name, value)



                            class LoggingOptions(_Entity_):
                                """
                                Logging options for events related to the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                    Configuration parameters enabling or modifying logging for events relating to the BGPgroup
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to logging for the BGP neighbor or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "logging-options"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "logging-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters enabling or modifying logging
                                    for events relating to the BGPgroup
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                        Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    
                                        **type**: bool
                                    
                                        **default value**: true
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', (YLeaf(YType.boolean, 'log-neighbor-state-changes'), ['bool'])),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.Config, ['log_neighbor_state_changes'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to logging for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: log_neighbor_state_changes
                                    
                                        Configure logging of peer state changes.  Default is to enable logging of peer state changes
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: true
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "logging-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('log_neighbor_state_changes', (YLeaf(YType.boolean, 'log-neighbor-state-changes'), ['bool'])),
                                        ])
                                        self.log_neighbor_state_changes = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.LoggingOptions.State, ['log_neighbor_state_changes'], name, value)



                            class EbgpMultihop(_Entity_):
                                """
                                eBGP multi\-hop parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to eBGP multihop for the BGP group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config>`
                                
                                .. attribute:: state
                                
                                    State information for eBGP multihop, for the BGP neighbor or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "ebgp-multihop"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "ebgp-multihop"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to eBGP multihop for the
                                    BGP group
                                    
                                    .. attribute:: enabled
                                    
                                        When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                        Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('multihop_ttl', (YLeaf(YType.uint8, 'multihop-ttl'), ['int'])),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.Config, ['enabled', 'multihop_ttl'], name, value)


                                class State(_Entity_):
                                    """
                                    State information for eBGP multihop, for the BGP neighbor
                                    or group
                                    
                                    .. attribute:: enabled
                                    
                                        When enabled the referenced group or neighbors are permitted to be indirectly connected \- including cases where the TTL can be decremented between the BGP peers
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: multihop_ttl
                                    
                                        Time\-to\-live value to use when packets are sent to the referenced group or neighbors and ebgp\-multihop is enabled
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "ebgp-multihop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('multihop_ttl', (YLeaf(YType.uint8, 'multihop-ttl'), ['int'])),
                                        ])
                                        self.enabled = None
                                        self.multihop_ttl = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EbgpMultihop.State, ['enabled', 'multihop_ttl'], name, value)



                            class RouteReflector(_Entity_):
                                """
                                Route reflector parameters for the BGPgroup
                                
                                .. attribute:: config
                                
                                    Configuraton parameters relating to route reflection for the BGPgroup
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to route reflection for the BGPgroup
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "route-reflector"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "route-reflector"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuraton parameters relating to route reflection
                                    for the BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                        route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: int
                                    
                                                **range:** 0..4294967295
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                    .. attribute:: route_reflector_client
                                    
                                        Configure the neighbor as a route reflector client
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', (YLeaf(YType.str, 'route-reflector-cluster-id'), ['int','str'])),
                                            ('route_reflector_client', (YLeaf(YType.boolean, 'route-reflector-client'), ['bool'])),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.Config, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to route reflection for the
                                    BGPgroup
                                    
                                    .. attribute:: route_reflector_cluster_id
                                    
                                        route\-reflector cluster id to use when local router is configured as a route reflector.  Commonly set at the group level, but allows a different cluster id to be set for each neighbor
                                    
                                        **type**: union of the below types:
                                    
                                            **type**: int
                                    
                                                **range:** 0..4294967295
                                    
                                            **type**: str
                                    
                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                    
                                        **config**: False
                                    
                                    .. attribute:: route_reflector_client
                                    
                                        Configure the neighbor as a route reflector client
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "route-reflector"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('route_reflector_cluster_id', (YLeaf(YType.str, 'route-reflector-cluster-id'), ['int','str'])),
                                            ('route_reflector_client', (YLeaf(YType.boolean, 'route-reflector-client'), ['bool'])),
                                        ])
                                        self.route_reflector_cluster_id = None
                                        self.route_reflector_client = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.RouteReflector.State, ['route_reflector_cluster_id', 'route_reflector_client'], name, value)



                            class AsPathOptions(_Entity_):
                                """
                                AS\_PATH manipulation parameters for the BGP neighbor or
                                group
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to AS\_PATH manipulation for the BGP peer or group
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config>`
                                
                                .. attribute:: state
                                
                                    State information relating to the AS\_PATH manipulation mechanisms for the BGP peer or group
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "as-path-options"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "as-path-options"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to AS\_PATH manipulation
                                    for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                        Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **default value**: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                        Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', (YLeaf(YType.uint8, 'allow-own-as'), ['int'])),
                                            ('replace_peer_as', (YLeaf(YType.boolean, 'replace-peer-as'), ['bool'])),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.Config, ['allow_own_as', 'replace_peer_as'], name, value)


                                class State(_Entity_):
                                    """
                                    State information relating to the AS\_PATH manipulation
                                    mechanisms for the BGP peer or group
                                    
                                    .. attribute:: allow_own_as
                                    
                                        Specify the number of occurrences of the local BGP speaker's AS that can occur within the AS\_PATH before it is rejected
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **config**: False
                                    
                                        **default value**: 0
                                    
                                    .. attribute:: replace_peer_as
                                    
                                        Replace occurrences of the peer's AS in the AS\_PATH with the local autonomous system number
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "as-path-options"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('allow_own_as', (YLeaf(YType.uint8, 'allow-own-as'), ['int'])),
                                            ('replace_peer_as', (YLeaf(YType.boolean, 'replace-peer-as'), ['bool'])),
                                        ])
                                        self.allow_own_as = None
                                        self.replace_peer_as = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AsPathOptions.State, ['allow_own_as', 'replace_peer_as'], name, value)



                            class AddPaths(_Entity_):
                                """
                                Parameters relating to the advertisement and receipt of
                                multiple paths for a single NLRI (add\-paths)
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to ADD\_PATHS
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config>`
                                
                                .. attribute:: state
                                
                                    State information associated with ADD\_PATHS
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "add-paths"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "add-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                        Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: send_max
                                    
                                        The maximum number of paths to advertise to neighbors for a single NLRI
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                        A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                                            ('send_max', (YLeaf(YType.uint8, 'send-max'), ['int'])),
                                            ('eligible_prefix_policy', (YLeaf(YType.str, 'eligible-prefix-policy'), ['str'])),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.Config, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)


                                class State(_Entity_):
                                    """
                                    State information associated with ADD\_PATHS
                                    
                                    .. attribute:: receive
                                    
                                        Enable ability to receive multiple path advertisements for an NLRI from the neighbor or group
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: send_max
                                    
                                        The maximum number of paths to advertise to neighbors for a single NLRI
                                    
                                        **type**: int
                                    
                                            **range:** 0..255
                                    
                                        **config**: False
                                    
                                    .. attribute:: eligible_prefix_policy
                                    
                                        A reference to a routing policy which can be used to restrict the prefixes for which add\-paths is enabled
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "add-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('receive', (YLeaf(YType.boolean, 'receive'), ['bool'])),
                                            ('send_max', (YLeaf(YType.uint8, 'send-max'), ['int'])),
                                            ('eligible_prefix_policy', (YLeaf(YType.str, 'eligible-prefix-policy'), ['str'])),
                                        ])
                                        self.receive = None
                                        self.send_max = None
                                        self.eligible_prefix_policy = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AddPaths.State, ['receive', 'send_max', 'eligible_prefix_policy'], name, value)



                            class UseMultiplePaths(_Entity_):
                                """
                                Parameters related to the use of multiple paths for the
                                same NLRI
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to multipath
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config>`
                                
                                .. attribute:: state
                                
                                    State parameters relating to multipath
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State>`
                                
                                    **config**: False
                                
                                .. attribute:: ebgp
                                
                                    Multipath parameters for eBGP
                                
                                    **type**:  :py:class:`Ebgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp>`
                                
                                .. attribute:: ibgp
                                
                                    Multipath parameters for iBGP
                                
                                    **type**:  :py:class:`Ibgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "use-multiple-paths"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp()
                                    self.ebgp.parent = self
                                    self._children_name_map["ebgp"] = "ebgp"

                                    self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp()
                                    self.ibgp.parent = self
                                    self._children_name_map["ibgp"] = "ibgp"
                                    self._segment_path = lambda: "use-multiple-paths"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                        Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Config, ['enabled'], name, value)


                                class State(_Entity_):
                                    """
                                    State parameters relating to multipath
                                    
                                    .. attribute:: enabled
                                    
                                        Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.State, ['enabled'], name, value)


                                class Ebgp(_Entity_):
                                    """
                                    Multipath parameters for eBGP
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to eBGP multipath
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information relating to eBGP multipath
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ebgp"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "ebgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                            Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: maximum_paths
                                        
                                            Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **default value**: 1
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                            ])
                                            self.allow_multiple_as = None
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information relating to eBGP multipath
                                        
                                        .. attribute:: allow_multiple_as
                                        
                                            Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: maximum_paths
                                        
                                            Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **config**: False
                                        
                                            **default value**: 1
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ebgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                            ])
                                            self.allow_multiple_as = None
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)



                                class Ibgp(_Entity_):
                                    """
                                    Multipath parameters for iBGP
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters relating to iBGP multipath
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information relating to iBGP multipath
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "ibgp"
                                        self.yang_parent_name = "use-multiple-paths"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "ibgp"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters relating to iBGP multipath
                                        
                                        .. attribute:: maximum_paths
                                        
                                            Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **default value**: 1
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "ibgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                            ])
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information relating to iBGP multipath
                                        
                                        .. attribute:: maximum_paths
                                        
                                            Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **config**: False
                                        
                                            **default value**: 1
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "ibgp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                            ])
                                            self.maximum_paths = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)




                            class ApplyPolicy(_Entity_):
                                """
                                Anchor point for routing policies in the model.
                                Import and export policies are with respect to the local
                                routing table, i.e., export (send) and import (receive),
                                depending on the context.
                                
                                .. attribute:: config
                                
                                    Policy configuration data
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for routing policy
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "apply-policy"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "apply-policy"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Policy configuration data.
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                        list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_export_policy
                                    
                                        explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                            ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                            ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for routing policy
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **config**: False
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    .. attribute:: export_policy
                                    
                                        list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: default_export_policy
                                    
                                        explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **config**: False
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "apply-policy"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                            ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                            ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self.export_policy = []
                                        self.default_export_policy = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)



                            class AfiSafis(_Entity_):
                                """
                                Per\-address\-family configuration parameters associated with
                                thegroup
                                
                                .. attribute:: afi_safi
                                
                                    AFI,SAFI configuration available for the neighbour or group
                                
                                    **type**: list of    :py:class:`AfiSafi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "afi-safis"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi))])
                                    self._leafs = OrderedDict()

                                    self.afi_safi = YList(self)
                                    self._segment_path = lambda: "afi-safis"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis, [], name, value)

                                class AfiSafi(_Entity_):
                                    """
                                    AFI,SAFI configuration available for the
                                    neighbour or group
                                    
                                    .. attribute:: afi_safi_name  (key)
                                    
                                        Reference to the AFI\-SAFI name used as a key for the AFI\-SAFI list
                                    
                                        **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                    
                                    .. attribute:: config
                                    
                                        Configuration parameters for the AFI\-SAFI
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config>`
                                    
                                    .. attribute:: state
                                    
                                        State information relating to the AFI\-SAFI
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: graceful_restart
                                    
                                        Parameters relating to BGP graceful\-restart
                                    
                                        **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart>`
                                    
                                    .. attribute:: route_selection_options
                                    
                                        Parameters relating to options for route selection
                                    
                                        **type**:  :py:class:`RouteSelectionOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions>`
                                    
                                    .. attribute:: use_multiple_paths
                                    
                                        Parameters related to the use of multiple paths for the same NLRI
                                    
                                        **type**:  :py:class:`UseMultiplePaths<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths>`
                                    
                                    .. attribute:: apply_policy
                                    
                                        Anchor point for routing policies in the model. Import and export policies are with respect to the local routing table, i.e., export (send) and import (receive), depending on the context
                                    
                                        **type**:  :py:class:`ApplyPolicy<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy>`
                                    
                                    .. attribute:: ipv4_unicast
                                    
                                        IPv4 unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast>`
                                    
                                    .. attribute:: ipv6_unicast
                                    
                                        IPv6 unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast>`
                                    
                                    .. attribute:: ipv4_labeled_unicast
                                    
                                        IPv4 Labeled Unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv4LabeledUnicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast>`
                                    
                                    .. attribute:: ipv6_labeled_unicast
                                    
                                        IPv6 Labeled Unicast configuration options
                                    
                                        **type**:  :py:class:`Ipv6LabeledUnicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_unicast
                                    
                                        Unicast IPv4 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv4Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_unicast
                                    
                                        Unicast IPv6 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv6Unicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast>`
                                    
                                    .. attribute:: l3vpn_ipv4_multicast
                                    
                                        Multicast IPv4 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv4Multicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast>`
                                    
                                    .. attribute:: l3vpn_ipv6_multicast
                                    
                                        Multicast IPv6 L3VPN configuration options
                                    
                                        **type**:  :py:class:`L3vpnIpv6Multicast<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast>`
                                    
                                    .. attribute:: l2vpn_vpls
                                    
                                        BGP\-signalled VPLS configuration options
                                    
                                        **type**:  :py:class:`L2vpnVpls<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls>`
                                    
                                    .. attribute:: l2vpn_evpn
                                    
                                        BGP EVPN configuration options
                                    
                                        **type**:  :py:class:`L2vpnEvpn<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "afi-safi"
                                        self.yang_parent_name = "afi-safis"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['afi_safi_name']
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart)), ("route-selection-options", ("route_selection_options", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions)), ("use-multiple-paths", ("use_multiple_paths", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths)), ("apply-policy", ("apply_policy", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy)), ("ipv4-unicast", ("ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast)), ("ipv6-unicast", ("ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast)), ("ipv4-labeled-unicast", ("ipv4_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast)), ("ipv6-labeled-unicast", ("ipv6_labeled_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast)), ("l3vpn-ipv4-unicast", ("l3vpn_ipv4_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast)), ("l3vpn-ipv6-unicast", ("l3vpn_ipv6_unicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast)), ("l3vpn-ipv4-multicast", ("l3vpn_ipv4_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast)), ("l3vpn-ipv6-multicast", ("l3vpn_ipv6_multicast", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast)), ("l2vpn-vpls", ("l2vpn_vpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls)), ("l2vpn-evpn", ("l2vpn_evpn", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn))])
                                        self._leafs = OrderedDict([
                                            ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                        ])
                                        self.afi_safi_name = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart()
                                        self.graceful_restart.parent = self
                                        self._children_name_map["graceful_restart"] = "graceful-restart"

                                        self.route_selection_options = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions()
                                        self.route_selection_options.parent = self
                                        self._children_name_map["route_selection_options"] = "route-selection-options"

                                        self.use_multiple_paths = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths()
                                        self.use_multiple_paths.parent = self
                                        self._children_name_map["use_multiple_paths"] = "use-multiple-paths"

                                        self.apply_policy = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy()
                                        self.apply_policy.parent = self
                                        self._children_name_map["apply_policy"] = "apply-policy"

                                        self.ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast()
                                        self.ipv4_unicast.parent = self
                                        self._children_name_map["ipv4_unicast"] = "ipv4-unicast"

                                        self.ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast()
                                        self.ipv6_unicast.parent = self
                                        self._children_name_map["ipv6_unicast"] = "ipv6-unicast"

                                        self.ipv4_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast()
                                        self.ipv4_labeled_unicast.parent = self
                                        self._children_name_map["ipv4_labeled_unicast"] = "ipv4-labeled-unicast"

                                        self.ipv6_labeled_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast()
                                        self.ipv6_labeled_unicast.parent = self
                                        self._children_name_map["ipv6_labeled_unicast"] = "ipv6-labeled-unicast"

                                        self.l3vpn_ipv4_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast()
                                        self.l3vpn_ipv4_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_unicast"] = "l3vpn-ipv4-unicast"

                                        self.l3vpn_ipv6_unicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast()
                                        self.l3vpn_ipv6_unicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_unicast"] = "l3vpn-ipv6-unicast"

                                        self.l3vpn_ipv4_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast()
                                        self.l3vpn_ipv4_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv4_multicast"] = "l3vpn-ipv4-multicast"

                                        self.l3vpn_ipv6_multicast = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast()
                                        self.l3vpn_ipv6_multicast.parent = self
                                        self._children_name_map["l3vpn_ipv6_multicast"] = "l3vpn-ipv6-multicast"

                                        self.l2vpn_vpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls()
                                        self.l2vpn_vpls.parent = self
                                        self._children_name_map["l2vpn_vpls"] = "l2vpn-vpls"

                                        self.l2vpn_evpn = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn()
                                        self.l2vpn_evpn.parent = self
                                        self._children_name_map["l2vpn_evpn"] = "l2vpn-evpn"
                                        self._segment_path = lambda: "afi-safi" + "[afi-safi-name='" + str(self.afi_safi_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi, ['afi_safi_name'], name, value)

                                    class Config(_Entity_):
                                        """
                                        Configuration parameters for the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                            AFI,SAFI
                                        
                                            **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                            This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Config, ['afi_safi_name', 'enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        State information relating to the AFI\-SAFI
                                        
                                        .. attribute:: afi_safi_name
                                        
                                            AFI,SAFI
                                        
                                            **type**:  :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_bgp_types.AFISAFITYPE>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: enabled
                                        
                                            This leaf indicates whether the IPv4 Unicast AFI,SAFI is enabled for the neighbour or group
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_safi_name', (YLeaf(YType.identityref, 'afi-safi-name'), [('ydk.models.openconfig.openconfig_bgp_types', 'AFISAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.State, ['afi_safi_name', 'enabled'], name, value)


                                    class GracefulRestart(_Entity_):
                                        """
                                        Parameters relating to BGP graceful\-restart
                                        
                                        .. attribute:: config
                                        
                                            Configuration options for BGP graceful\-restart
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for BGP graceful\-restart
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "graceful-restart"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "graceful-restart"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration options for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                                This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.Config, ['enabled'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for BGP graceful\-restart
                                            
                                            .. attribute:: enabled
                                            
                                                This leaf indicates whether graceful\-restart is enabled for this AFI\-SAFI
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "graceful-restart"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.GracefulRestart.State, ['enabled'], name, value)



                                    class RouteSelectionOptions(_Entity_):
                                        """
                                        Parameters relating to options for route selection
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to route selection options
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for the route selection options
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "route-selection-options"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "route-selection-options"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to route selection
                                            options
                                            
                                            .. attribute:: always_compare_med
                                            
                                                Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: ignore_as_path_length
                                            
                                                Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: external_compare_router_id
                                            
                                                When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                            
                                                **type**: bool
                                            
                                                **default value**: true
                                            
                                            .. attribute:: advertise_inactive_routes
                                            
                                                Advertise inactive routes to external peers.  The default is to only advertise active routes
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: enable_aigp
                                            
                                                Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            .. attribute:: ignore_next_hop_igp_metric
                                            
                                                Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "route-selection-options"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always_compare_med', (YLeaf(YType.boolean, 'always-compare-med'), ['bool'])),
                                                    ('ignore_as_path_length', (YLeaf(YType.boolean, 'ignore-as-path-length'), ['bool'])),
                                                    ('external_compare_router_id', (YLeaf(YType.boolean, 'external-compare-router-id'), ['bool'])),
                                                    ('advertise_inactive_routes', (YLeaf(YType.boolean, 'advertise-inactive-routes'), ['bool'])),
                                                    ('enable_aigp', (YLeaf(YType.boolean, 'enable-aigp'), ['bool'])),
                                                    ('ignore_next_hop_igp_metric', (YLeaf(YType.boolean, 'ignore-next-hop-igp-metric'), ['bool'])),
                                                ])
                                                self.always_compare_med = None
                                                self.ignore_as_path_length = None
                                                self.external_compare_router_id = None
                                                self.advertise_inactive_routes = None
                                                self.enable_aigp = None
                                                self.ignore_next_hop_igp_metric = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.Config, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for the route selection options
                                            
                                            .. attribute:: always_compare_med
                                            
                                                Compare multi\-exit discriminator (MED) value from different ASes when selecting the best route.  The default behavior is to only compare MEDs for paths received from the same AS
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: ignore_as_path_length
                                            
                                                Ignore the AS path length when selecting the best path. The default is to use the AS path length and prefer paths with shorter length
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: external_compare_router_id
                                            
                                                When comparing similar routes received from external BGP peers, use the router\-id as a criterion to select the active path
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: true
                                            
                                            .. attribute:: advertise_inactive_routes
                                            
                                                Advertise inactive routes to external peers.  The default is to only advertise active routes
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: enable_aigp
                                            
                                                Flag to enable sending / receiving accumulated IGP attribute in routing updates
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            .. attribute:: ignore_next_hop_igp_metric
                                            
                                                Ignore the IGP metric to the next\-hop when calculating BGP best\-path. The default is to select the route for which the metric to the next\-hop is lowest
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "route-selection-options"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('always_compare_med', (YLeaf(YType.boolean, 'always-compare-med'), ['bool'])),
                                                    ('ignore_as_path_length', (YLeaf(YType.boolean, 'ignore-as-path-length'), ['bool'])),
                                                    ('external_compare_router_id', (YLeaf(YType.boolean, 'external-compare-router-id'), ['bool'])),
                                                    ('advertise_inactive_routes', (YLeaf(YType.boolean, 'advertise-inactive-routes'), ['bool'])),
                                                    ('enable_aigp', (YLeaf(YType.boolean, 'enable-aigp'), ['bool'])),
                                                    ('ignore_next_hop_igp_metric', (YLeaf(YType.boolean, 'ignore-next-hop-igp-metric'), ['bool'])),
                                                ])
                                                self.always_compare_med = None
                                                self.ignore_as_path_length = None
                                                self.external_compare_router_id = None
                                                self.advertise_inactive_routes = None
                                                self.enable_aigp = None
                                                self.ignore_next_hop_igp_metric = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.RouteSelectionOptions.State, ['always_compare_med', 'ignore_as_path_length', 'external_compare_router_id', 'advertise_inactive_routes', 'enable_aigp', 'ignore_next_hop_igp_metric'], name, value)



                                    class UseMultiplePaths(_Entity_):
                                        """
                                        Parameters related to the use of multiple paths for the
                                        same NLRI
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters relating to multipath
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State parameters relating to multipath
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: ebgp
                                        
                                            Multipath parameters for eBGP
                                        
                                            **type**:  :py:class:`Ebgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp>`
                                        
                                        .. attribute:: ibgp
                                        
                                            Multipath parameters for iBGP
                                        
                                            **type**:  :py:class:`Ibgp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "use-multiple-paths"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State)), ("ebgp", ("ebgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp)), ("ibgp", ("ibgp", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"

                                            self.ebgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp()
                                            self.ebgp.parent = self
                                            self._children_name_map["ebgp"] = "ebgp"

                                            self.ibgp = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp()
                                            self.ibgp.parent = self
                                            self._children_name_map["ibgp"] = "ibgp"
                                            self._segment_path = lambda: "use-multiple-paths"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Configuration parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                                Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Config, ['enabled'], name, value)


                                        class State(_Entity_):
                                            """
                                            State parameters relating to multipath
                                            
                                            .. attribute:: enabled
                                            
                                                Whether the use of multiple paths for the same NLRI is enabled for the neighbor. This value is overridden by any more specific configuration value
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                ])
                                                self.enabled = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.State, ['enabled'], name, value)


                                        class Ebgp(_Entity_):
                                            """
                                            Multipath parameters for eBGP
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to eBGP multipath
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to eBGP multipath
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "ebgp"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "ebgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                    Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: maximum_paths
                                                
                                                    Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **default value**: 1
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                        ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.Config, ['allow_multiple_as', 'maximum_paths'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to eBGP multipath
                                                
                                                .. attribute:: allow_multiple_as
                                                
                                                    Allow multipath to use paths from different neighbouring ASes.  The default is to only consider multiple paths from the same neighbouring AS
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: maximum_paths
                                                
                                                    Maximum number of parallel paths to consider when using BGP multipath. The default is use a single path
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                    **default value**: 1
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ebgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('allow_multiple_as', (YLeaf(YType.boolean, 'allow-multiple-as'), ['bool'])),
                                                        ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                    ])
                                                    self.allow_multiple_as = None
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ebgp.State, ['allow_multiple_as', 'maximum_paths'], name, value)



                                        class Ibgp(_Entity_):
                                            """
                                            Multipath parameters for iBGP
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to iBGP multipath
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to iBGP multipath
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "ibgp"
                                                self.yang_parent_name = "use-multiple-paths"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "ibgp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to iBGP multipath
                                                
                                                .. attribute:: maximum_paths
                                                
                                                    Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **default value**: 1
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "ibgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                    ])
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.Config, ['maximum_paths'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to iBGP multipath
                                                
                                                .. attribute:: maximum_paths
                                                
                                                    Maximum number of parallel paths to consider when using iBGP multipath. The default is to use a single path
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                    **default value**: 1
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ibgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_paths', (YLeaf(YType.uint32, 'maximum-paths'), ['int'])),
                                                    ])
                                                    self.maximum_paths = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.UseMultiplePaths.Ibgp.State, ['maximum_paths'], name, value)




                                    class ApplyPolicy(_Entity_):
                                        """
                                        Anchor point for routing policies in the model.
                                        Import and export policies are with respect to the local
                                        routing table, i.e., export (send) and import (receive),
                                        depending on the context.
                                        
                                        .. attribute:: config
                                        
                                            Policy configuration data
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config>`
                                        
                                        .. attribute:: state
                                        
                                            Operational state for routing policy
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "apply-policy"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "apply-policy"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            Policy configuration data.
                                            
                                            .. attribute:: import_policy
                                            
                                                list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_import_policy
                                            
                                                explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                                list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                            .. attribute:: default_export_policy
                                            
                                                explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                                    ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                    ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                                    ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.Config, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)


                                        class State(_Entity_):
                                            """
                                            Operational state for routing policy
                                            
                                            .. attribute:: import_policy
                                            
                                                list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: default_import_policy
                                            
                                                explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **config**: False
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            .. attribute:: export_policy
                                            
                                                list of policy names in sequence to be applied on sending a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                            
                                                **type**: list of str
                                            
                                                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: default_export_policy
                                            
                                                explicitly set a default policy if no policy definition in the export policy chain is satisfied
                                            
                                                **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                            
                                                **config**: False
                                            
                                                **default value**: REJECT_ROUTE
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "apply-policy"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                                    ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                    ('export_policy', (YLeafList(YType.str, 'export-policy'), ['str'])),
                                                    ('default_export_policy', (YLeaf(YType.enumeration, 'default-export-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                                ])
                                                self.import_policy = []
                                                self.default_import_policy = None
                                                self.export_policy = []
                                                self.default_export_policy = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.ApplyPolicy.State, ['import_policy', 'default_import_policy', 'export_policy', 'default_export_policy'], name, value)



                                    class Ipv4Unicast(_Entity_):
                                        """
                                        IPv4 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for common IPv4 and IPv6 unicast parameters
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "ipv4-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)



                                        class Config(_Entity_):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.Config, ['send_default_route'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4Unicast.State, ['send_default_route'], name, value)



                                    class Ipv6Unicast(_Entity_):
                                        """
                                        IPv6 unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit>`
                                        
                                        .. attribute:: config
                                        
                                            Configuration parameters for common IPv4 and IPv6 unicast AFI\-SAFI options
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config>`
                                        
                                        .. attribute:: state
                                        
                                            State information for common IPv4 and IPv6 unicast parameters
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit)), ("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "ipv6-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)



                                        class Config(_Entity_):
                                            """
                                            Configuration parameters for common IPv4 and IPv6 unicast
                                            AFI\-SAFI options
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.Config, ['send_default_route'], name, value)


                                        class State(_Entity_):
                                            """
                                            State information for common IPv4 and IPv6 unicast
                                            parameters
                                            
                                            .. attribute:: send_default_route
                                            
                                                If set to true, send the default\-route to the neighbour(s)
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('send_default_route', (YLeaf(YType.boolean, 'send-default-route'), ['bool'])),
                                                ])
                                                self.send_default_route = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6Unicast.State, ['send_default_route'], name, value)



                                    class Ipv4LabeledUnicast(_Entity_):
                                        """
                                        IPv4 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv4-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "ipv4-labeled-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv4-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv4LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class Ipv6LabeledUnicast(_Entity_):
                                        """
                                        IPv6 Labeled Unicast configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "ipv6-labeled-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "ipv6-labeled-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "ipv6-labeled-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.Ipv6LabeledUnicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv4Unicast(_Entity_):
                                        """
                                        Unicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv4-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv4-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv6Unicast(_Entity_):
                                        """
                                        Unicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv6-unicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv6-unicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-unicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Unicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv4Multicast(_Entity_):
                                        """
                                        Multicast IPv4 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv4-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv4-multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv4-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv4Multicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L3vpnIpv6Multicast(_Entity_):
                                        """
                                        Multicast IPv6 L3VPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l3vpn-ipv6-multicast"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l3vpn-ipv6-multicast"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l3vpn-ipv6-multicast"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L3vpnIpv6Multicast.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L2vpnVpls(_Entity_):
                                        """
                                        BGP\-signalled VPLS configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l2vpn-vpls"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l2vpn-vpls"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-vpls"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnVpls.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)




                                    class L2vpnEvpn(_Entity_):
                                        """
                                        BGP EVPN configuration options
                                        
                                        .. attribute:: prefix_limit
                                        
                                            Configure the maximum number of prefixes that will be accepted from a peer
                                        
                                            **type**:  :py:class:`PrefixLimit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "l2vpn-evpn"
                                            self.yang_parent_name = "afi-safi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("prefix-limit", ("prefix_limit", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit))])
                                            self._leafs = OrderedDict()

                                            self.prefix_limit = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit()
                                            self.prefix_limit.parent = self
                                            self._children_name_map["prefix_limit"] = "prefix-limit"
                                            self._segment_path = lambda: "l2vpn-evpn"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn, [], name, value)

                                        class PrefixLimit(_Entity_):
                                            """
                                            Configure the maximum number of prefixes that will be
                                            accepted from a peer
                                            
                                            .. attribute:: config
                                            
                                                Configuration parameters relating to the prefix limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config>`
                                            
                                            .. attribute:: state
                                            
                                                State information relating to the prefix\-limit for the AFI\-SAFI
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "prefix-limit"
                                                self.yang_parent_name = "l2vpn-evpn"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "prefix-limit"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                Configuration parameters relating to the prefix
                                                limit for the AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.Config, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)


                                            class State(_Entity_):
                                                """
                                                State information relating to the prefix\-limit for the
                                                AFI\-SAFI
                                                
                                                .. attribute:: max_prefixes
                                                
                                                    Maximum number of prefixes that will be accepted from the neighbour
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: prevent_teardown
                                                
                                                    Do not tear down the BGP session when the maximum prefix limit is exceeded, but rather only log a warning. The default of this leaf is false, such that when it is not specified, the session is torn down
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                    **default value**: false
                                                
                                                .. attribute:: shutdown_threshold_pct
                                                
                                                    Threshold on number of prefixes that can be received from a neighbour before generation of warning messages or log entries. Expressed as a percentage of max\-prefixes
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..100
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_timer
                                                
                                                    Time interval in seconds after which the BGP session is re\-established after being torn down due to exceeding the max\-prefix limit
                                                
                                                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                                                
                                                        **range:** \-92233720368547758.08..92233720368547758.07
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "prefix-limit"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('max_prefixes', (YLeaf(YType.uint32, 'max-prefixes'), ['int'])),
                                                        ('prevent_teardown', (YLeaf(YType.boolean, 'prevent-teardown'), ['bool'])),
                                                        ('shutdown_threshold_pct', (YLeaf(YType.uint8, 'shutdown-threshold-pct'), ['int'])),
                                                        ('restart_timer', (YLeaf(YType.str, 'restart-timer'), ['Decimal64'])),
                                                    ])
                                                    self.max_prefixes = None
                                                    self.prevent_teardown = None
                                                    self.shutdown_threshold_pct = None
                                                    self.restart_timer = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.AfiSafis.AfiSafi.L2vpnEvpn.PrefixLimit.State, ['max_prefixes', 'prevent_teardown', 'shutdown_threshold_pct', 'restart_timer'], name, value)






                            class EnableBfd(_Entity_):
                                """
                                Enable BFD for liveliness detection to the next\-hop or
                                neighbour.
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to enabling BFD
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state parameters relating to enabing BFD
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-bfd'
                                _revision = '2018-11-21'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "enable-bfd"
                                    self.yang_parent_name = "peer-group"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "openconfig-bfd:enable-bfd"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to enabling BFD.
                                    
                                    .. attribute:: enabled
                                    
                                        When this leaf is set to true, BFD is used to detect the liveliness of the remote peer or next\-hop
                                    
                                        **type**: bool
                                    
                                    """
                                    _prefix = 'oc-bfd'
                                    _revision = '2018-11-21'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "enable-bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.enabled = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.Config, ['enabled'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state parameters relating to enabing BFD.
                                    
                                    .. attribute:: enabled
                                    
                                        When this leaf is set to true, BFD is used to detect the liveliness of the remote peer or next\-hop
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    .. attribute:: associated_session
                                    
                                        A reference to the BFD session that is tracking the liveliness of the remote entity
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`local_discriminator<ydk.models.openconfig.openconfig_bfd.Bfd.Interfaces.Interface.Peers.Peer>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-bfd'
                                    _revision = '2018-11-21'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "enable-bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('associated_session', (YLeaf(YType.str, 'associated-session'), ['str'])),
                                        ])
                                        self.enabled = None
                                        self.associated_session = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Bgp.PeerGroups.PeerGroup.EnableBfd.State, ['enabled', 'associated_session'], name, value)






                class Isis(_Entity_):
                    """
                    This container defines top\-level ISIS configuration and state
                    information.
                    
                    .. attribute:: global_
                    
                        This container defines global ISIS configuration and state information
                    
                        **type**:  :py:class:`Global<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global>`
                    
                    .. attribute:: levels
                    
                        This container defines ISIS level configuration and state information
                    
                        **type**:  :py:class:`Levels<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels>`
                    
                    .. attribute:: interfaces
                    
                        This container defines global ISIS interface configuration and state information
                    
                        **type**:  :py:class:`Interfaces<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces>`
                    
                    """
                    _prefix = 'oc-netinst'
                    _revision = '2017-01-13'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "isis"
                        self.yang_parent_name = "protocol"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("global", ("global_", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global)), ("levels", ("levels", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels)), ("interfaces", ("interfaces", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces))])
                        self._leafs = OrderedDict()

                        self.global_ = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global()
                        self.global_.parent = self
                        self._children_name_map["global_"] = "global"

                        self.levels = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels()
                        self.levels.parent = self
                        self._children_name_map["levels"] = "levels"

                        self.interfaces = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces()
                        self.interfaces.parent = self
                        self._children_name_map["interfaces"] = "interfaces"
                        self._segment_path = lambda: "isis"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis, [], name, value)

                    class Global(_Entity_):
                        """
                        This container defines global ISIS configuration and state
                        information.
                        
                        .. attribute:: config
                        
                            This container defines ISIS global configuration router
                        
                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config>`
                        
                        .. attribute:: state
                        
                            This container defines state for ISIS global router
                        
                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State>`
                        
                            **config**: False
                        
                        .. attribute:: lsp_bit
                        
                            This container defines ISIS LSP Operational Bits
                        
                            **type**:  :py:class:`LspBit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit>`
                        
                        .. attribute:: reference_bandwidth
                        
                            This container defines ISIS Reference Bandwidth
                        
                            **type**:  :py:class:`ReferenceBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth>`
                        
                        .. attribute:: nsr
                        
                            This container defines ISIS Non\-Stop Routing
                        
                            **type**:  :py:class:`Nsr<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr>`
                        
                        .. attribute:: graceful_restart
                        
                            This container defines ISIS Graceful Restart
                        
                            **type**:  :py:class:`GracefulRestart<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart>`
                        
                        .. attribute:: timers
                        
                            This container defines ISIS timers
                        
                            **type**:  :py:class:`Timers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers>`
                        
                        .. attribute:: transport
                        
                            This container defines ISIS transport
                        
                            **type**:  :py:class:`Transport<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport>`
                        
                        .. attribute:: mpls
                        
                            Configuration and operational state relating to MPLS\-related features in IS\-IS
                        
                            **type**:  :py:class:`Mpls<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls>`
                        
                        .. attribute:: igp_shortcuts
                        
                            This container defines IGP shortcuts configuration and state information
                        
                            **type**:  :py:class:`IgpShortcuts<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts>`
                        
                        .. attribute:: afi_safi
                        
                            This container defines address\-family specific configuration and state information
                        
                            **type**:  :py:class:`AfiSafi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi>`
                        
                        .. attribute:: segment_routing
                        
                            Configuration and operational state relating to segment routing
                        
                            **type**:  :py:class:`SegmentRouting<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting>`
                        
                        .. attribute:: inter_level_propagation_policies
                        
                            Policies to propagate prefixes between IS\-IS levels
                        
                            **type**:  :py:class:`InterLevelPropagationPolicies<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "global"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State)), ("lsp-bit", ("lsp_bit", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit)), ("reference-bandwidth", ("reference_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth)), ("nsr", ("nsr", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr)), ("graceful-restart", ("graceful_restart", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers)), ("transport", ("transport", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport)), ("mpls", ("mpls", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls)), ("igp-shortcuts", ("igp_shortcuts", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts)), ("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting)), ("inter-level-propagation-policies", ("inter_level_propagation_policies", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies))])
                            self._leafs = OrderedDict()

                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config()
                            self.config.parent = self
                            self._children_name_map["config"] = "config"

                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State()
                            self.state.parent = self
                            self._children_name_map["state"] = "state"

                            self.lsp_bit = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit()
                            self.lsp_bit.parent = self
                            self._children_name_map["lsp_bit"] = "lsp-bit"

                            self.reference_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth()
                            self.reference_bandwidth.parent = self
                            self._children_name_map["reference_bandwidth"] = "reference-bandwidth"

                            self.nsr = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr()
                            self.nsr.parent = self
                            self._children_name_map["nsr"] = "nsr"

                            self.graceful_restart = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart()
                            self.graceful_restart.parent = self
                            self._children_name_map["graceful_restart"] = "graceful-restart"

                            self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers()
                            self.timers.parent = self
                            self._children_name_map["timers"] = "timers"

                            self.transport = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport()
                            self.transport.parent = self
                            self._children_name_map["transport"] = "transport"

                            self.mpls = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls()
                            self.mpls.parent = self
                            self._children_name_map["mpls"] = "mpls"

                            self.igp_shortcuts = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts()
                            self.igp_shortcuts.parent = self
                            self._children_name_map["igp_shortcuts"] = "igp-shortcuts"

                            self.afi_safi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi()
                            self.afi_safi.parent = self
                            self._children_name_map["afi_safi"] = "afi-safi"

                            self.segment_routing = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting()
                            self.segment_routing.parent = self
                            self._children_name_map["segment_routing"] = "segment-routing"

                            self.inter_level_propagation_policies = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies()
                            self.inter_level_propagation_policies.parent = self
                            self._children_name_map["inter_level_propagation_policies"] = "inter-level-propagation-policies"
                            self._segment_path = lambda: "global"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global, [], name, value)

                        class Config(_Entity_):
                            """
                            This container defines ISIS global configuration router.
                            
                            .. attribute:: authentication_check
                            
                                When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                            
                                **type**: bool
                            
                                **default value**: true
                            
                            .. attribute:: instance
                            
                                ISIS Instance
                            
                                **type**: str
                            
                                **default value**: 0
                            
                            .. attribute:: net
                            
                                ISIS network entity title (NET). The first 8 bits are usually 49 (private AFI), next 16 bits represent area, next 48 bits represent system id and final 8 bits are set to 0
                            
                                **type**: list of str
                            
                                    **pattern:** ^[a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){3,9}\\.[a\-fA\-F0\-9]{2}$
                            
                            .. attribute:: maximum_area_addresses
                            
                                Maximum areas supported
                            
                                **type**: int
                            
                                    **range:** 0..255
                            
                                **default value**: 3
                            
                            .. attribute:: level_capability
                            
                                ISIS level capability(level\-1, level\-2,vlevel\-1\-2)
                            
                                **type**:  :py:class:`LevelType<ydk.models.openconfig.openconfig_isis_types.LevelType>`
                            
                                **default value**: LEVEL_1_2
                            
                            .. attribute:: max_ecmp_paths
                            
                                ISIS max\-paths count
                            
                                **type**: int
                            
                                    **range:** 0..255
                            
                            .. attribute:: poi_tlv
                            
                                ISIS purge TLV. When set to true, a TLV is added to purges to record the system ID  of the IS generating the purge
                            
                                **type**: bool
                            
                                **default value**: false
                            
                            .. attribute:: iid_tlv
                            
                                ISIS Instance Identifier TLV. When set to trues, the IID\-TLV identifies the unique instance as well as the topology/topologies to which the PDU applies
                            
                                **type**: bool
                            
                                **default value**: false
                            
                            .. attribute:: fast_flooding
                            
                                When set to true, IS will always flood the LSP that triggered an SPF before the router actually runs the SPF computation
                            
                                **type**: bool
                            
                                **default value**: true
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "config"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('authentication_check', (YLeaf(YType.boolean, 'authentication-check'), ['bool'])),
                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                    ('net', (YLeafList(YType.str, 'net'), ['str'])),
                                    ('maximum_area_addresses', (YLeaf(YType.uint8, 'maximum-area-addresses'), ['int'])),
                                    ('level_capability', (YLeaf(YType.enumeration, 'level-capability'), [('ydk.models.openconfig.openconfig_isis_types', 'LevelType', '')])),
                                    ('max_ecmp_paths', (YLeaf(YType.uint8, 'max-ecmp-paths'), ['int'])),
                                    ('poi_tlv', (YLeaf(YType.boolean, 'poi-tlv'), ['bool'])),
                                    ('iid_tlv', (YLeaf(YType.boolean, 'iid-tlv'), ['bool'])),
                                    ('fast_flooding', (YLeaf(YType.boolean, 'fast-flooding'), ['bool'])),
                                ])
                                self.authentication_check = None
                                self.instance = None
                                self.net = []
                                self.maximum_area_addresses = None
                                self.level_capability = None
                                self.max_ecmp_paths = None
                                self.poi_tlv = None
                                self.iid_tlv = None
                                self.fast_flooding = None
                                self._segment_path = lambda: "config"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Config, ['authentication_check', 'instance', 'net', 'maximum_area_addresses', 'level_capability', 'max_ecmp_paths', 'poi_tlv', 'iid_tlv', 'fast_flooding'], name, value)


                        class State(_Entity_):
                            """
                            This container defines state for ISIS global router.
                            
                            .. attribute:: authentication_check
                            
                                When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                            
                                **type**: bool
                            
                                **config**: False
                            
                                **default value**: true
                            
                            .. attribute:: instance
                            
                                ISIS Instance
                            
                                **type**: str
                            
                                **config**: False
                            
                                **default value**: 0
                            
                            .. attribute:: net
                            
                                ISIS network entity title (NET). The first 8 bits are usually 49 (private AFI), next 16 bits represent area, next 48 bits represent system id and final 8 bits are set to 0
                            
                                **type**: list of str
                            
                                    **pattern:** ^[a\-fA\-F0\-9]{2}(\\.[a\-fA\-F0\-9]{4}){3,9}\\.[a\-fA\-F0\-9]{2}$
                            
                                **config**: False
                            
                            .. attribute:: maximum_area_addresses
                            
                                Maximum areas supported
                            
                                **type**: int
                            
                                    **range:** 0..255
                            
                                **config**: False
                            
                                **default value**: 3
                            
                            .. attribute:: level_capability
                            
                                ISIS level capability(level\-1, level\-2,vlevel\-1\-2)
                            
                                **type**:  :py:class:`LevelType<ydk.models.openconfig.openconfig_isis_types.LevelType>`
                            
                                **config**: False
                            
                                **default value**: LEVEL_1_2
                            
                            .. attribute:: max_ecmp_paths
                            
                                ISIS max\-paths count
                            
                                **type**: int
                            
                                    **range:** 0..255
                            
                                **config**: False
                            
                            .. attribute:: poi_tlv
                            
                                ISIS purge TLV. When set to true, a TLV is added to purges to record the system ID  of the IS generating the purge
                            
                                **type**: bool
                            
                                **config**: False
                            
                                **default value**: false
                            
                            .. attribute:: iid_tlv
                            
                                ISIS Instance Identifier TLV. When set to trues, the IID\-TLV identifies the unique instance as well as the topology/topologies to which the PDU applies
                            
                                **type**: bool
                            
                                **config**: False
                            
                                **default value**: false
                            
                            .. attribute:: fast_flooding
                            
                                When set to true, IS will always flood the LSP that triggered an SPF before the router actually runs the SPF computation
                            
                                **type**: bool
                            
                                **config**: False
                            
                                **default value**: true
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "state"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('authentication_check', (YLeaf(YType.boolean, 'authentication-check'), ['bool'])),
                                    ('instance', (YLeaf(YType.str, 'instance'), ['str'])),
                                    ('net', (YLeafList(YType.str, 'net'), ['str'])),
                                    ('maximum_area_addresses', (YLeaf(YType.uint8, 'maximum-area-addresses'), ['int'])),
                                    ('level_capability', (YLeaf(YType.enumeration, 'level-capability'), [('ydk.models.openconfig.openconfig_isis_types', 'LevelType', '')])),
                                    ('max_ecmp_paths', (YLeaf(YType.uint8, 'max-ecmp-paths'), ['int'])),
                                    ('poi_tlv', (YLeaf(YType.boolean, 'poi-tlv'), ['bool'])),
                                    ('iid_tlv', (YLeaf(YType.boolean, 'iid-tlv'), ['bool'])),
                                    ('fast_flooding', (YLeaf(YType.boolean, 'fast-flooding'), ['bool'])),
                                ])
                                self.authentication_check = None
                                self.instance = None
                                self.net = []
                                self.maximum_area_addresses = None
                                self.level_capability = None
                                self.max_ecmp_paths = None
                                self.poi_tlv = None
                                self.iid_tlv = None
                                self.fast_flooding = None
                                self._segment_path = lambda: "state"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.State, ['authentication_check', 'instance', 'net', 'maximum_area_addresses', 'level_capability', 'max_ecmp_paths', 'poi_tlv', 'iid_tlv', 'fast_flooding'], name, value)


                        class LspBit(_Entity_):
                            """
                            This container defines ISIS LSP Operational Bits.
                            
                            .. attribute:: overload_bit
                            
                                This container defines Overload Bit configuration
                            
                                **type**:  :py:class:`OverloadBit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit>`
                            
                            .. attribute:: attached_bit
                            
                                This container defines Attached Bit
                            
                                **type**:  :py:class:`AttachedBit<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "lsp-bit"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("overload-bit", ("overload_bit", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit)), ("attached-bit", ("attached_bit", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit))])
                                self._leafs = OrderedDict()

                                self.overload_bit = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit()
                                self.overload_bit.parent = self
                                self._children_name_map["overload_bit"] = "overload-bit"

                                self.attached_bit = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit()
                                self.attached_bit.parent = self
                                self._children_name_map["attached_bit"] = "attached-bit"
                                self._segment_path = lambda: "lsp-bit"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit, [], name, value)

                            class OverloadBit(_Entity_):
                                """
                                This container defines Overload Bit configuration.
                                
                                .. attribute:: config
                                
                                    This container defines ISIS Overload Bit configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines state for ISIS Overload Bit
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State>`
                                
                                    **config**: False
                                
                                .. attribute:: reset_triggers
                                
                                    This container defines state for ISIS Overload Bit reset triggers
                                
                                    **type**:  :py:class:`ResetTriggers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "overload-bit"
                                    self.yang_parent_name = "lsp-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State)), ("reset-triggers", ("reset_triggers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.reset_triggers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers()
                                    self.reset_triggers.parent = self
                                    self._children_name_map["reset_triggers"] = "reset-triggers"
                                    self._segment_path = lambda: "overload-bit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS Overload Bit configuration.
                                    
                                    .. attribute:: set_bit
                                    
                                        When set to true, IS\-IS overload bit is set
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: set_bit_on_boot
                                    
                                        When set to true, the IS\-IS overload bit is set on system boot
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: advertise_high_metric
                                    
                                        When set to true, the local IS advertises links with the highest available metric regardless of their configured metric. The metric value is based on the metric style \- if wide metrics are utilised the metric is advertised as 16777214, otherwise they are advertised with a value of 63
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('set_bit', (YLeaf(YType.boolean, 'set-bit'), ['bool'])),
                                            ('set_bit_on_boot', (YLeaf(YType.boolean, 'set-bit-on-boot'), ['bool'])),
                                            ('advertise_high_metric', (YLeaf(YType.boolean, 'advertise-high-metric'), ['bool'])),
                                        ])
                                        self.set_bit = None
                                        self.set_bit_on_boot = None
                                        self.advertise_high_metric = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.Config, ['set_bit', 'set_bit_on_boot', 'advertise_high_metric'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines state for ISIS Overload Bit.
                                    
                                    .. attribute:: set_bit
                                    
                                        When set to true, IS\-IS overload bit is set
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: set_bit_on_boot
                                    
                                        When set to true, the IS\-IS overload bit is set on system boot
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: advertise_high_metric
                                    
                                        When set to true, the local IS advertises links with the highest available metric regardless of their configured metric. The metric value is based on the metric style \- if wide metrics are utilised the metric is advertised as 16777214, otherwise they are advertised with a value of 63
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('set_bit', (YLeaf(YType.boolean, 'set-bit'), ['bool'])),
                                            ('set_bit_on_boot', (YLeaf(YType.boolean, 'set-bit-on-boot'), ['bool'])),
                                            ('advertise_high_metric', (YLeaf(YType.boolean, 'advertise-high-metric'), ['bool'])),
                                        ])
                                        self.set_bit = None
                                        self.set_bit_on_boot = None
                                        self.advertise_high_metric = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.State, ['set_bit', 'set_bit_on_boot', 'advertise_high_metric'], name, value)


                                class ResetTriggers(_Entity_):
                                    """
                                    This container defines state for ISIS Overload Bit reset triggers
                                    
                                    .. attribute:: reset_trigger
                                    
                                        This list describes ISIS Overload reset trigger reasons
                                    
                                        **type**: list of    :py:class:`ResetTrigger<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "reset-triggers"
                                        self.yang_parent_name = "overload-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("reset-trigger", ("reset_trigger", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger))])
                                        self._leafs = OrderedDict()

                                        self.reset_trigger = YList(self)
                                        self._segment_path = lambda: "reset-triggers"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers, [], name, value)

                                    class ResetTrigger(_Entity_):
                                        """
                                        This list describes ISIS Overload reset trigger reasons.
                                        
                                        .. attribute:: reset_trigger  (key)
                                        
                                            Reference to the reset trigger reason
                                        
                                            **type**:  :py:class:`OVERLOADRESETTRIGGERTYPE<ydk.models.openconfig.openconfig_isis_types.OVERLOADRESETTRIGGERTYPE>`
                                        
                                        .. attribute:: config
                                        
                                            This container defines ISIS Overload Bit reset trigger configuration
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config>`
                                        
                                        .. attribute:: state
                                        
                                            This container defines state for ISIS Overload Bit reset triggers
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "reset-trigger"
                                            self.yang_parent_name = "reset-triggers"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = ['reset_trigger']
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State))])
                                            self._leafs = OrderedDict([
                                                ('reset_trigger', (YLeaf(YType.identityref, 'reset-trigger'), [('ydk.models.openconfig.openconfig_isis_types', 'OVERLOADRESETTRIGGERTYPE')])),
                                            ])
                                            self.reset_trigger = None

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "reset-trigger" + "[reset-trigger='" + str(self.reset_trigger) + "']"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger, ['reset_trigger'], name, value)

                                        class Config(_Entity_):
                                            """
                                            This container defines ISIS Overload Bit reset trigger
                                            configuration.
                                            
                                            .. attribute:: reset_trigger
                                            
                                                In the case that the system sets the overload bit on start, the system should reset the bit (i.e., clear the overload bit) upon the specified trigger
                                            
                                                **type**:  :py:class:`OVERLOADRESETTRIGGERTYPE<ydk.models.openconfig.openconfig_isis_types.OVERLOADRESETTRIGGERTYPE>`
                                            
                                            .. attribute:: delay
                                            
                                                If a reset trigger is specified, the system should delay resetting the overload bit for the specified number of seconds after the trigger occurs
                                            
                                                **type**: int
                                            
                                                    **range:** 0..65535
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "reset-trigger"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('reset_trigger', (YLeaf(YType.identityref, 'reset-trigger'), [('ydk.models.openconfig.openconfig_isis_types', 'OVERLOADRESETTRIGGERTYPE')])),
                                                    ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                                                ])
                                                self.reset_trigger = None
                                                self.delay = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.Config, ['reset_trigger', 'delay'], name, value)


                                        class State(_Entity_):
                                            """
                                            This container defines state for ISIS Overload Bit reset
                                            triggers.
                                            
                                            .. attribute:: reset_trigger
                                            
                                                In the case that the system sets the overload bit on start, the system should reset the bit (i.e., clear the overload bit) upon the specified trigger
                                            
                                                **type**:  :py:class:`OVERLOADRESETTRIGGERTYPE<ydk.models.openconfig.openconfig_isis_types.OVERLOADRESETTRIGGERTYPE>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: delay
                                            
                                                If a reset trigger is specified, the system should delay resetting the overload bit for the specified number of seconds after the trigger occurs
                                            
                                                **type**: int
                                            
                                                    **range:** 0..65535
                                            
                                                **config**: False
                                            
                                                **units**: seconds
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "reset-trigger"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('reset_trigger', (YLeaf(YType.identityref, 'reset-trigger'), [('ydk.models.openconfig.openconfig_isis_types', 'OVERLOADRESETTRIGGERTYPE')])),
                                                    ('delay', (YLeaf(YType.uint16, 'delay'), ['int'])),
                                                ])
                                                self.reset_trigger = None
                                                self.delay = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.OverloadBit.ResetTriggers.ResetTrigger.State, ['reset_trigger', 'delay'], name, value)





                            class AttachedBit(_Entity_):
                                """
                                This container defines Attached Bit.
                                
                                .. attribute:: config
                                
                                    This container defines Attached Bit configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines state for Link State PDU Bit
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "attached-bit"
                                    self.yang_parent_name = "lsp-bit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "attached-bit"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines Attached Bit configuration.
                                    
                                    .. attribute:: ignore_bit
                                    
                                        When set to true, if the attached bit is set on an incoming Level 1 IS\-IS, the local system ignores it. In this case the local system does not set a default route to the L1L2 router advertising the PDU with the attached bit set
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: suppress_bit
                                    
                                        When set to true, if the local IS acts as a L1L2 router, then the attached bit is not advertised in locally generated PDUs
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "attached-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore_bit', (YLeaf(YType.boolean, 'ignore-bit'), ['bool'])),
                                            ('suppress_bit', (YLeaf(YType.boolean, 'suppress-bit'), ['bool'])),
                                        ])
                                        self.ignore_bit = None
                                        self.suppress_bit = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.Config, ['ignore_bit', 'suppress_bit'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines state for Link State PDU Bit.
                                    
                                    .. attribute:: ignore_bit
                                    
                                        When set to true, if the attached bit is set on an incoming Level 1 IS\-IS, the local system ignores it. In this case the local system does not set a default route to the L1L2 router advertising the PDU with the attached bit set
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: suppress_bit
                                    
                                        When set to true, if the local IS acts as a L1L2 router, then the attached bit is not advertised in locally generated PDUs
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "attached-bit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ignore_bit', (YLeaf(YType.boolean, 'ignore-bit'), ['bool'])),
                                            ('suppress_bit', (YLeaf(YType.boolean, 'suppress-bit'), ['bool'])),
                                        ])
                                        self.ignore_bit = None
                                        self.suppress_bit = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.LspBit.AttachedBit.State, ['ignore_bit', 'suppress_bit'], name, value)




                        class ReferenceBandwidth(_Entity_):
                            """
                            This container defines ISIS Reference Bandwidth.
                            
                            .. attribute:: config
                            
                                This container defines Reference Bandwidth configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config>`
                            
                            .. attribute:: state
                            
                                This container defines state for Reference Bandwidth
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "reference-bandwidth"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "reference-bandwidth"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth, [], name, value)

                            class Config(_Entity_):
                                """
                                This container defines Reference Bandwidth configuration
                                
                                .. attribute:: reference_bandwidth
                                
                                    ISIS Reference Bandwidth value
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "reference-bandwidth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                    ])
                                    self.reference_bandwidth = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.Config, ['reference_bandwidth'], name, value)


                            class State(_Entity_):
                                """
                                This container defines state for Reference Bandwidth.
                                
                                .. attribute:: reference_bandwidth
                                
                                    ISIS Reference Bandwidth value
                                
                                    **type**: int
                                
                                        **range:** 0..4294967295
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "reference-bandwidth"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('reference_bandwidth', (YLeaf(YType.uint32, 'reference-bandwidth'), ['int'])),
                                    ])
                                    self.reference_bandwidth = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.ReferenceBandwidth.State, ['reference_bandwidth'], name, value)



                        class Nsr(_Entity_):
                            """
                            This container defines ISIS Non\-Stop Routing.
                            
                            .. attribute:: config
                            
                                This container defines Non\-Stop\-Routing configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config>`
                            
                            .. attribute:: state
                            
                                This container defines state for Non\-Stop\-Routing
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "nsr"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "nsr"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr, [], name, value)

                            class Config(_Entity_):
                                """
                                This container defines Non\-Stop\-Routing configuration.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "nsr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.Config, ['enabled'], name, value)


                            class State(_Entity_):
                                """
                                This container defines state for Non\-Stop\-Routing
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "nsr"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Nsr.State, ['enabled'], name, value)



                        class GracefulRestart(_Entity_):
                            """
                            This container defines ISIS Graceful Restart.
                            
                            .. attribute:: config
                            
                                This container defines ISIS graceful\-restart configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config>`
                            
                            .. attribute:: state
                            
                                This container defines state information for ISIS graceful\-restart
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "graceful-restart"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "graceful-restart"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart, [], name, value)

                            class Config(_Entity_):
                                """
                                This container defines ISIS graceful\-restart configuration.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: helper_only
                                
                                    Enable or disable the IS\-IS graceful restart helper function. When this leaf is set, the local system does not utilise the IS\-IS graceful restart procedures during its own restart, but supports retaining forwarding information during a remote speaker's restart
                                
                                    **type**: bool
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.Config, ['enabled', 'helper_only'], name, value)


                            class State(_Entity_):
                                """
                                This container defines state information for ISIS graceful\-restart.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: helper_only
                                
                                    Enable or disable the IS\-IS graceful restart helper function. When this leaf is set, the local system does not utilise the IS\-IS graceful restart procedures during its own restart, but supports retaining forwarding information during a remote speaker's restart
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "graceful-restart"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('helper_only', (YLeaf(YType.boolean, 'helper-only'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self.helper_only = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.GracefulRestart.State, ['enabled', 'helper_only'], name, value)



                        class Timers(_Entity_):
                            """
                            This container defines ISIS timers.
                            
                            .. attribute:: config
                            
                                This container defines ISIS global timers configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config>`
                            
                            .. attribute:: state
                            
                                This container defines state information for ISIS global timers
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State>`
                            
                                **config**: False
                            
                            .. attribute:: spf
                            
                                This container defines ISIS SPF timer settings
                            
                                **type**:  :py:class:`Spf<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf>`
                            
                            .. attribute:: lsp_generation
                            
                                This container defines ISIS LSP Generation
                            
                                **type**:  :py:class:`LspGeneration<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "timers"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State)), ("spf", ("spf", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf)), ("lsp-generation", ("lsp_generation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.spf = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf()
                                self.spf.parent = self
                                self._children_name_map["spf"] = "spf"

                                self.lsp_generation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration()
                                self.lsp_generation.parent = self
                                self._children_name_map["lsp_generation"] = "lsp-generation"
                                self._segment_path = lambda: "timers"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers, [], name, value)

                            class Config(_Entity_):
                                """
                                This container defines ISIS global timers configuration.
                                
                                .. attribute:: lsp_lifetime_interval
                                
                                    Time interval in seconds that specifies how long an LSP remains in LSDB without being refreshed
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **units**: seconds
                                
                                    **default value**: 1200
                                
                                .. attribute:: lsp_refresh_interval
                                
                                    Time interval in seconds that specifies how often route topology that a device originates is transmitted in LSPs
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **units**: seconds
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_lifetime_interval', (YLeaf(YType.uint16, 'lsp-lifetime-interval'), ['int'])),
                                        ('lsp_refresh_interval', (YLeaf(YType.uint16, 'lsp-refresh-interval'), ['int'])),
                                    ])
                                    self.lsp_lifetime_interval = None
                                    self.lsp_refresh_interval = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Config, ['lsp_lifetime_interval', 'lsp_refresh_interval'], name, value)


                            class State(_Entity_):
                                """
                                This container defines state information for ISIS global timers.
                                
                                .. attribute:: lsp_lifetime_interval
                                
                                    Time interval in seconds that specifies how long an LSP remains in LSDB without being refreshed
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                    **units**: seconds
                                
                                    **default value**: 1200
                                
                                .. attribute:: lsp_refresh_interval
                                
                                    Time interval in seconds that specifies how often route topology that a device originates is transmitted in LSPs
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                    **units**: seconds
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_lifetime_interval', (YLeaf(YType.uint16, 'lsp-lifetime-interval'), ['int'])),
                                        ('lsp_refresh_interval', (YLeaf(YType.uint16, 'lsp-refresh-interval'), ['int'])),
                                    ])
                                    self.lsp_lifetime_interval = None
                                    self.lsp_refresh_interval = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.State, ['lsp_lifetime_interval', 'lsp_refresh_interval'], name, value)


                            class Spf(_Entity_):
                                """
                                This container defines ISIS SPF timer settings.
                                
                                .. attribute:: config
                                
                                    This container defines ISIS SPF timers configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines state information for ISIS SPF timers
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "spf"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "spf"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS SPF timers configuration.
                                    
                                    .. attribute:: spf_hold_interval
                                    
                                        SPF Hold Down time interval in milliseconds
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                        **default value**: 5000
                                    
                                    .. attribute:: spf_first_interval
                                    
                                        Time interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: spf_second_interval
                                    
                                        Time interval in milliseconds between the first and second SPF calculation
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "spf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('spf_hold_interval', (YLeaf(YType.uint64, 'spf-hold-interval'), ['int'])),
                                            ('spf_first_interval', (YLeaf(YType.uint64, 'spf-first-interval'), ['int'])),
                                            ('spf_second_interval', (YLeaf(YType.uint64, 'spf-second-interval'), ['int'])),
                                        ])
                                        self.spf_hold_interval = None
                                        self.spf_first_interval = None
                                        self.spf_second_interval = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.Config, ['spf_hold_interval', 'spf_first_interval', 'spf_second_interval'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines state information for ISIS SPF timers.
                                    
                                    .. attribute:: spf_hold_interval
                                    
                                        SPF Hold Down time interval in milliseconds
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                        **default value**: 5000
                                    
                                    .. attribute:: spf_first_interval
                                    
                                        Time interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: spf_second_interval
                                    
                                        Time interval in milliseconds between the first and second SPF calculation
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: adaptive_timer
                                    
                                        ISIS adaptive timer types (linear, exponential)
                                    
                                        **type**:  :py:class:`AdaptiveTimerType<ydk.models.openconfig.openconfig_isis_types.AdaptiveTimerType>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "spf"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('spf_hold_interval', (YLeaf(YType.uint64, 'spf-hold-interval'), ['int'])),
                                            ('spf_first_interval', (YLeaf(YType.uint64, 'spf-first-interval'), ['int'])),
                                            ('spf_second_interval', (YLeaf(YType.uint64, 'spf-second-interval'), ['int'])),
                                            ('adaptive_timer', (YLeaf(YType.enumeration, 'adaptive-timer'), [('ydk.models.openconfig.openconfig_isis_types', 'AdaptiveTimerType', '')])),
                                        ])
                                        self.spf_hold_interval = None
                                        self.spf_first_interval = None
                                        self.spf_second_interval = None
                                        self.adaptive_timer = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.Spf.State, ['spf_hold_interval', 'spf_first_interval', 'spf_second_interval', 'adaptive_timer'], name, value)



                            class LspGeneration(_Entity_):
                                """
                                This container defines ISIS LSP Generation.
                                
                                .. attribute:: config
                                
                                    This container defines ISIS LSP Generation timers configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines state information for ISIS LSP Generation timers
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "lsp-generation"
                                    self.yang_parent_name = "timers"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "lsp-generation"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS LSP Generation timers
                                    configuration.
                                    
                                    .. attribute:: lsp_max_wait_interval
                                    
                                        Time interval in milliseconds that specifies max interval between two consecutive occurrences of an LSP being generated
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: lsp_first_wait_interval
                                    
                                        Time interval in milliseconds that specifies the first LSP generation delay
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: lsp_second_wait_interval
                                    
                                        Time interval in milliseconds that specifies the millisecond LSP generation delay
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "lsp-generation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_max_wait_interval', (YLeaf(YType.uint64, 'lsp-max-wait-interval'), ['int'])),
                                            ('lsp_first_wait_interval', (YLeaf(YType.uint64, 'lsp-first-wait-interval'), ['int'])),
                                            ('lsp_second_wait_interval', (YLeaf(YType.uint64, 'lsp-second-wait-interval'), ['int'])),
                                        ])
                                        self.lsp_max_wait_interval = None
                                        self.lsp_first_wait_interval = None
                                        self.lsp_second_wait_interval = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.Config, ['lsp_max_wait_interval', 'lsp_first_wait_interval', 'lsp_second_wait_interval'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines state information for ISIS LSP Generation
                                    timers.
                                    
                                    .. attribute:: lsp_max_wait_interval
                                    
                                        Time interval in milliseconds that specifies max interval between two consecutive occurrences of an LSP being generated
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: lsp_first_wait_interval
                                    
                                        Time interval in milliseconds that specifies the first LSP generation delay
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: lsp_second_wait_interval
                                    
                                        Time interval in milliseconds that specifies the millisecond LSP generation delay
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                    .. attribute:: adaptive_timer
                                    
                                        ISIS adaptive timer types (linear, exponential)
                                    
                                        **type**:  :py:class:`AdaptiveTimerType<ydk.models.openconfig.openconfig_isis_types.AdaptiveTimerType>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "lsp-generation"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lsp_max_wait_interval', (YLeaf(YType.uint64, 'lsp-max-wait-interval'), ['int'])),
                                            ('lsp_first_wait_interval', (YLeaf(YType.uint64, 'lsp-first-wait-interval'), ['int'])),
                                            ('lsp_second_wait_interval', (YLeaf(YType.uint64, 'lsp-second-wait-interval'), ['int'])),
                                            ('adaptive_timer', (YLeaf(YType.enumeration, 'adaptive-timer'), [('ydk.models.openconfig.openconfig_isis_types', 'AdaptiveTimerType', '')])),
                                        ])
                                        self.lsp_max_wait_interval = None
                                        self.lsp_first_wait_interval = None
                                        self.lsp_second_wait_interval = None
                                        self.adaptive_timer = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Timers.LspGeneration.State, ['lsp_max_wait_interval', 'lsp_first_wait_interval', 'lsp_second_wait_interval', 'adaptive_timer'], name, value)




                        class Transport(_Entity_):
                            """
                            This container defines ISIS transport.
                            
                            .. attribute:: config
                            
                                This container defines ISIS transport related configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config>`
                            
                            .. attribute:: state
                            
                                This container defines state information for ISIS transport parameters
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "transport"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "transport"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport, [], name, value)

                            class Config(_Entity_):
                                """
                                This container defines ISIS transport related configuration.
                                
                                .. attribute:: lsp_mtu_size
                                
                                    The maximum size in bytes of an IS\-IS Link state PDU
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "transport"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_mtu_size', (YLeaf(YType.uint16, 'lsp-mtu-size'), ['int'])),
                                    ])
                                    self.lsp_mtu_size = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.Config, ['lsp_mtu_size'], name, value)


                            class State(_Entity_):
                                """
                                This container defines state information for ISIS transport
                                parameters.
                                
                                .. attribute:: lsp_mtu_size
                                
                                    The maximum size in bytes of an IS\-IS Link state PDU
                                
                                    **type**: int
                                
                                        **range:** 0..65535
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "transport"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lsp_mtu_size', (YLeaf(YType.uint16, 'lsp-mtu-size'), ['int'])),
                                    ])
                                    self.lsp_mtu_size = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Transport.State, ['lsp_mtu_size'], name, value)



                        class Mpls(_Entity_):
                            """
                            Configuration and operational state relating to MPLS\-related
                            features in IS\-IS
                            
                            .. attribute:: igp_ldp_sync
                            
                                Configuration and operational state relating to synchronisation between the LDP and IS\-IS
                            
                                **type**:  :py:class:`IgpLdpSync<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "mpls"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("igp-ldp-sync", ("igp_ldp_sync", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync))])
                                self._leafs = OrderedDict()

                                self.igp_ldp_sync = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync()
                                self.igp_ldp_sync.parent = self
                                self._children_name_map["igp_ldp_sync"] = "igp-ldp-sync"
                                self._segment_path = lambda: "mpls"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls, [], name, value)

                            class IgpLdpSync(_Entity_):
                                """
                                Configuration and operational state relating to synchronisation
                                between the LDP and IS\-IS
                                
                                .. attribute:: config
                                
                                    This container defines ISIS/IGP configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines state information for ISIS/LDP Sync
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "igp-ldp-sync"
                                    self.yang_parent_name = "mpls"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "igp-ldp-sync"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS/IGP configuration.
                                    
                                    .. attribute:: enabled
                                    
                                        When set to true, rely on IGP/LDP synchronization. IGP cost for link is maintained at max until LDP adjacencies are established 
                                    
                                        **type**: bool
                                    
                                        **default value**: true
                                    
                                    .. attribute:: post_session_up_delay
                                    
                                        Specifies a delay, expressed in units of seconds, between the LDP session to the IGP neighbor being established, and it being considered synchronized by the IGP
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **units**: seconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "igp-ldp-sync"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('post_session_up_delay', (YLeaf(YType.uint16, 'post-session-up-delay'), ['int'])),
                                        ])
                                        self.enabled = None
                                        self.post_session_up_delay = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.Config, ['enabled', 'post_session_up_delay'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines state information for ISIS/LDP Sync.
                                    
                                    .. attribute:: enabled
                                    
                                        When set to true, rely on IGP/LDP synchronization. IGP cost for link is maintained at max until LDP adjacencies are established 
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: true
                                    
                                    .. attribute:: post_session_up_delay
                                    
                                        Specifies a delay, expressed in units of seconds, between the LDP session to the IGP neighbor being established, and it being considered synchronized by the IGP
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                        **units**: seconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "igp-ldp-sync"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('post_session_up_delay', (YLeaf(YType.uint16, 'post-session-up-delay'), ['int'])),
                                        ])
                                        self.enabled = None
                                        self.post_session_up_delay = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.Mpls.IgpLdpSync.State, ['enabled', 'post_session_up_delay'], name, value)




                        class IgpShortcuts(_Entity_):
                            """
                            This container defines IGP shortcuts configuration and state
                            information.
                            
                            .. attribute:: afi
                            
                                Address\-family list
                            
                                **type**: list of    :py:class:`Afi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "igp-shortcuts"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("afi", ("afi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi))])
                                self._leafs = OrderedDict()

                                self.afi = YList(self)
                                self._segment_path = lambda: "igp-shortcuts"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts, [], name, value)

                            class Afi(_Entity_):
                                """
                                Address\-family list.
                                
                                .. attribute:: afi_name  (key)
                                
                                    Reference to address\-family type
                                
                                    **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                
                                .. attribute:: config
                                
                                    This container defines ISIS Shortcuts configuration parameters
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines ISIS Shortcuts state information
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "afi"
                                    self.yang_parent_name = "igp-shortcuts"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['afi_name']
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State))])
                                    self._leafs = OrderedDict([
                                        ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                    ])
                                    self.afi_name = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "afi" + "[afi-name='" + str(self.afi_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi, ['afi_name'], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS Shortcuts configuration parameters
                                    
                                    .. attribute:: afi_name
                                    
                                        Address\-family type
                                    
                                        **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: nh_type
                                    
                                        Tunnel NH Type(RSVP,SR). When present it implies that nh\-type shortcut is enabled for a specified AFI
                                    
                                        **type**: list of   :py:class:`PATHSETUPPROTOCOL<ydk.models.openconfig.openconfig_mpls_types.PATHSETUPPROTOCOL>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "afi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                            ('nh_type', (YLeafList(YType.identityref, 'nh-type'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPPROTOCOL')])),
                                        ])
                                        self.afi_name = None
                                        self.nh_type = []
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.Config, ['afi_name', 'nh_type'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines ISIS Shortcuts state information
                                    
                                    .. attribute:: afi_name
                                    
                                        Address\-family type
                                    
                                        **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: nh_type
                                    
                                        Tunnel NH Type(RSVP,SR). When present it implies that nh\-type shortcut is enabled for a specified AFI
                                    
                                        **type**: list of   :py:class:`PATHSETUPPROTOCOL<ydk.models.openconfig.openconfig_mpls_types.PATHSETUPPROTOCOL>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "afi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                            ('nh_type', (YLeafList(YType.identityref, 'nh-type'), [('ydk.models.openconfig.openconfig_mpls_types', 'PATHSETUPPROTOCOL')])),
                                        ])
                                        self.afi_name = None
                                        self.nh_type = []
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.IgpShortcuts.Afi.State, ['afi_name', 'nh_type'], name, value)




                        class AfiSafi(_Entity_):
                            """
                            This container defines address\-family specific configuration
                            and state information.
                            
                            .. attribute:: af
                            
                                Address\-family/Subsequent Address\-family list
                            
                                **type**: list of    :py:class:`Af<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "afi-safi"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("af", ("af", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af))])
                                self._leafs = OrderedDict()

                                self.af = YList(self)
                                self._segment_path = lambda: "afi-safi"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi, [], name, value)

                            class Af(_Entity_):
                                """
                                Address\-family/Subsequent Address\-family list.
                                
                                .. attribute:: afi_name  (key)
                                
                                    Reference to address\-family type
                                
                                    **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                
                                .. attribute:: safi_name  (key)
                                
                                    Reference to subsequent address\-family type
                                
                                    **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                
                                .. attribute:: config
                                
                                    This container defines AFI\-SAFI configuration parameters
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines AFI\-SAFI State information
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State>`
                                
                                    **config**: False
                                
                                .. attribute:: multi_topology
                                
                                    This container defines multi\-topology address\-family configuration and state information. ISIS TLV 235, 237
                                
                                    **type**:  :py:class:`MultiTopology<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "af"
                                    self.yang_parent_name = "afi-safi"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['afi_name','safi_name']
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State)), ("multi-topology", ("multi_topology", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology))])
                                    self._leafs = OrderedDict([
                                        ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                        ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                    ])
                                    self.afi_name = None
                                    self.safi_name = None

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.multi_topology = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology()
                                    self.multi_topology.parent = self
                                    self._children_name_map["multi_topology"] = "multi-topology"
                                    self._segment_path = lambda: "af" + "[afi-name='" + str(self.afi_name) + "']" + "[safi-name='" + str(self.safi_name) + "']"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af, ['afi_name', 'safi_name'], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines AFI\-SAFI configuration parameters
                                    
                                    .. attribute:: afi_name
                                    
                                        Address\-family type
                                    
                                        **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: safi_name
                                    
                                        Subsequent address\-family type
                                    
                                        **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                    
                                    .. attribute:: metric
                                    
                                        ISIS metric value(default=10)
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **default value**: 10
                                    
                                    .. attribute:: enabled
                                    
                                        When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    
                                        **type**: bool
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                            ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None
                                        self.metric = None
                                        self.enabled = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.Config, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines AFI\-SAFI State information
                                    
                                    .. attribute:: afi_name
                                    
                                        Address\-family type
                                    
                                        **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: safi_name
                                    
                                        Subsequent address\-family type
                                    
                                        **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: metric
                                    
                                        ISIS metric value(default=10)
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                        **default value**: 10
                                    
                                    .. attribute:: enabled
                                    
                                        When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                            ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None
                                        self.metric = None
                                        self.enabled = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.State, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                class MultiTopology(_Entity_):
                                    """
                                    This container defines multi\-topology address\-family configuration
                                    and state information. ISIS TLV 235, 237.
                                    
                                    .. attribute:: config
                                    
                                        This container defines AFI\-SAFI multi\-topology configuration parameters
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config>`
                                    
                                    .. attribute:: state
                                    
                                        This container defines AFI\-SAFI multi\-topology state information
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "multi-topology"
                                        self.yang_parent_name = "af"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "multi-topology"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        This container defines AFI\-SAFI multi\-topology configuration
                                        parameters
                                        
                                        .. attribute:: afi_name
                                        
                                            Address\-family type
                                        
                                            **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                        .. attribute:: safi_name
                                        
                                            Subsequent address\-family type
                                        
                                            **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "multi-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.Config, ['afi_name', 'safi_name'], name, value)


                                    class State(_Entity_):
                                        """
                                        This container defines AFI\-SAFI multi\-topology state information
                                        
                                        .. attribute:: afi_name
                                        
                                            Address\-family type
                                        
                                            **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: safi_name
                                        
                                            Subsequent address\-family type
                                        
                                            **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: enabled
                                        
                                            When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "multi-topology"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.AfiSafi.Af.MultiTopology.State, ['afi_name', 'safi_name', 'enabled'], name, value)





                        class SegmentRouting(_Entity_):
                            """
                            Configuration and operational state relating to segment routing.
                            
                            .. attribute:: config
                            
                                Configuration parameters relating to the configuration of segment routing for the IGP instance
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config>`
                            
                            .. attribute:: state
                            
                                Operational state parameters relating to segment routing for the IGP instance
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State>`
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "segment-routing"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State))])
                                self._leafs = OrderedDict()

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"
                                self._segment_path = lambda: "segment-routing"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting, [], name, value)

                            class Config(_Entity_):
                                """
                                Configuration parameters relating to the configuration of segment
                                routing for the IGP instance.
                                
                                .. attribute:: enabled
                                
                                    When this leaf is set to true, the segment routing extensions are utilised within the IGP
                                
                                    **type**: bool
                                
                                .. attribute:: srgb
                                
                                    A reference to the Segment Routing Global Block (SRGB) that is to be used by this IGP instance
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                                
                                .. attribute:: srlb
                                
                                    A reference to the Segment Routing Local Block (SRLB) that is to be advertised by the IGP instance
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "segment-routing"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('srgb', (YLeaf(YType.str, 'srgb'), ['str'])),
                                        ('srlb', (YLeaf(YType.str, 'srlb'), ['str'])),
                                    ])
                                    self.enabled = None
                                    self.srgb = None
                                    self.srlb = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.Config, ['enabled', 'srgb', 'srlb'], name, value)


                            class State(_Entity_):
                                """
                                Operational state parameters relating to segment routing for the
                                IGP instance.
                                
                                .. attribute:: enabled
                                
                                    When this leaf is set to true, the segment routing extensions are utilised within the IGP
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                .. attribute:: srgb
                                
                                    A reference to the Segment Routing Global Block (SRGB) that is to be used by this IGP instance
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srgbs.Srgb.Config>`
                                
                                    **config**: False
                                
                                .. attribute:: srlb
                                
                                    A reference to the Segment Routing Local Block (SRLB) that is to be advertised by the IGP instance
                                
                                    **type**: str
                                
                                    **refers to**:  :py:class:`local_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.SegmentRouting.Srlbs.Srlb.Config>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "segment-routing"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('srgb', (YLeaf(YType.str, 'srgb'), ['str'])),
                                        ('srlb', (YLeaf(YType.str, 'srlb'), ['str'])),
                                    ])
                                    self.enabled = None
                                    self.srgb = None
                                    self.srlb = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.SegmentRouting.State, ['enabled', 'srgb', 'srlb'], name, value)



                        class InterLevelPropagationPolicies(_Entity_):
                            """
                            Policies to propagate prefixes between IS\-IS levels.
                            
                            .. attribute:: level1_to_level2
                            
                                Policies relating to prefixes to be propagated from Level 1 to Level 2
                            
                                **type**:  :py:class:`Level1ToLevel2<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2>`
                            
                            .. attribute:: level2_to_level1
                            
                                Policies relating to prefixes to be propagated from Level2 to Level 1
                            
                                **type**:  :py:class:`Level2ToLevel1<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "inter-level-propagation-policies"
                                self.yang_parent_name = "global"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("level1-to-level2", ("level1_to_level2", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2)), ("level2-to-level1", ("level2_to_level1", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1))])
                                self._leafs = OrderedDict()

                                self.level1_to_level2 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2()
                                self.level1_to_level2.parent = self
                                self._children_name_map["level1_to_level2"] = "level1-to-level2"

                                self.level2_to_level1 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1()
                                self.level2_to_level1.parent = self
                                self._children_name_map["level2_to_level1"] = "level2-to-level1"
                                self._segment_path = lambda: "inter-level-propagation-policies"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies, [], name, value)

                            class Level1ToLevel2(_Entity_):
                                """
                                Policies relating to prefixes to be propagated from
                                Level 1 to Level 2.
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the propagation of prefixes from IS\-IS Level 1 to Level 2
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state parameters relating to the propagation of prefixes from IS\-IS Level 1 to Level 2
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "level1-to-level2"
                                    self.yang_parent_name = "inter-level-propagation-policies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "level1-to-level2"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the propagation
                                    of prefixes from IS\-IS Level 1 to Level 2.
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "level1-to-level2"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.Config, ['import_policy', 'default_import_policy'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state parameters relating to the
                                    propagation of prefixes from IS\-IS Level 1 to Level 2.
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **config**: False
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "level1-to-level2"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level1ToLevel2.State, ['import_policy', 'default_import_policy'], name, value)



                            class Level2ToLevel1(_Entity_):
                                """
                                Policies relating to prefixes to be propagated from
                                Level2 to Level 1.
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to the propagation of prefixes from IS\-IS Level 2 to Level 1
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state parameters relating to the propagation of prefixes from IS\-IS Level 2 to Level 1
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "level2-to-level1"
                                    self.yang_parent_name = "inter-level-propagation-policies"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "level2-to-level1"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to the propagation
                                    of prefixes from IS\-IS Level 2 to Level 1.
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "level2-to-level1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.Config, ['import_policy', 'default_import_policy'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state parameters relating to the propagation
                                    of prefixes from IS\-IS Level 2 to Level 1.
                                    
                                    .. attribute:: import_policy
                                    
                                        list of policy names in sequence to be applied on receiving a routing update in the current context, e.g., for the current peer group, neighbor, address family, etc
                                    
                                        **type**: list of str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_routing_policy.RoutingPolicy.PolicyDefinitions.PolicyDefinition>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: default_import_policy
                                    
                                        explicitly set a default policy if no policy definition in the import policy chain is satisfied
                                    
                                        **type**:  :py:class:`DefaultPolicyType<ydk.models.openconfig.openconfig_routing_policy.DefaultPolicyType>`
                                    
                                        **config**: False
                                    
                                        **default value**: REJECT_ROUTE
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "level2-to-level1"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('import_policy', (YLeafList(YType.str, 'import-policy'), ['str'])),
                                            ('default_import_policy', (YLeaf(YType.enumeration, 'default-import-policy'), [('ydk.models.openconfig.openconfig_routing_policy', 'DefaultPolicyType', '')])),
                                        ])
                                        self.import_policy = []
                                        self.default_import_policy = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Global.InterLevelPropagationPolicies.Level2ToLevel1.State, ['import_policy', 'default_import_policy'], name, value)





                    class Levels(_Entity_):
                        """
                        This container defines ISIS level configuration and state
                        information.
                        
                        .. attribute:: level
                        
                            Configuration and operational state parameters related to a particular level within the IS\-IS protocol instance
                        
                            **type**: list of    :py:class:`Level<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "levels"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("level", ("level", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level))])
                            self._leafs = OrderedDict()

                            self.level = YList(self)
                            self._segment_path = lambda: "levels"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels, [], name, value)

                        class Level(_Entity_):
                            """
                            Configuration and operational state parameters related to a
                            particular level within the IS\-IS protocol instance
                            
                            .. attribute:: level_number  (key)
                            
                                Reference to ISIS level\-number
                            
                                **type**: int
                            
                                    **range:** 1..2
                            
                                **refers to**:  :py:class:`level_number<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config>`
                            
                            .. attribute:: config
                            
                                This container defines ISIS level based configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config>`
                            
                            .. attribute:: state
                            
                                This container defines ISIS level state information
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State>`
                            
                                **config**: False
                            
                            .. attribute:: system_level_counters
                            
                                This container defines ISIS system level counters
                            
                                **type**:  :py:class:`SystemLevelCounters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters>`
                            
                            .. attribute:: link_state_database
                            
                                This container defines ISIS LSDB
                            
                                **type**:  :py:class:`LinkStateDatabase<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase>`
                            
                                **config**: False
                            
                            .. attribute:: traffic_engineering
                            
                                This container defines ISIS TE
                            
                                **type**:  :py:class:`TrafficEngineering<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering>`
                            
                            .. attribute:: route_preference
                            
                                This container defines Administrative Distance (or preference) assigned to ISIS routes (level1 internal, level2 internal, level1 external, level2 external)
                            
                                **type**:  :py:class:`RoutePreference<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference>`
                            
                            .. attribute:: authentication
                            
                                This container defines ISIS authentication
                            
                                **type**:  :py:class:`Authentication<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "level"
                                self.yang_parent_name = "levels"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['level_number']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State)), ("system-level-counters", ("system_level_counters", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters)), ("link-state-database", ("link_state_database", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase)), ("traffic-engineering", ("traffic_engineering", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering)), ("route-preference", ("route_preference", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication))])
                                self._leafs = OrderedDict([
                                    ('level_number', (YLeaf(YType.str, 'level-number'), ['int'])),
                                ])
                                self.level_number = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.system_level_counters = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters()
                                self.system_level_counters.parent = self
                                self._children_name_map["system_level_counters"] = "system-level-counters"

                                self.link_state_database = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase()
                                self.link_state_database.parent = self
                                self._children_name_map["link_state_database"] = "link-state-database"

                                self.traffic_engineering = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering()
                                self.traffic_engineering.parent = self
                                self._children_name_map["traffic_engineering"] = "traffic-engineering"

                                self.route_preference = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference()
                                self.route_preference.parent = self
                                self._children_name_map["route_preference"] = "route-preference"

                                self.authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"
                                self._segment_path = lambda: "level" + "[level-number='" + str(self.level_number) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level, ['level_number'], name, value)

                            class Config(_Entity_):
                                """
                                This container defines ISIS level based configuration.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: level_number
                                
                                    ISIS level number (level\-1, level\-2)
                                
                                    **type**: int
                                
                                        **range:** 1..2
                                
                                .. attribute:: metric_style
                                
                                    ISIS metric style types(narrow, wide)
                                
                                    **type**:  :py:class:`MetricStyle<ydk.models.openconfig.openconfig_isis_types.MetricStyle>`
                                
                                .. attribute:: authentication_check
                                
                                    When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                                
                                    **type**: bool
                                
                                    **default value**: true
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('level_number', (YLeaf(YType.uint8, 'level-number'), ['int'])),
                                        ('metric_style', (YLeaf(YType.enumeration, 'metric-style'), [('ydk.models.openconfig.openconfig_isis_types', 'MetricStyle', '')])),
                                        ('authentication_check', (YLeaf(YType.boolean, 'authentication-check'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self.level_number = None
                                    self.metric_style = None
                                    self.authentication_check = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Config, ['enabled', 'level_number', 'metric_style', 'authentication_check'], name, value)


                            class State(_Entity_):
                                """
                                This container defines ISIS level state information.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: level_number
                                
                                    ISIS level number (level\-1, level\-2)
                                
                                    **type**: int
                                
                                        **range:** 1..2
                                
                                    **config**: False
                                
                                .. attribute:: metric_style
                                
                                    ISIS metric style types(narrow, wide)
                                
                                    **type**:  :py:class:`MetricStyle<ydk.models.openconfig.openconfig_isis_types.MetricStyle>`
                                
                                    **config**: False
                                
                                .. attribute:: authentication_check
                                
                                    When set to true, reject all ISIS protocol PDUs that either have a mismatch in authentication\-type or authentication\-key
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: true
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('level_number', (YLeaf(YType.uint8, 'level-number'), ['int'])),
                                        ('metric_style', (YLeaf(YType.enumeration, 'metric-style'), [('ydk.models.openconfig.openconfig_isis_types', 'MetricStyle', '')])),
                                        ('authentication_check', (YLeaf(YType.boolean, 'authentication-check'), ['bool'])),
                                    ])
                                    self.enabled = None
                                    self.level_number = None
                                    self.metric_style = None
                                    self.authentication_check = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.State, ['enabled', 'level_number', 'metric_style', 'authentication_check'], name, value)


                            class SystemLevelCounters(_Entity_):
                                """
                                This container defines ISIS system level counters.
                                
                                .. attribute:: state
                                
                                    The container defines a list of system counters for the IS
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "system-level-counters"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State))])
                                    self._leafs = OrderedDict()

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "system-level-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters, [], name, value)

                                class State(_Entity_):
                                    """
                                    The container defines a list of system counters for the IS.
                                    
                                    .. attribute:: corrupted_lsps
                                    
                                        Number of corrupted in\-memory LSPs detected. LSPs received from the wire with a bad checksum are silently dropped and not counted. LSPs received from the wire with parse errors are counted by lsp\-errors. MIB Entry\: SysCorrLSPs
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: database_overloads
                                    
                                        Number of times the database has become overloaded. MIB entry\: SysLSPL(Level)DbaseOloads
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: manual_address_drop_from_areas
                                    
                                        Number of times a manual address has been dropped from area. MIB Entry\: SysManAddrDropFromAreas
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: exceed_max_seq_nums
                                    
                                        The number of times the system has attempted to exceed the maximum sequence number. MIB Entry\: SysAttmptToExMaxSeqNums
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: seq_num_skips
                                    
                                        Number of times a sequence number skip has occurred. MIB Entry\: SysSeqNumSkips
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: own_lsp_purges
                                    
                                        Number of times a zero\-aged copy of the system's own LSP is received from some other node. MIB Entry\: isisSysOwnLSPPurges
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: id_len_mismatch
                                    
                                        Number of times a PDU is received with a different value for ID field length from that of the receiving system. MIB Entry\: isisSysIDFieldLenMismatches
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: part_changes
                                    
                                        The number of partition changes detected. MIB Entry\: SysPartChanges
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: max_area_address_mismatches
                                    
                                        Number of times a PDU is received with a different value for MaximumAreaAddresses from that of the receiving system. MIB Entry\: SysMaxAreaAddrMismatches
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: auth_fails
                                    
                                        The number of authentication key failures. MIB Entry\: SysAuthFails
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: spf_runs
                                    
                                        The number of times SPF was ran at this level
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: auth_type_fails
                                    
                                        The number of authentication type mismatches
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: lsp_errors
                                    
                                        The number of received LSPs with errors
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "system-level-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('corrupted_lsps', (YLeaf(YType.uint32, 'corrupted-lsps'), ['int'])),
                                            ('database_overloads', (YLeaf(YType.uint32, 'database-overloads'), ['int'])),
                                            ('manual_address_drop_from_areas', (YLeaf(YType.uint32, 'manual-address-drop-from-areas'), ['int'])),
                                            ('exceed_max_seq_nums', (YLeaf(YType.uint32, 'exceed-max-seq-nums'), ['int'])),
                                            ('seq_num_skips', (YLeaf(YType.uint32, 'seq-num-skips'), ['int'])),
                                            ('own_lsp_purges', (YLeaf(YType.uint32, 'own-lsp-purges'), ['int'])),
                                            ('id_len_mismatch', (YLeaf(YType.uint32, 'id-len-mismatch'), ['int'])),
                                            ('part_changes', (YLeaf(YType.uint32, 'part-changes'), ['int'])),
                                            ('max_area_address_mismatches', (YLeaf(YType.uint32, 'max-area-address-mismatches'), ['int'])),
                                            ('auth_fails', (YLeaf(YType.uint32, 'auth-fails'), ['int'])),
                                            ('spf_runs', (YLeaf(YType.uint32, 'spf-runs'), ['int'])),
                                            ('auth_type_fails', (YLeaf(YType.uint32, 'auth-type-fails'), ['int'])),
                                            ('lsp_errors', (YLeaf(YType.uint32, 'lsp-errors'), ['int'])),
                                        ])
                                        self.corrupted_lsps = None
                                        self.database_overloads = None
                                        self.manual_address_drop_from_areas = None
                                        self.exceed_max_seq_nums = None
                                        self.seq_num_skips = None
                                        self.own_lsp_purges = None
                                        self.id_len_mismatch = None
                                        self.part_changes = None
                                        self.max_area_address_mismatches = None
                                        self.auth_fails = None
                                        self.spf_runs = None
                                        self.auth_type_fails = None
                                        self.lsp_errors = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.SystemLevelCounters.State, ['corrupted_lsps', 'database_overloads', 'manual_address_drop_from_areas', 'exceed_max_seq_nums', 'seq_num_skips', 'own_lsp_purges', 'id_len_mismatch', 'part_changes', 'max_area_address_mismatches', 'auth_fails', 'spf_runs', 'auth_type_fails', 'lsp_errors'], name, value)



                            class LinkStateDatabase(_Entity_):
                                """
                                This container defines ISIS LSDB.
                                
                                .. attribute:: lsp
                                
                                    This list describes LSPs in the LSDB
                                
                                    **type**: list of    :py:class:`Lsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "link-state-database"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("lsp", ("lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp))])
                                    self._leafs = OrderedDict()

                                    self.lsp = YList(self)
                                    self._segment_path = lambda: "link-state-database"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase, [], name, value)

                                class Lsp(_Entity_):
                                    """
                                    This list describes LSPs in the LSDB.
                                    
                                    .. attribute:: lsp_id  (key)
                                    
                                        A reference to the Link State PDU ID
                                    
                                        **type**: str
                                    
                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9][0\-9]\-[0\-9][0\-9]$
                                    
                                        **refers to**:  :py:class:`lsp_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: state
                                    
                                        State parameters of Link State PDU
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: tlvs
                                    
                                        This container defines Link State PDU State TLVs
                                    
                                        **type**:  :py:class:`Tlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: undefined_tlvs
                                    
                                        Surrounding container for a list of unknown TLVs
                                    
                                        **type**:  :py:class:`UndefinedTlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "lsp"
                                        self.yang_parent_name = "link-state-database"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['lsp_id']
                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State)), ("tlvs", ("tlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs)), ("undefined-tlvs", ("undefined_tlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs))])
                                        self._leafs = OrderedDict([
                                            ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                        ])
                                        self.lsp_id = None

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.tlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs()
                                        self.tlvs.parent = self
                                        self._children_name_map["tlvs"] = "tlvs"

                                        self.undefined_tlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs()
                                        self.undefined_tlvs.parent = self
                                        self._children_name_map["undefined_tlvs"] = "undefined-tlvs"
                                        self._segment_path = lambda: "lsp" + "[lsp-id='" + str(self.lsp_id) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp, ['lsp_id'], name, value)

                                    class State(_Entity_):
                                        """
                                        State parameters of Link State PDU.
                                        
                                        .. attribute:: lsp_id
                                        
                                            LSP ID of the LSP
                                        
                                            **type**: str
                                        
                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9][0\-9]\-[0\-9][0\-9]$
                                        
                                            **config**: False
                                        
                                        .. attribute:: maximum_area_addresses
                                        
                                            Number of area addresses permitted for this ISs area. 0 indicates the IS only supports three area addresses (by default). Any number inclusive of 1 and 254 indicates the number of areas allowed
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                        .. attribute:: version
                                        
                                            PDU version. This is set to 1
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                            **default value**: 1
                                        
                                        .. attribute:: version2
                                        
                                            PDU version2. This is set to 1
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                            **default value**: 1
                                        
                                        .. attribute:: id_length
                                        
                                            Length of the ID field of NSAP addresses and NETs used in this routing domain
                                        
                                            **type**: int
                                        
                                                **range:** 0..255
                                        
                                            **config**: False
                                        
                                        .. attribute:: pdu_type
                                        
                                            Link State PDU type
                                        
                                            **type**:  :py:class:`PduType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State.PduType>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: remaining_lifetime
                                        
                                            Remaining lifetime in seconds before the LSP expiration
                                        
                                            **type**: int
                                        
                                                **range:** 0..65535
                                        
                                            **config**: False
                                        
                                            **units**: seconds
                                        
                                        .. attribute:: sequence_number
                                        
                                            Sequence number of the LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..4294967295
                                        
                                            **config**: False
                                        
                                        .. attribute:: checksum
                                        
                                            Checksum of the LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..65535
                                        
                                            **config**: False
                                        
                                        .. attribute:: pdu_length
                                        
                                            Total length of the LSP
                                        
                                            **type**: int
                                        
                                                **range:** 0..65535
                                        
                                            **config**: False
                                        
                                        .. attribute:: flags
                                        
                                            LSP Type\-Block flags
                                        
                                            **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State.Flags>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: is_type
                                        
                                            Type of neighboring system
                                        
                                            **type**: int
                                        
                                                **range:** 1..2
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "lsp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lsp_id', (YLeaf(YType.str, 'lsp-id'), ['str'])),
                                                ('maximum_area_addresses', (YLeaf(YType.uint8, 'maximum-area-addresses'), ['int'])),
                                                ('version', (YLeaf(YType.uint8, 'version'), ['int'])),
                                                ('version2', (YLeaf(YType.uint8, 'version2'), ['int'])),
                                                ('id_length', (YLeaf(YType.uint8, 'id-length'), ['int'])),
                                                ('pdu_type', (YLeaf(YType.enumeration, 'pdu-type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State.PduType')])),
                                                ('remaining_lifetime', (YLeaf(YType.uint16, 'remaining-lifetime'), ['int'])),
                                                ('sequence_number', (YLeaf(YType.uint32, 'sequence-number'), ['int'])),
                                                ('checksum', (YLeaf(YType.uint16, 'checksum'), ['int'])),
                                                ('pdu_length', (YLeaf(YType.uint16, 'pdu-length'), ['int'])),
                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State.Flags')])),
                                                ('is_type', (YLeaf(YType.uint8, 'is-type'), ['int'])),
                                            ])
                                            self.lsp_id = None
                                            self.maximum_area_addresses = None
                                            self.version = None
                                            self.version2 = None
                                            self.id_length = None
                                            self.pdu_type = None
                                            self.remaining_lifetime = None
                                            self.sequence_number = None
                                            self.checksum = None
                                            self.pdu_length = None
                                            self.flags = []
                                            self.is_type = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.State, ['lsp_id', 'maximum_area_addresses', 'version', 'version2', 'id_length', 'pdu_type', 'remaining_lifetime', 'sequence_number', 'checksum', 'pdu_length', 'flags', 'is_type'], name, value)

                                        class Flags(Enum):
                                            """
                                            Flags (Enum Class)

                                            .. data:: PARTITION_REPAIR = 0

                                                When set, the originator supports partition

                                                repair.

                                            .. data:: ATTACHED_ERROR = 1

                                                When set, the originator is attached to another

                                                area using the referred metric.

                                            .. data:: ATTACHED_EXPENSE = 2

                                                When set, the originator is attached to another

                                                area using the referred metric.

                                            .. data:: ATTACHED_DELAY = 3

                                                When set, the originator is attached to another

                                                area using the referred metric.

                                            .. data:: ATTACHED_DEFAULT = 4

                                                When set, the originator is attached to another

                                                area using the referred metric.

                                            .. data:: OVERLOAD = 5

                                                When set, the originator is overloaded, and must

                                                be avoided in path calculation.

                                            """

                                            PARTITION_REPAIR = Enum.YLeaf(0, "PARTITION_REPAIR")

                                            ATTACHED_ERROR = Enum.YLeaf(1, "ATTACHED_ERROR")

                                            ATTACHED_EXPENSE = Enum.YLeaf(2, "ATTACHED_EXPENSE")

                                            ATTACHED_DELAY = Enum.YLeaf(3, "ATTACHED_DELAY")

                                            ATTACHED_DEFAULT = Enum.YLeaf(4, "ATTACHED_DEFAULT")

                                            OVERLOAD = Enum.YLeaf(5, "OVERLOAD")


                                        class PduType(Enum):
                                            """
                                            PduType (Enum Class)

                                            .. data:: LEVEL_1 = 0

                                                This enum describes ISIS level 1 PDU.

                                            .. data:: LEVEL_2 = 1

                                                This enum describes ISIS level 2 PDU.

                                            """

                                            LEVEL_1 = Enum.YLeaf(0, "LEVEL_1")

                                            LEVEL_2 = Enum.YLeaf(1, "LEVEL_2")



                                    class Tlvs(_Entity_):
                                        """
                                        This container defines Link State PDU State TLVs.
                                        
                                        .. attribute:: tlv
                                        
                                            List of TLV types in the LSDB for the specified LSP
                                        
                                            **type**: list of    :py:class:`Tlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "tlvs"
                                            self.yang_parent_name = "lsp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tlv", ("tlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv))])
                                            self._leafs = OrderedDict()

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "tlvs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs, [], name, value)

                                        class Tlv(_Entity_):
                                            """
                                            List of TLV types in the LSDB for the specified LSP.
                                            
                                            .. attribute:: type  (key)
                                            
                                                Reference to the TLV's type
                                            
                                                **type**:  :py:class:`ISISTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISTLVTYPE>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: state
                                            
                                                Operational state parameters relating to the specified LSP
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: area_address
                                            
                                                This container defines TLV 1
                                            
                                                **type**:  :py:class:`AreaAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: lsp_buffer_size
                                            
                                                This container defines TLV 14 \- the LSP Buffer Size TLV
                                            
                                                **type**:  :py:class:`LspBufferSize<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: nlpid
                                            
                                                This container defines TLV 129
                                            
                                                **type**:  :py:class:`Nlpid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: hostname
                                            
                                                This container defines TLV 137
                                            
                                                **type**:  :py:class:`Hostname<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv4_interface_addresses
                                            
                                                This container defines TLV 132
                                            
                                                **type**:  :py:class:`Ipv4InterfaceAddresses<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv6_interface_addresses
                                            
                                                This container defines TLV 232
                                            
                                                **type**:  :py:class:`Ipv6InterfaceAddresses<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv4_te_router_id
                                            
                                                This container defines TLV 134
                                            
                                                **type**:  :py:class:`Ipv4TeRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv6_te_router_id
                                            
                                                This container defines TLV 140
                                            
                                                **type**:  :py:class:`Ipv6TeRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: instance_ids
                                            
                                                This container defines ISIS Instance Identifier TLV
                                            
                                                **type**:  :py:class:`InstanceIds<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv4_srlgs
                                            
                                                This container defines ISIS SRLG TLV 138
                                            
                                                **type**:  :py:class:`Ipv4Srlgs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv6_srlgs
                                            
                                                This container defines ISIS SRLG TLV
                                            
                                                **type**:  :py:class:`Ipv6Srlgs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: purge_oi
                                            
                                                This container defines ISIS purge TLV
                                            
                                                **type**:  :py:class:`PurgeOi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: router_capabilities
                                            
                                                This container defines router capabilities
                                            
                                                **type**:  :py:class:`RouterCapabilities<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: is_reachability
                                            
                                                This container describes list of ISIS neighbors and attributes
                                            
                                                **type**:  :py:class:`IsReachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv4_internal_reachability
                                            
                                                This container defines list of IPv4 internal reachability information
                                            
                                                **type**:  :py:class:`Ipv4InternalReachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv4_external_reachability
                                            
                                                This container defines list of IPv4 external reachability information
                                            
                                                **type**:  :py:class:`Ipv4ExternalReachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: authentication
                                            
                                                This container defines authentication information of the node
                                            
                                                **type**:  :py:class:`Authentication<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: extended_is_reachability
                                            
                                                This container defines list of ISIS extended reachability neighbors
                                            
                                                **type**:  :py:class:`ExtendedIsReachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: extended_ipv4_reachability
                                            
                                                This container defines list of IPv4 extended reachability information
                                            
                                                **type**:  :py:class:`ExtendedIpv4Reachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: ipv6_reachability
                                            
                                                This container defines list of IPv6 reachability information
                                            
                                                **type**:  :py:class:`Ipv6Reachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: multi_topology
                                            
                                                This container defines the topology supported
                                            
                                                **type**:  :py:class:`MultiTopology<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: isis_neighbor_attribute
                                            
                                                This container defines list of ISIS topology neighbors for extended ISIS LSP (multiple system IDs). 
                                            
                                                **type**:  :py:class:`IsisNeighborAttribute<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: is_alias_id
                                            
                                                This container defines the IS\-Alias TLV which allows extension\-capable ISs to recognize the Originating System of an Extended LSP set. It identifies the Normal system\- id of the Originating System
                                            
                                                **type**:  :py:class:`IsAliasId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: mt_isn
                                            
                                                This container defines list of ISIS multi\-topology neighbors
                                            
                                                **type**:  :py:class:`MtIsn<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: mt_isis_neighbor_attribute
                                            
                                                This container defines list of ISIS multi\-topology neighbors
                                            
                                                **type**:  :py:class:`MtIsisNeighborAttribute<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: mt_ipv4_reachability
                                            
                                                This container defines list of IPv4 reachability Information in multi\-topology environment
                                            
                                                **type**:  :py:class:`MtIpv4Reachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: mt_ipv6_reachability
                                            
                                                This container defines list of IPv6 reachability information in multi \- topology environment
                                            
                                                **type**:  :py:class:`MtIpv6Reachability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "tlvs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['type']
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State)), ("area-address", ("area_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress)), ("lsp-buffer-size", ("lsp_buffer_size", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize)), ("nlpid", ("nlpid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid)), ("hostname", ("hostname", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname)), ("ipv4-interface-addresses", ("ipv4_interface_addresses", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses)), ("ipv6-interface-addresses", ("ipv6_interface_addresses", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses)), ("ipv4-te-router-id", ("ipv4_te_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId)), ("ipv6-te-router-id", ("ipv6_te_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId)), ("instance-ids", ("instance_ids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds)), ("ipv4-srlgs", ("ipv4_srlgs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs)), ("ipv6-srlgs", ("ipv6_srlgs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs)), ("purge-oi", ("purge_oi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi)), ("router-capabilities", ("router_capabilities", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities)), ("is-reachability", ("is_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability)), ("ipv4-internal-reachability", ("ipv4_internal_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability)), ("ipv4-external-reachability", ("ipv4_external_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication)), ("extended-is-reachability", ("extended_is_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability)), ("extended-ipv4-reachability", ("extended_ipv4_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability)), ("ipv6-reachability", ("ipv6_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability)), ("multi-topology", ("multi_topology", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology)), ("isis-neighbor-attribute", ("isis_neighbor_attribute", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute)), ("is-alias-id", ("is_alias_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId)), ("mt-isn", ("mt_isn", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn)), ("mt-isis-neighbor-attribute", ("mt_isis_neighbor_attribute", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute)), ("mt-ipv4-reachability", ("mt_ipv4_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability)), ("mt-ipv6-reachability", ("mt_ipv6_reachability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability))])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISTLVTYPE')])),
                                                ])
                                                self.type = None

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"

                                                self.area_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress()
                                                self.area_address.parent = self
                                                self._children_name_map["area_address"] = "area-address"

                                                self.lsp_buffer_size = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize()
                                                self.lsp_buffer_size.parent = self
                                                self._children_name_map["lsp_buffer_size"] = "lsp-buffer-size"

                                                self.nlpid = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid()
                                                self.nlpid.parent = self
                                                self._children_name_map["nlpid"] = "nlpid"

                                                self.hostname = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname()
                                                self.hostname.parent = self
                                                self._children_name_map["hostname"] = "hostname"

                                                self.ipv4_interface_addresses = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses()
                                                self.ipv4_interface_addresses.parent = self
                                                self._children_name_map["ipv4_interface_addresses"] = "ipv4-interface-addresses"

                                                self.ipv6_interface_addresses = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses()
                                                self.ipv6_interface_addresses.parent = self
                                                self._children_name_map["ipv6_interface_addresses"] = "ipv6-interface-addresses"

                                                self.ipv4_te_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId()
                                                self.ipv4_te_router_id.parent = self
                                                self._children_name_map["ipv4_te_router_id"] = "ipv4-te-router-id"

                                                self.ipv6_te_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId()
                                                self.ipv6_te_router_id.parent = self
                                                self._children_name_map["ipv6_te_router_id"] = "ipv6-te-router-id"

                                                self.instance_ids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds()
                                                self.instance_ids.parent = self
                                                self._children_name_map["instance_ids"] = "instance-ids"

                                                self.ipv4_srlgs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs()
                                                self.ipv4_srlgs.parent = self
                                                self._children_name_map["ipv4_srlgs"] = "ipv4-srlgs"

                                                self.ipv6_srlgs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs()
                                                self.ipv6_srlgs.parent = self
                                                self._children_name_map["ipv6_srlgs"] = "ipv6-srlgs"

                                                self.purge_oi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi()
                                                self.purge_oi.parent = self
                                                self._children_name_map["purge_oi"] = "purge-oi"

                                                self.router_capabilities = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities()
                                                self.router_capabilities.parent = self
                                                self._children_name_map["router_capabilities"] = "router-capabilities"

                                                self.is_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability()
                                                self.is_reachability.parent = self
                                                self._children_name_map["is_reachability"] = "is-reachability"

                                                self.ipv4_internal_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability()
                                                self.ipv4_internal_reachability.parent = self
                                                self._children_name_map["ipv4_internal_reachability"] = "ipv4-internal-reachability"

                                                self.ipv4_external_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability()
                                                self.ipv4_external_reachability.parent = self
                                                self._children_name_map["ipv4_external_reachability"] = "ipv4-external-reachability"

                                                self.authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication()
                                                self.authentication.parent = self
                                                self._children_name_map["authentication"] = "authentication"

                                                self.extended_is_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability()
                                                self.extended_is_reachability.parent = self
                                                self._children_name_map["extended_is_reachability"] = "extended-is-reachability"

                                                self.extended_ipv4_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability()
                                                self.extended_ipv4_reachability.parent = self
                                                self._children_name_map["extended_ipv4_reachability"] = "extended-ipv4-reachability"

                                                self.ipv6_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability()
                                                self.ipv6_reachability.parent = self
                                                self._children_name_map["ipv6_reachability"] = "ipv6-reachability"

                                                self.multi_topology = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology()
                                                self.multi_topology.parent = self
                                                self._children_name_map["multi_topology"] = "multi-topology"

                                                self.isis_neighbor_attribute = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute()
                                                self.isis_neighbor_attribute.parent = self
                                                self._children_name_map["isis_neighbor_attribute"] = "isis-neighbor-attribute"

                                                self.is_alias_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId()
                                                self.is_alias_id.parent = self
                                                self._children_name_map["is_alias_id"] = "is-alias-id"

                                                self.mt_isn = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn()
                                                self.mt_isn.parent = self
                                                self._children_name_map["mt_isn"] = "mt-isn"

                                                self.mt_isis_neighbor_attribute = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute()
                                                self.mt_isis_neighbor_attribute.parent = self
                                                self._children_name_map["mt_isis_neighbor_attribute"] = "mt-isis-neighbor-attribute"

                                                self.mt_ipv4_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability()
                                                self.mt_ipv4_reachability.parent = self
                                                self._children_name_map["mt_ipv4_reachability"] = "mt-ipv4-reachability"

                                                self.mt_ipv6_reachability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability()
                                                self.mt_ipv6_reachability.parent = self
                                                self._children_name_map["mt_ipv6_reachability"] = "mt-ipv6-reachability"
                                                self._segment_path = lambda: "tlv" + "[type='" + str(self.type) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv, ['type'], name, value)

                                            class State(_Entity_):
                                                """
                                                Operational state parameters relating to the specified
                                                LSP
                                                
                                                .. attribute:: type
                                                
                                                    The type of TLV being described. The type of TLV is expressed as a canonical name
                                                
                                                    **type**:  :py:class:`ISISTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISTLVTYPE>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISTLVTYPE')])),
                                                    ])
                                                    self.type = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.State, ['type'], name, value)


                                            class AreaAddress(_Entity_):
                                                """
                                                This container defines TLV 1.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 1
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "area-address"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "area-address"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 1.
                                                    
                                                    .. attribute:: address
                                                    
                                                        Area adress(es) of the IS. Set of manual area addresses of this IS
                                                    
                                                        **type**: list of str
                                                    
                                                            **pattern:** ^[0\-9A\-Fa\-f]{2}\\.([0\-9A\-Fa\-f]{4}\\.){0,3}$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "area-address"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.AreaAddress.State, ['address'], name, value)



                                            class LspBufferSize(_Entity_):
                                                """
                                                This container defines TLV 14 \- the LSP Buffer Size
                                                TLV.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of TLV 14
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "lsp-buffer-size"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "lsp-buffer-size"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of TLV 14.
                                                    
                                                    .. attribute:: size
                                                    
                                                        The maximum MTU that the advertising system can receive, expressed in bytes
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..65535
                                                    
                                                        **config**: False
                                                    
                                                        **units**: bytes
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "lsp-buffer-size"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('size', (YLeaf(YType.uint16, 'size'), ['int'])),
                                                        ])
                                                        self.size = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.LspBufferSize.State, ['size'], name, value)



                                            class Nlpid(_Entity_):
                                                """
                                                This container defines TLV 129.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 129
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "nlpid"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "nlpid"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 129.
                                                    
                                                    .. attribute:: nlpid
                                                    
                                                        Protocol supported. IPv4 is defined as (0xcc) and IPv6 \- (0x8e)
                                                    
                                                        **type**: list of   :py:class:`Nlpid_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State.Nlpid_>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "nlpid"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('nlpid', (YLeafList(YType.enumeration, 'nlpid'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State.Nlpid_')])),
                                                        ])
                                                        self.nlpid = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Nlpid.State, ['nlpid'], name, value)

                                                    class Nlpid_(Enum):
                                                        """
                                                        Nlpid\_ (Enum Class)

                                                        .. data:: IPV4 = 0

                                                            IPv4 Address family.

                                                        .. data:: IPV6 = 1

                                                            IPv6 Address family.

                                                        """

                                                        IPV4 = Enum.YLeaf(0, "IPV4")

                                                        IPV6 = Enum.YLeaf(1, "IPV6")




                                            class Hostname(_Entity_):
                                                """
                                                This container defines TLV 137.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 137
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "hostname"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "hostname"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 137.
                                                    
                                                    .. attribute:: hostname
                                                    
                                                        Name of the node
                                                    
                                                        **type**: list of str
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "hostname"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('hostname', (YLeafList(YType.str, 'hostname'), ['str'])),
                                                        ])
                                                        self.hostname = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Hostname.State, ['hostname'], name, value)



                                            class Ipv4InterfaceAddresses(_Entity_):
                                                """
                                                This container defines TLV 132.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 132
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv4-interface-addresses"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "ipv4-interface-addresses"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 132.
                                                    
                                                    .. attribute:: address
                                                    
                                                        IPv4 address(es) of the interface corresponding to the SNPA over which this PDU is to be transmitted
                                                    
                                                        **type**: list of str
                                                    
                                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv4-interface-addresses"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InterfaceAddresses.State, ['address'], name, value)



                                            class Ipv6InterfaceAddresses(_Entity_):
                                                """
                                                This container defines TLV 232.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 232
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv6-interface-addresses"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "ipv6-interface-addresses"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 232.
                                                    
                                                    .. attribute:: address
                                                    
                                                        IPv6 interface addresses of the node.  MUST contain only the non\-link\-local IPv6 addresses assigned to the IS
                                                    
                                                        **type**: list of str
                                                    
                                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv6-interface-addresses"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                        ])
                                                        self.address = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6InterfaceAddresses.State, ['address'], name, value)



                                            class Ipv4TeRouterId(_Entity_):
                                                """
                                                This container defines TLV 134.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 134
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv4-te-router-id"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "ipv4-te-router-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 134.
                                                    
                                                    .. attribute:: router_id
                                                    
                                                        IPv4 Traffic Engineering router ID of the node. For traffic engineering, it guarantees that we have a single stable address that can always be referenced in a path that will be reachable from multiple hops away, regardless of the state of the node's interfaces
                                                    
                                                        **type**: list of str
                                                    
                                                            **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv4-te-router-id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('router_id', (YLeafList(YType.str, 'router-id'), ['str'])),
                                                        ])
                                                        self.router_id = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4TeRouterId.State, ['router_id'], name, value)



                                            class Ipv6TeRouterId(_Entity_):
                                                """
                                                This container defines TLV 140.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of ISIS TLV 140
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv6-te-router-id"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "ipv6-te-router-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of ISIS TLV 140.
                                                    
                                                    .. attribute:: router_id
                                                    
                                                        IPv6 Traffic Engineering router ID of the node. For traffic engineering, it guarantees that we have a single stable address that can always be referenced in a path that will be reachable from multiple hops away, regardless of the state of the node's interfaces
                                                    
                                                        **type**: list of str
                                                    
                                                            **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "ipv6-te-router-id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('router_id', (YLeafList(YType.str, 'router-id'), ['str'])),
                                                        ])
                                                        self.router_id = []
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6TeRouterId.State, ['router_id'], name, value)



                                            class InstanceIds(_Entity_):
                                                """
                                                This container defines ISIS Instance Identifier TLV.
                                                
                                                .. attribute:: instance_id
                                                
                                                    A list of instance IDs received within TLV 7 within an IS\-IS LSP. In the case that more than one instance of TLV 7 is included in the LSP, the instance IDs specified within the instances are concatenated within this list
                                                
                                                    **type**: list of    :py:class:`InstanceId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "instance-ids"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("instance-id", ("instance_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId))])
                                                    self._leafs = OrderedDict()

                                                    self.instance_id = YList(self)
                                                    self._segment_path = lambda: "instance-ids"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds, [], name, value)

                                                class InstanceId(_Entity_):
                                                    """
                                                    A list of instance IDs received within TLV 7 within an
                                                    IS\-IS LSP. In the case that more than one instance of
                                                    TLV 7 is included in the LSP, the instance IDs specified
                                                    within the instances are concatenated within this
                                                    list.
                                                    
                                                    .. attribute:: instance_id  (key)
                                                    
                                                        Reference to the unique instance ID
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..65535
                                                    
                                                        **refers to**:  :py:class:`instance_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: state
                                                    
                                                        State parameters of ISIS TLV 7
                                                    
                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "instance-id"
                                                        self.yang_parent_name = "instance-ids"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_id']
                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State))])
                                                        self._leafs = OrderedDict([
                                                            ('instance_id', (YLeaf(YType.str, 'instance-id'), ['int'])),
                                                        ])
                                                        self.instance_id = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "instance-id" + "[instance-id='" + str(self.instance_id) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId, ['instance_id'], name, value)

                                                    class State(_Entity_):
                                                        """
                                                        State parameters of ISIS TLV 7.
                                                        
                                                        .. attribute:: instance_id
                                                        
                                                            An Instance Identifier (IID) to uniquely identify an IS\-IS instance. When the IID = 0, the list of supported ITIDs MUST NOT be present. An IID\-TLV with IID = 0 MUST NOT appear in an SNP or LSP. When the TLV appears (with a non\-zero IID) in an SNP or LSP, exactly one ITID. MUST be present indicating the topology with which the PDU is associated. If no ITIDs or multiple ITIDs are present or the IID is zero, then the PDU MUST be ignored
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..65535
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: topology_id
                                                        
                                                            Instance\-Specific Topology Identifiers (ITIDs)
                                                        
                                                            **type**: list of int
                                                        
                                                                **range:** 0..65535
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "instance-id"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_id', (YLeaf(YType.uint16, 'instance-id'), ['int'])),
                                                                ('topology_id', (YLeafList(YType.uint16, 'topology-id'), ['int'])),
                                                            ])
                                                            self.instance_id = None
                                                            self.topology_id = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.InstanceIds.InstanceId.State, ['instance_id', 'topology_id'], name, value)




                                            class Ipv4Srlgs(_Entity_):
                                                """
                                                This container defines ISIS SRLG TLV 138.
                                                
                                                .. attribute:: ipv4_srlg
                                                
                                                    Instance of the IPv4 SRLG TLV
                                                
                                                    **type**: list of    :py:class:`Ipv4Srlg<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv4-srlgs"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv4-srlg", ("ipv4_srlg", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv4_srlg = YList(self)
                                                    self._segment_path = lambda: "ipv4-srlgs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs, [], name, value)

                                                class Ipv4Srlg(_Entity_):
                                                    """
                                                    Instance of the IPv4 SRLG TLV
                                                    
                                                    .. attribute:: instance_number  (key)
                                                    
                                                        Reference to the instance number of TLV 138
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..4294967295
                                                    
                                                        **refers to**:  :py:class:`instance_number<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: state
                                                    
                                                        State parameters of TLV 138
                                                    
                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "ipv4-srlg"
                                                        self.yang_parent_name = "ipv4-srlgs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_number']
                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State))])
                                                        self._leafs = OrderedDict([
                                                            ('instance_number', (YLeaf(YType.str, 'instance-number'), ['int'])),
                                                        ])
                                                        self.instance_number = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "ipv4-srlg" + "[instance-number='" + str(self.instance_number) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg, ['instance_number'], name, value)

                                                    class State(_Entity_):
                                                        """
                                                        State parameters of TLV 138.
                                                        
                                                        .. attribute:: instance_number
                                                        
                                                            An arbitrary unsigned 32\-bit integer used to disambiguate the instance of TLV 138. The instance identifier is synthesised by the system and may be renumbered for the same SRLG definition in subsequent advertised LSPs if (and only if) the entire list of SRLGs is replaced
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4294967295
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: system_id
                                                        
                                                            Neighbor system ID
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: psn_number
                                                        
                                                            Pseudonode number if the neighbor is on a LAN interface
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..255
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: flags
                                                        
                                                            SRLG flags
                                                        
                                                            **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State.Flags>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: ipv4_interface_address
                                                        
                                                            IPv4 interface address
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: ipv4_neighbor_address
                                                        
                                                            IPv4 neighbor address
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: srlg_value
                                                        
                                                            List of SRLG values
                                                        
                                                            **type**: list of int
                                                        
                                                                **range:** 0..4294967295
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv4-srlg"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ('psn_number', (YLeaf(YType.uint8, 'psn-number'), ['int'])),
                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State.Flags')])),
                                                                ('ipv4_interface_address', (YLeaf(YType.str, 'ipv4-interface-address'), ['str'])),
                                                                ('ipv4_neighbor_address', (YLeaf(YType.str, 'ipv4-neighbor-address'), ['str'])),
                                                                ('srlg_value', (YLeafList(YType.uint32, 'srlg-value'), ['int'])),
                                                            ])
                                                            self.instance_number = None
                                                            self.system_id = None
                                                            self.psn_number = None
                                                            self.flags = []
                                                            self.ipv4_interface_address = None
                                                            self.ipv4_neighbor_address = None
                                                            self.srlg_value = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4Srlgs.Ipv4Srlg.State, ['instance_number', 'system_id', 'psn_number', 'flags', 'ipv4_interface_address', 'ipv4_neighbor_address', 'srlg_value'], name, value)

                                                        class Flags(Enum):
                                                            """
                                                            Flags (Enum Class)

                                                            .. data:: NUMBERED = 0

                                                                When set, the interface is numbered, whereas if

                                                                unset indicates that the interface is

                                                                unnumbered.

                                                            """

                                                            NUMBERED = Enum.YLeaf(0, "NUMBERED")





                                            class Ipv6Srlgs(_Entity_):
                                                """
                                                This container defines ISIS SRLG TLV.
                                                
                                                .. attribute:: ipv6_srlg
                                                
                                                    Instance of the IPv6 SRLG TLV
                                                
                                                    **type**: list of    :py:class:`Ipv6Srlg<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv6-srlgs"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("ipv6-srlg", ("ipv6_srlg", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg))])
                                                    self._leafs = OrderedDict()

                                                    self.ipv6_srlg = YList(self)
                                                    self._segment_path = lambda: "ipv6-srlgs"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs, [], name, value)

                                                class Ipv6Srlg(_Entity_):
                                                    """
                                                    Instance of the IPv6 SRLG TLV.
                                                    
                                                    .. attribute:: instance_number  (key)
                                                    
                                                        Reference to the instance number of the IPv6 Shared Risk Link Group (SRLG) TLV
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..4294967295
                                                    
                                                        **refers to**:  :py:class:`instance_number<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: state
                                                    
                                                        State parameters of TLV 139
                                                    
                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "ipv6-srlg"
                                                        self.yang_parent_name = "ipv6-srlgs"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_number']
                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State))])
                                                        self._leafs = OrderedDict([
                                                            ('instance_number', (YLeaf(YType.str, 'instance-number'), ['int'])),
                                                        ])
                                                        self.instance_number = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"
                                                        self._segment_path = lambda: "ipv6-srlg" + "[instance-number='" + str(self.instance_number) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg, ['instance_number'], name, value)

                                                    class State(_Entity_):
                                                        """
                                                        State parameters of TLV 139.
                                                        
                                                        .. attribute:: instance_number
                                                        
                                                            An arbitrary unsigned 32\-bit integer used to disambiguate the instance of TLV 138. The instance identifier is synthesised by the system and may be renumbered for the same SRLG definition in subsequent advertised LSPs if (and only if) the entire list of SRLGs is replaced
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4294967295
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: system_id
                                                        
                                                            Neighbor system ID
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: psn_number
                                                        
                                                            Pseudonode number if the neighbor is on a LAN interface
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..255
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: flags
                                                        
                                                            IPv6 SRLG flags
                                                        
                                                            **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State.Flags>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: ipv6_interface_address
                                                        
                                                            IPv6 interface address or Link Local Identifier
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: ipv6_neighbor_address
                                                        
                                                            IPv6 neighbor address or Link Remote Identifier
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: srlg_value
                                                        
                                                            SRLG values
                                                        
                                                            **type**: list of int
                                                        
                                                                **range:** 0..4294967295
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "ipv6-srlg"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ('psn_number', (YLeaf(YType.uint8, 'psn-number'), ['int'])),
                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State.Flags')])),
                                                                ('ipv6_interface_address', (YLeaf(YType.str, 'ipv6-interface-address'), ['str'])),
                                                                ('ipv6_neighbor_address', (YLeaf(YType.str, 'ipv6-neighbor-address'), ['str'])),
                                                                ('srlg_value', (YLeafList(YType.uint32, 'srlg-value'), ['int'])),
                                                            ])
                                                            self.instance_number = None
                                                            self.system_id = None
                                                            self.psn_number = None
                                                            self.flags = []
                                                            self.ipv6_interface_address = None
                                                            self.ipv6_neighbor_address = None
                                                            self.srlg_value = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Srlgs.Ipv6Srlg.State, ['instance_number', 'system_id', 'psn_number', 'flags', 'ipv6_interface_address', 'ipv6_neighbor_address', 'srlg_value'], name, value)

                                                        class Flags(Enum):
                                                            """
                                                            Flags (Enum Class)

                                                            .. data:: NA = 0

                                                                When set, the IPv6 neighbour address is

                                                                included, whereas if unset, it is omitted

                                                            """

                                                            NA = Enum.YLeaf(0, "NA")





                                            class PurgeOi(_Entity_):
                                                """
                                                This container defines ISIS purge TLV.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of TLV 13
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "purge-oi"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "purge-oi"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of TLV 13.
                                                    
                                                    .. attribute:: system_id_count
                                                    
                                                        Number of system IDs carried in this TLV
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..255
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: source_system_id
                                                    
                                                        System ID of the Intermediate System that inserted this TLV
                                                    
                                                        **type**: str
                                                    
                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: received_system_id
                                                    
                                                        System ID of the Intermediate System from which the purge was received
                                                    
                                                        **type**: str
                                                    
                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "purge-oi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('system_id_count', (YLeaf(YType.uint8, 'system-id-count'), ['int'])),
                                                            ('source_system_id', (YLeaf(YType.str, 'source-system-id'), ['str'])),
                                                            ('received_system_id', (YLeaf(YType.str, 'received-system-id'), ['str'])),
                                                        ])
                                                        self.system_id_count = None
                                                        self.source_system_id = None
                                                        self.received_system_id = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.PurgeOi.State, ['system_id_count', 'source_system_id', 'received_system_id'], name, value)



                                            class RouterCapabilities(_Entity_):
                                                """
                                                This container defines router capabilities.
                                                
                                                .. attribute:: capability
                                                
                                                    This list describes IS Router capabilities
                                                
                                                    **type**: list of    :py:class:`Capability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "router-capabilities"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("capability", ("capability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability))])
                                                    self._leafs = OrderedDict()

                                                    self.capability = YList(self)
                                                    self._segment_path = lambda: "router-capabilities"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities, [], name, value)

                                                class Capability(_Entity_):
                                                    """
                                                    This list describes IS Router capabilities.
                                                    
                                                    .. attribute:: instance_number  (key)
                                                    
                                                        Reference to the instance number of the router capability TLV
                                                    
                                                        **type**: int
                                                    
                                                            **range:** 0..4294967295
                                                    
                                                        **refers to**:  :py:class:`instance_number<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: state
                                                    
                                                        State parameters of TLV 242
                                                    
                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: subtlvs
                                                    
                                                        This container describes router capability TLV sub\-TLVs
                                                    
                                                        **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: undefined_subtlvs
                                                    
                                                        This container describes undefined ISIS TLVs
                                                    
                                                        **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "capability"
                                                        self.yang_parent_name = "router-capabilities"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = ['instance_number']
                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs))])
                                                        self._leafs = OrderedDict([
                                                            ('instance_number', (YLeaf(YType.str, 'instance-number'), ['int'])),
                                                        ])
                                                        self.instance_number = None

                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State()
                                                        self.state.parent = self
                                                        self._children_name_map["state"] = "state"

                                                        self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs()
                                                        self.subtlvs.parent = self
                                                        self._children_name_map["subtlvs"] = "subtlvs"

                                                        self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs()
                                                        self.undefined_subtlvs.parent = self
                                                        self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                        self._segment_path = lambda: "capability" + "[instance-number='" + str(self.instance_number) + "']"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability, ['instance_number'], name, value)

                                                    class State(_Entity_):
                                                        """
                                                        State parameters of TLV 242.
                                                        
                                                        .. attribute:: instance_number
                                                        
                                                            A unique instance number for the instance of the router capabilities TLV. The instance number should be autogenerated by the producer of the data and may be renumbered if the entire LSP contents are replaced in subsequent advertisements
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4294967295
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: router_id
                                                        
                                                            IPv4 router\-id
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: flags
                                                        
                                                            Router capability flags
                                                        
                                                            **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State.Flags>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "state"
                                                            self.yang_parent_name = "capability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('instance_number', (YLeaf(YType.uint32, 'instance-number'), ['int'])),
                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State.Flags')])),
                                                            ])
                                                            self.instance_number = None
                                                            self.router_id = None
                                                            self.flags = []
                                                            self._segment_path = lambda: "state"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.State, ['instance_number', 'router_id', 'flags'], name, value)

                                                        class Flags(Enum):
                                                            """
                                                            Flags (Enum Class)

                                                            .. data:: FLOOD = 0

                                                                When the S bit is set(1), the IS - IS Router

                                                                CAPABILITY TLV MUST be flooded across the entire

                                                                routing domain. When the S bit is not set(0),

                                                                the TLV MUST NOT be leaked between levels . This

                                                                bit MUST NOT be altered during the TLV

                                                                leaking.

                                                            .. data:: DOWN = 1

                                                                When the IS-IS Router CAPABILITY TLV is leaked

                                                                from level - 2 to level-1, the Down bit MUST be

                                                                set. Otherwise, this bit MUST be clear. IS - IS

                                                                Router capability TLVs with the Down bit set

                                                                MUST NOT be leaked from level - 1 to level-2.

                                                                This is to prevent TLV looping.

                                                            """

                                                            FLOOD = Enum.YLeaf(0, "FLOOD")

                                                            DOWN = Enum.YLeaf(1, "DOWN")



                                                    class Subtlvs(_Entity_):
                                                        """
                                                        This container describes router capability TLV
                                                        sub\-TLVs
                                                        
                                                        .. attribute:: subtlv
                                                        
                                                            List of subTLV types in the LSDB for the specified TLV
                                                        
                                                            **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "subtlvs"
                                                            self.yang_parent_name = "capability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv))])
                                                            self._leafs = OrderedDict()

                                                            self.subtlv = YList(self)
                                                            self._segment_path = lambda: "subtlvs"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs, [], name, value)

                                                        class Subtlv(_Entity_):
                                                            """
                                                            List of subTLV types in the LSDB for the specified
                                                            TLV
                                                            
                                                            .. attribute:: type  (key)
                                                            
                                                                Reference to the sub\-TLV type
                                                            
                                                                **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of IS Router Capabilities
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.State>`
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: segment_routing_algorithms
                                                            
                                                                This container defines SR algorithm sub\-TLV 19
                                                            
                                                                **type**:  :py:class:`SegmentRoutingAlgorithms<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms>`
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: segment_routing_capability
                                                            
                                                                This container defines SR Capability sub\-TLV 2
                                                            
                                                                **type**:  :py:class:`SegmentRoutingCapability<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "subtlv"
                                                                self.yang_parent_name = "subtlvs"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['type']
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.State)), ("segment-routing-algorithms", ("segment_routing_algorithms", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms)), ("segment-routing-capability", ("segment_routing_capability", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability))])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                ])
                                                                self.type = None

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"

                                                                self.segment_routing_algorithms = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms()
                                                                self.segment_routing_algorithms.parent = self
                                                                self._children_name_map["segment_routing_algorithms"] = "segment-routing-algorithms"

                                                                self.segment_routing_capability = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability()
                                                                self.segment_routing_capability.parent = self
                                                                self._children_name_map["segment_routing_capability"] = "segment-routing-capability"
                                                                self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv, ['type'], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of IS Router Capabilities
                                                                
                                                                .. attribute:: type
                                                                
                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                
                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                    ])
                                                                    self.type = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.State, ['type'], name, value)


                                                            class SegmentRoutingAlgorithms(_Entity_):
                                                                """
                                                                This container defines SR algorithm sub\-TLV 19.
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of sub\-TLV 19 \- Segment Routing Algorithm
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "segment-routing-algorithms"
                                                                    self.yang_parent_name = "subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.State))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "segment-routing-algorithms"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms, [], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of sub\-TLV 19 \- Segment
                                                                    Routing Algorithm.
                                                                    
                                                                    .. attribute:: algorithm
                                                                    
                                                                        The Segment Routing algorithm that is described by the TLV
                                                                    
                                                                        **type**: list of   :py:class:`Algorithm<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.State.Algorithm>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "segment-routing-algorithms"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('algorithm', (YLeafList(YType.enumeration, 'algorithm'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.State.Algorithm')])),
                                                                        ])
                                                                        self.algorithm = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingAlgorithms.State, ['algorithm'], name, value)

                                                                    class Algorithm(Enum):
                                                                        """
                                                                        Algorithm (Enum Class)

                                                                        .. data:: SPF = 0

                                                                            Shortest Path First (SPF) algorithm

                                                                            based on link metric.  This is the

                                                                            well-known shortest path algorithm as

                                                                            computed by the IS-IS Decision process.

                                                                            Consistent with the deployed practice

                                                                            for link-state protocols, algorithm 0

                                                                            permits any node to overwrite the SPF

                                                                            path with a different path based on

                                                                            local policy.

                                                                        .. data:: STRICT_SPF = 1

                                                                            Strict Shortest Path First (SPF)

                                                                            algorithm based on link metric. The

                                                                            algorithm is identical to algorithm 0

                                                                            but algorithm 1 requires that all nodes

                                                                            along the path will honor the SPF

                                                                            routing decision. Local policy MUST NOT

                                                                            alter the forwarding decision computed

                                                                            by algorithm 1 at the node claiming to

                                                                            support algorithm 1.

                                                                        """

                                                                        SPF = Enum.YLeaf(0, "SPF")

                                                                        STRICT_SPF = Enum.YLeaf(1, "STRICT_SPF")




                                                            class SegmentRoutingCapability(_Entity_):
                                                                """
                                                                This container defines SR Capability sub\-TLV 2.
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of IS SR Router Capability
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: srgb_descriptors
                                                                
                                                                    SRGB Descriptors included within the SR capability sub\-TLV
                                                                
                                                                    **type**:  :py:class:`SrgbDescriptors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "segment-routing-capability"
                                                                    self.yang_parent_name = "subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.State)), ("srgb-descriptors", ("srgb_descriptors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors))])
                                                                    self._leafs = OrderedDict()

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.srgb_descriptors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors()
                                                                    self.srgb_descriptors.parent = self
                                                                    self._children_name_map["srgb_descriptors"] = "srgb-descriptors"
                                                                    self._segment_path = lambda: "segment-routing-capability"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability, [], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of IS SR Router Capability
                                                                    
                                                                    .. attribute:: flags
                                                                    
                                                                        Segment Routing Capability Flags
                                                                    
                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.State.Flags>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "segment-routing-capability"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.State.Flags')])),
                                                                        ])
                                                                        self.flags = []
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.State, ['flags'], name, value)

                                                                    class Flags(Enum):
                                                                        """
                                                                        Flags (Enum Class)

                                                                        .. data:: IPV4_MPLS = 0

                                                                            When set, the router is capable of

                                                                            processing SR MPLS encapsulated IPv4

                                                                            packets on all interfaces.

                                                                        .. data:: IPV6_MPLS = 1

                                                                            When set, the router is capable of

                                                                            processing SR MPLS encapsulated IPv6

                                                                            packets on all interfaces.

                                                                        .. data:: IPV6_SR = 2

                                                                            When set, the router is capable of

                                                                            processing the IPv6 Segment Routing Header

                                                                            on all interfaces.

                                                                        """

                                                                        IPV4_MPLS = Enum.YLeaf(0, "IPV4_MPLS")

                                                                        IPV6_MPLS = Enum.YLeaf(1, "IPV6_MPLS")

                                                                        IPV6_SR = Enum.YLeaf(2, "IPV6_SR")



                                                                class SrgbDescriptors(_Entity_):
                                                                    """
                                                                    SRGB Descriptors included within the SR
                                                                    capability sub\-TLV
                                                                    
                                                                    .. attribute:: srgb_descriptor
                                                                    
                                                                        Descriptor entry within the SR capabilty sub\-TLV
                                                                    
                                                                        **type**: list of    :py:class:`SrgbDescriptor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "srgb-descriptors"
                                                                        self.yang_parent_name = "segment-routing-capability"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("srgb-descriptor", ("srgb_descriptor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor))])
                                                                        self._leafs = OrderedDict()

                                                                        self.srgb_descriptor = YList(self)
                                                                        self._segment_path = lambda: "srgb-descriptors"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors, [], name, value)

                                                                    class SrgbDescriptor(_Entity_):
                                                                        """
                                                                        Descriptor entry within the SR capabilty
                                                                        sub\-TLV
                                                                        
                                                                        .. attribute:: range  (key)
                                                                        
                                                                            Reference to unique SRGB Descriptor
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **refers to**:  :py:class:`range<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of the SR range
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "srgb-descriptor"
                                                                            self.yang_parent_name = "srgb-descriptors"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['range']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('range', (YLeaf(YType.str, 'range'), ['int'])),
                                                                            ])
                                                                            self.range = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "srgb-descriptor" + "[range='" + str(self.range) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor, ['range'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of the SR range
                                                                            
                                                                            .. attribute:: range
                                                                            
                                                                                Number of SRGB elements. The range value MUST be greater than 0
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..4294967295
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: label
                                                                            
                                                                                The first value of the SRGB when expressed as an MPLS label
                                                                            
                                                                                **type**: union of the below types:
                                                                            
                                                                                    **type**: int
                                                                            
                                                                                        **range:** 16..1048575
                                                                            
                                                                                    **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "srgb-descriptor"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('range', (YLeaf(YType.uint32, 'range'), ['int'])),
                                                                                    ('label', (YLeaf(YType.str, 'label'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', '')])),
                                                                                ])
                                                                                self.range = None
                                                                                self.label = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.Subtlvs.Subtlv.SegmentRoutingCapability.SrgbDescriptors.SrgbDescriptor.State, ['range', 'label'], name, value)







                                                    class UndefinedSubtlvs(_Entity_):
                                                        """
                                                        This container describes undefined ISIS TLVs.
                                                        
                                                        .. attribute:: undefined_subtlv
                                                        
                                                            Sub\-TLVs that are not defined in the model or not recognised by system
                                                        
                                                            **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "undefined-subtlvs"
                                                            self.yang_parent_name = "capability"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv))])
                                                            self._leafs = OrderedDict()

                                                            self.undefined_subtlv = YList(self)
                                                            self._segment_path = lambda: "undefined-subtlvs"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs, [], name, value)

                                                        class UndefinedSubtlv(_Entity_):
                                                            """
                                                            Sub\-TLVs that are not defined in the model or not
                                                            recognised by system.
                                                            
                                                            .. attribute:: type  (key)
                                                            
                                                                Reference to the type of the undefined sub\-TLV
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 0..255
                                                            
                                                                **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of the undefined sub\-TLV
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "undefined-subtlv"
                                                                self.yang_parent_name = "undefined-subtlvs"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = ['type']
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                self._leafs = OrderedDict([
                                                                    ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                ])
                                                                self.type = None

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of the undefined sub\-TLV.
                                                                
                                                                .. attribute:: type
                                                                
                                                                    TLV Type
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..255
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: length
                                                                
                                                                    TLV length
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..255
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: value
                                                                
                                                                    TLV value
                                                                
                                                                    **type**: str
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "undefined-subtlv"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                        ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                        ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                    ])
                                                                    self.type = None
                                                                    self.length = None
                                                                    self.value = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.RouterCapabilities.Capability.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)






                                            class IsReachability(_Entity_):
                                                """
                                                This container describes list of ISIS neighbors and
                                                attributes.
                                                
                                                .. attribute:: neighbors
                                                
                                                    This container describes IS neighbors
                                                
                                                    **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "is-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors))])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._segment_path = lambda: "is-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability, [], name, value)

                                                class Neighbors(_Entity_):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                        IS reachability neighbor attributes
                                                    
                                                        **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "is-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors, [], name, value)

                                                    class Neighbor(_Entity_):
                                                        """
                                                        IS reachability neighbor attributes.
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                            Reference to the system ID of the neighbor
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **refers to**:  :py:class:`system_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of IS standard neighbor
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: default_metric
                                                        
                                                            This container defines ISIS Default Metric
                                                        
                                                            **type**:  :py:class:`DefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: delay_metric
                                                        
                                                            This container defines the ISIS delay metric
                                                        
                                                            **type**:  :py:class:`DelayMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: expense_metric
                                                        
                                                            This container defines the ISIS expense metric
                                                        
                                                            **type**:  :py:class:`ExpenseMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: error_metric
                                                        
                                                            This container defines the ISIS error metric
                                                        
                                                            **type**:  :py:class:`ErrorMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['system_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.State)), ("default-metric", ("default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric)), ("delay-metric", ("delay_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric)), ("expense-metric", ("expense_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric)), ("error-metric", ("error_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric))])
                                                            self._leafs = OrderedDict([
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                            ])
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric()
                                                            self.default_metric.parent = self
                                                            self._children_name_map["default_metric"] = "default-metric"

                                                            self.delay_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric()
                                                            self.delay_metric.parent = self
                                                            self._children_name_map["delay_metric"] = "delay-metric"

                                                            self.expense_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric()
                                                            self.expense_metric.parent = self
                                                            self._children_name_map["expense_metric"] = "expense-metric"

                                                            self.error_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric()
                                                            self.error_metric.parent = self
                                                            self._children_name_map["error_metric"] = "error-metric"
                                                            self._segment_path = lambda: "neighbor" + "[system-id='" + str(self.system_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor, ['system_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of IS standard neighbor.
                                                            
                                                            .. attribute:: system_id
                                                            
                                                                System\-ID of IS neighbor
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.system_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.State, ['system_id'], name, value)


                                                        class DefaultMetric(_Entity_):
                                                            """
                                                            This container defines ISIS Default Metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters for default\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "default-metric"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "default-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters for default\-metric.
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Default\-Metric Flags
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric.State.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS default metric value. This is a metric understood by every Intermediate system in the domain. Each circuit shall have a positive  integral value assigned for this metric. The value may be associated with any  objective function of the circuit, but by convention is intended to measure the capacity of the circuit for handling traffic, for example, its throughput in  bits\-per\-second. Higher values indicate a lower capacity
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "default-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('flags', (YLeaf(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric.State.Flags')])),
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                    ])
                                                                    self.flags = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DefaultMetric.State, ['flags', 'metric'], name, value)

                                                                class Flags(Enum):
                                                                    """
                                                                    Flags (Enum Class)

                                                                    .. data:: INTERNAL = 0

                                                                        When set to zero, indicates internal metrics.

                                                                    """

                                                                    INTERNAL = Enum.YLeaf(0, "INTERNAL")




                                                        class DelayMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS delay metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of delay\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "delay-metric"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "delay-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of delay\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS delay metric value. This metric measures the transit delay of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value. Higher values indicate a longer transit delay
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Delay Metric Flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "delay-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.DelayMetric.State, ['metric', 'flags'], name, value)



                                                        class ExpenseMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS expense metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of expense\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "expense-metric"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "expense-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of expense\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS expense metric value. This metric measures the monetary cost of utilising the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value1). Higher values indicate a larger monetary expense
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Expense Metric Flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "expense-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ExpenseMetric.State, ['metric', 'flags'], name, value)



                                                        class ErrorMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS error metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of error\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "error-metric"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "error-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of error\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS error metric value. This metric measures the residual error probability of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a non\-zero value. Higher values indicate a larger probability of undetected errors on the circuit
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    IS\-IS error metric flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "error-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsReachability.Neighbors.Neighbor.ErrorMetric.State, ['metric', 'flags'], name, value)






                                            class Ipv4InternalReachability(_Entity_):
                                                """
                                                This container defines list of IPv4 internal reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                    This container describes IS prefixes
                                                
                                                    **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv4-internal-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes))])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._segment_path = lambda: "ipv4-internal-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability, [], name, value)

                                                class Prefixes(_Entity_):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                        IPv4 prefixes and internal reachability attributes
                                                    
                                                        **type**: list of    :py:class:`Prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "ipv4-internal-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes, [], name, value)

                                                    class Prefix(_Entity_):
                                                        """
                                                        IPv4 prefixes and internal reachability attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the IPv4 prefix
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of IPv4 standard prefix
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: default_metric
                                                        
                                                            This container defines ISIS Default Metric
                                                        
                                                            **type**:  :py:class:`DefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: delay_metric
                                                        
                                                            This container defines the ISIS delay metric
                                                        
                                                            **type**:  :py:class:`DelayMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: expense_metric
                                                        
                                                            This container defines the ISIS expense metric
                                                        
                                                            **type**:  :py:class:`ExpenseMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: error_metric
                                                        
                                                            This container defines the ISIS error metric
                                                        
                                                            **type**:  :py:class:`ErrorMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.State)), ("default-metric", ("default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric)), ("delay-metric", ("delay_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric)), ("expense-metric", ("expense_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric)), ("error-metric", ("error_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric))])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric()
                                                            self.default_metric.parent = self
                                                            self._children_name_map["default_metric"] = "default-metric"

                                                            self.delay_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric()
                                                            self.delay_metric.parent = self
                                                            self._children_name_map["delay_metric"] = "delay-metric"

                                                            self.expense_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric()
                                                            self.expense_metric.parent = self
                                                            self._children_name_map["expense_metric"] = "expense-metric"

                                                            self.error_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric()
                                                            self.error_metric.parent = self
                                                            self._children_name_map["error_metric"] = "error-metric"
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix, ['prefix'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of IPv4 standard prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                                The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                IPv4 prefix contained within reachability TLVs
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.up_down = None
                                                                self.prefix = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.State, ['up_down', 'prefix'], name, value)


                                                        class DefaultMetric(_Entity_):
                                                            """
                                                            This container defines ISIS Default Metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters for default\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "default-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "default-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters for default\-metric.
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Default\-Metric Flags
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric.State.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS default metric value. This is a metric understood by every Intermediate system in the domain. Each circuit shall have a positive  integral value assigned for this metric. The value may be associated with any  objective function of the circuit, but by convention is intended to measure the capacity of the circuit for handling traffic, for example, its throughput in  bits\-per\-second. Higher values indicate a lower capacity
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "default-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('flags', (YLeaf(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric.State.Flags')])),
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                    ])
                                                                    self.flags = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DefaultMetric.State, ['flags', 'metric'], name, value)

                                                                class Flags(Enum):
                                                                    """
                                                                    Flags (Enum Class)

                                                                    .. data:: INTERNAL = 0

                                                                        When set to zero, indicates internal metrics.

                                                                    """

                                                                    INTERNAL = Enum.YLeaf(0, "INTERNAL")




                                                        class DelayMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS delay metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of delay\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "delay-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "delay-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of delay\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS delay metric value. This metric measures the transit delay of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value. Higher values indicate a longer transit delay
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Delay Metric Flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "delay-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.DelayMetric.State, ['metric', 'flags'], name, value)



                                                        class ExpenseMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS expense metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of expense\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "expense-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "expense-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of expense\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS expense metric value. This metric measures the monetary cost of utilising the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value1). Higher values indicate a larger monetary expense
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Expense Metric Flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "expense-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ExpenseMetric.State, ['metric', 'flags'], name, value)



                                                        class ErrorMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS error metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of error\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "error-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "error-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of error\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS error metric value. This metric measures the residual error probability of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a non\-zero value. Higher values indicate a larger probability of undetected errors on the circuit
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    IS\-IS error metric flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "error-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4InternalReachability.Prefixes.Prefix.ErrorMetric.State, ['metric', 'flags'], name, value)






                                            class Ipv4ExternalReachability(_Entity_):
                                                """
                                                This container defines list of IPv4 external reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                    This container describes IS neighbors
                                                
                                                    **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv4-external-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes))])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._segment_path = lambda: "ipv4-external-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability, [], name, value)

                                                class Prefixes(_Entity_):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                        IPv4 external prefixes and reachability attributes
                                                    
                                                        **type**: list of    :py:class:`Prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "ipv4-external-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes, [], name, value)

                                                    class Prefix(_Entity_):
                                                        """
                                                        IPv4 external prefixes and reachability attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the IPv4 prefix
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of IPv4 standard prefix
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: default_metric
                                                        
                                                            This container defines ISIS Default Metric
                                                        
                                                            **type**:  :py:class:`DefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: delay_metric
                                                        
                                                            This container defines the ISIS delay metric
                                                        
                                                            **type**:  :py:class:`DelayMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: expense_metric
                                                        
                                                            This container defines the ISIS expense metric
                                                        
                                                            **type**:  :py:class:`ExpenseMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: error_metric
                                                        
                                                            This container defines the ISIS error metric
                                                        
                                                            **type**:  :py:class:`ErrorMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.State)), ("default-metric", ("default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric)), ("delay-metric", ("delay_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric)), ("expense-metric", ("expense_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric)), ("error-metric", ("error_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric))])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric()
                                                            self.default_metric.parent = self
                                                            self._children_name_map["default_metric"] = "default-metric"

                                                            self.delay_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric()
                                                            self.delay_metric.parent = self
                                                            self._children_name_map["delay_metric"] = "delay-metric"

                                                            self.expense_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric()
                                                            self.expense_metric.parent = self
                                                            self._children_name_map["expense_metric"] = "expense-metric"

                                                            self.error_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric()
                                                            self.error_metric.parent = self
                                                            self._children_name_map["error_metric"] = "error-metric"
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix, ['prefix'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of IPv4 standard prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                                The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                IPv4 prefix contained within reachability TLVs
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ])
                                                                self.up_down = None
                                                                self.prefix = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.State, ['up_down', 'prefix'], name, value)


                                                        class DefaultMetric(_Entity_):
                                                            """
                                                            This container defines ISIS Default Metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters for default\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "default-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "default-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters for default\-metric.
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Default\-Metric Flags
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric.State.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS default metric value. This is a metric understood by every Intermediate system in the domain. Each circuit shall have a positive  integral value assigned for this metric. The value may be associated with any  objective function of the circuit, but by convention is intended to measure the capacity of the circuit for handling traffic, for example, its throughput in  bits\-per\-second. Higher values indicate a lower capacity
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "default-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('flags', (YLeaf(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric.State.Flags')])),
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                    ])
                                                                    self.flags = None
                                                                    self.metric = None
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DefaultMetric.State, ['flags', 'metric'], name, value)

                                                                class Flags(Enum):
                                                                    """
                                                                    Flags (Enum Class)

                                                                    .. data:: INTERNAL = 0

                                                                        When set to zero, indicates internal metrics.

                                                                    """

                                                                    INTERNAL = Enum.YLeaf(0, "INTERNAL")




                                                        class DelayMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS delay metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of delay\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "delay-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "delay-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of delay\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS delay metric value. This metric measures the transit delay of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value. Higher values indicate a longer transit delay
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Delay Metric Flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "delay-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.DelayMetric.State, ['metric', 'flags'], name, value)



                                                        class ExpenseMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS expense metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of expense\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "expense-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "expense-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of expense\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS expense metric value. This metric measures the monetary cost of utilising the associated circuit. It is an optional metric, which if assigned to a circuit shall have a positive integral value1). Higher values indicate a larger monetary expense
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    ISIS Expense Metric Flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "expense-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ExpenseMetric.State, ['metric', 'flags'], name, value)



                                                        class ErrorMetric(_Entity_):
                                                            """
                                                            This container defines the ISIS error metric.
                                                            
                                                            .. attribute:: state
                                                            
                                                                State parameters of error\-metric
                                                            
                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric.State>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "error-metric"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric.State))])
                                                                self._leafs = OrderedDict()

                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric.State()
                                                                self.state.parent = self
                                                                self._children_name_map["state"] = "state"
                                                                self._segment_path = lambda: "error-metric"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric, [], name, value)

                                                            class State(_Entity_):
                                                                """
                                                                State parameters of error\-metric.
                                                                
                                                                .. attribute:: metric
                                                                
                                                                    ISIS error metric value. This metric measures the residual error probability of the associated circuit. It is an optional metric, which if assigned to a circuit shall have a non\-zero value. Higher values indicate a larger probability of undetected errors on the circuit
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 1..63
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    IS\-IS error metric flags
                                                                
                                                                    **type**: list of   :py:class:`IsisMetricFlags<ydk.models.openconfig.openconfig_isis.IsisMetricFlags>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "state"
                                                                    self.yang_parent_name = "error-metric"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = []
                                                                    self._child_classes = OrderedDict([])
                                                                    self._leafs = OrderedDict([
                                                                        ('metric', (YLeaf(YType.uint8, 'metric'), ['int'])),
                                                                        ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_isis', 'IsisMetricFlags', '')])),
                                                                    ])
                                                                    self.metric = None
                                                                    self.flags = []
                                                                    self._segment_path = lambda: "state"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv4ExternalReachability.Prefixes.Prefix.ErrorMetric.State, ['metric', 'flags'], name, value)






                                            class Authentication(_Entity_):
                                                """
                                                This container defines authentication information of the
                                                node.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of TLV 10
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "authentication"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "authentication"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of TLV 10.
                                                    
                                                    .. attribute:: crypto_type
                                                    
                                                        Authentication type to be used
                                                    
                                                        **type**:  :py:class:`CryptoType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State.CryptoType>`
                                                    
                                                        **config**: False
                                                    
                                                    .. attribute:: authentication_key
                                                    
                                                        Authentication key to be used
                                                    
                                                        **type**: str
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "authentication"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('crypto_type', (YLeaf(YType.enumeration, 'crypto-type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State.CryptoType')])),
                                                            ('authentication_key', (YLeaf(YType.str, 'authentication-key'), ['str'])),
                                                        ])
                                                        self.crypto_type = None
                                                        self.authentication_key = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Authentication.State, ['crypto_type', 'authentication_key'], name, value)

                                                    class CryptoType(Enum):
                                                        """
                                                        CryptoType (Enum Class)

                                                        .. data:: HMAC_MD5 = 0

                                                            HMAC-MD5 Authentication type.

                                                        .. data:: CLEARTEXT = 1

                                                            Cleartext Authentication type.

                                                        """

                                                        HMAC_MD5 = Enum.YLeaf(0, "HMAC_MD5")

                                                        CLEARTEXT = Enum.YLeaf(1, "CLEARTEXT")




                                            class ExtendedIsReachability(_Entity_):
                                                """
                                                This container defines list of ISIS extended reachability
                                                neighbors.
                                                
                                                .. attribute:: neighbors
                                                
                                                    This container describes IS neighbors
                                                
                                                    **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "extended-is-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors))])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._segment_path = lambda: "extended-is-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability, [], name, value)

                                                class Neighbors(_Entity_):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                        This list describes ISIS extended neighbors and reachability attributes
                                                    
                                                        **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "extended-is-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors, [], name, value)

                                                    class Neighbor(_Entity_):
                                                        """
                                                        This list describes ISIS extended neighbors and
                                                        reachability attributes.
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                            Reference to the neighboring system's system ID
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **refers to**:  :py:class:`system_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters corresponding to the extended neighbour
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: instances
                                                        
                                                            This list contains all instances of an adjacency between the originating IS and the remote IS. Multiple instances are used where there are parallel adjacencies between two systems
                                                        
                                                            **type**:  :py:class:`Instances<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['system_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.State)), ("instances", ("instances", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances))])
                                                            self._leafs = OrderedDict([
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                            ])
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.instances = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances()
                                                            self.instances.parent = self
                                                            self._children_name_map["instances"] = "instances"
                                                            self._segment_path = lambda: "neighbor" + "[system-id='" + str(self.system_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor, ['system_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters corresponding to the extended
                                                            neighbour.
                                                            
                                                            .. attribute:: system_id
                                                            
                                                                System\-id of the neighbor
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.system_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.State, ['system_id'], name, value)


                                                        class Instances(_Entity_):
                                                            """
                                                            This list contains all instances of an adjacency
                                                            between the originating IS and the remote IS.
                                                            Multiple instances are used where there are
                                                            parallel adjacencies between two systems.
                                                            
                                                            .. attribute:: instance
                                                            
                                                                Instance of the TLV to the remote IS neighbor
                                                            
                                                                **type**: list of    :py:class:`Instance<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "instances"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("instance", ("instance", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance))])
                                                                self._leafs = OrderedDict()

                                                                self.instance = YList(self)
                                                                self._segment_path = lambda: "instances"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances, [], name, value)

                                                            class Instance(_Entity_):
                                                                """
                                                                Instance of the TLV to the remote IS neighbor.
                                                                
                                                                .. attribute:: id  (key)
                                                                
                                                                    Reference to the unique identifier for the instance of the extended IS reachability sub\-TLV
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..18446744073709551615
                                                                
                                                                    **refers to**:  :py:class:`id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of extended neighbor
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: subtlvs
                                                                
                                                                    This container describes IS Neighbor sub\-TLVs
                                                                
                                                                    **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: undefined_subtlvs
                                                                
                                                                    This container describes undefined ISIS TLVs
                                                                
                                                                    **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "instance"
                                                                    self.yang_parent_name = "instances"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['id']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs))])
                                                                    self._leafs = OrderedDict([
                                                                        ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                                                    ])
                                                                    self.id = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs()
                                                                    self.subtlvs.parent = self
                                                                    self._children_name_map["subtlvs"] = "subtlvs"

                                                                    self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs()
                                                                    self.undefined_subtlvs.parent = self
                                                                    self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                                    self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance, ['id'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of extended neighbor
                                                                    
                                                                    .. attribute:: id
                                                                    
                                                                        Unique identifier for the instance of the TLV for the IS neighbor. The instance ID is not required to be consistent across across readvertisements of the LSP
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..18446744073709551615
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                        Metric value
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 1..16777215
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('id', (YLeaf(YType.uint64, 'id'), ['int'])),
                                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ])
                                                                        self.id = None
                                                                        self.metric = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.State, ['id', 'metric'], name, value)


                                                                class Subtlvs(_Entity_):
                                                                    """
                                                                    This container describes IS Neighbor sub\-TLVs.
                                                                    
                                                                    .. attribute:: subtlv
                                                                    
                                                                        List of subTLV types in the LSDB for the specified TLV
                                                                    
                                                                        **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.subtlv = YList(self)
                                                                        self._segment_path = lambda: "subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs, [], name, value)

                                                                    class Subtlv(_Entity_):
                                                                        """
                                                                        List of subTLV types in the LSDB for the specified TLV.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the sub\-TLV type
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of IS neighbor state
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                            This container defines sub\-TLV 3
                                                                        
                                                                            **type**:  :py:class:`AdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_id
                                                                        
                                                                            This container defines sub\-TLV 4
                                                                        
                                                                            **type**:  :py:class:`LinkId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                            This container defines sub\-TLV 6
                                                                        
                                                                            **type**:  :py:class:`Ipv4InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 8
                                                                        
                                                                            **type**:  :py:class:`Ipv4NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 9
                                                                        
                                                                            **type**:  :py:class:`MaxLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 10
                                                                        
                                                                            **type**:  :py:class:`MaxReservableLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unreserved_bandwidth
                                                                        
                                                                            This container defines unreserved\-bandwidth. The units are bytes per second
                                                                        
                                                                            **type**:  :py:class:`UnreservedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                            This container defines sub\-TLV 12
                                                                        
                                                                            **type**:  :py:class:`Ipv6InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 13
                                                                        
                                                                            **type**:  :py:class:`Ipv6NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                            This container defines sub\-TLV 14
                                                                        
                                                                            **type**:  :py:class:`ExtendedAdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                            This container defines sub\-TLV 18
                                                                        
                                                                            **type**:  :py:class:`TeDefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_attributes
                                                                        
                                                                            This container defines link\-attributes
                                                                        
                                                                            **type**:  :py:class:`LinkAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                            ISIS LSDB parameters relating to the type of link protection offered
                                                                        
                                                                            **type**:  :py:class:`LinkProtectionType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: bandwidth_constraints
                                                                        
                                                                            This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                        
                                                                            **type**:  :py:class:`BandwidthConstraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                            This container defines sub\-TLV 23
                                                                        
                                                                            **type**:  :py:class:`UnconstrainedLsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: adjacency_sids
                                                                        
                                                                            This container defines segment routing adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`AdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: lan_adjacency_sids
                                                                        
                                                                            This container defines segment routing LAN adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`LanAdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay
                                                                        
                                                                            This container defines unidirectional link delay
                                                                        
                                                                            **type**:  :py:class:`LinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: min_max_link_delay
                                                                        
                                                                            This container defines min/max link delay
                                                                        
                                                                            **type**:  :py:class:`MinMaxLinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay_variation
                                                                        
                                                                            This container defines unidirectional link delay variation
                                                                        
                                                                            **type**:  :py:class:`LinkDelayVariation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                            This container defines unidirectional link loss delay
                                                                        
                                                                            **type**:  :py:class:`LinkLoss<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                            This container defines unidirectional residual bandwidth
                                                                        
                                                                            **type**:  :py:class:`ResidualBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                            This container defines unidirectional lavailable bandwidth
                                                                        
                                                                            **type**:  :py:class:`AvailableBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                            This container defines unidirectional utilized bandwidth
                                                                        
                                                                            **type**:  :py:class:`UtilizedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "subtlv"
                                                                            self.yang_parent_name = "subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup)), ("link-id", ("link_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"

                                                                            self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup()
                                                                            self.admin_group.parent = self
                                                                            self._children_name_map["admin_group"] = "admin-group"

                                                                            self.link_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId()
                                                                            self.link_id.parent = self
                                                                            self._children_name_map["link_id"] = "link-id"

                                                                            self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                            self.ipv4_interface_address.parent = self
                                                                            self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"

                                                                            self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                            self.ipv4_neighbor_address.parent = self
                                                                            self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"

                                                                            self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                            self.max_link_bandwidth.parent = self
                                                                            self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"

                                                                            self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                            self.max_reservable_link_bandwidth.parent = self
                                                                            self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"

                                                                            self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                            self.unreserved_bandwidth.parent = self
                                                                            self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"

                                                                            self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                            self.ipv6_interface_address.parent = self
                                                                            self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"

                                                                            self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                            self.ipv6_neighbor_address.parent = self
                                                                            self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"

                                                                            self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                            self.extended_admin_group.parent = self
                                                                            self._children_name_map["extended_admin_group"] = "extended-admin-group"

                                                                            self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric()
                                                                            self.te_default_metric.parent = self
                                                                            self._children_name_map["te_default_metric"] = "te-default-metric"

                                                                            self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes()
                                                                            self.link_attributes.parent = self
                                                                            self._children_name_map["link_attributes"] = "link-attributes"

                                                                            self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType()
                                                                            self.link_protection_type.parent = self
                                                                            self._children_name_map["link_protection_type"] = "link-protection-type"

                                                                            self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints()
                                                                            self.bandwidth_constraints.parent = self
                                                                            self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"

                                                                            self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                            self.unconstrained_lsp.parent = self
                                                                            self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"

                                                                            self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids()
                                                                            self.adjacency_sids.parent = self
                                                                            self._children_name_map["adjacency_sids"] = "adjacency-sids"

                                                                            self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids()
                                                                            self.lan_adjacency_sids.parent = self
                                                                            self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"

                                                                            self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay()
                                                                            self.link_delay.parent = self
                                                                            self._children_name_map["link_delay"] = "link-delay"

                                                                            self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                            self.min_max_link_delay.parent = self
                                                                            self._children_name_map["min_max_link_delay"] = "min-max-link-delay"

                                                                            self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation()
                                                                            self.link_delay_variation.parent = self
                                                                            self._children_name_map["link_delay_variation"] = "link-delay-variation"

                                                                            self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss()
                                                                            self.link_loss.parent = self
                                                                            self._children_name_map["link_loss"] = "link-loss"

                                                                            self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth()
                                                                            self.residual_bandwidth.parent = self
                                                                            self._children_name_map["residual_bandwidth"] = "residual-bandwidth"

                                                                            self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth()
                                                                            self.available_bandwidth.parent = self
                                                                            self._children_name_map["available_bandwidth"] = "available-bandwidth"

                                                                            self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                            self.utilized_bandwidth.parent = self
                                                                            self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                            self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of IS neighbor state
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                            
                                                                                **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ])
                                                                                self.type = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                        class AdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 3.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 3
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 3.
                                                                                
                                                                                .. attribute:: admin_group
                                                                                
                                                                                    The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('admin_group', (YLeafList(YType.uint32, 'admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)



                                                                        class LinkId(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 4.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 4
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-id"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-id"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 4.
                                                                                
                                                                                .. attribute:: local
                                                                                
                                                                                    The value field of this sub\-TLV contains 4 octets of Link Local Identifier followed by 4 octets of Link Remote Identifier
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: remote
                                                                                
                                                                                    If the Link Remote Identifier is unknown, it is set to 0
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-id"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                                                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                                                                    ])
                                                                                    self.local = None
                                                                                    self.remote = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State, ['local', 'remote'], name, value)



                                                                        class Ipv4InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 6.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 6
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 6.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv4NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 8.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 8
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 8.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['address'], name, value)



                                                                        class MaxLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 9.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 9
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 9.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class MaxReservableLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 10.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 10
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-reservable-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-reservable-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 10.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class UnreservedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unreserved\-bandwidth. The units
                                                                            are bytes per second.
                                                                            
                                                                            .. attribute:: setup_priority
                                                                            
                                                                                Setup priority (0 through 7) for unreserved bandwidth
                                                                            
                                                                                **type**: list of    :py:class:`SetupPriority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unreserved-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                                self._leafs = OrderedDict()

                                                                                self.setup_priority = YList(self)
                                                                                self._segment_path = lambda: "unreserved-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)

                                                                            class SetupPriority(_Entity_):
                                                                                """
                                                                                Setup priority (0 through 7) for unreserved
                                                                                bandwidth.
                                                                                
                                                                                .. attribute:: priority  (key)
                                                                                
                                                                                    Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..7
                                                                                
                                                                                    **refers to**:  :py:class:`priority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 11
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "setup-priority"
                                                                                    self.yang_parent_name = "unreserved-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['priority']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('priority', (YLeaf(YType.str, 'priority'), ['int'])),
                                                                                    ])
                                                                                    self.priority = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    11.
                                                                                    
                                                                                    .. attribute:: priority
                                                                                    
                                                                                        Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..7
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                        The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **length:** 4..4
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                        **units**: bytes per second
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "setup-priority"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                                            ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                        ])
                                                                                        self.priority = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'bandwidth'], name, value)




                                                                        class Ipv6InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 12.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 12
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 12.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv6NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 13.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 13
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 13.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['address'], name, value)



                                                                        class ExtendedAdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 14.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 14
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "extended-admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "extended-admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 14.
                                                                                
                                                                                .. attribute:: extended_admin_group
                                                                                
                                                                                    The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "extended-admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('extended_admin_group', (YLeafList(YType.uint32, 'extended-admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.extended_admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)



                                                                        class TeDefaultMetric(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 18.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 18
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "te-default-metric"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "te-default-metric"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 18.
                                                                                
                                                                                .. attribute:: metric
                                                                                
                                                                                    This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "te-default-metric"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                                    ])
                                                                                    self.metric = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State, ['metric'], name, value)



                                                                        class LinkAttributes(_Entity_):
                                                                            """
                                                                            This container defines link\-attributes.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 19
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-attributes"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-attributes"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                19.
                                                                                
                                                                                .. attribute:: local_protection
                                                                                
                                                                                    Link local\-protection attributes
                                                                                
                                                                                    **type**: list of   :py:class:`LocalProtection<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-attributes"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local_protection', (YLeafList(YType.enumeration, 'local-protection'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection')])),
                                                                                    ])
                                                                                    self.local_protection = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                                class LocalProtection(Enum):
                                                                                    """
                                                                                    LocalProtection (Enum Class)

                                                                                    .. data:: LOCAL_PROTECTION = 0

                                                                                        If set, local protection is available for the

                                                                                        link.

                                                                                    .. data:: LINK_EXCLUDED = 1

                                                                                        If set, the link is excluded from local

                                                                                        protection.

                                                                                    """

                                                                                    LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                                    LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")




                                                                        class LinkProtectionType(_Entity_):
                                                                            """
                                                                            ISIS LSDB parameters relating to the type of link
                                                                            protection offered.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 20
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-protection-type"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-protection-type"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 20.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    Link protection capabilities
                                                                                
                                                                                    **type**: list of   :py:class:`Type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-protection-type"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeafList(YType.enumeration, 'type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type')])),
                                                                                    ])
                                                                                    self.type = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State, ['type'], name, value)

                                                                                class Type(Enum):
                                                                                    """
                                                                                    Type (Enum Class)

                                                                                    .. data:: EXTRA_TRAFFIC = 0

                                                                                        If set the link has extra traffic protection. If

                                                                                        the link is of type Extra Traffic, it means that

                                                                                        the link is protecting another link or links. The

                                                                                        LSPs on a link of this type will be lost if any of

                                                                                        the links it is protecting fail.

                                                                                    .. data:: UNPROTECTED = 1

                                                                                        If set, the link is unprotected. If the link is

                                                                                        of type Unprotected, it means that there is no

                                                                                        other link protecting this link.  The LSPs on a

                                                                                        link of this type will be lost if the link

                                                                                        fails.

                                                                                    .. data:: SHARED = 2

                                                                                        If set, the link has shared protection. If the

                                                                                        link is of type Shared, it means that there are

                                                                                        one or more disjoint links of type Extra Traffic

                                                                                        that are protecting this link.  These Extra

                                                                                        Traffic links are shared between one or more links

                                                                                        of type Shared.

                                                                                    .. data:: ONE_ONE = 3

                                                                                        If set, the link has dedicated 1:1 protection. If

                                                                                        the link is of type Dedicated 1:1, it means that

                                                                                        there is one dedicated disjoint link of type Extra

                                                                                        Traffic that is protecting this link.

                                                                                    .. data:: PLUS_ONE = 4

                                                                                        If set, the link has dedicated 1+1 protection. If

                                                                                        the link is of type Dedicated 1+1, it means that a

                                                                                        dedicated disjoint link is protecting this link.

                                                                                        However, the protecting link is not advertised in

                                                                                        the link state database and is therefore not

                                                                                        available for the routing of LSPs.

                                                                                    .. data:: ENHANCED = 5

                                                                                        If set the link has enhanced protection.  If the

                                                                                        link is of type Enhanced, it means that a

                                                                                        protection scheme that is more reliable than

                                                                                        Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                                        being used to protect this link.

                                                                                    """

                                                                                    EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                                    UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                                    SHARED = Enum.YLeaf(2, "SHARED")

                                                                                    ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                                    PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                                    ENHANCED = Enum.YLeaf(5, "ENHANCED")




                                                                        class BandwidthConstraints(_Entity_):
                                                                            """
                                                                            This container defines bandwidth\-constraints. For DS\-TE,
                                                                            the existing Maximum Reservable link bandwidth parameter
                                                                            is retained, but its semantics is generalized and
                                                                            interpreted as the aggregate bandwidth constraint across
                                                                            all Class\-Types
                                                                            
                                                                            .. attribute:: bandwidth_constraint
                                                                            
                                                                                List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                            
                                                                                **type**: list of    :py:class:`BandwidthConstraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "bandwidth-constraints"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.bandwidth_constraint = YList(self)
                                                                                self._segment_path = lambda: "bandwidth-constraints"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)

                                                                            class BandwidthConstraint(_Entity_):
                                                                                """
                                                                                List of the Bandwidth Constraints sub\-TLV instances
                                                                                present in the TLV.
                                                                                
                                                                                .. attribute:: model_id  (key)
                                                                                
                                                                                    Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..255
                                                                                
                                                                                    **refers to**:  :py:class:`model_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 22
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: constraints
                                                                                
                                                                                    Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**:  :py:class:`Constraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "bandwidth-constraint"
                                                                                    self.yang_parent_name = "bandwidth-constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['model_id']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('model_id', (YLeaf(YType.str, 'model-id'), ['int'])),
                                                                                    ])
                                                                                    self.model_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"

                                                                                    self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                                    self.constraints.parent = self
                                                                                    self._children_name_map["constraints"] = "constraints"
                                                                                    self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    22.
                                                                                    
                                                                                    .. attribute:: model_id
                                                                                    
                                                                                        Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('model_id', (YLeaf(YType.uint8, 'model-id'), ['int'])),
                                                                                        ])
                                                                                        self.model_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                                class Constraints(_Entity_):
                                                                                    """
                                                                                    Constraints contained within the Bandwidth
                                                                                    Constraints sub\-TLV
                                                                                    
                                                                                    .. attribute:: constraint
                                                                                    
                                                                                        List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                                    
                                                                                        **type**: list of    :py:class:`Constraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "constraints"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                        self._leafs = OrderedDict()

                                                                                        self.constraint = YList(self)
                                                                                        self._segment_path = lambda: "constraints"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)

                                                                                    class Constraint(_Entity_):
                                                                                        """
                                                                                        List of the constraints within the Bandwidth
                                                                                        Constraints sub\-TLV. The BC0 level is indicated by
                                                                                        the constraint\-id leaf being set to 0, with BCN
                                                                                        being indicated by constraint\-id N.
                                                                                        
                                                                                        .. attribute:: constraint_id  (key)
                                                                                        
                                                                                            Reference to the unique ID for the BCN level
                                                                                        
                                                                                            **type**: int
                                                                                        
                                                                                                **range:** 0..4294967295
                                                                                        
                                                                                            **refers to**:  :py:class:`constraint_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        .. attribute:: state
                                                                                        
                                                                                            Operational state parameters of the BCN level
                                                                                        
                                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        """
                                                                                        _prefix = 'oc-netinst'
                                                                                        _revision = '2017-01-13'

                                                                                        def __init__(self):
                                                                                            super().__init__()

                                                                                            self.yang_name = "constraint"
                                                                                            self.yang_parent_name = "constraints"
                                                                                            self.is_top_level_class = False
                                                                                            self.has_list_ancestor = True
                                                                                            self.ylist_key_names = ['constraint_id']
                                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                            self._leafs = OrderedDict([
                                                                                                ('constraint_id', (YLeaf(YType.str, 'constraint-id'), ['int'])),
                                                                                            ])
                                                                                            self.constraint_id = None

                                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                            self.state.parent = self
                                                                                            self._children_name_map["state"] = "state"
                                                                                            self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"
                                                                                            self._is_frozen = True

                                                                                        def __setattr__(self, name, value):
                                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)

                                                                                        class State(_Entity_):
                                                                                            """
                                                                                            Operational state parameters of the BCN level
                                                                                            
                                                                                            .. attribute:: constraint_id
                                                                                            
                                                                                                Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                            
                                                                                                **type**: int
                                                                                            
                                                                                                    **range:** 0..4294967295
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                            .. attribute:: bandwidth
                                                                                            
                                                                                                The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                            
                                                                                                **type**: str
                                                                                            
                                                                                                    **length:** 4..4
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                                **units**: bytes per second
                                                                                            
                                                                                            """
                                                                                            _prefix = 'oc-netinst'
                                                                                            _revision = '2017-01-13'

                                                                                            def __init__(self):
                                                                                                super().__init__()

                                                                                                self.yang_name = "state"
                                                                                                self.yang_parent_name = "constraint"
                                                                                                self.is_top_level_class = False
                                                                                                self.has_list_ancestor = True
                                                                                                self.ylist_key_names = []
                                                                                                self._child_classes = OrderedDict([])
                                                                                                self._leafs = OrderedDict([
                                                                                                    ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                                    ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                                ])
                                                                                                self.constraint_id = None
                                                                                                self.bandwidth = None
                                                                                                self._segment_path = lambda: "state"
                                                                                                self._is_frozen = True

                                                                                            def __setattr__(self, name, value):
                                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)






                                                                        class UnconstrainedLsp(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 23.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 23
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unconstrained-lsp"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "unconstrained-lsp"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 23.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: count
                                                                                
                                                                                    Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..65535
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "unconstrained-lsp"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.count = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'count'], name, value)



                                                                        class AdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing adjacency SIDs.
                                                                            
                                                                            .. attribute:: adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`AdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids, [], name, value)

                                                                            class AdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "adjacency-sid"
                                                                                    self.yang_parent_name = "adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LanAdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing LAN adjacency
                                                                            SIDs
                                                                            
                                                                            .. attribute:: lan_adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`LanAdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "lan-adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.lan_adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "lan-adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)

                                                                            class LanAdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the LAN Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of LAN Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "lan-adjacency-sid"
                                                                                    self.yang_parent_name = "lan-adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of LAN Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        LAN Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with LAN\-Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: neighbor_id
                                                                                    
                                                                                        System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "lan-adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self.neighbor_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LinkDelay(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 33
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                33.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)



                                                                        class MinMaxLinkDelay(_Entity_):
                                                                            """
                                                                            This container defines min/max link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 34
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "min-max-link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "min-max-link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                34.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: min_delay
                                                                                
                                                                                    Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                .. attribute:: max_delay
                                                                                
                                                                                    Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "min-max-link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                                                        ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.min_delay = None
                                                                                    self.max_delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)



                                                                        class LinkDelayVariation(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay
                                                                            variation.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 35
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay-variation"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay-variation"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                35.
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay-variation"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)



                                                                        class LinkLoss(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link loss delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 36
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-loss"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-loss"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                36.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: link_loss
                                                                                
                                                                                    Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-loss"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('link_loss', (YLeaf(YType.uint32, 'link-loss'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.link_loss = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)



                                                                        class ResidualBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional residual
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 37
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "residual-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "residual-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                37.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "residual-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State, ['bandwidth'], name, value)



                                                                        class AvailableBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional lavailable
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 38
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "available-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "available-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                38.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "available-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'bandwidth'], name, value)



                                                                        class UtilizedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional utilized
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 39
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "utilized-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "utilized-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                39.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "utilized-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'bandwidth'], name, value)





                                                                class UndefinedSubtlvs(_Entity_):
                                                                    """
                                                                    This container describes undefined ISIS TLVs.
                                                                    
                                                                    .. attribute:: undefined_subtlv
                                                                    
                                                                        Sub\-TLVs that are not defined in the model or not recognised by system
                                                                    
                                                                        **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "undefined-subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.undefined_subtlv = YList(self)
                                                                        self._segment_path = lambda: "undefined-subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs, [], name, value)

                                                                    class UndefinedSubtlv(_Entity_):
                                                                        """
                                                                        Sub\-TLVs that are not defined in the model or not
                                                                        recognised by system.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the type of the undefined sub\-TLV
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..255
                                                                        
                                                                            **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of the undefined sub\-TLV
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "undefined-subtlv"
                                                                            self.yang_parent_name = "undefined-subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of the undefined sub\-TLV.
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                TLV Type
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: length
                                                                            
                                                                                TLV length
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                TLV value
                                                                            
                                                                                **type**: str
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "undefined-subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                    ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                    ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.length = None
                                                                                self.value = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIsReachability.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)









                                            class ExtendedIpv4Reachability(_Entity_):
                                                """
                                                This container defines list of IPv4 extended reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                    This container describes IS prefixes
                                                
                                                    **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "extended-ipv4-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes))])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._segment_path = lambda: "extended-ipv4-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability, [], name, value)

                                                class Prefixes(_Entity_):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                        This list describes IPv4 extended prefixes and attributes
                                                    
                                                        **type**: list of    :py:class:`Prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "extended-ipv4-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes, [], name, value)

                                                    class Prefix(_Entity_):
                                                        """
                                                        This list describes IPv4 extended prefixes and
                                                        attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the IPv4 prefix that the TLV describes the attributes of
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of an IPv4 extended prefix
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                            This container describes IS prefix sub\-TLVs
                                                        
                                                            **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                            This container describes undefined ISIS TLVs
                                                        
                                                            **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix, ['prefix'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of an IPv4 extended prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                                The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                                The Sub\-TLV present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                IPv4 prefix contained within extended reachability TLVs
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: metric
                                                            
                                                                ISIS metric value
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 1..16777215
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                    ('s_bit', (YLeaf(YType.boolean, 's-bit'), ['bool'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ])
                                                                self.up_down = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.State, ['up_down', 's_bit', 'prefix', 'metric'], name, value)


                                                        class Subtlvs(_Entity_):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                                List of subTLV types in the LSDB for the specified TLV
                                                            
                                                                **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs, [], name, value)

                                                            class Subtlv(_Entity_):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the sub\-TLV type
                                                                
                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters for a prefix
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag
                                                                
                                                                    This container defines sub\-TLV 1
                                                                
                                                                    **type**:  :py:class:`Tag<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                    This container defines sub\-TLV 2
                                                                
                                                                    **type**:  :py:class:`Tag64<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    This container defines sub\-TLV 4
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                    This container defines sub\-TLV 11
                                                                
                                                                    **type**:  :py:class:`Ipv4SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                    This container defines sub\-TLV 12
                                                                
                                                                    **type**:  :py:class:`Ipv6SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                    This container defines segment routing extensions for prefixes
                                                                
                                                                    **type**:  :py:class:`PrefixSids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    
                                                                        **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 1
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                            List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)



                                                                class Tag64(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 2
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag64"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                            List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..18446744073709551615
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)



                                                                class Flags(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 4
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "flags"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                            Additional prefix reachability flags
                                                                        
                                                                            **type**: list of   :py:class:`Flags_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_')])),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                                External prefix flag. Set if the prefix has been

                                                                                redistributed from another protocol. This includes

                                                                                the case where multiple virtual routers are

                                                                                supported and the source of the redistributed prefix

                                                                                is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                                Readvertisement flag. Set when the prefix has been

                                                                                leaked from one level to another (upwards or

                                                                                downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                                Node flag. Set when the prefix identifies the

                                                                                advertising router, i.e., the prefix is a host

                                                                                prefix advertising  a globally reachable address

                                                                                typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")




                                                                class Ipv4SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 11
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv4-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class Ipv6SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 12
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv6-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class PrefixSids(_Entity_):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    
                                                                        **type**: list of    :py:class:`PrefixSid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)

                                                                    class PrefixSid(_Entity_):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                            Reference to the value of the prefix SID
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters for Prefix\-SID
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                IGP Prefix\-SID value
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..4294967295
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                                Flags associated with Prefix Segment\-ID
                                                                            
                                                                                **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                                Prefix\-SID algorithm to be used for path computation
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags')])),
                                                                                    ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                .. data:: READVERTISEMENT = 0

                                                                                    Readvertisment flag. When set, the prefix to which

                                                                                    this Prefix-SID is attached, has been propagated by

                                                                                    the router either from another level or from

                                                                                    redistribution.

                                                                                .. data:: NODE = 1

                                                                                    Node flag. When set, the Prefix-SID refers to the

                                                                                    router identified by the prefix. Typically, the

                                                                                    N-Flag is set on Prefix-SIDs attached to a router

                                                                                    loopback address.

                                                                                .. data:: NO_PHP = 2

                                                                                    Penultimate-Hop-Popping flag. When set, then the

                                                                                    penultimate hop MUST NOT pop the Prefix-SID before

                                                                                    delivering the packet to the node that advertised

                                                                                    the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                    Explicit-Null flag. When set, any upstream neighbor

                                                                                    of the Prefix-SID originator MUST replace the

                                                                                    Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                    value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                    the packet.

                                                                                .. data:: VALUE = 4

                                                                                    Value flag. When set, the Prefix-SID carries a

                                                                                    value (instead of an index). By default the flag is

                                                                                    UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                    Local flag. When set, the value/index carried by

                                                                                    the Prefix-SID has local significance. By default

                                                                                    the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                NO_PHP = Enum.YLeaf(2, "NO_PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")







                                                        class UndefinedSubtlvs(_Entity_):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                                Sub\-TLVs that are not defined in the model or not recognised by system
                                                            
                                                                **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)

                                                            class UndefinedSubtlv(_Entity_):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the type of the undefined sub\-TLV
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..255
                                                                
                                                                    **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of the undefined sub\-TLV
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        TLV Type
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                        TLV length
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                        TLV value
                                                                    
                                                                        **type**: str
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.ExtendedIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)







                                            class Ipv6Reachability(_Entity_):
                                                """
                                                This container defines list of IPv6 reachability
                                                information.
                                                
                                                .. attribute:: prefixes
                                                
                                                    This container describes IS prefixes
                                                
                                                    **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "ipv6-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes))])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._segment_path = lambda: "ipv6-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability, [], name, value)

                                                class Prefixes(_Entity_):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                        This list defines IPv6 extended prefix attributes
                                                    
                                                        **type**: list of    :py:class:`Prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "ipv6-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes, [], name, value)

                                                    class Prefix(_Entity_):
                                                        """
                                                        This list defines IPv6 extended prefix attributes.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the IPv6 prefix that the TLV corresponds to
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of IPv6 prefix attributes
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                            This container describes IS prefix sub\-TLVs
                                                        
                                                            **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                            This container describes undefined ISIS TLVs
                                                        
                                                            **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ])
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix, ['prefix'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of IPv6 prefix attributes
                                                            
                                                            .. attribute:: up_down
                                                            
                                                                The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: x_bit
                                                            
                                                                The external bit. Set when the prefix was distributed into IS\-IS from another routing protocol
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                                The sub\-tlv present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                IPv6 prefix contained within extended reachability TLVs
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: metric
                                                            
                                                                ISIS metric value
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 1..16777215
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                    ('x_bit', (YLeaf(YType.boolean, 'x-bit'), ['bool'])),
                                                                    ('s_bit', (YLeaf(YType.boolean, 's-bit'), ['bool'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                ])
                                                                self.up_down = None
                                                                self.x_bit = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.State, ['up_down', 'x_bit', 's_bit', 'prefix', 'metric'], name, value)


                                                        class Subtlvs(_Entity_):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                                List of subTLV types in the LSDB for the specified TLV
                                                            
                                                                **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs, [], name, value)

                                                            class Subtlv(_Entity_):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the sub\-TLV type
                                                                
                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters for a prefix
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag
                                                                
                                                                    This container defines sub\-TLV 1
                                                                
                                                                    **type**:  :py:class:`Tag<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                    This container defines sub\-TLV 2
                                                                
                                                                    **type**:  :py:class:`Tag64<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    This container defines sub\-TLV 4
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                    This container defines sub\-TLV 11
                                                                
                                                                    **type**:  :py:class:`Ipv4SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                    This container defines sub\-TLV 12
                                                                
                                                                    **type**:  :py:class:`Ipv6SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                    This container defines segment routing extensions for prefixes
                                                                
                                                                    **type**:  :py:class:`PrefixSids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    
                                                                        **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 1
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                            List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)



                                                                class Tag64(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 2
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag64"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                            List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..18446744073709551615
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)



                                                                class Flags(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 4
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "flags"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                            Additional prefix reachability flags
                                                                        
                                                                            **type**: list of   :py:class:`Flags_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_')])),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                                External prefix flag. Set if the prefix has been

                                                                                redistributed from another protocol. This includes

                                                                                the case where multiple virtual routers are

                                                                                supported and the source of the redistributed prefix

                                                                                is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                                Readvertisement flag. Set when the prefix has been

                                                                                leaked from one level to another (upwards or

                                                                                downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                                Node flag. Set when the prefix identifies the

                                                                                advertising router, i.e., the prefix is a host

                                                                                prefix advertising  a globally reachable address

                                                                                typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")




                                                                class Ipv4SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 11
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv4-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class Ipv6SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 12
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv6-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class PrefixSids(_Entity_):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    
                                                                        **type**: list of    :py:class:`PrefixSid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)

                                                                    class PrefixSid(_Entity_):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                            Reference to the value of the prefix SID
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters for Prefix\-SID
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                IGP Prefix\-SID value
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..4294967295
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                                Flags associated with Prefix Segment\-ID
                                                                            
                                                                                **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                                Prefix\-SID algorithm to be used for path computation
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags')])),
                                                                                    ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                .. data:: READVERTISEMENT = 0

                                                                                    Readvertisment flag. When set, the prefix to which

                                                                                    this Prefix-SID is attached, has been propagated by

                                                                                    the router either from another level or from

                                                                                    redistribution.

                                                                                .. data:: NODE = 1

                                                                                    Node flag. When set, the Prefix-SID refers to the

                                                                                    router identified by the prefix. Typically, the

                                                                                    N-Flag is set on Prefix-SIDs attached to a router

                                                                                    loopback address.

                                                                                .. data:: NO_PHP = 2

                                                                                    Penultimate-Hop-Popping flag. When set, then the

                                                                                    penultimate hop MUST NOT pop the Prefix-SID before

                                                                                    delivering the packet to the node that advertised

                                                                                    the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                    Explicit-Null flag. When set, any upstream neighbor

                                                                                    of the Prefix-SID originator MUST replace the

                                                                                    Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                    value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                    the packet.

                                                                                .. data:: VALUE = 4

                                                                                    Value flag. When set, the Prefix-SID carries a

                                                                                    value (instead of an index). By default the flag is

                                                                                    UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                    Local flag. When set, the value/index carried by

                                                                                    the Prefix-SID has local significance. By default

                                                                                    the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                NO_PHP = Enum.YLeaf(2, "NO_PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")







                                                        class UndefinedSubtlvs(_Entity_):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                                Sub\-TLVs that are not defined in the model or not recognised by system
                                                            
                                                                **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)

                                                            class UndefinedSubtlv(_Entity_):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the type of the undefined sub\-TLV
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..255
                                                                
                                                                    **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of the undefined sub\-TLV
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        TLV Type
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                        TLV length
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                        TLV value
                                                                    
                                                                        **type**: str
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.Ipv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)







                                            class MultiTopology(_Entity_):
                                                """
                                                This container defines the topology supported.
                                                
                                                .. attribute:: topologies
                                                
                                                    This container describes IS topologies
                                                
                                                    **type**:  :py:class:`Topologies<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "multi-topology"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("topologies", ("topologies", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies))])
                                                    self._leafs = OrderedDict()

                                                    self.topologies = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies()
                                                    self.topologies.parent = self
                                                    self._children_name_map["topologies"] = "topologies"
                                                    self._segment_path = lambda: "multi-topology"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology, [], name, value)

                                                class Topologies(_Entity_):
                                                    """
                                                    This container describes IS topologies.
                                                    
                                                    .. attribute:: topology
                                                    
                                                        This list describes a topology
                                                    
                                                        **type**: list of    :py:class:`Topology<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "topologies"
                                                        self.yang_parent_name = "multi-topology"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("topology", ("topology", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology))])
                                                        self._leafs = OrderedDict()

                                                        self.topology = YList(self)
                                                        self._segment_path = lambda: "topologies"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies, [], name, value)

                                                    class Topology(_Entity_):
                                                        """
                                                        This list describes a topology.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                            Reference to the multi\-topology ID being described by the list entry
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4095
                                                        
                                                            **refers to**:  :py:class:`mt_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of IS multi\-topology TLV 229
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "topology"
                                                            self.yang_parent_name = "topologies"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State))])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', (YLeaf(YType.str, 'mt-id'), ['int'])),
                                                            ])
                                                            self.mt_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._segment_path = lambda: "topology" + "[mt-id='" + str(self.mt_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology, ['mt_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of IS multi\-topology TLV 229.
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                                Multi\-topology ID
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 0..4095
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: attributes
                                                            
                                                                Attributes of the LSP for the associated topology
                                                            
                                                                **type**:  :py:class:`Attributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State.Attributes>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "topology"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                    ('attributes', (YLeaf(YType.enumeration, 'attributes'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State.Attributes')])),
                                                                ])
                                                                self.mt_id = None
                                                                self.attributes = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MultiTopology.Topologies.Topology.State, ['mt_id', 'attributes'], name, value)

                                                            class Attributes(Enum):
                                                                """
                                                                Attributes (Enum Class)

                                                                .. data:: OVERLOAD = 0

                                                                    When set, node is overloaded, still part of

                                                                    the topology but cannot be used for transit.

                                                                .. data:: ATTACHED = 1

                                                                    When set, node is attached to another area

                                                                    using the referred metric and can be used as

                                                                    default gateway.

                                                                """

                                                                OVERLOAD = Enum.YLeaf(0, "OVERLOAD")

                                                                ATTACHED = Enum.YLeaf(1, "ATTACHED")






                                            class IsisNeighborAttribute(_Entity_):
                                                """
                                                This container defines list of ISIS topology neighbors
                                                for extended ISIS LSP (multiple system IDs). 
                                                
                                                .. attribute:: neighbors
                                                
                                                    This container describes IS neighbors
                                                
                                                    **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "isis-neighbor-attribute"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors))])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._segment_path = lambda: "isis-neighbor-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute, [], name, value)

                                                class Neighbors(_Entity_):
                                                    """
                                                    This container describes IS neighbors.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                        This list describes ISIS extended neighbors and reachability attributes
                                                    
                                                        **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "isis-neighbor-attribute"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors, [], name, value)

                                                    class Neighbor(_Entity_):
                                                        """
                                                        This list describes ISIS extended neighbors and
                                                        reachability attributes.
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                            Reference to the neighboring system's system ID
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **refers to**:  :py:class:`system_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters corresponding to the extended neighbour
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: instances
                                                        
                                                            This list contains all instances of an adjacency between the originating IS and the remote IS. Multiple instances are used where there are parallel adjacencies between two systems
                                                        
                                                            **type**:  :py:class:`Instances<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['system_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State)), ("instances", ("instances", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances))])
                                                            self._leafs = OrderedDict([
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                            ])
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.instances = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances()
                                                            self.instances.parent = self
                                                            self._children_name_map["instances"] = "instances"
                                                            self._segment_path = lambda: "neighbor" + "[system-id='" + str(self.system_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor, ['system_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters corresponding to the extended
                                                            neighbour.
                                                            
                                                            .. attribute:: system_id
                                                            
                                                                System\-id of the neighbor
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.system_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.State, ['system_id'], name, value)


                                                        class Instances(_Entity_):
                                                            """
                                                            This list contains all instances of an adjacency
                                                            between the originating IS and the remote IS.
                                                            Multiple instances are used where there are
                                                            parallel adjacencies between two systems.
                                                            
                                                            .. attribute:: instance
                                                            
                                                                Instance of the TLV to the remote IS neighbor
                                                            
                                                                **type**: list of    :py:class:`Instance<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "instances"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("instance", ("instance", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance))])
                                                                self._leafs = OrderedDict()

                                                                self.instance = YList(self)
                                                                self._segment_path = lambda: "instances"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances, [], name, value)

                                                            class Instance(_Entity_):
                                                                """
                                                                Instance of the TLV to the remote IS neighbor.
                                                                
                                                                .. attribute:: id  (key)
                                                                
                                                                    Reference to the unique identifier for the instance of the extended IS reachability sub\-TLV
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..18446744073709551615
                                                                
                                                                    **refers to**:  :py:class:`id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of extended neighbor
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: subtlvs
                                                                
                                                                    This container describes IS Neighbor sub\-TLVs
                                                                
                                                                    **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: undefined_subtlvs
                                                                
                                                                    This container describes undefined ISIS TLVs
                                                                
                                                                    **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "instance"
                                                                    self.yang_parent_name = "instances"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['id']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs))])
                                                                    self._leafs = OrderedDict([
                                                                        ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                                                    ])
                                                                    self.id = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs()
                                                                    self.subtlvs.parent = self
                                                                    self._children_name_map["subtlvs"] = "subtlvs"

                                                                    self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs()
                                                                    self.undefined_subtlvs.parent = self
                                                                    self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                                    self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance, ['id'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of extended neighbor
                                                                    
                                                                    .. attribute:: id
                                                                    
                                                                        Unique identifier for the instance of the TLV for the IS neighbor. The instance ID is not required to be consistent across across readvertisements of the LSP
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..18446744073709551615
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                        Metric value
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 1..16777215
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('id', (YLeaf(YType.uint64, 'id'), ['int'])),
                                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                        ])
                                                                        self.id = None
                                                                        self.metric = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State, ['id', 'metric'], name, value)


                                                                class Subtlvs(_Entity_):
                                                                    """
                                                                    This container describes IS Neighbor sub\-TLVs.
                                                                    
                                                                    .. attribute:: subtlv
                                                                    
                                                                        List of subTLV types in the LSDB for the specified TLV
                                                                    
                                                                        **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.subtlv = YList(self)
                                                                        self._segment_path = lambda: "subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs, [], name, value)

                                                                    class Subtlv(_Entity_):
                                                                        """
                                                                        List of subTLV types in the LSDB for the specified TLV.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the sub\-TLV type
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of IS neighbor state
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                            This container defines sub\-TLV 3
                                                                        
                                                                            **type**:  :py:class:`AdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_id
                                                                        
                                                                            This container defines sub\-TLV 4
                                                                        
                                                                            **type**:  :py:class:`LinkId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                            This container defines sub\-TLV 6
                                                                        
                                                                            **type**:  :py:class:`Ipv4InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 8
                                                                        
                                                                            **type**:  :py:class:`Ipv4NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 9
                                                                        
                                                                            **type**:  :py:class:`MaxLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 10
                                                                        
                                                                            **type**:  :py:class:`MaxReservableLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unreserved_bandwidth
                                                                        
                                                                            This container defines unreserved\-bandwidth. The units are bytes per second
                                                                        
                                                                            **type**:  :py:class:`UnreservedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                            This container defines sub\-TLV 12
                                                                        
                                                                            **type**:  :py:class:`Ipv6InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 13
                                                                        
                                                                            **type**:  :py:class:`Ipv6NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                            This container defines sub\-TLV 14
                                                                        
                                                                            **type**:  :py:class:`ExtendedAdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                            This container defines sub\-TLV 18
                                                                        
                                                                            **type**:  :py:class:`TeDefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_attributes
                                                                        
                                                                            This container defines link\-attributes
                                                                        
                                                                            **type**:  :py:class:`LinkAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                            ISIS LSDB parameters relating to the type of link protection offered
                                                                        
                                                                            **type**:  :py:class:`LinkProtectionType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: bandwidth_constraints
                                                                        
                                                                            This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                        
                                                                            **type**:  :py:class:`BandwidthConstraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                            This container defines sub\-TLV 23
                                                                        
                                                                            **type**:  :py:class:`UnconstrainedLsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: adjacency_sids
                                                                        
                                                                            This container defines segment routing adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`AdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: lan_adjacency_sids
                                                                        
                                                                            This container defines segment routing LAN adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`LanAdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay
                                                                        
                                                                            This container defines unidirectional link delay
                                                                        
                                                                            **type**:  :py:class:`LinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: min_max_link_delay
                                                                        
                                                                            This container defines min/max link delay
                                                                        
                                                                            **type**:  :py:class:`MinMaxLinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay_variation
                                                                        
                                                                            This container defines unidirectional link delay variation
                                                                        
                                                                            **type**:  :py:class:`LinkDelayVariation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                            This container defines unidirectional link loss delay
                                                                        
                                                                            **type**:  :py:class:`LinkLoss<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                            This container defines unidirectional residual bandwidth
                                                                        
                                                                            **type**:  :py:class:`ResidualBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                            This container defines unidirectional lavailable bandwidth
                                                                        
                                                                            **type**:  :py:class:`AvailableBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                            This container defines unidirectional utilized bandwidth
                                                                        
                                                                            **type**:  :py:class:`UtilizedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "subtlv"
                                                                            self.yang_parent_name = "subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup)), ("link-id", ("link_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"

                                                                            self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup()
                                                                            self.admin_group.parent = self
                                                                            self._children_name_map["admin_group"] = "admin-group"

                                                                            self.link_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId()
                                                                            self.link_id.parent = self
                                                                            self._children_name_map["link_id"] = "link-id"

                                                                            self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                            self.ipv4_interface_address.parent = self
                                                                            self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"

                                                                            self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                            self.ipv4_neighbor_address.parent = self
                                                                            self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"

                                                                            self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                            self.max_link_bandwidth.parent = self
                                                                            self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"

                                                                            self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                            self.max_reservable_link_bandwidth.parent = self
                                                                            self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"

                                                                            self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                            self.unreserved_bandwidth.parent = self
                                                                            self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"

                                                                            self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                            self.ipv6_interface_address.parent = self
                                                                            self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"

                                                                            self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                            self.ipv6_neighbor_address.parent = self
                                                                            self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"

                                                                            self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                            self.extended_admin_group.parent = self
                                                                            self._children_name_map["extended_admin_group"] = "extended-admin-group"

                                                                            self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric()
                                                                            self.te_default_metric.parent = self
                                                                            self._children_name_map["te_default_metric"] = "te-default-metric"

                                                                            self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes()
                                                                            self.link_attributes.parent = self
                                                                            self._children_name_map["link_attributes"] = "link-attributes"

                                                                            self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType()
                                                                            self.link_protection_type.parent = self
                                                                            self._children_name_map["link_protection_type"] = "link-protection-type"

                                                                            self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints()
                                                                            self.bandwidth_constraints.parent = self
                                                                            self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"

                                                                            self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                            self.unconstrained_lsp.parent = self
                                                                            self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"

                                                                            self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids()
                                                                            self.adjacency_sids.parent = self
                                                                            self._children_name_map["adjacency_sids"] = "adjacency-sids"

                                                                            self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids()
                                                                            self.lan_adjacency_sids.parent = self
                                                                            self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"

                                                                            self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay()
                                                                            self.link_delay.parent = self
                                                                            self._children_name_map["link_delay"] = "link-delay"

                                                                            self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                            self.min_max_link_delay.parent = self
                                                                            self._children_name_map["min_max_link_delay"] = "min-max-link-delay"

                                                                            self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation()
                                                                            self.link_delay_variation.parent = self
                                                                            self._children_name_map["link_delay_variation"] = "link-delay-variation"

                                                                            self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss()
                                                                            self.link_loss.parent = self
                                                                            self._children_name_map["link_loss"] = "link-loss"

                                                                            self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth()
                                                                            self.residual_bandwidth.parent = self
                                                                            self._children_name_map["residual_bandwidth"] = "residual-bandwidth"

                                                                            self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth()
                                                                            self.available_bandwidth.parent = self
                                                                            self._children_name_map["available_bandwidth"] = "available-bandwidth"

                                                                            self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                            self.utilized_bandwidth.parent = self
                                                                            self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                            self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of IS neighbor state
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                            
                                                                                **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ])
                                                                                self.type = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                        class AdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 3.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 3
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 3.
                                                                                
                                                                                .. attribute:: admin_group
                                                                                
                                                                                    The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('admin_group', (YLeafList(YType.uint32, 'admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)



                                                                        class LinkId(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 4.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 4
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-id"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-id"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 4.
                                                                                
                                                                                .. attribute:: local
                                                                                
                                                                                    The value field of this sub\-TLV contains 4 octets of Link Local Identifier followed by 4 octets of Link Remote Identifier
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: remote
                                                                                
                                                                                    If the Link Remote Identifier is unknown, it is set to 0
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-id"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                                                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                                                                    ])
                                                                                    self.local = None
                                                                                    self.remote = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State, ['local', 'remote'], name, value)



                                                                        class Ipv4InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 6.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 6
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 6.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv4NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 8.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 8
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 8.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['address'], name, value)



                                                                        class MaxLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 9.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 9
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 9.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class MaxReservableLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 10.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 10
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-reservable-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-reservable-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 10.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class UnreservedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unreserved\-bandwidth. The units
                                                                            are bytes per second.
                                                                            
                                                                            .. attribute:: setup_priority
                                                                            
                                                                                Setup priority (0 through 7) for unreserved bandwidth
                                                                            
                                                                                **type**: list of    :py:class:`SetupPriority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unreserved-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                                self._leafs = OrderedDict()

                                                                                self.setup_priority = YList(self)
                                                                                self._segment_path = lambda: "unreserved-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)

                                                                            class SetupPriority(_Entity_):
                                                                                """
                                                                                Setup priority (0 through 7) for unreserved
                                                                                bandwidth.
                                                                                
                                                                                .. attribute:: priority  (key)
                                                                                
                                                                                    Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..7
                                                                                
                                                                                    **refers to**:  :py:class:`priority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 11
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "setup-priority"
                                                                                    self.yang_parent_name = "unreserved-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['priority']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('priority', (YLeaf(YType.str, 'priority'), ['int'])),
                                                                                    ])
                                                                                    self.priority = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    11.
                                                                                    
                                                                                    .. attribute:: priority
                                                                                    
                                                                                        Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..7
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                        The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **length:** 4..4
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                        **units**: bytes per second
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "setup-priority"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                                            ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                        ])
                                                                                        self.priority = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'bandwidth'], name, value)




                                                                        class Ipv6InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 12.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 12
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 12.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv6NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 13.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 13
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 13.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['address'], name, value)



                                                                        class ExtendedAdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 14.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 14
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "extended-admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "extended-admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 14.
                                                                                
                                                                                .. attribute:: extended_admin_group
                                                                                
                                                                                    The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "extended-admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('extended_admin_group', (YLeafList(YType.uint32, 'extended-admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.extended_admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)



                                                                        class TeDefaultMetric(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 18.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 18
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "te-default-metric"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "te-default-metric"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 18.
                                                                                
                                                                                .. attribute:: metric
                                                                                
                                                                                    This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "te-default-metric"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                                    ])
                                                                                    self.metric = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State, ['metric'], name, value)



                                                                        class LinkAttributes(_Entity_):
                                                                            """
                                                                            This container defines link\-attributes.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 19
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-attributes"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-attributes"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                19.
                                                                                
                                                                                .. attribute:: local_protection
                                                                                
                                                                                    Link local\-protection attributes
                                                                                
                                                                                    **type**: list of   :py:class:`LocalProtection<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-attributes"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local_protection', (YLeafList(YType.enumeration, 'local-protection'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection')])),
                                                                                    ])
                                                                                    self.local_protection = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                                class LocalProtection(Enum):
                                                                                    """
                                                                                    LocalProtection (Enum Class)

                                                                                    .. data:: LOCAL_PROTECTION = 0

                                                                                        If set, local protection is available for the

                                                                                        link.

                                                                                    .. data:: LINK_EXCLUDED = 1

                                                                                        If set, the link is excluded from local

                                                                                        protection.

                                                                                    """

                                                                                    LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                                    LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")




                                                                        class LinkProtectionType(_Entity_):
                                                                            """
                                                                            ISIS LSDB parameters relating to the type of link
                                                                            protection offered.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 20
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-protection-type"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-protection-type"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 20.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    Link protection capabilities
                                                                                
                                                                                    **type**: list of   :py:class:`Type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-protection-type"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeafList(YType.enumeration, 'type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type')])),
                                                                                    ])
                                                                                    self.type = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State, ['type'], name, value)

                                                                                class Type(Enum):
                                                                                    """
                                                                                    Type (Enum Class)

                                                                                    .. data:: EXTRA_TRAFFIC = 0

                                                                                        If set the link has extra traffic protection. If

                                                                                        the link is of type Extra Traffic, it means that

                                                                                        the link is protecting another link or links. The

                                                                                        LSPs on a link of this type will be lost if any of

                                                                                        the links it is protecting fail.

                                                                                    .. data:: UNPROTECTED = 1

                                                                                        If set, the link is unprotected. If the link is

                                                                                        of type Unprotected, it means that there is no

                                                                                        other link protecting this link.  The LSPs on a

                                                                                        link of this type will be lost if the link

                                                                                        fails.

                                                                                    .. data:: SHARED = 2

                                                                                        If set, the link has shared protection. If the

                                                                                        link is of type Shared, it means that there are

                                                                                        one or more disjoint links of type Extra Traffic

                                                                                        that are protecting this link.  These Extra

                                                                                        Traffic links are shared between one or more links

                                                                                        of type Shared.

                                                                                    .. data:: ONE_ONE = 3

                                                                                        If set, the link has dedicated 1:1 protection. If

                                                                                        the link is of type Dedicated 1:1, it means that

                                                                                        there is one dedicated disjoint link of type Extra

                                                                                        Traffic that is protecting this link.

                                                                                    .. data:: PLUS_ONE = 4

                                                                                        If set, the link has dedicated 1+1 protection. If

                                                                                        the link is of type Dedicated 1+1, it means that a

                                                                                        dedicated disjoint link is protecting this link.

                                                                                        However, the protecting link is not advertised in

                                                                                        the link state database and is therefore not

                                                                                        available for the routing of LSPs.

                                                                                    .. data:: ENHANCED = 5

                                                                                        If set the link has enhanced protection.  If the

                                                                                        link is of type Enhanced, it means that a

                                                                                        protection scheme that is more reliable than

                                                                                        Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                                        being used to protect this link.

                                                                                    """

                                                                                    EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                                    UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                                    SHARED = Enum.YLeaf(2, "SHARED")

                                                                                    ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                                    PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                                    ENHANCED = Enum.YLeaf(5, "ENHANCED")




                                                                        class BandwidthConstraints(_Entity_):
                                                                            """
                                                                            This container defines bandwidth\-constraints. For DS\-TE,
                                                                            the existing Maximum Reservable link bandwidth parameter
                                                                            is retained, but its semantics is generalized and
                                                                            interpreted as the aggregate bandwidth constraint across
                                                                            all Class\-Types
                                                                            
                                                                            .. attribute:: bandwidth_constraint
                                                                            
                                                                                List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                            
                                                                                **type**: list of    :py:class:`BandwidthConstraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "bandwidth-constraints"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.bandwidth_constraint = YList(self)
                                                                                self._segment_path = lambda: "bandwidth-constraints"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)

                                                                            class BandwidthConstraint(_Entity_):
                                                                                """
                                                                                List of the Bandwidth Constraints sub\-TLV instances
                                                                                present in the TLV.
                                                                                
                                                                                .. attribute:: model_id  (key)
                                                                                
                                                                                    Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..255
                                                                                
                                                                                    **refers to**:  :py:class:`model_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 22
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: constraints
                                                                                
                                                                                    Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**:  :py:class:`Constraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "bandwidth-constraint"
                                                                                    self.yang_parent_name = "bandwidth-constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['model_id']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('model_id', (YLeaf(YType.str, 'model-id'), ['int'])),
                                                                                    ])
                                                                                    self.model_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"

                                                                                    self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                                    self.constraints.parent = self
                                                                                    self._children_name_map["constraints"] = "constraints"
                                                                                    self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    22.
                                                                                    
                                                                                    .. attribute:: model_id
                                                                                    
                                                                                        Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('model_id', (YLeaf(YType.uint8, 'model-id'), ['int'])),
                                                                                        ])
                                                                                        self.model_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                                class Constraints(_Entity_):
                                                                                    """
                                                                                    Constraints contained within the Bandwidth
                                                                                    Constraints sub\-TLV
                                                                                    
                                                                                    .. attribute:: constraint
                                                                                    
                                                                                        List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                                    
                                                                                        **type**: list of    :py:class:`Constraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "constraints"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                        self._leafs = OrderedDict()

                                                                                        self.constraint = YList(self)
                                                                                        self._segment_path = lambda: "constraints"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)

                                                                                    class Constraint(_Entity_):
                                                                                        """
                                                                                        List of the constraints within the Bandwidth
                                                                                        Constraints sub\-TLV. The BC0 level is indicated by
                                                                                        the constraint\-id leaf being set to 0, with BCN
                                                                                        being indicated by constraint\-id N.
                                                                                        
                                                                                        .. attribute:: constraint_id  (key)
                                                                                        
                                                                                            Reference to the unique ID for the BCN level
                                                                                        
                                                                                            **type**: int
                                                                                        
                                                                                                **range:** 0..4294967295
                                                                                        
                                                                                            **refers to**:  :py:class:`constraint_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        .. attribute:: state
                                                                                        
                                                                                            Operational state parameters of the BCN level
                                                                                        
                                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        """
                                                                                        _prefix = 'oc-netinst'
                                                                                        _revision = '2017-01-13'

                                                                                        def __init__(self):
                                                                                            super().__init__()

                                                                                            self.yang_name = "constraint"
                                                                                            self.yang_parent_name = "constraints"
                                                                                            self.is_top_level_class = False
                                                                                            self.has_list_ancestor = True
                                                                                            self.ylist_key_names = ['constraint_id']
                                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                            self._leafs = OrderedDict([
                                                                                                ('constraint_id', (YLeaf(YType.str, 'constraint-id'), ['int'])),
                                                                                            ])
                                                                                            self.constraint_id = None

                                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                            self.state.parent = self
                                                                                            self._children_name_map["state"] = "state"
                                                                                            self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"
                                                                                            self._is_frozen = True

                                                                                        def __setattr__(self, name, value):
                                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)

                                                                                        class State(_Entity_):
                                                                                            """
                                                                                            Operational state parameters of the BCN level
                                                                                            
                                                                                            .. attribute:: constraint_id
                                                                                            
                                                                                                Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                            
                                                                                                **type**: int
                                                                                            
                                                                                                    **range:** 0..4294967295
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                            .. attribute:: bandwidth
                                                                                            
                                                                                                The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                            
                                                                                                **type**: str
                                                                                            
                                                                                                    **length:** 4..4
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                                **units**: bytes per second
                                                                                            
                                                                                            """
                                                                                            _prefix = 'oc-netinst'
                                                                                            _revision = '2017-01-13'

                                                                                            def __init__(self):
                                                                                                super().__init__()

                                                                                                self.yang_name = "state"
                                                                                                self.yang_parent_name = "constraint"
                                                                                                self.is_top_level_class = False
                                                                                                self.has_list_ancestor = True
                                                                                                self.ylist_key_names = []
                                                                                                self._child_classes = OrderedDict([])
                                                                                                self._leafs = OrderedDict([
                                                                                                    ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                                    ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                                ])
                                                                                                self.constraint_id = None
                                                                                                self.bandwidth = None
                                                                                                self._segment_path = lambda: "state"
                                                                                                self._is_frozen = True

                                                                                            def __setattr__(self, name, value):
                                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)






                                                                        class UnconstrainedLsp(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 23.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 23
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unconstrained-lsp"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "unconstrained-lsp"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 23.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: count
                                                                                
                                                                                    Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..65535
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "unconstrained-lsp"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.count = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'count'], name, value)



                                                                        class AdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing adjacency SIDs.
                                                                            
                                                                            .. attribute:: adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`AdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids, [], name, value)

                                                                            class AdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "adjacency-sid"
                                                                                    self.yang_parent_name = "adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LanAdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing LAN adjacency
                                                                            SIDs
                                                                            
                                                                            .. attribute:: lan_adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`LanAdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "lan-adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.lan_adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "lan-adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)

                                                                            class LanAdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the LAN Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of LAN Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "lan-adjacency-sid"
                                                                                    self.yang_parent_name = "lan-adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of LAN Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        LAN Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with LAN\-Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: neighbor_id
                                                                                    
                                                                                        System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "lan-adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self.neighbor_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LinkDelay(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 33
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                33.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)



                                                                        class MinMaxLinkDelay(_Entity_):
                                                                            """
                                                                            This container defines min/max link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 34
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "min-max-link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "min-max-link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                34.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: min_delay
                                                                                
                                                                                    Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                .. attribute:: max_delay
                                                                                
                                                                                    Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "min-max-link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                                                        ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.min_delay = None
                                                                                    self.max_delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)



                                                                        class LinkDelayVariation(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay
                                                                            variation.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 35
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay-variation"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay-variation"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                35.
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay-variation"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)



                                                                        class LinkLoss(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link loss delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 36
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-loss"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-loss"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                36.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: link_loss
                                                                                
                                                                                    Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-loss"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('link_loss', (YLeaf(YType.uint32, 'link-loss'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.link_loss = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)



                                                                        class ResidualBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional residual
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 37
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "residual-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "residual-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                37.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "residual-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State, ['bandwidth'], name, value)



                                                                        class AvailableBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional lavailable
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 38
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "available-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "available-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                38.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "available-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'bandwidth'], name, value)



                                                                        class UtilizedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional utilized
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 39
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "utilized-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "utilized-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                39.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "utilized-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'bandwidth'], name, value)





                                                                class UndefinedSubtlvs(_Entity_):
                                                                    """
                                                                    This container describes undefined ISIS TLVs.
                                                                    
                                                                    .. attribute:: undefined_subtlv
                                                                    
                                                                        Sub\-TLVs that are not defined in the model or not recognised by system
                                                                    
                                                                        **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "undefined-subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.undefined_subtlv = YList(self)
                                                                        self._segment_path = lambda: "undefined-subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs, [], name, value)

                                                                    class UndefinedSubtlv(_Entity_):
                                                                        """
                                                                        Sub\-TLVs that are not defined in the model or not
                                                                        recognised by system.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the type of the undefined sub\-TLV
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..255
                                                                        
                                                                            **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of the undefined sub\-TLV
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "undefined-subtlv"
                                                                            self.yang_parent_name = "undefined-subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of the undefined sub\-TLV.
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                TLV Type
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: length
                                                                            
                                                                                TLV length
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                TLV value
                                                                            
                                                                                **type**: str
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "undefined-subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                    ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                    ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.length = None
                                                                                self.value = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)









                                            class IsAliasId(_Entity_):
                                                """
                                                This container defines the IS\-Alias TLV which allows
                                                extension\-capable ISs to recognize the Originating System
                                                of an Extended LSP set. It identifies the Normal system\-
                                                id of the Originating System.
                                                
                                                .. attribute:: state
                                                
                                                    State parameters of alias ID
                                                
                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "is-alias-id"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State))])
                                                    self._leafs = OrderedDict()

                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State()
                                                    self.state.parent = self
                                                    self._children_name_map["state"] = "state"
                                                    self._segment_path = lambda: "is-alias-id"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId, [], name, value)

                                                class State(_Entity_):
                                                    """
                                                    State parameters of alias ID.
                                                    
                                                    .. attribute:: alias_id
                                                    
                                                        List of alias ID(s)
                                                    
                                                        **type**: str
                                                    
                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "state"
                                                        self.yang_parent_name = "is-alias-id"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('alias_id', (YLeaf(YType.str, 'alias-id'), ['str'])),
                                                        ])
                                                        self.alias_id = None
                                                        self._segment_path = lambda: "state"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.IsAliasId.State, ['alias_id'], name, value)



                                            class MtIsn(_Entity_):
                                                """
                                                This container defines list of ISIS multi\-topology
                                                neighbors.
                                                
                                                .. attribute:: neighbors
                                                
                                                    MT\-IS neigbor attributes
                                                
                                                    **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "mt-isn"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors))])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._segment_path = lambda: "mt-isn"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn, [], name, value)

                                                class Neighbors(_Entity_):
                                                    """
                                                    MT\-IS neigbor attributes.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                        This container describes IS neighbors
                                                    
                                                        **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "mt-isn"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors, [], name, value)

                                                    class Neighbor(_Entity_):
                                                        """
                                                        This container describes IS neighbors.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                            Reference to the topology that the neighbor is within
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4095
                                                        
                                                            **refers to**:  :py:class:`mt_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                            Reference to the System ID of the neighbor
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **refers to**:  :py:class:`system_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            Operational state parameters related to the MT ISN TLV
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: instances
                                                        
                                                            This list contains all instances of an adjacency between the originating and remote IS. Multiple instances are used to indicate where there are parallel adjacencies between systems
                                                        
                                                            **type**:  :py:class:`Instances<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id','system_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State)), ("instances", ("instances", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances))])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', (YLeaf(YType.str, 'mt-id'), ['int'])),
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                            ])
                                                            self.mt_id = None
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.instances = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances()
                                                            self.instances.parent = self
                                                            self._children_name_map["instances"] = "instances"
                                                            self._segment_path = lambda: "neighbor" + "[mt-id='" + str(self.mt_id) + "']" + "[system-id='" + str(self.system_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor, ['mt_id', 'system_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            Operational state parameters related to the
                                                            MT ISN TLV.
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                                Identifier of a topology being announced
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 0..4095
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: system_id
                                                            
                                                                System\-id of the IS neighbor
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.mt_id = None
                                                                self.system_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.State, ['mt_id', 'system_id'], name, value)


                                                        class Instances(_Entity_):
                                                            """
                                                            This list contains all instances of an adjacency
                                                            between the originating and remote IS. Multiple
                                                            instances are used to indicate where there are
                                                            parallel adjacencies between systems.
                                                            
                                                            .. attribute:: instance
                                                            
                                                                Instance of TLV\-222 between the originating and remote IS
                                                            
                                                                **type**: list of    :py:class:`Instance<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "instances"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("instance", ("instance", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance))])
                                                                self._leafs = OrderedDict()

                                                                self.instance = YList(self)
                                                                self._segment_path = lambda: "instances"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances, [], name, value)

                                                            class Instance(_Entity_):
                                                                """
                                                                Instance of TLV\-222 between the originating
                                                                and remote IS.
                                                                
                                                                .. attribute:: id  (key)
                                                                
                                                                    Reference to the unique identifier for the instance of the multi\-topology IS neighbor TLV instance
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..18446744073709551615
                                                                
                                                                    **refers to**:  :py:class:`id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of MT neighbor
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: subtlvs
                                                                
                                                                    This container describes IS Neighbor sub\-TLVs
                                                                
                                                                    **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: undefined_subtlvs
                                                                
                                                                    This container describes undefined ISIS TLVs
                                                                
                                                                    **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "instance"
                                                                    self.yang_parent_name = "instances"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['id']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs))])
                                                                    self._leafs = OrderedDict([
                                                                        ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                                                    ])
                                                                    self.id = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs()
                                                                    self.subtlvs.parent = self
                                                                    self._children_name_map["subtlvs"] = "subtlvs"

                                                                    self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs()
                                                                    self.undefined_subtlvs.parent = self
                                                                    self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                                    self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance, ['id'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of MT neighbor.
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                        ISIS metric value
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 1..16777215
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: id
                                                                    
                                                                        Unique identifier for the TLV instance for the neighbor. The ID is not required to be consistent across readvertisements of the LSP
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..18446744073709551615
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                            ('id', (YLeaf(YType.uint64, 'id'), ['int'])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.id = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.State, ['metric', 'id'], name, value)


                                                                class Subtlvs(_Entity_):
                                                                    """
                                                                    This container describes IS Neighbor sub\-TLVs.
                                                                    
                                                                    .. attribute:: subtlv
                                                                    
                                                                        List of subTLV types in the LSDB for the specified TLV
                                                                    
                                                                        **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.subtlv = YList(self)
                                                                        self._segment_path = lambda: "subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs, [], name, value)

                                                                    class Subtlv(_Entity_):
                                                                        """
                                                                        List of subTLV types in the LSDB for the specified TLV.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the sub\-TLV type
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of IS neighbor state
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                            This container defines sub\-TLV 3
                                                                        
                                                                            **type**:  :py:class:`AdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_id
                                                                        
                                                                            This container defines sub\-TLV 4
                                                                        
                                                                            **type**:  :py:class:`LinkId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                            This container defines sub\-TLV 6
                                                                        
                                                                            **type**:  :py:class:`Ipv4InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 8
                                                                        
                                                                            **type**:  :py:class:`Ipv4NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 9
                                                                        
                                                                            **type**:  :py:class:`MaxLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 10
                                                                        
                                                                            **type**:  :py:class:`MaxReservableLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unreserved_bandwidth
                                                                        
                                                                            This container defines unreserved\-bandwidth. The units are bytes per second
                                                                        
                                                                            **type**:  :py:class:`UnreservedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                            This container defines sub\-TLV 12
                                                                        
                                                                            **type**:  :py:class:`Ipv6InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 13
                                                                        
                                                                            **type**:  :py:class:`Ipv6NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                            This container defines sub\-TLV 14
                                                                        
                                                                            **type**:  :py:class:`ExtendedAdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                            This container defines sub\-TLV 18
                                                                        
                                                                            **type**:  :py:class:`TeDefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_attributes
                                                                        
                                                                            This container defines link\-attributes
                                                                        
                                                                            **type**:  :py:class:`LinkAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                            ISIS LSDB parameters relating to the type of link protection offered
                                                                        
                                                                            **type**:  :py:class:`LinkProtectionType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: bandwidth_constraints
                                                                        
                                                                            This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                        
                                                                            **type**:  :py:class:`BandwidthConstraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                            This container defines sub\-TLV 23
                                                                        
                                                                            **type**:  :py:class:`UnconstrainedLsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: adjacency_sids
                                                                        
                                                                            This container defines segment routing adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`AdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: lan_adjacency_sids
                                                                        
                                                                            This container defines segment routing LAN adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`LanAdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay
                                                                        
                                                                            This container defines unidirectional link delay
                                                                        
                                                                            **type**:  :py:class:`LinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: min_max_link_delay
                                                                        
                                                                            This container defines min/max link delay
                                                                        
                                                                            **type**:  :py:class:`MinMaxLinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay_variation
                                                                        
                                                                            This container defines unidirectional link delay variation
                                                                        
                                                                            **type**:  :py:class:`LinkDelayVariation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                            This container defines unidirectional link loss delay
                                                                        
                                                                            **type**:  :py:class:`LinkLoss<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                            This container defines unidirectional residual bandwidth
                                                                        
                                                                            **type**:  :py:class:`ResidualBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                            This container defines unidirectional lavailable bandwidth
                                                                        
                                                                            **type**:  :py:class:`AvailableBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                            This container defines unidirectional utilized bandwidth
                                                                        
                                                                            **type**:  :py:class:`UtilizedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "subtlv"
                                                                            self.yang_parent_name = "subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup)), ("link-id", ("link_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"

                                                                            self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup()
                                                                            self.admin_group.parent = self
                                                                            self._children_name_map["admin_group"] = "admin-group"

                                                                            self.link_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId()
                                                                            self.link_id.parent = self
                                                                            self._children_name_map["link_id"] = "link-id"

                                                                            self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                            self.ipv4_interface_address.parent = self
                                                                            self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"

                                                                            self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                            self.ipv4_neighbor_address.parent = self
                                                                            self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"

                                                                            self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                            self.max_link_bandwidth.parent = self
                                                                            self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"

                                                                            self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                            self.max_reservable_link_bandwidth.parent = self
                                                                            self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"

                                                                            self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                            self.unreserved_bandwidth.parent = self
                                                                            self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"

                                                                            self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                            self.ipv6_interface_address.parent = self
                                                                            self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"

                                                                            self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                            self.ipv6_neighbor_address.parent = self
                                                                            self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"

                                                                            self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                            self.extended_admin_group.parent = self
                                                                            self._children_name_map["extended_admin_group"] = "extended-admin-group"

                                                                            self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric()
                                                                            self.te_default_metric.parent = self
                                                                            self._children_name_map["te_default_metric"] = "te-default-metric"

                                                                            self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes()
                                                                            self.link_attributes.parent = self
                                                                            self._children_name_map["link_attributes"] = "link-attributes"

                                                                            self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType()
                                                                            self.link_protection_type.parent = self
                                                                            self._children_name_map["link_protection_type"] = "link-protection-type"

                                                                            self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints()
                                                                            self.bandwidth_constraints.parent = self
                                                                            self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"

                                                                            self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                            self.unconstrained_lsp.parent = self
                                                                            self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"

                                                                            self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids()
                                                                            self.adjacency_sids.parent = self
                                                                            self._children_name_map["adjacency_sids"] = "adjacency-sids"

                                                                            self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids()
                                                                            self.lan_adjacency_sids.parent = self
                                                                            self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"

                                                                            self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay()
                                                                            self.link_delay.parent = self
                                                                            self._children_name_map["link_delay"] = "link-delay"

                                                                            self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                            self.min_max_link_delay.parent = self
                                                                            self._children_name_map["min_max_link_delay"] = "min-max-link-delay"

                                                                            self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation()
                                                                            self.link_delay_variation.parent = self
                                                                            self._children_name_map["link_delay_variation"] = "link-delay-variation"

                                                                            self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss()
                                                                            self.link_loss.parent = self
                                                                            self._children_name_map["link_loss"] = "link-loss"

                                                                            self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth()
                                                                            self.residual_bandwidth.parent = self
                                                                            self._children_name_map["residual_bandwidth"] = "residual-bandwidth"

                                                                            self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth()
                                                                            self.available_bandwidth.parent = self
                                                                            self._children_name_map["available_bandwidth"] = "available-bandwidth"

                                                                            self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                            self.utilized_bandwidth.parent = self
                                                                            self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                            self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of IS neighbor state
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                            
                                                                                **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ])
                                                                                self.type = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                        class AdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 3.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 3
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 3.
                                                                                
                                                                                .. attribute:: admin_group
                                                                                
                                                                                    The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('admin_group', (YLeafList(YType.uint32, 'admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)



                                                                        class LinkId(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 4.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 4
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-id"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-id"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 4.
                                                                                
                                                                                .. attribute:: local
                                                                                
                                                                                    The value field of this sub\-TLV contains 4 octets of Link Local Identifier followed by 4 octets of Link Remote Identifier
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: remote
                                                                                
                                                                                    If the Link Remote Identifier is unknown, it is set to 0
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-id"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                                                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                                                                    ])
                                                                                    self.local = None
                                                                                    self.remote = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State, ['local', 'remote'], name, value)



                                                                        class Ipv4InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 6.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 6
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 6.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv4NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 8.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 8
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 8.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['address'], name, value)



                                                                        class MaxLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 9.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 9
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 9.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class MaxReservableLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 10.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 10
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-reservable-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-reservable-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 10.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class UnreservedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unreserved\-bandwidth. The units
                                                                            are bytes per second.
                                                                            
                                                                            .. attribute:: setup_priority
                                                                            
                                                                                Setup priority (0 through 7) for unreserved bandwidth
                                                                            
                                                                                **type**: list of    :py:class:`SetupPriority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unreserved-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                                self._leafs = OrderedDict()

                                                                                self.setup_priority = YList(self)
                                                                                self._segment_path = lambda: "unreserved-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)

                                                                            class SetupPriority(_Entity_):
                                                                                """
                                                                                Setup priority (0 through 7) for unreserved
                                                                                bandwidth.
                                                                                
                                                                                .. attribute:: priority  (key)
                                                                                
                                                                                    Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..7
                                                                                
                                                                                    **refers to**:  :py:class:`priority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 11
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "setup-priority"
                                                                                    self.yang_parent_name = "unreserved-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['priority']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('priority', (YLeaf(YType.str, 'priority'), ['int'])),
                                                                                    ])
                                                                                    self.priority = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    11.
                                                                                    
                                                                                    .. attribute:: priority
                                                                                    
                                                                                        Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..7
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                        The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **length:** 4..4
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                        **units**: bytes per second
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "setup-priority"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                                            ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                        ])
                                                                                        self.priority = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'bandwidth'], name, value)




                                                                        class Ipv6InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 12.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 12
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 12.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv6NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 13.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 13
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 13.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['address'], name, value)



                                                                        class ExtendedAdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 14.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 14
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "extended-admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "extended-admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 14.
                                                                                
                                                                                .. attribute:: extended_admin_group
                                                                                
                                                                                    The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "extended-admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('extended_admin_group', (YLeafList(YType.uint32, 'extended-admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.extended_admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)



                                                                        class TeDefaultMetric(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 18.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 18
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "te-default-metric"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "te-default-metric"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 18.
                                                                                
                                                                                .. attribute:: metric
                                                                                
                                                                                    This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "te-default-metric"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                                    ])
                                                                                    self.metric = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State, ['metric'], name, value)



                                                                        class LinkAttributes(_Entity_):
                                                                            """
                                                                            This container defines link\-attributes.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 19
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-attributes"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-attributes"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                19.
                                                                                
                                                                                .. attribute:: local_protection
                                                                                
                                                                                    Link local\-protection attributes
                                                                                
                                                                                    **type**: list of   :py:class:`LocalProtection<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-attributes"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local_protection', (YLeafList(YType.enumeration, 'local-protection'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection')])),
                                                                                    ])
                                                                                    self.local_protection = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                                class LocalProtection(Enum):
                                                                                    """
                                                                                    LocalProtection (Enum Class)

                                                                                    .. data:: LOCAL_PROTECTION = 0

                                                                                        If set, local protection is available for the

                                                                                        link.

                                                                                    .. data:: LINK_EXCLUDED = 1

                                                                                        If set, the link is excluded from local

                                                                                        protection.

                                                                                    """

                                                                                    LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                                    LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")




                                                                        class LinkProtectionType(_Entity_):
                                                                            """
                                                                            ISIS LSDB parameters relating to the type of link
                                                                            protection offered.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 20
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-protection-type"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-protection-type"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 20.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    Link protection capabilities
                                                                                
                                                                                    **type**: list of   :py:class:`Type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-protection-type"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeafList(YType.enumeration, 'type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type')])),
                                                                                    ])
                                                                                    self.type = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State, ['type'], name, value)

                                                                                class Type(Enum):
                                                                                    """
                                                                                    Type (Enum Class)

                                                                                    .. data:: EXTRA_TRAFFIC = 0

                                                                                        If set the link has extra traffic protection. If

                                                                                        the link is of type Extra Traffic, it means that

                                                                                        the link is protecting another link or links. The

                                                                                        LSPs on a link of this type will be lost if any of

                                                                                        the links it is protecting fail.

                                                                                    .. data:: UNPROTECTED = 1

                                                                                        If set, the link is unprotected. If the link is

                                                                                        of type Unprotected, it means that there is no

                                                                                        other link protecting this link.  The LSPs on a

                                                                                        link of this type will be lost if the link

                                                                                        fails.

                                                                                    .. data:: SHARED = 2

                                                                                        If set, the link has shared protection. If the

                                                                                        link is of type Shared, it means that there are

                                                                                        one or more disjoint links of type Extra Traffic

                                                                                        that are protecting this link.  These Extra

                                                                                        Traffic links are shared between one or more links

                                                                                        of type Shared.

                                                                                    .. data:: ONE_ONE = 3

                                                                                        If set, the link has dedicated 1:1 protection. If

                                                                                        the link is of type Dedicated 1:1, it means that

                                                                                        there is one dedicated disjoint link of type Extra

                                                                                        Traffic that is protecting this link.

                                                                                    .. data:: PLUS_ONE = 4

                                                                                        If set, the link has dedicated 1+1 protection. If

                                                                                        the link is of type Dedicated 1+1, it means that a

                                                                                        dedicated disjoint link is protecting this link.

                                                                                        However, the protecting link is not advertised in

                                                                                        the link state database and is therefore not

                                                                                        available for the routing of LSPs.

                                                                                    .. data:: ENHANCED = 5

                                                                                        If set the link has enhanced protection.  If the

                                                                                        link is of type Enhanced, it means that a

                                                                                        protection scheme that is more reliable than

                                                                                        Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                                        being used to protect this link.

                                                                                    """

                                                                                    EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                                    UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                                    SHARED = Enum.YLeaf(2, "SHARED")

                                                                                    ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                                    PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                                    ENHANCED = Enum.YLeaf(5, "ENHANCED")




                                                                        class BandwidthConstraints(_Entity_):
                                                                            """
                                                                            This container defines bandwidth\-constraints. For DS\-TE,
                                                                            the existing Maximum Reservable link bandwidth parameter
                                                                            is retained, but its semantics is generalized and
                                                                            interpreted as the aggregate bandwidth constraint across
                                                                            all Class\-Types
                                                                            
                                                                            .. attribute:: bandwidth_constraint
                                                                            
                                                                                List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                            
                                                                                **type**: list of    :py:class:`BandwidthConstraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "bandwidth-constraints"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.bandwidth_constraint = YList(self)
                                                                                self._segment_path = lambda: "bandwidth-constraints"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)

                                                                            class BandwidthConstraint(_Entity_):
                                                                                """
                                                                                List of the Bandwidth Constraints sub\-TLV instances
                                                                                present in the TLV.
                                                                                
                                                                                .. attribute:: model_id  (key)
                                                                                
                                                                                    Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..255
                                                                                
                                                                                    **refers to**:  :py:class:`model_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 22
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: constraints
                                                                                
                                                                                    Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**:  :py:class:`Constraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "bandwidth-constraint"
                                                                                    self.yang_parent_name = "bandwidth-constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['model_id']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('model_id', (YLeaf(YType.str, 'model-id'), ['int'])),
                                                                                    ])
                                                                                    self.model_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"

                                                                                    self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                                    self.constraints.parent = self
                                                                                    self._children_name_map["constraints"] = "constraints"
                                                                                    self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    22.
                                                                                    
                                                                                    .. attribute:: model_id
                                                                                    
                                                                                        Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('model_id', (YLeaf(YType.uint8, 'model-id'), ['int'])),
                                                                                        ])
                                                                                        self.model_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                                class Constraints(_Entity_):
                                                                                    """
                                                                                    Constraints contained within the Bandwidth
                                                                                    Constraints sub\-TLV
                                                                                    
                                                                                    .. attribute:: constraint
                                                                                    
                                                                                        List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                                    
                                                                                        **type**: list of    :py:class:`Constraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "constraints"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                        self._leafs = OrderedDict()

                                                                                        self.constraint = YList(self)
                                                                                        self._segment_path = lambda: "constraints"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)

                                                                                    class Constraint(_Entity_):
                                                                                        """
                                                                                        List of the constraints within the Bandwidth
                                                                                        Constraints sub\-TLV. The BC0 level is indicated by
                                                                                        the constraint\-id leaf being set to 0, with BCN
                                                                                        being indicated by constraint\-id N.
                                                                                        
                                                                                        .. attribute:: constraint_id  (key)
                                                                                        
                                                                                            Reference to the unique ID for the BCN level
                                                                                        
                                                                                            **type**: int
                                                                                        
                                                                                                **range:** 0..4294967295
                                                                                        
                                                                                            **refers to**:  :py:class:`constraint_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        .. attribute:: state
                                                                                        
                                                                                            Operational state parameters of the BCN level
                                                                                        
                                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        """
                                                                                        _prefix = 'oc-netinst'
                                                                                        _revision = '2017-01-13'

                                                                                        def __init__(self):
                                                                                            super().__init__()

                                                                                            self.yang_name = "constraint"
                                                                                            self.yang_parent_name = "constraints"
                                                                                            self.is_top_level_class = False
                                                                                            self.has_list_ancestor = True
                                                                                            self.ylist_key_names = ['constraint_id']
                                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                            self._leafs = OrderedDict([
                                                                                                ('constraint_id', (YLeaf(YType.str, 'constraint-id'), ['int'])),
                                                                                            ])
                                                                                            self.constraint_id = None

                                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                            self.state.parent = self
                                                                                            self._children_name_map["state"] = "state"
                                                                                            self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"
                                                                                            self._is_frozen = True

                                                                                        def __setattr__(self, name, value):
                                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)

                                                                                        class State(_Entity_):
                                                                                            """
                                                                                            Operational state parameters of the BCN level
                                                                                            
                                                                                            .. attribute:: constraint_id
                                                                                            
                                                                                                Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                            
                                                                                                **type**: int
                                                                                            
                                                                                                    **range:** 0..4294967295
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                            .. attribute:: bandwidth
                                                                                            
                                                                                                The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                            
                                                                                                **type**: str
                                                                                            
                                                                                                    **length:** 4..4
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                                **units**: bytes per second
                                                                                            
                                                                                            """
                                                                                            _prefix = 'oc-netinst'
                                                                                            _revision = '2017-01-13'

                                                                                            def __init__(self):
                                                                                                super().__init__()

                                                                                                self.yang_name = "state"
                                                                                                self.yang_parent_name = "constraint"
                                                                                                self.is_top_level_class = False
                                                                                                self.has_list_ancestor = True
                                                                                                self.ylist_key_names = []
                                                                                                self._child_classes = OrderedDict([])
                                                                                                self._leafs = OrderedDict([
                                                                                                    ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                                    ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                                ])
                                                                                                self.constraint_id = None
                                                                                                self.bandwidth = None
                                                                                                self._segment_path = lambda: "state"
                                                                                                self._is_frozen = True

                                                                                            def __setattr__(self, name, value):
                                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)






                                                                        class UnconstrainedLsp(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 23.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 23
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unconstrained-lsp"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "unconstrained-lsp"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 23.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: count
                                                                                
                                                                                    Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..65535
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "unconstrained-lsp"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.count = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'count'], name, value)



                                                                        class AdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing adjacency SIDs.
                                                                            
                                                                            .. attribute:: adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`AdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids, [], name, value)

                                                                            class AdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "adjacency-sid"
                                                                                    self.yang_parent_name = "adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LanAdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing LAN adjacency
                                                                            SIDs
                                                                            
                                                                            .. attribute:: lan_adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`LanAdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "lan-adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.lan_adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "lan-adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)

                                                                            class LanAdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the LAN Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of LAN Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "lan-adjacency-sid"
                                                                                    self.yang_parent_name = "lan-adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of LAN Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        LAN Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with LAN\-Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: neighbor_id
                                                                                    
                                                                                        System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "lan-adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self.neighbor_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LinkDelay(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 33
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                33.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)



                                                                        class MinMaxLinkDelay(_Entity_):
                                                                            """
                                                                            This container defines min/max link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 34
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "min-max-link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "min-max-link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                34.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: min_delay
                                                                                
                                                                                    Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                .. attribute:: max_delay
                                                                                
                                                                                    Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "min-max-link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                                                        ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.min_delay = None
                                                                                    self.max_delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)



                                                                        class LinkDelayVariation(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay
                                                                            variation.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 35
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay-variation"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay-variation"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                35.
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay-variation"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)



                                                                        class LinkLoss(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link loss delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 36
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-loss"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-loss"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                36.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: link_loss
                                                                                
                                                                                    Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-loss"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('link_loss', (YLeaf(YType.uint32, 'link-loss'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.link_loss = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)



                                                                        class ResidualBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional residual
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 37
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "residual-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "residual-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                37.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "residual-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State, ['bandwidth'], name, value)



                                                                        class AvailableBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional lavailable
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 38
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "available-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "available-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                38.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "available-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'bandwidth'], name, value)



                                                                        class UtilizedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional utilized
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 39
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "utilized-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "utilized-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                39.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "utilized-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'bandwidth'], name, value)





                                                                class UndefinedSubtlvs(_Entity_):
                                                                    """
                                                                    This container describes undefined ISIS TLVs.
                                                                    
                                                                    .. attribute:: undefined_subtlv
                                                                    
                                                                        Sub\-TLVs that are not defined in the model or not recognised by system
                                                                    
                                                                        **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "undefined-subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.undefined_subtlv = YList(self)
                                                                        self._segment_path = lambda: "undefined-subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs, [], name, value)

                                                                    class UndefinedSubtlv(_Entity_):
                                                                        """
                                                                        Sub\-TLVs that are not defined in the model or not
                                                                        recognised by system.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the type of the undefined sub\-TLV
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..255
                                                                        
                                                                            **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of the undefined sub\-TLV
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "undefined-subtlv"
                                                                            self.yang_parent_name = "undefined-subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of the undefined sub\-TLV.
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                TLV Type
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: length
                                                                            
                                                                                TLV length
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                TLV value
                                                                            
                                                                                **type**: str
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "undefined-subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                    ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                    ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.length = None
                                                                                self.value = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsn.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)









                                            class MtIsisNeighborAttribute(_Entity_):
                                                """
                                                This container defines list of ISIS multi\-topology
                                                neighbors.
                                                
                                                .. attribute:: neighbors
                                                
                                                    MT\-IS neigbor attributes
                                                
                                                    **type**:  :py:class:`Neighbors<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "mt-isis-neighbor-attribute"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("neighbors", ("neighbors", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors))])
                                                    self._leafs = OrderedDict()

                                                    self.neighbors = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors()
                                                    self.neighbors.parent = self
                                                    self._children_name_map["neighbors"] = "neighbors"
                                                    self._segment_path = lambda: "mt-isis-neighbor-attribute"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute, [], name, value)

                                                class Neighbors(_Entity_):
                                                    """
                                                    MT\-IS neigbor attributes.
                                                    
                                                    .. attribute:: neighbor
                                                    
                                                        This container describes IS neighbors
                                                    
                                                        **type**: list of    :py:class:`Neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "neighbors"
                                                        self.yang_parent_name = "mt-isis-neighbor-attribute"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("neighbor", ("neighbor", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor))])
                                                        self._leafs = OrderedDict()

                                                        self.neighbor = YList(self)
                                                        self._segment_path = lambda: "neighbors"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors, [], name, value)

                                                    class Neighbor(_Entity_):
                                                        """
                                                        This container describes IS neighbors.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                            Reference to the topology that the neighbor is within
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4095
                                                        
                                                            **refers to**:  :py:class:`mt_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: system_id  (key)
                                                        
                                                            Reference to the System ID of the neighbor
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                        
                                                            **refers to**:  :py:class:`system_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            Operational state parameters related to the MT ISN TLV
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: instances
                                                        
                                                            This list contains all instances of an adjacency between the originating and remote IS. Multiple instances are used to indicate where there are parallel adjacencies between systems
                                                        
                                                            **type**:  :py:class:`Instances<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "neighbor"
                                                            self.yang_parent_name = "neighbors"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id','system_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State)), ("instances", ("instances", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances))])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', (YLeaf(YType.str, 'mt-id'), ['int'])),
                                                                ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                            ])
                                                            self.mt_id = None
                                                            self.system_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.instances = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances()
                                                            self.instances.parent = self
                                                            self._children_name_map["instances"] = "instances"
                                                            self._segment_path = lambda: "neighbor" + "[mt-id='" + str(self.mt_id) + "']" + "[system-id='" + str(self.system_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor, ['mt_id', 'system_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            Operational state parameters related to the
                                                            MT ISN TLV.
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                                Identifier of a topology being announced
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 0..4095
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: system_id
                                                            
                                                                System\-id of the IS neighbor
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                                ])
                                                                self.mt_id = None
                                                                self.system_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.State, ['mt_id', 'system_id'], name, value)


                                                        class Instances(_Entity_):
                                                            """
                                                            This list contains all instances of an adjacency
                                                            between the originating and remote IS. Multiple
                                                            instances are used to indicate where there are
                                                            parallel adjacencies between systems.
                                                            
                                                            .. attribute:: instance
                                                            
                                                                Instance of TLV\-222 between the originating and remote IS
                                                            
                                                                **type**: list of    :py:class:`Instance<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "instances"
                                                                self.yang_parent_name = "neighbor"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("instance", ("instance", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance))])
                                                                self._leafs = OrderedDict()

                                                                self.instance = YList(self)
                                                                self._segment_path = lambda: "instances"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances, [], name, value)

                                                            class Instance(_Entity_):
                                                                """
                                                                Instance of TLV\-222 between the originating
                                                                and remote IS.
                                                                
                                                                .. attribute:: id  (key)
                                                                
                                                                    Reference to the unique identifier for the instance of the multi\-topology IS neighbor TLV instance
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..18446744073709551615
                                                                
                                                                    **refers to**:  :py:class:`id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of MT neighbor
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: subtlvs
                                                                
                                                                    This container describes IS Neighbor sub\-TLVs
                                                                
                                                                    **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: undefined_subtlvs
                                                                
                                                                    This container describes undefined ISIS TLVs
                                                                
                                                                    **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "instance"
                                                                    self.yang_parent_name = "instances"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['id']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs))])
                                                                    self._leafs = OrderedDict([
                                                                        ('id', (YLeaf(YType.str, 'id'), ['int'])),
                                                                    ])
                                                                    self.id = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs()
                                                                    self.subtlvs.parent = self
                                                                    self._children_name_map["subtlvs"] = "subtlvs"

                                                                    self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs()
                                                                    self.undefined_subtlvs.parent = self
                                                                    self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                                    self._segment_path = lambda: "instance" + "[id='" + str(self.id) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance, ['id'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of MT neighbor.
                                                                    
                                                                    .. attribute:: metric
                                                                    
                                                                        ISIS metric value
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 1..16777215
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: id
                                                                    
                                                                        Unique identifier for the TLV instance for the neighbor. The ID is not required to be consistent across readvertisements of the LSP
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..18446744073709551615
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                            ('id', (YLeaf(YType.uint64, 'id'), ['int'])),
                                                                        ])
                                                                        self.metric = None
                                                                        self.id = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.State, ['metric', 'id'], name, value)


                                                                class Subtlvs(_Entity_):
                                                                    """
                                                                    This container describes IS Neighbor sub\-TLVs.
                                                                    
                                                                    .. attribute:: subtlv
                                                                    
                                                                        List of subTLV types in the LSDB for the specified TLV
                                                                    
                                                                        **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.subtlv = YList(self)
                                                                        self._segment_path = lambda: "subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs, [], name, value)

                                                                    class Subtlv(_Entity_):
                                                                        """
                                                                        List of subTLV types in the LSDB for the specified TLV.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the sub\-TLV type
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of IS neighbor state
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: admin_group
                                                                        
                                                                            This container defines sub\-TLV 3
                                                                        
                                                                            **type**:  :py:class:`AdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_id
                                                                        
                                                                            This container defines sub\-TLV 4
                                                                        
                                                                            **type**:  :py:class:`LinkId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_interface_address
                                                                        
                                                                            This container defines sub\-TLV 6
                                                                        
                                                                            **type**:  :py:class:`Ipv4InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv4_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 8
                                                                        
                                                                            **type**:  :py:class:`Ipv4NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 9
                                                                        
                                                                            **type**:  :py:class:`MaxLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: max_reservable_link_bandwidth
                                                                        
                                                                            This container defines sub\-TLV 10
                                                                        
                                                                            **type**:  :py:class:`MaxReservableLinkBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unreserved_bandwidth
                                                                        
                                                                            This container defines unreserved\-bandwidth. The units are bytes per second
                                                                        
                                                                            **type**:  :py:class:`UnreservedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_interface_address
                                                                        
                                                                            This container defines sub\-TLV 12
                                                                        
                                                                            **type**:  :py:class:`Ipv6InterfaceAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: ipv6_neighbor_address
                                                                        
                                                                            This container defines sub\-TLV 13
                                                                        
                                                                            **type**:  :py:class:`Ipv6NeighborAddress<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: extended_admin_group
                                                                        
                                                                            This container defines sub\-TLV 14
                                                                        
                                                                            **type**:  :py:class:`ExtendedAdminGroup<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: te_default_metric
                                                                        
                                                                            This container defines sub\-TLV 18
                                                                        
                                                                            **type**:  :py:class:`TeDefaultMetric<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_attributes
                                                                        
                                                                            This container defines link\-attributes
                                                                        
                                                                            **type**:  :py:class:`LinkAttributes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_protection_type
                                                                        
                                                                            ISIS LSDB parameters relating to the type of link protection offered
                                                                        
                                                                            **type**:  :py:class:`LinkProtectionType<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: bandwidth_constraints
                                                                        
                                                                            This container defines bandwidth\-constraints. For DS\-TE, the existing Maximum Reservable link bandwidth parameter is retained, but its semantics is generalized and interpreted as the aggregate bandwidth constraint across all Class\-Types
                                                                        
                                                                            **type**:  :py:class:`BandwidthConstraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: unconstrained_lsp
                                                                        
                                                                            This container defines sub\-TLV 23
                                                                        
                                                                            **type**:  :py:class:`UnconstrainedLsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: adjacency_sids
                                                                        
                                                                            This container defines segment routing adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`AdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: lan_adjacency_sids
                                                                        
                                                                            This container defines segment routing LAN adjacency SIDs
                                                                        
                                                                            **type**:  :py:class:`LanAdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay
                                                                        
                                                                            This container defines unidirectional link delay
                                                                        
                                                                            **type**:  :py:class:`LinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: min_max_link_delay
                                                                        
                                                                            This container defines min/max link delay
                                                                        
                                                                            **type**:  :py:class:`MinMaxLinkDelay<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_delay_variation
                                                                        
                                                                            This container defines unidirectional link delay variation
                                                                        
                                                                            **type**:  :py:class:`LinkDelayVariation<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: link_loss
                                                                        
                                                                            This container defines unidirectional link loss delay
                                                                        
                                                                            **type**:  :py:class:`LinkLoss<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: residual_bandwidth
                                                                        
                                                                            This container defines unidirectional residual bandwidth
                                                                        
                                                                            **type**:  :py:class:`ResidualBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: available_bandwidth
                                                                        
                                                                            This container defines unidirectional lavailable bandwidth
                                                                        
                                                                            **type**:  :py:class:`AvailableBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: utilized_bandwidth
                                                                        
                                                                            This container defines unidirectional utilized bandwidth
                                                                        
                                                                            **type**:  :py:class:`UtilizedBandwidth<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "subtlv"
                                                                            self.yang_parent_name = "subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State)), ("admin-group", ("admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup)), ("link-id", ("link_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId)), ("ipv4-interface-address", ("ipv4_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress)), ("ipv4-neighbor-address", ("ipv4_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress)), ("max-link-bandwidth", ("max_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth)), ("max-reservable-link-bandwidth", ("max_reservable_link_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth)), ("unreserved-bandwidth", ("unreserved_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth)), ("ipv6-interface-address", ("ipv6_interface_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress)), ("ipv6-neighbor-address", ("ipv6_neighbor_address", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress)), ("extended-admin-group", ("extended_admin_group", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup)), ("te-default-metric", ("te_default_metric", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric)), ("link-attributes", ("link_attributes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes)), ("link-protection-type", ("link_protection_type", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType)), ("bandwidth-constraints", ("bandwidth_constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints)), ("unconstrained-lsp", ("unconstrained_lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids)), ("lan-adjacency-sids", ("lan_adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids)), ("link-delay", ("link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay)), ("min-max-link-delay", ("min_max_link_delay", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay)), ("link-delay-variation", ("link_delay_variation", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation)), ("link-loss", ("link_loss", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss)), ("residual-bandwidth", ("residual_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth)), ("available-bandwidth", ("available_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth)), ("utilized-bandwidth", ("utilized_bandwidth", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"

                                                                            self.admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup()
                                                                            self.admin_group.parent = self
                                                                            self._children_name_map["admin_group"] = "admin-group"

                                                                            self.link_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId()
                                                                            self.link_id.parent = self
                                                                            self._children_name_map["link_id"] = "link-id"

                                                                            self.ipv4_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress()
                                                                            self.ipv4_interface_address.parent = self
                                                                            self._children_name_map["ipv4_interface_address"] = "ipv4-interface-address"

                                                                            self.ipv4_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress()
                                                                            self.ipv4_neighbor_address.parent = self
                                                                            self._children_name_map["ipv4_neighbor_address"] = "ipv4-neighbor-address"

                                                                            self.max_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth()
                                                                            self.max_link_bandwidth.parent = self
                                                                            self._children_name_map["max_link_bandwidth"] = "max-link-bandwidth"

                                                                            self.max_reservable_link_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth()
                                                                            self.max_reservable_link_bandwidth.parent = self
                                                                            self._children_name_map["max_reservable_link_bandwidth"] = "max-reservable-link-bandwidth"

                                                                            self.unreserved_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth()
                                                                            self.unreserved_bandwidth.parent = self
                                                                            self._children_name_map["unreserved_bandwidth"] = "unreserved-bandwidth"

                                                                            self.ipv6_interface_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress()
                                                                            self.ipv6_interface_address.parent = self
                                                                            self._children_name_map["ipv6_interface_address"] = "ipv6-interface-address"

                                                                            self.ipv6_neighbor_address = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress()
                                                                            self.ipv6_neighbor_address.parent = self
                                                                            self._children_name_map["ipv6_neighbor_address"] = "ipv6-neighbor-address"

                                                                            self.extended_admin_group = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup()
                                                                            self.extended_admin_group.parent = self
                                                                            self._children_name_map["extended_admin_group"] = "extended-admin-group"

                                                                            self.te_default_metric = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric()
                                                                            self.te_default_metric.parent = self
                                                                            self._children_name_map["te_default_metric"] = "te-default-metric"

                                                                            self.link_attributes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes()
                                                                            self.link_attributes.parent = self
                                                                            self._children_name_map["link_attributes"] = "link-attributes"

                                                                            self.link_protection_type = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType()
                                                                            self.link_protection_type.parent = self
                                                                            self._children_name_map["link_protection_type"] = "link-protection-type"

                                                                            self.bandwidth_constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints()
                                                                            self.bandwidth_constraints.parent = self
                                                                            self._children_name_map["bandwidth_constraints"] = "bandwidth-constraints"

                                                                            self.unconstrained_lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp()
                                                                            self.unconstrained_lsp.parent = self
                                                                            self._children_name_map["unconstrained_lsp"] = "unconstrained-lsp"

                                                                            self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids()
                                                                            self.adjacency_sids.parent = self
                                                                            self._children_name_map["adjacency_sids"] = "adjacency-sids"

                                                                            self.lan_adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids()
                                                                            self.lan_adjacency_sids.parent = self
                                                                            self._children_name_map["lan_adjacency_sids"] = "lan-adjacency-sids"

                                                                            self.link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay()
                                                                            self.link_delay.parent = self
                                                                            self._children_name_map["link_delay"] = "link-delay"

                                                                            self.min_max_link_delay = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay()
                                                                            self.min_max_link_delay.parent = self
                                                                            self._children_name_map["min_max_link_delay"] = "min-max-link-delay"

                                                                            self.link_delay_variation = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation()
                                                                            self.link_delay_variation.parent = self
                                                                            self._children_name_map["link_delay_variation"] = "link-delay-variation"

                                                                            self.link_loss = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss()
                                                                            self.link_loss.parent = self
                                                                            self._children_name_map["link_loss"] = "link-loss"

                                                                            self.residual_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth()
                                                                            self.residual_bandwidth.parent = self
                                                                            self._children_name_map["residual_bandwidth"] = "residual-bandwidth"

                                                                            self.available_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth()
                                                                            self.available_bandwidth.parent = self
                                                                            self._children_name_map["available_bandwidth"] = "available-bandwidth"

                                                                            self.utilized_bandwidth = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth()
                                                                            self.utilized_bandwidth.parent = self
                                                                            self._children_name_map["utilized_bandwidth"] = "utilized-bandwidth"
                                                                            self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of IS neighbor state
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                            
                                                                                **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ])
                                                                                self.type = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                        class AdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 3.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 3
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 3.
                                                                                
                                                                                .. attribute:: admin_group
                                                                                
                                                                                    The administrative group sub\-TLV contains a 4\-octet bit mask assigned by the network administrator.  Each set bit corresponds to one administrative group assigned to the interface. By convention, the least significant bit is referred to as group 0, and the most significant bit is referred to as group 31
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('admin_group', (YLeafList(YType.uint32, 'admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdminGroup.State, ['admin_group'], name, value)



                                                                        class LinkId(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 4.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 4
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-id"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-id"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 4.
                                                                                
                                                                                .. attribute:: local
                                                                                
                                                                                    The value field of this sub\-TLV contains 4 octets of Link Local Identifier followed by 4 octets of Link Remote Identifier
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: remote
                                                                                
                                                                                    If the Link Remote Identifier is unknown, it is set to 0
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-id"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local', (YLeaf(YType.uint32, 'local'), ['int'])),
                                                                                        ('remote', (YLeaf(YType.uint32, 'remote'), ['int'])),
                                                                                    ])
                                                                                    self.local = None
                                                                                    self.remote = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkId.State, ['local', 'remote'], name, value)



                                                                        class Ipv4InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 6.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 6
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 6.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A 4\-octet IPv4 address for the interface described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv4NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 8.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 8
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv4-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv4-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 8.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    A single IPv4 address for a neighboring router on this link. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv4-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv4NeighborAddress.State, ['address'], name, value)



                                                                        class MaxLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 9.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 9
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 9.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum bandwidth that can be used on this link in this direction (from the system originating the LSP to its neighbors).  It is encoded in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class MaxReservableLinkBandwidth(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 10.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 10
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "max-reservable-link-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "max-reservable-link-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 10.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The maximum amount of bandwidth that can be reserved in this direction on this link.  Note that for oversubscription purposes,  this can be greater than the bandwidth of the link. It is encoded  in 32 bits in IEEE floating point format.  The units are bytes (not bits!) per second
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "max-reservable-link-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MaxReservableLinkBandwidth.State, ['bandwidth'], name, value)



                                                                        class UnreservedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unreserved\-bandwidth. The units
                                                                            are bytes per second.
                                                                            
                                                                            .. attribute:: setup_priority
                                                                            
                                                                                Setup priority (0 through 7) for unreserved bandwidth
                                                                            
                                                                                **type**: list of    :py:class:`SetupPriority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unreserved-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("setup-priority", ("setup_priority", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority))])
                                                                                self._leafs = OrderedDict()

                                                                                self.setup_priority = YList(self)
                                                                                self._segment_path = lambda: "unreserved-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth, [], name, value)

                                                                            class SetupPriority(_Entity_):
                                                                                """
                                                                                Setup priority (0 through 7) for unreserved
                                                                                bandwidth.
                                                                                
                                                                                .. attribute:: priority  (key)
                                                                                
                                                                                    Reference to the setup priority to which the unreserved bandwidth corresponds
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..7
                                                                                
                                                                                    **refers to**:  :py:class:`priority<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 11
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "setup-priority"
                                                                                    self.yang_parent_name = "unreserved-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['priority']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('priority', (YLeaf(YType.str, 'priority'), ['int'])),
                                                                                    ])
                                                                                    self.priority = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "setup-priority" + "[priority='" + str(self.priority) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority, ['priority'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    11.
                                                                                    
                                                                                    .. attribute:: priority
                                                                                    
                                                                                        Setup priority level of 0 through 7 to be used by Unreserved Bandwidth sub\-TLV 11
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..7
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: bandwidth
                                                                                    
                                                                                        The amount of bandwidth reservable in this direction on this link. Note that for oversubscription purposes, this can be greater than the bandwidth of the link. It contains eight 32\-bit IEEE floating point numbers(one for each priority). The units are bytes (not bits!) per second. The values correspond to the bandwidth that can be reserved with a setup priority of 0 through 7, arranged in increasing order with priority 0 occurring at the start of the sub\-TLV, and priority 7 at the end of the sub\-TLV
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **length:** 4..4
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                        **units**: bytes per second
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "setup-priority"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                                                            ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                        ])
                                                                                        self.priority = None
                                                                                        self.bandwidth = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnreservedBandwidth.SetupPriority.State, ['priority', 'bandwidth'], name, value)




                                                                        class Ipv6InterfaceAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 12.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 12
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-interface-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-interface-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 12.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for the interface described by the containing  Extended IS Reachability TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-interface-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6InterfaceAddress.State, ['address'], name, value)



                                                                        class Ipv6NeighborAddress(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 13.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 13
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "ipv6-neighbor-address"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "ipv6-neighbor-address"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 13.
                                                                                
                                                                                .. attribute:: address
                                                                                
                                                                                    Contains a 16\-octet IPv6 address for a neighboring router on the link described by the (main) TLV. This sub\-TLV can occur multiple times
                                                                                
                                                                                    **type**: list of str
                                                                                
                                                                                        **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "ipv6-neighbor-address"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('address', (YLeafList(YType.str, 'address'), ['str'])),
                                                                                    ])
                                                                                    self.address = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.Ipv6NeighborAddress.State, ['address'], name, value)



                                                                        class ExtendedAdminGroup(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 14.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 14
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "extended-admin-group"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "extended-admin-group"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 14.
                                                                                
                                                                                .. attribute:: extended_admin_group
                                                                                
                                                                                    The extended\-admin\-group sub\-TLV is used in addition to the Administrative Groups when it is desirable to make more than 32 colors available for advertisement in a network
                                                                                
                                                                                    **type**: list of int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "extended-admin-group"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('extended_admin_group', (YLeafList(YType.uint32, 'extended-admin-group'), ['int'])),
                                                                                    ])
                                                                                    self.extended_admin_group = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ExtendedAdminGroup.State, ['extended_admin_group'], name, value)



                                                                        class TeDefaultMetric(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 18.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 18
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "te-default-metric"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "te-default-metric"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 18.
                                                                                
                                                                                .. attribute:: metric
                                                                                
                                                                                    This metric is administratively assigned and can be used to present a differently weighted topology to traffic engineering SPF calculations. To preclude overflow within a traffic engineering SPF implementation, all metrics greater than or equal to MAX\_PATH\_METRIC SHALL be considered to have a metric of MAX\_PATH\_METRIC
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "te-default-metric"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                                    ])
                                                                                    self.metric = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.TeDefaultMetric.State, ['metric'], name, value)



                                                                        class LinkAttributes(_Entity_):
                                                                            """
                                                                            This container defines link\-attributes.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 19
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-attributes"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-attributes"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                19.
                                                                                
                                                                                .. attribute:: local_protection
                                                                                
                                                                                    Link local\-protection attributes
                                                                                
                                                                                    **type**: list of   :py:class:`LocalProtection<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-attributes"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('local_protection', (YLeafList(YType.enumeration, 'local-protection'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State.LocalProtection')])),
                                                                                    ])
                                                                                    self.local_protection = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkAttributes.State, ['local_protection'], name, value)

                                                                                class LocalProtection(Enum):
                                                                                    """
                                                                                    LocalProtection (Enum Class)

                                                                                    .. data:: LOCAL_PROTECTION = 0

                                                                                        If set, local protection is available for the

                                                                                        link.

                                                                                    .. data:: LINK_EXCLUDED = 1

                                                                                        If set, the link is excluded from local

                                                                                        protection.

                                                                                    """

                                                                                    LOCAL_PROTECTION = Enum.YLeaf(0, "LOCAL_PROTECTION")

                                                                                    LINK_EXCLUDED = Enum.YLeaf(1, "LINK_EXCLUDED")




                                                                        class LinkProtectionType(_Entity_):
                                                                            """
                                                                            ISIS LSDB parameters relating to the type of link
                                                                            protection offered.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 20
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-protection-type"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-protection-type"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 20.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    Link protection capabilities
                                                                                
                                                                                    **type**: list of   :py:class:`Type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-protection-type"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeafList(YType.enumeration, 'type'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State.Type')])),
                                                                                    ])
                                                                                    self.type = []
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkProtectionType.State, ['type'], name, value)

                                                                                class Type(Enum):
                                                                                    """
                                                                                    Type (Enum Class)

                                                                                    .. data:: EXTRA_TRAFFIC = 0

                                                                                        If set the link has extra traffic protection. If

                                                                                        the link is of type Extra Traffic, it means that

                                                                                        the link is protecting another link or links. The

                                                                                        LSPs on a link of this type will be lost if any of

                                                                                        the links it is protecting fail.

                                                                                    .. data:: UNPROTECTED = 1

                                                                                        If set, the link is unprotected. If the link is

                                                                                        of type Unprotected, it means that there is no

                                                                                        other link protecting this link.  The LSPs on a

                                                                                        link of this type will be lost if the link

                                                                                        fails.

                                                                                    .. data:: SHARED = 2

                                                                                        If set, the link has shared protection. If the

                                                                                        link is of type Shared, it means that there are

                                                                                        one or more disjoint links of type Extra Traffic

                                                                                        that are protecting this link.  These Extra

                                                                                        Traffic links are shared between one or more links

                                                                                        of type Shared.

                                                                                    .. data:: ONE_ONE = 3

                                                                                        If set, the link has dedicated 1:1 protection. If

                                                                                        the link is of type Dedicated 1:1, it means that

                                                                                        there is one dedicated disjoint link of type Extra

                                                                                        Traffic that is protecting this link.

                                                                                    .. data:: PLUS_ONE = 4

                                                                                        If set, the link has dedicated 1+1 protection. If

                                                                                        the link is of type Dedicated 1+1, it means that a

                                                                                        dedicated disjoint link is protecting this link.

                                                                                        However, the protecting link is not advertised in

                                                                                        the link state database and is therefore not

                                                                                        available for the routing of LSPs.

                                                                                    .. data:: ENHANCED = 5

                                                                                        If set the link has enhanced protection.  If the

                                                                                        link is of type Enhanced, it means that a

                                                                                        protection scheme that is more reliable than

                                                                                        Dedicated 1+1, e.g., 4 fiber BLSR/MS-SPRING, is

                                                                                        being used to protect this link.

                                                                                    """

                                                                                    EXTRA_TRAFFIC = Enum.YLeaf(0, "EXTRA_TRAFFIC")

                                                                                    UNPROTECTED = Enum.YLeaf(1, "UNPROTECTED")

                                                                                    SHARED = Enum.YLeaf(2, "SHARED")

                                                                                    ONE_ONE = Enum.YLeaf(3, "ONE_ONE")

                                                                                    PLUS_ONE = Enum.YLeaf(4, "PLUS_ONE")

                                                                                    ENHANCED = Enum.YLeaf(5, "ENHANCED")




                                                                        class BandwidthConstraints(_Entity_):
                                                                            """
                                                                            This container defines bandwidth\-constraints. For DS\-TE,
                                                                            the existing Maximum Reservable link bandwidth parameter
                                                                            is retained, but its semantics is generalized and
                                                                            interpreted as the aggregate bandwidth constraint across
                                                                            all Class\-Types
                                                                            
                                                                            .. attribute:: bandwidth_constraint
                                                                            
                                                                                List of the Bandwidth Constraints sub\-TLV instances present in the TLV
                                                                            
                                                                                **type**: list of    :py:class:`BandwidthConstraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "bandwidth-constraints"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("bandwidth-constraint", ("bandwidth_constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint))])
                                                                                self._leafs = OrderedDict()

                                                                                self.bandwidth_constraint = YList(self)
                                                                                self._segment_path = lambda: "bandwidth-constraints"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints, [], name, value)

                                                                            class BandwidthConstraint(_Entity_):
                                                                                """
                                                                                List of the Bandwidth Constraints sub\-TLV instances
                                                                                present in the TLV.
                                                                                
                                                                                .. attribute:: model_id  (key)
                                                                                
                                                                                    Reference to the model ID associated with the instance of the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..255
                                                                                
                                                                                    **refers to**:  :py:class:`model_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of IS Extended Reachability sub\-TLV 22
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: constraints
                                                                                
                                                                                    Constraints contained within the Bandwidth Constraints sub\-TLV
                                                                                
                                                                                    **type**:  :py:class:`Constraints<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "bandwidth-constraint"
                                                                                    self.yang_parent_name = "bandwidth-constraints"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['model_id']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State)), ("constraints", ("constraints", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('model_id', (YLeaf(YType.str, 'model-id'), ['int'])),
                                                                                    ])
                                                                                    self.model_id = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"

                                                                                    self.constraints = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints()
                                                                                    self.constraints.parent = self
                                                                                    self._children_name_map["constraints"] = "constraints"
                                                                                    self._segment_path = lambda: "bandwidth-constraint" + "[model-id='" + str(self.model_id) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint, ['model_id'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of IS Extended Reachability sub\-TLV
                                                                                    22.
                                                                                    
                                                                                    .. attribute:: model_id
                                                                                    
                                                                                        Identifier for the Bandwidth Constraints  Model currently in use by the LSR initiating the IGP advertisement
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('model_id', (YLeaf(YType.uint8, 'model-id'), ['int'])),
                                                                                        ])
                                                                                        self.model_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.State, ['model_id'], name, value)


                                                                                class Constraints(_Entity_):
                                                                                    """
                                                                                    Constraints contained within the Bandwidth
                                                                                    Constraints sub\-TLV
                                                                                    
                                                                                    .. attribute:: constraint
                                                                                    
                                                                                        List of the constraints within the Bandwidth Constraints sub\-TLV. The BC0 level is indicated by the constraint\-id leaf being set to 0, with BCN being indicated by constraint\-id N
                                                                                    
                                                                                        **type**: list of    :py:class:`Constraint<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "constraints"
                                                                                        self.yang_parent_name = "bandwidth-constraint"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([("constraint", ("constraint", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint))])
                                                                                        self._leafs = OrderedDict()

                                                                                        self.constraint = YList(self)
                                                                                        self._segment_path = lambda: "constraints"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints, [], name, value)

                                                                                    class Constraint(_Entity_):
                                                                                        """
                                                                                        List of the constraints within the Bandwidth
                                                                                        Constraints sub\-TLV. The BC0 level is indicated by
                                                                                        the constraint\-id leaf being set to 0, with BCN
                                                                                        being indicated by constraint\-id N.
                                                                                        
                                                                                        .. attribute:: constraint_id  (key)
                                                                                        
                                                                                            Reference to the unique ID for the BCN level
                                                                                        
                                                                                            **type**: int
                                                                                        
                                                                                                **range:** 0..4294967295
                                                                                        
                                                                                            **refers to**:  :py:class:`constraint_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        .. attribute:: state
                                                                                        
                                                                                            Operational state parameters of the BCN level
                                                                                        
                                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State>`
                                                                                        
                                                                                            **config**: False
                                                                                        
                                                                                        """
                                                                                        _prefix = 'oc-netinst'
                                                                                        _revision = '2017-01-13'

                                                                                        def __init__(self):
                                                                                            super().__init__()

                                                                                            self.yang_name = "constraint"
                                                                                            self.yang_parent_name = "constraints"
                                                                                            self.is_top_level_class = False
                                                                                            self.has_list_ancestor = True
                                                                                            self.ylist_key_names = ['constraint_id']
                                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State))])
                                                                                            self._leafs = OrderedDict([
                                                                                                ('constraint_id', (YLeaf(YType.str, 'constraint-id'), ['int'])),
                                                                                            ])
                                                                                            self.constraint_id = None

                                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State()
                                                                                            self.state.parent = self
                                                                                            self._children_name_map["state"] = "state"
                                                                                            self._segment_path = lambda: "constraint" + "[constraint-id='" + str(self.constraint_id) + "']"
                                                                                            self._is_frozen = True

                                                                                        def __setattr__(self, name, value):
                                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint, ['constraint_id'], name, value)

                                                                                        class State(_Entity_):
                                                                                            """
                                                                                            Operational state parameters of the BCN level
                                                                                            
                                                                                            .. attribute:: constraint_id
                                                                                            
                                                                                                Unique reference for the bandwidth constraint level. BC0 is indicated by this leaf being set to zero, with BCN represented by this leaf being set to N
                                                                                            
                                                                                                **type**: int
                                                                                            
                                                                                                    **range:** 0..4294967295
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                            .. attribute:: bandwidth
                                                                                            
                                                                                                The bandwidth constraint, expressed as a 32\-bit IEEE floating point number expressed in bytes per second
                                                                                            
                                                                                                **type**: str
                                                                                            
                                                                                                    **length:** 4..4
                                                                                            
                                                                                                **config**: False
                                                                                            
                                                                                                **units**: bytes per second
                                                                                            
                                                                                            """
                                                                                            _prefix = 'oc-netinst'
                                                                                            _revision = '2017-01-13'

                                                                                            def __init__(self):
                                                                                                super().__init__()

                                                                                                self.yang_name = "state"
                                                                                                self.yang_parent_name = "constraint"
                                                                                                self.is_top_level_class = False
                                                                                                self.has_list_ancestor = True
                                                                                                self.ylist_key_names = []
                                                                                                self._child_classes = OrderedDict([])
                                                                                                self._leafs = OrderedDict([
                                                                                                    ('constraint_id', (YLeaf(YType.uint32, 'constraint-id'), ['int'])),
                                                                                                    ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                                ])
                                                                                                self.constraint_id = None
                                                                                                self.bandwidth = None
                                                                                                self._segment_path = lambda: "state"
                                                                                                self._is_frozen = True

                                                                                            def __setattr__(self, name, value):
                                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.BandwidthConstraints.BandwidthConstraint.Constraints.Constraint.State, ['constraint_id', 'bandwidth'], name, value)






                                                                        class UnconstrainedLsp(_Entity_):
                                                                            """
                                                                            This container defines sub\-TLV 23.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of sub\-TLV 23
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "unconstrained-lsp"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "unconstrained-lsp"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of sub\-TLV 23.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: count
                                                                                
                                                                                    Unconstrained TE LSP count(TE Label Switched Paths (LSPs) signalled with zero bandwidth)
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..65535
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "unconstrained-lsp"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('count', (YLeaf(YType.uint16, 'count'), ['int'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.count = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UnconstrainedLsp.State, ['type', 'count'], name, value)



                                                                        class AdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing adjacency SIDs.
                                                                            
                                                                            .. attribute:: adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`AdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids, [], name, value)

                                                                            class AdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "adjacency-sid"
                                                                                    self.yang_parent_name = "adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AdjacencySids.AdjacencySid.State, ['value', 'flags', 'weight'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LanAdjacencySids(_Entity_):
                                                                            """
                                                                            This container defines segment routing LAN adjacency
                                                                            SIDs
                                                                            
                                                                            .. attribute:: lan_adjacency_sid
                                                                            
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is an IGP segment attached to a unidirectional adjacency or a set of unidirectional adjacencies. By default, an IGP\- Adjacency Segment is local to the node which advertises it
                                                                            
                                                                                **type**: list of    :py:class:`LanAdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "lan-adjacency-sids"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("lan-adjacency-sid", ("lan_adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid))])
                                                                                self._leafs = OrderedDict()

                                                                                self.lan_adjacency_sid = YList(self)
                                                                                self._segment_path = lambda: "lan-adjacency-sids"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids, [], name, value)

                                                                            class LanAdjacencySid(_Entity_):
                                                                                """
                                                                                Adjacency Segment\-IDs List. An IGP\-Adjacency Segment is
                                                                                an IGP segment attached to a unidirectional adjacency or
                                                                                a set of unidirectional adjacencies. By default, an IGP\-
                                                                                Adjacency Segment is local to the node which advertises
                                                                                it.
                                                                                
                                                                                .. attribute:: value  (key)
                                                                                
                                                                                    Reference to the value of the LAN Adjacency\-SID
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: state
                                                                                
                                                                                    State parameters of LAN Adjacency\-SID
                                                                                
                                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "lan-adjacency-sid"
                                                                                    self.yang_parent_name = "lan-adjacency-sids"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = ['value']
                                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State))])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                                    ])
                                                                                    self.value = None

                                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State()
                                                                                    self.state.parent = self
                                                                                    self._children_name_map["state"] = "state"
                                                                                    self._segment_path = lambda: "lan-adjacency-sid" + "[value='" + str(self.value) + "']"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid, ['value'], name, value)

                                                                                class State(_Entity_):
                                                                                    """
                                                                                    State parameters of LAN Adjacency\-SID.
                                                                                    
                                                                                    .. attribute:: value
                                                                                    
                                                                                        LAN Adjacency\-SID value
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..4294967295
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: flags
                                                                                    
                                                                                        Flags associated with LAN\-Adj\-Segment\-ID
                                                                                    
                                                                                        **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags>`
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: weight
                                                                                    
                                                                                        Value that represents the weight of the Adj\-SID for the purpose of load balancing
                                                                                    
                                                                                        **type**: int
                                                                                    
                                                                                            **range:** 0..255
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    .. attribute:: neighbor_id
                                                                                    
                                                                                        System ID of the neighbor associated with the LAN\- Adj\-Segment\-ID value
                                                                                    
                                                                                        **type**: str
                                                                                    
                                                                                            **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                                                    
                                                                                        **config**: False
                                                                                    
                                                                                    """
                                                                                    _prefix = 'oc-netinst'
                                                                                    _revision = '2017-01-13'

                                                                                    def __init__(self):
                                                                                        super().__init__()

                                                                                        self.yang_name = "state"
                                                                                        self.yang_parent_name = "lan-adjacency-sid"
                                                                                        self.is_top_level_class = False
                                                                                        self.has_list_ancestor = True
                                                                                        self.ylist_key_names = []
                                                                                        self._child_classes = OrderedDict([])
                                                                                        self._leafs = OrderedDict([
                                                                                            ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                            ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State.Flags')])),
                                                                                            ('weight', (YLeaf(YType.uint8, 'weight'), ['int'])),
                                                                                            ('neighbor_id', (YLeaf(YType.str, 'neighbor-id'), ['str'])),
                                                                                        ])
                                                                                        self.value = None
                                                                                        self.flags = []
                                                                                        self.weight = None
                                                                                        self.neighbor_id = None
                                                                                        self._segment_path = lambda: "state"
                                                                                        self._is_frozen = True

                                                                                    def __setattr__(self, name, value):
                                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LanAdjacencySids.LanAdjacencySid.State, ['value', 'flags', 'weight', 'neighbor_id'], name, value)

                                                                                    class Flags(Enum):
                                                                                        """
                                                                                        Flags (Enum Class)

                                                                                        .. data:: ADDRESS_FAMILY = 0

                                                                                            Address-family flag. When unset, the Adj-SID

                                                                                            refers to an adjacency with outgoing IPv4

                                                                                            encapsulation. If set then the Adj-SID refers to

                                                                                            an adjacency with outgoing IPv6 encapsulation.

                                                                                        .. data:: BACKUP = 1

                                                                                            Backup flag. When set, the Adj-SID refers to an

                                                                                            adjacency being protected (e.g.: using IPFRR or

                                                                                            MPLS-FRR).

                                                                                        .. data:: VALUE = 2

                                                                                            Value flag. When set, the SID carries a value

                                                                                            (instead of an index). By default the flag is

                                                                                            SET.

                                                                                        .. data:: LOCAL = 3

                                                                                            Local flag. When set, the value/index carried

                                                                                            by the SID has local significance. By default

                                                                                            the flag is SET.

                                                                                        .. data:: SET = 4

                                                                                            Set flag. When set, the S-Flag indicates that

                                                                                            the Adj-SID refers to a set of adjacencies.

                                                                                        """

                                                                                        ADDRESS_FAMILY = Enum.YLeaf(0, "ADDRESS_FAMILY")

                                                                                        BACKUP = Enum.YLeaf(1, "BACKUP")

                                                                                        VALUE = Enum.YLeaf(2, "VALUE")

                                                                                        LOCAL = Enum.YLeaf(3, "LOCAL")

                                                                                        SET = Enum.YLeaf(4, "SET")





                                                                        class LinkDelay(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 33
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                33.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay value (in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelay.State, ['a_bit', 'delay'], name, value)



                                                                        class MinMaxLinkDelay(_Entity_):
                                                                            """
                                                                            This container defines min/max link delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 34
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "min-max-link-delay"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "min-max-link-delay"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                34.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: min_delay
                                                                                
                                                                                    Minimum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                .. attribute:: max_delay
                                                                                
                                                                                    Maximum measured link delay value(in microseconds) between two directly connected IS\-IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "min-max-link-delay"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('min_delay', (YLeaf(YType.uint32, 'min-delay'), ['int'])),
                                                                                        ('max_delay', (YLeaf(YType.uint32, 'max-delay'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.min_delay = None
                                                                                    self.max_delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.MinMaxLinkDelay.State, ['a_bit', 'min_delay', 'max_delay'], name, value)



                                                                        class LinkDelayVariation(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link delay
                                                                            variation.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 35
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-delay-variation"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-delay-variation"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                35.
                                                                                
                                                                                .. attribute:: delay
                                                                                
                                                                                    Average link delay between two directly connected IS\- IS neighbors over a configurable interval
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: microseconds
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-delay-variation"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('delay', (YLeaf(YType.uint32, 'delay'), ['int'])),
                                                                                    ])
                                                                                    self.delay = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkDelayVariation.State, ['delay'], name, value)



                                                                        class LinkLoss(_Entity_):
                                                                            """
                                                                            This container defines unidirectional link loss delay.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 36
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "link-loss"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "link-loss"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                36.
                                                                                
                                                                                .. attribute:: a_bit
                                                                                
                                                                                    The A bit is set when the measured value of this parameter exceeds its configured maximum threshold. The A bit is cleared when the measured value falls below its configured reuse threshold
                                                                                
                                                                                    **type**: bool
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: link_loss
                                                                                
                                                                                    Link packet loss as a percentage of the total traffic sent over a configurable interval. The basic unit is 0.000003%, where (2^24 \- 2) is 50.331642%. This value is the highest packet\-loss percentage that can be expressed (the assumption being that precision is more important on high\-speed links than the ability to advertise loss rates greater than this, and that high\- speed links with over 50% loss are unusable). Therefore, measured values that are larger than the field maximum SHOULD be encoded as the maximum value
                                                                                
                                                                                    **type**: int
                                                                                
                                                                                        **range:** 0..4294967295
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "link-loss"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('a_bit', (YLeaf(YType.boolean, 'a-bit'), ['bool'])),
                                                                                        ('link_loss', (YLeaf(YType.uint32, 'link-loss'), ['int'])),
                                                                                    ])
                                                                                    self.a_bit = None
                                                                                    self.link_loss = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.LinkLoss.State, ['a_bit', 'link_loss'], name, value)



                                                                        class ResidualBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional residual
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 37
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "residual-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "residual-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                37.
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    Residual bandwidth on a link,forwarding adjacency [RFC4206], or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, residual bandwidth is defined to be the Maximum Bandwidth [RFC5305] minus the bandwidth currently allocated to RSVP\-TE label switched paths. For a bundled link, residual bandwidth is defined to be the sum of the component link residual bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "residual-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.ResidualBandwidth.State, ['bandwidth'], name, value)



                                                                        class AvailableBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional lavailable
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 38
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "available-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "available-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                38.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The available bandwidth on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second. For a link or forwarding adjacency, available bandwidth is defined to be residual bandwidth minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths minus the measured bandwidth used for the actual forwarding of non\-RSVP\-TE label switched path packets.  For a bundled link, available bandwidth is defined to be the sum of the component link available bandwidths
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "available-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.AvailableBandwidth.State, ['type', 'bandwidth'], name, value)



                                                                        class UtilizedBandwidth(_Entity_):
                                                                            """
                                                                            This container defines unidirectional utilized
                                                                            bandwidth.
                                                                            
                                                                            .. attribute:: state
                                                                            
                                                                                State parameters of IS Extended Reachability sub\-TLV 39
                                                                            
                                                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "utilized-bandwidth"
                                                                                self.yang_parent_name = "subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State))])
                                                                                self._leafs = OrderedDict()

                                                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State()
                                                                                self.state.parent = self
                                                                                self._children_name_map["state"] = "state"
                                                                                self._segment_path = lambda: "utilized-bandwidth"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth, [], name, value)

                                                                            class State(_Entity_):
                                                                                """
                                                                                State parameters of IS Extended Reachability sub\-TLV
                                                                                39.
                                                                                
                                                                                .. attribute:: type
                                                                                
                                                                                    The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                                
                                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                .. attribute:: bandwidth
                                                                                
                                                                                    The bandwidth utilization on a link, forwarding adjacency, or bundled link in IEEE floating\-point format with units of bytes per second.  For a link or forwarding adjacency, bandwidth utilization represents the actual utilization of the link (i.e., as measured by the advertising node).  For a bundled link, bandwidth utilization is defined to be the sum of the component link bandwidth utilizations
                                                                                
                                                                                    **type**: str
                                                                                
                                                                                        **length:** 4..4
                                                                                
                                                                                    **config**: False
                                                                                
                                                                                    **units**: bytes per second
                                                                                
                                                                                """
                                                                                _prefix = 'oc-netinst'
                                                                                _revision = '2017-01-13'

                                                                                def __init__(self):
                                                                                    super().__init__()

                                                                                    self.yang_name = "state"
                                                                                    self.yang_parent_name = "utilized-bandwidth"
                                                                                    self.is_top_level_class = False
                                                                                    self.has_list_ancestor = True
                                                                                    self.ylist_key_names = []
                                                                                    self._child_classes = OrderedDict([])
                                                                                    self._leafs = OrderedDict([
                                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                        ('bandwidth', (YLeaf(YType.str, 'bandwidth'), ['str'])),
                                                                                    ])
                                                                                    self.type = None
                                                                                    self.bandwidth = None
                                                                                    self._segment_path = lambda: "state"
                                                                                    self._is_frozen = True

                                                                                def __setattr__(self, name, value):
                                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.Subtlvs.Subtlv.UtilizedBandwidth.State, ['type', 'bandwidth'], name, value)





                                                                class UndefinedSubtlvs(_Entity_):
                                                                    """
                                                                    This container describes undefined ISIS TLVs.
                                                                    
                                                                    .. attribute:: undefined_subtlv
                                                                    
                                                                        Sub\-TLVs that are not defined in the model or not recognised by system
                                                                    
                                                                        **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "undefined-subtlvs"
                                                                        self.yang_parent_name = "instance"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                        self._leafs = OrderedDict()

                                                                        self.undefined_subtlv = YList(self)
                                                                        self._segment_path = lambda: "undefined-subtlvs"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs, [], name, value)

                                                                    class UndefinedSubtlv(_Entity_):
                                                                        """
                                                                        Sub\-TLVs that are not defined in the model or not
                                                                        recognised by system.
                                                                        
                                                                        .. attribute:: type  (key)
                                                                        
                                                                            Reference to the type of the undefined sub\-TLV
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..255
                                                                        
                                                                            **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters of the undefined sub\-TLV
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "undefined-subtlv"
                                                                            self.yang_parent_name = "undefined-subtlvs"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['type']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                            ])
                                                                            self.type = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters of the undefined sub\-TLV.
                                                                            
                                                                            .. attribute:: type
                                                                            
                                                                                TLV Type
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: length
                                                                            
                                                                                TLV length
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                TLV value
                                                                            
                                                                                **type**: str
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "undefined-subtlv"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                                    ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                                    ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                                ])
                                                                                self.type = None
                                                                                self.length = None
                                                                                self.value = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIsisNeighborAttribute.Neighbors.Neighbor.Instances.Instance.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)









                                            class MtIpv4Reachability(_Entity_):
                                                """
                                                This container defines list of IPv4 reachability
                                                Information in multi\-topology environment.
                                                
                                                .. attribute:: prefixes
                                                
                                                    This container describes IS prefixes
                                                
                                                    **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "mt-ipv4-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes))])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._segment_path = lambda: "mt-ipv4-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability, [], name, value)

                                                class Prefixes(_Entity_):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                        IPv4 prefixes that are contained within MT reachability TLV
                                                    
                                                        **type**: list of    :py:class:`Prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "mt-ipv4-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes, [], name, value)

                                                    class Prefix(_Entity_):
                                                        """
                                                        IPv4 prefixes that are contained within MT
                                                        reachability TLV.
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                            Reference to the topology ID of the topology that the prefix is within
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4095
                                                        
                                                            **refers to**:  :py:class:`mt_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the prefix to which reachability is being advertised
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters of an IPv4 extended prefix
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                            This container describes IS prefix sub\-TLVs
                                                        
                                                            **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                            This container describes undefined ISIS TLVs
                                                        
                                                            **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['mt_id','prefix']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._leafs = OrderedDict([
                                                                ('mt_id', (YLeaf(YType.str, 'mt-id'), ['int'])),
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ])
                                                            self.mt_id = None
                                                            self.prefix = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._segment_path = lambda: "prefix" + "[mt-id='" + str(self.mt_id) + "']" + "[prefix='" + str(self.prefix) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix, ['mt_id', 'prefix'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters of an IPv4 extended prefix.
                                                            
                                                            .. attribute:: up_down
                                                            
                                                                The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                                The Sub\-TLV present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                IPv4 prefix contained within extended reachability TLVs
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))$
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: metric
                                                            
                                                                ISIS metric value
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 1..16777215
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                                Multi\-topology ID
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 0..4095
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                    ('s_bit', (YLeaf(YType.boolean, 's-bit'), ['bool'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                    ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                ])
                                                                self.up_down = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self.mt_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.State, ['up_down', 's_bit', 'prefix', 'metric', 'mt_id'], name, value)


                                                        class Subtlvs(_Entity_):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                                List of subTLV types in the LSDB for the specified TLV
                                                            
                                                                **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs, [], name, value)

                                                            class Subtlv(_Entity_):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the sub\-TLV type
                                                                
                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters for a prefix
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag
                                                                
                                                                    This container defines sub\-TLV 1
                                                                
                                                                    **type**:  :py:class:`Tag<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                    This container defines sub\-TLV 2
                                                                
                                                                    **type**:  :py:class:`Tag64<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    This container defines sub\-TLV 4
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                    This container defines sub\-TLV 11
                                                                
                                                                    **type**:  :py:class:`Ipv4SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                    This container defines sub\-TLV 12
                                                                
                                                                    **type**:  :py:class:`Ipv6SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                    This container defines segment routing extensions for prefixes
                                                                
                                                                    **type**:  :py:class:`PrefixSids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    
                                                                        **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 1
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                            List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)



                                                                class Tag64(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 2
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag64"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                            List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..18446744073709551615
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)



                                                                class Flags(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 4
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "flags"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                            Additional prefix reachability flags
                                                                        
                                                                            **type**: list of   :py:class:`Flags_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_')])),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                                External prefix flag. Set if the prefix has been

                                                                                redistributed from another protocol. This includes

                                                                                the case where multiple virtual routers are

                                                                                supported and the source of the redistributed prefix

                                                                                is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                                Readvertisement flag. Set when the prefix has been

                                                                                leaked from one level to another (upwards or

                                                                                downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                                Node flag. Set when the prefix identifies the

                                                                                advertising router, i.e., the prefix is a host

                                                                                prefix advertising  a globally reachable address

                                                                                typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")




                                                                class Ipv4SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 11
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv4-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class Ipv6SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 12
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv6-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class PrefixSids(_Entity_):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    
                                                                        **type**: list of    :py:class:`PrefixSid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)

                                                                    class PrefixSid(_Entity_):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                            Reference to the value of the prefix SID
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters for Prefix\-SID
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                IGP Prefix\-SID value
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..4294967295
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                                Flags associated with Prefix Segment\-ID
                                                                            
                                                                                **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                                Prefix\-SID algorithm to be used for path computation
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags')])),
                                                                                    ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                .. data:: READVERTISEMENT = 0

                                                                                    Readvertisment flag. When set, the prefix to which

                                                                                    this Prefix-SID is attached, has been propagated by

                                                                                    the router either from another level or from

                                                                                    redistribution.

                                                                                .. data:: NODE = 1

                                                                                    Node flag. When set, the Prefix-SID refers to the

                                                                                    router identified by the prefix. Typically, the

                                                                                    N-Flag is set on Prefix-SIDs attached to a router

                                                                                    loopback address.

                                                                                .. data:: NO_PHP = 2

                                                                                    Penultimate-Hop-Popping flag. When set, then the

                                                                                    penultimate hop MUST NOT pop the Prefix-SID before

                                                                                    delivering the packet to the node that advertised

                                                                                    the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                    Explicit-Null flag. When set, any upstream neighbor

                                                                                    of the Prefix-SID originator MUST replace the

                                                                                    Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                    value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                    the packet.

                                                                                .. data:: VALUE = 4

                                                                                    Value flag. When set, the Prefix-SID carries a

                                                                                    value (instead of an index). By default the flag is

                                                                                    UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                    Local flag. When set, the value/index carried by

                                                                                    the Prefix-SID has local significance. By default

                                                                                    the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                NO_PHP = Enum.YLeaf(2, "NO_PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")







                                                        class UndefinedSubtlvs(_Entity_):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                                Sub\-TLVs that are not defined in the model or not recognised by system
                                                            
                                                                **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)

                                                            class UndefinedSubtlv(_Entity_):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the type of the undefined sub\-TLV
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..255
                                                                
                                                                    **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of the undefined sub\-TLV
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        TLV Type
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                        TLV length
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                        TLV value
                                                                    
                                                                        **type**: str
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv4Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)







                                            class MtIpv6Reachability(_Entity_):
                                                """
                                                This container defines list of IPv6 reachability
                                                information in multi \- topology environment.
                                                
                                                .. attribute:: prefixes
                                                
                                                    This container describes IS prefixes
                                                
                                                    **type**:  :py:class:`Prefixes<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "mt-ipv6-reachability"
                                                    self.yang_parent_name = "tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefixes", ("prefixes", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes))])
                                                    self._leafs = OrderedDict()

                                                    self.prefixes = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes()
                                                    self.prefixes.parent = self
                                                    self._children_name_map["prefixes"] = "prefixes"
                                                    self._segment_path = lambda: "mt-ipv6-reachability"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability, [], name, value)

                                                class Prefixes(_Entity_):
                                                    """
                                                    This container describes IS prefixes.
                                                    
                                                    .. attribute:: prefix
                                                    
                                                        List of IPv6 prefixes contained within MT reachability TLV
                                                    
                                                        **type**: list of    :py:class:`Prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix>`
                                                    
                                                        **config**: False
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefixes"
                                                        self.yang_parent_name = "mt-ipv6-reachability"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix", ("prefix", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix = YList(self)
                                                        self._segment_path = lambda: "prefixes"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes, [], name, value)

                                                    class Prefix(_Entity_):
                                                        """
                                                        List of IPv6 prefixes contained within MT
                                                        reachability TLV.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the IPv6 prefix described by the TLV
                                                        
                                                            **type**: str
                                                        
                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: mt_id  (key)
                                                        
                                                            Reference to the multi\-topology ID
                                                        
                                                            **type**: int
                                                        
                                                                **range:** 0..4095
                                                        
                                                            **refers to**:  :py:class:`mt_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: state
                                                        
                                                            State parameters relating an IPv6 prefix attribute
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: subtlvs
                                                        
                                                            This container describes IS prefix sub\-TLVs
                                                        
                                                            **type**:  :py:class:`Subtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        .. attribute:: undefined_subtlvs
                                                        
                                                            This container describes undefined ISIS TLVs
                                                        
                                                            **type**:  :py:class:`UndefinedSubtlvs<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix"
                                                            self.yang_parent_name = "prefixes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix','mt_id']
                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State)), ("subtlvs", ("subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs)), ("undefined-subtlvs", ("undefined_subtlvs", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs))])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                ('mt_id', (YLeaf(YType.str, 'mt-id'), ['int'])),
                                                            ])
                                                            self.prefix = None
                                                            self.mt_id = None

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"

                                                            self.subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs()
                                                            self.subtlvs.parent = self
                                                            self._children_name_map["subtlvs"] = "subtlvs"

                                                            self.undefined_subtlvs = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs()
                                                            self.undefined_subtlvs.parent = self
                                                            self._children_name_map["undefined_subtlvs"] = "undefined-subtlvs"
                                                            self._segment_path = lambda: "prefix" + "[prefix='" + str(self.prefix) + "']" + "[mt-id='" + str(self.mt_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix, ['prefix', 'mt_id'], name, value)

                                                        class State(_Entity_):
                                                            """
                                                            State parameters relating an IPv6 prefix attribute
                                                            
                                                            .. attribute:: up_down
                                                            
                                                                The up/down bit. Set if a prefix is advertised from a higher level to a lower level (e.g., level 2 to level 1), indicating that the prefix has traveled down the hierarchy. Prefixes that have the up/down bit set may only be advertised down the hierarchy, i.e., to lower levels. When a prefix is first injected into IS\-IS, the bit is UNSET
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: x_bit
                                                            
                                                                The external bit. Set when the prefix was distributed into IS\-IS from another routing protocol
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: s_bit
                                                            
                                                                The sub\-tlv present bit. If UNSET, the octets of Sub\-TLVs are not present. Otherwise, the bit is set and the octet following the prefix will contain the length of the Sub\-TLV portion of the structure
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                IPv6 prefix contained within extended reachability TLVs
                                                            
                                                                **type**: str
                                                            
                                                                    **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))/(12[0\-8]\|1[0\-1][0\-9]\|[1\-9][0\-9]\|[0\-9])$
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: metric
                                                            
                                                                ISIS metric value
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 1..16777215
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: mt_id
                                                            
                                                                Multi\-topology ID
                                                            
                                                                **type**: int
                                                            
                                                                    **range:** 0..4095
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('up_down', (YLeaf(YType.boolean, 'up-down'), ['bool'])),
                                                                    ('x_bit', (YLeaf(YType.boolean, 'x-bit'), ['bool'])),
                                                                    ('s_bit', (YLeaf(YType.boolean, 's-bit'), ['bool'])),
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                                    ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                                    ('mt_id', (YLeaf(YType.uint16, 'mt-id'), ['int'])),
                                                                ])
                                                                self.up_down = None
                                                                self.x_bit = None
                                                                self.s_bit = None
                                                                self.prefix = None
                                                                self.metric = None
                                                                self.mt_id = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.State, ['up_down', 'x_bit', 's_bit', 'prefix', 'metric', 'mt_id'], name, value)


                                                        class Subtlvs(_Entity_):
                                                            """
                                                            This container describes IS prefix sub\-TLVs.
                                                            
                                                            .. attribute:: subtlv
                                                            
                                                                List of subTLV types in the LSDB for the specified TLV
                                                            
                                                                **type**: list of    :py:class:`Subtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("subtlv", ("subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.subtlv = YList(self)
                                                                self._segment_path = lambda: "subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs, [], name, value)

                                                            class Subtlv(_Entity_):
                                                                """
                                                                List of subTLV types in the LSDB for the specified TLV.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the sub\-TLV type
                                                                
                                                                    **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters for a prefix
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag
                                                                
                                                                    This container defines sub\-TLV 1
                                                                
                                                                    **type**:  :py:class:`Tag<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: tag64
                                                                
                                                                    This container defines sub\-TLV 2
                                                                
                                                                    **type**:  :py:class:`Tag64<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: flags
                                                                
                                                                    This container defines sub\-TLV 4
                                                                
                                                                    **type**:  :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv4_source_router_id
                                                                
                                                                    This container defines sub\-TLV 11
                                                                
                                                                    **type**:  :py:class:`Ipv4SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: ipv6_source_router_id
                                                                
                                                                    This container defines sub\-TLV 12
                                                                
                                                                    **type**:  :py:class:`Ipv6SourceRouterId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: prefix_sids
                                                                
                                                                    This container defines segment routing extensions for prefixes
                                                                
                                                                    **type**:  :py:class:`PrefixSids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "subtlv"
                                                                    self.yang_parent_name = "subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State)), ("tag", ("tag", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag)), ("tag64", ("tag64", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64)), ("flags", ("flags", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags)), ("ipv4-source-router-id", ("ipv4_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId)), ("ipv6-source-router-id", ("ipv6_source_router_id", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId)), ("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"

                                                                    self.tag = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag()
                                                                    self.tag.parent = self
                                                                    self._children_name_map["tag"] = "tag"

                                                                    self.tag64 = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64()
                                                                    self.tag64.parent = self
                                                                    self._children_name_map["tag64"] = "tag64"

                                                                    self.flags = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags()
                                                                    self.flags.parent = self
                                                                    self._children_name_map["flags"] = "flags"

                                                                    self.ipv4_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId()
                                                                    self.ipv4_source_router_id.parent = self
                                                                    self._children_name_map["ipv4_source_router_id"] = "ipv4-source-router-id"

                                                                    self.ipv6_source_router_id = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId()
                                                                    self.ipv6_source_router_id.parent = self
                                                                    self._children_name_map["ipv6_source_router_id"] = "ipv6-source-router-id"

                                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids()
                                                                    self.prefix_sids.parent = self
                                                                    self._children_name_map["prefix_sids"] = "prefix-sids"
                                                                    self._segment_path = lambda: "subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters for a prefix.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                    
                                                                        **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                        ])
                                                                        self.type = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.State, ['type'], name, value)


                                                                class Tag(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 1.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 1
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 1.
                                                                        
                                                                        .. attribute:: tag32
                                                                        
                                                                            List of 32\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag32', (YLeafList(YType.uint32, 'tag32'), ['int'])),
                                                                            ])
                                                                            self.tag32 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag.State, ['tag32'], name, value)



                                                                class Tag64(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 2.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 2
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "tag64"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "tag64"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 2.
                                                                        
                                                                        .. attribute:: tag64
                                                                        
                                                                            List of 64\-bit tags associated with the prefix. Example uses of these tags include carrying BGP standard (or extended) communities and controlling redistribution between levels and areas, different routing protocols, or multiple instances of IS\-IS running on the same router
                                                                        
                                                                            **type**: list of int
                                                                        
                                                                                **range:** 0..18446744073709551615
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "tag64"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('tag64', (YLeafList(YType.uint64, 'tag64'), ['int'])),
                                                                            ])
                                                                            self.tag64 = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Tag64.State, ['tag64'], name, value)



                                                                class Flags(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 4.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 4
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "flags"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "flags"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 4.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: flags
                                                                        
                                                                            Additional prefix reachability flags
                                                                        
                                                                            **type**: list of   :py:class:`Flags_<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "flags"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State.Flags_')])),
                                                                            ])
                                                                            self.type = None
                                                                            self.flags = []
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Flags.State, ['type', 'flags'], name, value)

                                                                        class Flags_(Enum):
                                                                            """
                                                                            Flags\_ (Enum Class)

                                                                            .. data:: EXTERNAL_FLAG = 0

                                                                                External prefix flag. Set if the prefix has been

                                                                                redistributed from another protocol. This includes

                                                                                the case where multiple virtual routers are

                                                                                supported and the source of the redistributed prefix

                                                                                is another IS-IS instance.

                                                                            .. data:: READVERTISEMENT_FLAG = 1

                                                                                Readvertisement flag. Set when the prefix has been

                                                                                leaked from one level to another (upwards or

                                                                                downwards).

                                                                            .. data:: NODE_FLAG = 2

                                                                                Node flag. Set when the prefix identifies the

                                                                                advertising router, i.e., the prefix is a host

                                                                                prefix advertising  a globally reachable address

                                                                                typically associated with a loopback address.

                                                                            """

                                                                            EXTERNAL_FLAG = Enum.YLeaf(0, "EXTERNAL_FLAG")

                                                                            READVERTISEMENT_FLAG = Enum.YLeaf(1, "READVERTISEMENT_FLAG")

                                                                            NODE_FLAG = Enum.YLeaf(2, "NODE_FLAG")




                                                                class Ipv4SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 11.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 11
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv4-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv4-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 11.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv4 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv4-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv4SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class Ipv6SourceRouterId(_Entity_):
                                                                    """
                                                                    This container defines sub\-TLV 12.
                                                                    
                                                                    .. attribute:: state
                                                                    
                                                                        State parameters of sub\-TLV 12
                                                                    
                                                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "ipv6-source-router-id"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State))])
                                                                        self._leafs = OrderedDict()

                                                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State()
                                                                        self.state.parent = self
                                                                        self._children_name_map["state"] = "state"
                                                                        self._segment_path = lambda: "ipv6-source-router-id"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId, [], name, value)

                                                                    class State(_Entity_):
                                                                        """
                                                                        State parameters of sub\-TLV 12.
                                                                        
                                                                        .. attribute:: type
                                                                        
                                                                            The type of subTLV being described. The type of subTLV is expressed as a canonical name
                                                                        
                                                                            **type**:  :py:class:`ISISSUBTLVTYPE<ydk.models.openconfig.openconfig_isis_lsdb_types.ISISSUBTLVTYPE>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: router_id
                                                                        
                                                                            IPv6 Source router ID address. In cases where the advertisement is an identifier for the advertising router (e.g., with the N\-flag set in the Prefix Attribute Flags sub\-TLV), it may be useful for other routers to know the source of the advertisement. When reachability advertisement is leaked from one level to another, Router ID advertised is always the Router ID of the IS\-IS instance that originated the advertisement. This would be true even if the prefix had been learned from another protocol
                                                                        
                                                                            **type**: str
                                                                        
                                                                                **pattern:** ^(([0\-9a\-fA\-F]{1,4}\:){7}[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,7}\:\|([0\-9a\-fA\-F]{1,4}\:){1,6}\:[0\-9a\-fA\-F]{1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,5}(\:[0\-9a\-fA\-F]{1,4}){1,2}\|([0\-9a\-fA\-F]{1,4}\:){1,4}(\:[0\-9a\-fA\-F]{1,4}){1,3}\|([0\-9a\-fA\-F]{1,4}\:){1,3}(\:[0\-9a\-fA\-F]{1,4}){1,4}\|([0\-9a\-fA\-F]{1,4}\:){1,2}(\:[0\-9a\-fA\-F]{1,4}){1,5}\|[0\-9a\-fA\-F]{1,4}\:((\:[0\-9a\-fA\-F]{1,4}){1,6})\|\:((\:[0\-9a\-fA\-F]{1,4}){1,7}\|\:))$
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "state"
                                                                            self.yang_parent_name = "ipv6-source-router-id"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = []
                                                                            self._child_classes = OrderedDict([])
                                                                            self._leafs = OrderedDict([
                                                                                ('type', (YLeaf(YType.identityref, 'type'), [('ydk.models.openconfig.openconfig_isis_lsdb_types', 'ISISSUBTLVTYPE')])),
                                                                                ('router_id', (YLeaf(YType.str, 'router-id'), ['str'])),
                                                                            ])
                                                                            self.type = None
                                                                            self.router_id = None
                                                                            self._segment_path = lambda: "state"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.Ipv6SourceRouterId.State, ['type', 'router_id'], name, value)



                                                                class PrefixSids(_Entity_):
                                                                    """
                                                                    This container defines segment routing extensions for
                                                                    prefixes.
                                                                    
                                                                    .. attribute:: prefix_sid
                                                                    
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment attached to an IGP prefix. An IGP\-Prefix Segment is global (unless explicitly advertised otherwise) within the SR/IGP domain
                                                                    
                                                                        **type**: list of    :py:class:`PrefixSid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid>`
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "prefix-sids"
                                                                        self.yang_parent_name = "subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid))])
                                                                        self._leafs = OrderedDict()

                                                                        self.prefix_sid = YList(self)
                                                                        self._segment_path = lambda: "prefix-sids"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids, [], name, value)

                                                                    class PrefixSid(_Entity_):
                                                                        """
                                                                        Prefix Segment\-ID list. IGP\-Prefix Segment is an IGP segment
                                                                        attached to an IGP prefix. An IGP\-Prefix Segment is global
                                                                        (unless explicitly advertised otherwise) within the SR/IGP
                                                                        domain.
                                                                        
                                                                        .. attribute:: value  (key)
                                                                        
                                                                            Reference to the value of the prefix SID
                                                                        
                                                                            **type**: int
                                                                        
                                                                                **range:** 0..4294967295
                                                                        
                                                                            **refers to**:  :py:class:`value<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        .. attribute:: state
                                                                        
                                                                            State parameters for Prefix\-SID
                                                                        
                                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State>`
                                                                        
                                                                            **config**: False
                                                                        
                                                                        """
                                                                        _prefix = 'oc-netinst'
                                                                        _revision = '2017-01-13'

                                                                        def __init__(self):
                                                                            super().__init__()

                                                                            self.yang_name = "prefix-sid"
                                                                            self.yang_parent_name = "prefix-sids"
                                                                            self.is_top_level_class = False
                                                                            self.has_list_ancestor = True
                                                                            self.ylist_key_names = ['value']
                                                                            self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State))])
                                                                            self._leafs = OrderedDict([
                                                                                ('value', (YLeaf(YType.str, 'value'), ['int'])),
                                                                            ])
                                                                            self.value = None

                                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State()
                                                                            self.state.parent = self
                                                                            self._children_name_map["state"] = "state"
                                                                            self._segment_path = lambda: "prefix-sid" + "[value='" + str(self.value) + "']"
                                                                            self._is_frozen = True

                                                                        def __setattr__(self, name, value):
                                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid, ['value'], name, value)

                                                                        class State(_Entity_):
                                                                            """
                                                                            State parameters for Prefix\-SID.
                                                                            
                                                                            .. attribute:: value
                                                                            
                                                                                IGP Prefix\-SID value
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..4294967295
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: flags
                                                                            
                                                                                Flags associated with Prefix Segment\-ID
                                                                            
                                                                                **type**: list of   :py:class:`Flags<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags>`
                                                                            
                                                                                **config**: False
                                                                            
                                                                            .. attribute:: algorithm
                                                                            
                                                                                Prefix\-SID algorithm to be used for path computation
                                                                            
                                                                                **type**: int
                                                                            
                                                                                    **range:** 0..255
                                                                            
                                                                                **config**: False
                                                                            
                                                                            """
                                                                            _prefix = 'oc-netinst'
                                                                            _revision = '2017-01-13'

                                                                            def __init__(self):
                                                                                super().__init__()

                                                                                self.yang_name = "state"
                                                                                self.yang_parent_name = "prefix-sid"
                                                                                self.is_top_level_class = False
                                                                                self.has_list_ancestor = True
                                                                                self.ylist_key_names = []
                                                                                self._child_classes = OrderedDict([])
                                                                                self._leafs = OrderedDict([
                                                                                    ('value', (YLeaf(YType.uint32, 'value'), ['int'])),
                                                                                    ('flags', (YLeafList(YType.enumeration, 'flags'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State.Flags')])),
                                                                                    ('algorithm', (YLeaf(YType.uint8, 'algorithm'), ['int'])),
                                                                                ])
                                                                                self.value = None
                                                                                self.flags = []
                                                                                self.algorithm = None
                                                                                self._segment_path = lambda: "state"
                                                                                self._is_frozen = True

                                                                            def __setattr__(self, name, value):
                                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.Subtlvs.Subtlv.PrefixSids.PrefixSid.State, ['value', 'flags', 'algorithm'], name, value)

                                                                            class Flags(Enum):
                                                                                """
                                                                                Flags (Enum Class)

                                                                                .. data:: READVERTISEMENT = 0

                                                                                    Readvertisment flag. When set, the prefix to which

                                                                                    this Prefix-SID is attached, has been propagated by

                                                                                    the router either from another level or from

                                                                                    redistribution.

                                                                                .. data:: NODE = 1

                                                                                    Node flag. When set, the Prefix-SID refers to the

                                                                                    router identified by the prefix. Typically, the

                                                                                    N-Flag is set on Prefix-SIDs attached to a router

                                                                                    loopback address.

                                                                                .. data:: NO_PHP = 2

                                                                                    Penultimate-Hop-Popping flag. When set, then the

                                                                                    penultimate hop MUST NOT pop the Prefix-SID before

                                                                                    delivering the packet to the node that advertised

                                                                                    the Prefix-SID.

                                                                                .. data:: EXPLICIT_NULL = 3

                                                                                    Explicit-Null flag. When set, any upstream neighbor

                                                                                    of the Prefix-SID originator MUST replace the

                                                                                    Prefix-SID with a Prefix-SID having an Explicit-NULL

                                                                                    value (0 for IPv4 and 2 for IPv6) before forwarding

                                                                                    the packet.

                                                                                .. data:: VALUE = 4

                                                                                    Value flag. When set, the Prefix-SID carries a

                                                                                    value (instead of an index). By default the flag is

                                                                                    UNSET.

                                                                                .. data:: LOCAL = 5

                                                                                    Local flag. When set, the value/index carried by

                                                                                    the Prefix-SID has local significance. By default

                                                                                    the flag is UNSET.

                                                                                """

                                                                                READVERTISEMENT = Enum.YLeaf(0, "READVERTISEMENT")

                                                                                NODE = Enum.YLeaf(1, "NODE")

                                                                                NO_PHP = Enum.YLeaf(2, "NO_PHP")

                                                                                EXPLICIT_NULL = Enum.YLeaf(3, "EXPLICIT_NULL")

                                                                                VALUE = Enum.YLeaf(4, "VALUE")

                                                                                LOCAL = Enum.YLeaf(5, "LOCAL")







                                                        class UndefinedSubtlvs(_Entity_):
                                                            """
                                                            This container describes undefined ISIS TLVs.
                                                            
                                                            .. attribute:: undefined_subtlv
                                                            
                                                                Sub\-TLVs that are not defined in the model or not recognised by system
                                                            
                                                                **type**: list of    :py:class:`UndefinedSubtlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "undefined-subtlvs"
                                                                self.yang_parent_name = "prefix"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([("undefined-subtlv", ("undefined_subtlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv))])
                                                                self._leafs = OrderedDict()

                                                                self.undefined_subtlv = YList(self)
                                                                self._segment_path = lambda: "undefined-subtlvs"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs, [], name, value)

                                                            class UndefinedSubtlv(_Entity_):
                                                                """
                                                                Sub\-TLVs that are not defined in the model or not
                                                                recognised by system.
                                                                
                                                                .. attribute:: type  (key)
                                                                
                                                                    Reference to the type of the undefined sub\-TLV
                                                                
                                                                    **type**: int
                                                                
                                                                        **range:** 0..255
                                                                
                                                                    **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                .. attribute:: state
                                                                
                                                                    State parameters of the undefined sub\-TLV
                                                                
                                                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State>`
                                                                
                                                                    **config**: False
                                                                
                                                                """
                                                                _prefix = 'oc-netinst'
                                                                _revision = '2017-01-13'

                                                                def __init__(self):
                                                                    super().__init__()

                                                                    self.yang_name = "undefined-subtlv"
                                                                    self.yang_parent_name = "undefined-subtlvs"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self.ylist_key_names = ['type']
                                                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State))])
                                                                    self._leafs = OrderedDict([
                                                                        ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                                    ])
                                                                    self.type = None

                                                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State()
                                                                    self.state.parent = self
                                                                    self._children_name_map["state"] = "state"
                                                                    self._segment_path = lambda: "undefined-subtlv" + "[type='" + str(self.type) + "']"
                                                                    self._is_frozen = True

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv, ['type'], name, value)

                                                                class State(_Entity_):
                                                                    """
                                                                    State parameters of the undefined sub\-TLV.
                                                                    
                                                                    .. attribute:: type
                                                                    
                                                                        TLV Type
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: length
                                                                    
                                                                        TLV length
                                                                    
                                                                        **type**: int
                                                                    
                                                                            **range:** 0..255
                                                                    
                                                                        **config**: False
                                                                    
                                                                    .. attribute:: value
                                                                    
                                                                        TLV value
                                                                    
                                                                        **type**: str
                                                                    
                                                                        **config**: False
                                                                    
                                                                    """
                                                                    _prefix = 'oc-netinst'
                                                                    _revision = '2017-01-13'

                                                                    def __init__(self):
                                                                        super().__init__()

                                                                        self.yang_name = "state"
                                                                        self.yang_parent_name = "undefined-subtlv"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self.ylist_key_names = []
                                                                        self._child_classes = OrderedDict([])
                                                                        self._leafs = OrderedDict([
                                                                            ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                                            ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                                            ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                                        ])
                                                                        self.type = None
                                                                        self.length = None
                                                                        self.value = None
                                                                        self._segment_path = lambda: "state"
                                                                        self._is_frozen = True

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.Tlvs.Tlv.MtIpv6Reachability.Prefixes.Prefix.UndefinedSubtlvs.UndefinedSubtlv.State, ['type', 'length', 'value'], name, value)









                                    class UndefinedTlvs(_Entity_):
                                        """
                                        Surrounding container for a list of unknown TLVs.
                                        
                                        .. attribute:: undefined_tlv
                                        
                                            List of TLVs that are not defined within the model, or are not recognised by the system
                                        
                                            **type**: list of    :py:class:`UndefinedTlv<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "undefined-tlvs"
                                            self.yang_parent_name = "lsp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("undefined-tlv", ("undefined_tlv", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv))])
                                            self._leafs = OrderedDict()

                                            self.undefined_tlv = YList(self)
                                            self._segment_path = lambda: "undefined-tlvs"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs, [], name, value)

                                        class UndefinedTlv(_Entity_):
                                            """
                                            List of TLVs that are not defined within the model, or are
                                            not recognised by the system.
                                            
                                            .. attribute:: type  (key)
                                            
                                                Reference to the undefined TLV's type
                                            
                                                **type**: int
                                            
                                                    **range:** 0..255
                                            
                                                **refers to**:  :py:class:`type<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: state
                                            
                                                State parameters of the undefined TLV
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "undefined-tlv"
                                                self.yang_parent_name = "undefined-tlvs"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['type']
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State))])
                                                self._leafs = OrderedDict([
                                                    ('type', (YLeaf(YType.str, 'type'), ['int'])),
                                                ])
                                                self.type = None

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "undefined-tlv" + "[type='" + str(self.type) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv, ['type'], name, value)

                                            class State(_Entity_):
                                                """
                                                State parameters of the undefined TLV.
                                                
                                                .. attribute:: type
                                                
                                                    TLV Type
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..255
                                                
                                                    **config**: False
                                                
                                                .. attribute:: length
                                                
                                                    TLV length
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..255
                                                
                                                    **config**: False
                                                
                                                .. attribute:: value
                                                
                                                    TLV value
                                                
                                                    **type**: str
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "undefined-tlv"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('type', (YLeaf(YType.uint8, 'type'), ['int'])),
                                                        ('length', (YLeaf(YType.uint8, 'length'), ['int'])),
                                                        ('value', (YLeaf(YType.str, 'value'), ['str'])),
                                                    ])
                                                    self.type = None
                                                    self.length = None
                                                    self.value = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.LinkStateDatabase.Lsp.UndefinedTlvs.UndefinedTlv.State, ['type', 'length', 'value'], name, value)






                            class TrafficEngineering(_Entity_):
                                """
                                This container defines ISIS TE.
                                
                                .. attribute:: config
                                
                                    This container defines ISIS TE configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines ISIS TE state information
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "traffic-engineering"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "traffic-engineering"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS TE configuration.
                                    
                                    .. attribute:: enabled
                                    
                                        When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: ipv4_router_id
                                    
                                        IPv4 MPLS Traffic Engineering Router\-ID
                                    
                                        **type**: str
                                    
                                            **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_router_id
                                    
                                        IPv6 MPLS Traffic Engineering Router\-ID
                                    
                                        **type**: str
                                    
                                            **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "traffic-engineering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('ipv4_router_id', (YLeaf(YType.str, 'ipv4-router-id'), ['str'])),
                                            ('ipv6_router_id', (YLeaf(YType.str, 'ipv6-router-id'), ['str'])),
                                        ])
                                        self.enabled = None
                                        self.ipv4_router_id = None
                                        self.ipv6_router_id = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.Config, ['enabled', 'ipv4_router_id', 'ipv6_router_id'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines ISIS TE state information.
                                    
                                    .. attribute:: enabled
                                    
                                        When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: ipv4_router_id
                                    
                                        IPv4 MPLS Traffic Engineering Router\-ID
                                    
                                        **type**: str
                                    
                                            **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                        **config**: False
                                    
                                    .. attribute:: ipv6_router_id
                                    
                                        IPv6 MPLS Traffic Engineering Router\-ID
                                    
                                        **type**: str
                                    
                                            **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "traffic-engineering"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ('ipv4_router_id', (YLeaf(YType.str, 'ipv4-router-id'), ['str'])),
                                            ('ipv6_router_id', (YLeaf(YType.str, 'ipv6-router-id'), ['str'])),
                                        ])
                                        self.enabled = None
                                        self.ipv4_router_id = None
                                        self.ipv6_router_id = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.TrafficEngineering.State, ['enabled', 'ipv4_router_id', 'ipv6_router_id'], name, value)



                            class RoutePreference(_Entity_):
                                """
                                This container defines Administrative Distance (or preference)
                                assigned to ISIS routes (level1 internal, level2 internal, level1
                                external, level2 external).
                                
                                .. attribute:: config
                                
                                    This container defines route preference configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines ISIS route preference state information
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "route-preference"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "route-preference"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines route preference configuration.
                                    
                                    .. attribute:: external_route_preference
                                    
                                        Administrative Distance(preference) for external ISIS routes
                                    
                                        **type**: int
                                    
                                            **range:** 1..255
                                    
                                    .. attribute:: internal_route_preference
                                    
                                        Administrative Distance(preference) for internal ISIS routes
                                    
                                        **type**: int
                                    
                                            **range:** 1..255
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "route-preference"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external_route_preference', (YLeaf(YType.uint8, 'external-route-preference'), ['int'])),
                                            ('internal_route_preference', (YLeaf(YType.uint8, 'internal-route-preference'), ['int'])),
                                        ])
                                        self.external_route_preference = None
                                        self.internal_route_preference = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.Config, ['external_route_preference', 'internal_route_preference'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines ISIS route preference state information.
                                    
                                    .. attribute:: external_route_preference
                                    
                                        Administrative Distance(preference) for external ISIS routes
                                    
                                        **type**: int
                                    
                                            **range:** 1..255
                                    
                                        **config**: False
                                    
                                    .. attribute:: internal_route_preference
                                    
                                        Administrative Distance(preference) for internal ISIS routes
                                    
                                        **type**: int
                                    
                                            **range:** 1..255
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "route-preference"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('external_route_preference', (YLeaf(YType.uint8, 'external-route-preference'), ['int'])),
                                            ('internal_route_preference', (YLeaf(YType.uint8, 'internal-route-preference'), ['int'])),
                                        ])
                                        self.external_route_preference = None
                                        self.internal_route_preference = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.RoutePreference.State, ['external_route_preference', 'internal_route_preference'], name, value)



                            class Authentication(_Entity_):
                                """
                                This container defines ISIS authentication.
                                
                                .. attribute:: config
                                
                                    This container defines ISIS authentication configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines ISIS authentication state
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State>`
                                
                                    **config**: False
                                
                                .. attribute:: key
                                
                                    This container defines ISIS authentication key
                                
                                    **type**:  :py:class:`Key<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key>`
                                
                                .. attribute:: keychain
                                
                                    This container defines keychain parameters
                                
                                    **type**:  :py:class:`Keychain<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "level"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State)), ("key", ("key", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key)), ("keychain", ("keychain", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.key = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"

                                    self.keychain = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS authentication configuration.
                                    
                                    .. attribute:: csnp_authentication
                                    
                                        Enable or disable for IS\-IS CSNPs
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: psnp_authentication
                                    
                                        Enable or disable authentication for IS\-IS PSNPs
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    .. attribute:: lsp_authentication
                                    
                                        Enable or disable authentication for IS\-IS LSPs
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_authentication', (YLeaf(YType.boolean, 'csnp-authentication'), ['bool'])),
                                            ('psnp_authentication', (YLeaf(YType.boolean, 'psnp-authentication'), ['bool'])),
                                            ('lsp_authentication', (YLeaf(YType.boolean, 'lsp-authentication'), ['bool'])),
                                        ])
                                        self.csnp_authentication = None
                                        self.psnp_authentication = None
                                        self.lsp_authentication = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Config, ['csnp_authentication', 'psnp_authentication', 'lsp_authentication'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines ISIS authentication state.
                                    
                                    .. attribute:: csnp_authentication
                                    
                                        Enable or disable for IS\-IS CSNPs
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: psnp_authentication
                                    
                                        Enable or disable authentication for IS\-IS PSNPs
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    .. attribute:: lsp_authentication
                                    
                                        Enable or disable authentication for IS\-IS LSPs
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_authentication', (YLeaf(YType.boolean, 'csnp-authentication'), ['bool'])),
                                            ('psnp_authentication', (YLeaf(YType.boolean, 'psnp-authentication'), ['bool'])),
                                            ('lsp_authentication', (YLeaf(YType.boolean, 'lsp-authentication'), ['bool'])),
                                        ])
                                        self.csnp_authentication = None
                                        self.psnp_authentication = None
                                        self.lsp_authentication = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.State, ['csnp_authentication', 'psnp_authentication', 'lsp_authentication'], name, value)


                                class Key(_Entity_):
                                    """
                                    This container defines ISIS authentication key
                                    
                                    .. attribute:: config
                                    
                                        This container defines ISIS authentication key configuration
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config>`
                                    
                                    .. attribute:: state
                                    
                                        This container defines ISIS authentication key state
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        This container defines ISIS authentication key configuration.
                                        
                                        .. attribute:: auth_password
                                        
                                            Authentication key string
                                        
                                            **type**: str
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.Config, ['auth_password'], name, value)


                                    class State(_Entity_):
                                        """
                                        This container defines ISIS authentication key state.
                                        
                                        .. attribute:: auth_password
                                        
                                            Authentication key string
                                        
                                            **type**: str
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Levels.Level.Authentication.Key.State, ['auth_password'], name, value)



                                class Keychain(_Entity_):
                                    """
                                    This container defines keychain parameters.
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "keychain"
                                        self._is_frozen = True





                    class Interfaces(_Entity_):
                        """
                        This container defines global ISIS interface configuration and
                        state information.
                        
                        .. attribute:: interface
                        
                            This list contains ISIS interfaces
                        
                            **type**: list of    :py:class:`Interface<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface>`
                        
                        """
                        _prefix = 'oc-netinst'
                        _revision = '2017-01-13'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "interfaces"
                            self.yang_parent_name = "isis"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface))])
                            self._leafs = OrderedDict()

                            self.interface = YList(self)
                            self._segment_path = lambda: "interfaces"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces, [], name, value)

                        class Interface(_Entity_):
                            """
                            This list contains ISIS interfaces.
                            
                            .. attribute:: interface_id  (key)
                            
                                Reference to interface\-id
                            
                                **type**: str
                            
                                **refers to**:  :py:class:`interface_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config>`
                            
                            .. attribute:: config
                            
                                This container defines ISIS interface configuration
                            
                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config>`
                            
                            .. attribute:: state
                            
                                This container defines state information for ISIS interfaces
                            
                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State>`
                            
                                **config**: False
                            
                            .. attribute:: circuit_counters
                            
                                This container defines state information for ISIS circuit counters
                            
                                **type**:  :py:class:`CircuitCounters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters>`
                            
                            .. attribute:: authentication
                            
                                This container defines ISIS authentication
                            
                                **type**:  :py:class:`Authentication<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication>`
                            
                            .. attribute:: afi_safi
                            
                                This container defines address\-family specific configuration and state information
                            
                                **type**:  :py:class:`AfiSafi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi>`
                            
                            .. attribute:: levels
                            
                                This container defines ISIS level specific configuration and state information
                            
                                **type**:  :py:class:`Levels<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels>`
                            
                            .. attribute:: timers
                            
                                This container describes ISIS interface timers configuration
                            
                                **type**:  :py:class:`Timers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers>`
                            
                            .. attribute:: bfd
                            
                                This container defines BFD
                            
                                **type**:  :py:class:`Bfd<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd>`
                            
                            .. attribute:: interface_ref
                            
                                Reference to an interface or subinterface
                            
                                **type**:  :py:class:`InterfaceRef<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef>`
                            
                            """
                            _prefix = 'oc-netinst'
                            _revision = '2017-01-13'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "interfaces"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_id']
                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State)), ("circuit-counters", ("circuit_counters", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters)), ("authentication", ("authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication)), ("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi)), ("levels", ("levels", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers)), ("bfd", ("bfd", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd)), ("interface-ref", ("interface_ref", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef))])
                                self._leafs = OrderedDict([
                                    ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                ])
                                self.interface_id = None

                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config()
                                self.config.parent = self
                                self._children_name_map["config"] = "config"

                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State()
                                self.state.parent = self
                                self._children_name_map["state"] = "state"

                                self.circuit_counters = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters()
                                self.circuit_counters.parent = self
                                self._children_name_map["circuit_counters"] = "circuit-counters"

                                self.authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication()
                                self.authentication.parent = self
                                self._children_name_map["authentication"] = "authentication"

                                self.afi_safi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi()
                                self.afi_safi.parent = self
                                self._children_name_map["afi_safi"] = "afi-safi"

                                self.levels = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels()
                                self.levels.parent = self
                                self._children_name_map["levels"] = "levels"

                                self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers()
                                self.timers.parent = self
                                self._children_name_map["timers"] = "timers"

                                self.bfd = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd()
                                self.bfd.parent = self
                                self._children_name_map["bfd"] = "bfd"

                                self.interface_ref = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef()
                                self.interface_ref.parent = self
                                self._children_name_map["interface_ref"] = "interface-ref"
                                self._segment_path = lambda: "interface" + "[interface-id='" + str(self.interface_id) + "']"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface, ['interface_id'], name, value)

                            class Config(_Entity_):
                                """
                                This container defines ISIS interface configuration.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: interface_id
                                
                                    Interface for which ISIS configuration is to be applied
                                
                                    **type**: str
                                
                                .. attribute:: passive
                                
                                    When set to true, the referenced interface is a passive interface such that it is not eligible to establish adjacencies with other systems, but is advertised into the IS\-IS topology
                                
                                    **type**: bool
                                
                                    **default value**: false
                                
                                .. attribute:: hello_padding
                                
                                    This leaf controls padding type for IS\-IS Hello PDUs
                                
                                    **type**:  :py:class:`HelloPaddingType<ydk.models.openconfig.openconfig_isis_types.HelloPaddingType>`
                                
                                .. attribute:: circuit_type
                                
                                    ISIS circuit type (p2p, broadcast)
                                
                                    **type**:  :py:class:`CircuitType<ydk.models.openconfig.openconfig_isis_types.CircuitType>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "config"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                        ('passive', (YLeaf(YType.boolean, 'passive'), ['bool'])),
                                        ('hello_padding', (YLeaf(YType.enumeration, 'hello-padding'), [('ydk.models.openconfig.openconfig_isis_types', 'HelloPaddingType', '')])),
                                        ('circuit_type', (YLeaf(YType.enumeration, 'circuit-type'), [('ydk.models.openconfig.openconfig_isis_types', 'CircuitType', '')])),
                                    ])
                                    self.enabled = None
                                    self.interface_id = None
                                    self.passive = None
                                    self.hello_padding = None
                                    self.circuit_type = None
                                    self._segment_path = lambda: "config"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Config, ['enabled', 'interface_id', 'passive', 'hello_padding', 'circuit_type'], name, value)


                            class State(_Entity_):
                                """
                                This container defines state information for ISIS interfaces.
                                
                                .. attribute:: enabled
                                
                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: interface_id
                                
                                    Interface for which ISIS configuration is to be applied
                                
                                    **type**: str
                                
                                    **config**: False
                                
                                .. attribute:: passive
                                
                                    When set to true, the referenced interface is a passive interface such that it is not eligible to establish adjacencies with other systems, but is advertised into the IS\-IS topology
                                
                                    **type**: bool
                                
                                    **config**: False
                                
                                    **default value**: false
                                
                                .. attribute:: hello_padding
                                
                                    This leaf controls padding type for IS\-IS Hello PDUs
                                
                                    **type**:  :py:class:`HelloPaddingType<ydk.models.openconfig.openconfig_isis_types.HelloPaddingType>`
                                
                                    **config**: False
                                
                                .. attribute:: circuit_type
                                
                                    ISIS circuit type (p2p, broadcast)
                                
                                    **type**:  :py:class:`CircuitType<ydk.models.openconfig.openconfig_isis_types.CircuitType>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "state"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                        ('interface_id', (YLeaf(YType.str, 'interface-id'), ['str'])),
                                        ('passive', (YLeaf(YType.boolean, 'passive'), ['bool'])),
                                        ('hello_padding', (YLeaf(YType.enumeration, 'hello-padding'), [('ydk.models.openconfig.openconfig_isis_types', 'HelloPaddingType', '')])),
                                        ('circuit_type', (YLeaf(YType.enumeration, 'circuit-type'), [('ydk.models.openconfig.openconfig_isis_types', 'CircuitType', '')])),
                                    ])
                                    self.enabled = None
                                    self.interface_id = None
                                    self.passive = None
                                    self.hello_padding = None
                                    self.circuit_type = None
                                    self._segment_path = lambda: "state"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.State, ['enabled', 'interface_id', 'passive', 'hello_padding', 'circuit_type'], name, value)


                            class CircuitCounters(_Entity_):
                                """
                                This container defines state information for ISIS circuit counters.
                                
                                .. attribute:: state
                                
                                    The container defines a list of counters for IS circuit
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "circuit-counters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State))])
                                    self._leafs = OrderedDict()

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "circuit-counters"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters, [], name, value)

                                class State(_Entity_):
                                    """
                                    The container defines a list of counters for IS circuit.
                                    
                                    .. attribute:: adj_changes
                                    
                                        Number of times an adjacency state change has occurred on this circuit. MIB Entry\: CircAdjChanges
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: init_fails
                                    
                                        Number of times initialization of this circuit has failed. This counts events such as PPP NCP failures. MIB Entry\: CircInitFails
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: rejected_adj
                                    
                                        Number of times an adjacency has been rejected on this circuit. MIB Entry\: CircRejAdjs
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: id_field_len_mismatches
                                    
                                        Number of times an IS\-IS control PDU with an ID field length different from that for this system has been received. MIB Entry\: CircIDFieldLenMismatches
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: max_area_address_mismatches
                                    
                                        Number of times an IS\-IS control PDU with a max area address field different from that for this system has been received. MIB Entry\: CircMaxAreaAddrMismatches
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: auth_type_fails
                                    
                                        Number of times an IS\-IS control PDU with an auth type field different from that for this system has been received. MIB Entry\: CircAuthTypeFails
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: auth_fails
                                    
                                        Number of times an IS\-IS control PDU with the correct auth type has failed to pass authentication validation. MIB Entry\: CircAuthFails
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: lan_dis_changes
                                    
                                        Number of times the Designated IS has changed on this circuit at this level. If the circuit is point to point, this count is zero. MIB Entry\: CircLANDesISChanges
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    .. attribute:: adj_number
                                    
                                        Number of adjacencies on this circuit. MIB Entry\: CircNumAdj
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "circuit-counters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('adj_changes', (YLeaf(YType.uint32, 'adj-changes'), ['int'])),
                                            ('init_fails', (YLeaf(YType.uint32, 'init-fails'), ['int'])),
                                            ('rejected_adj', (YLeaf(YType.uint32, 'rejected-adj'), ['int'])),
                                            ('id_field_len_mismatches', (YLeaf(YType.uint32, 'id-field-len-mismatches'), ['int'])),
                                            ('max_area_address_mismatches', (YLeaf(YType.uint32, 'max-area-address-mismatches'), ['int'])),
                                            ('auth_type_fails', (YLeaf(YType.uint32, 'auth-type-fails'), ['int'])),
                                            ('auth_fails', (YLeaf(YType.uint32, 'auth-fails'), ['int'])),
                                            ('lan_dis_changes', (YLeaf(YType.uint32, 'lan-dis-changes'), ['int'])),
                                            ('adj_number', (YLeaf(YType.uint32, 'adj-number'), ['int'])),
                                        ])
                                        self.adj_changes = None
                                        self.init_fails = None
                                        self.rejected_adj = None
                                        self.id_field_len_mismatches = None
                                        self.max_area_address_mismatches = None
                                        self.auth_type_fails = None
                                        self.auth_fails = None
                                        self.lan_dis_changes = None
                                        self.adj_number = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.CircuitCounters.State, ['adj_changes', 'init_fails', 'rejected_adj', 'id_field_len_mismatches', 'max_area_address_mismatches', 'auth_type_fails', 'auth_fails', 'lan_dis_changes', 'adj_number'], name, value)



                            class Authentication(_Entity_):
                                """
                                This container defines ISIS authentication.
                                
                                .. attribute:: config
                                
                                    This container defines ISIS authentication configuration
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines ISIS authentication state
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State>`
                                
                                    **config**: False
                                
                                .. attribute:: key
                                
                                    This container defines ISIS authentication key
                                
                                    **type**:  :py:class:`Key<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key>`
                                
                                .. attribute:: keychain
                                
                                    This container defines keychain parameters
                                
                                    **type**:  :py:class:`Keychain<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "authentication"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State)), ("key", ("key", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key)), ("keychain", ("keychain", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"

                                    self.key = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key()
                                    self.key.parent = self
                                    self._children_name_map["key"] = "key"

                                    self.keychain = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Keychain()
                                    self.keychain.parent = self
                                    self._children_name_map["keychain"] = "keychain"
                                    self._segment_path = lambda: "authentication"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines ISIS authentication configuration.
                                    
                                    .. attribute:: hello_authentication
                                    
                                        Enabled or disable ISIS Hello authentication
                                    
                                        **type**: bool
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_authentication', (YLeaf(YType.boolean, 'hello-authentication'), ['bool'])),
                                        ])
                                        self.hello_authentication = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Config, ['hello_authentication'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines ISIS authentication state.
                                    
                                    .. attribute:: hello_authentication
                                    
                                        Enabled or disable ISIS Hello authentication
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                        **default value**: false
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('hello_authentication', (YLeaf(YType.boolean, 'hello-authentication'), ['bool'])),
                                        ])
                                        self.hello_authentication = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.State, ['hello_authentication'], name, value)


                                class Key(_Entity_):
                                    """
                                    This container defines ISIS authentication key
                                    
                                    .. attribute:: config
                                    
                                        This container defines ISIS authentication key configuration
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config>`
                                    
                                    .. attribute:: state
                                    
                                        This container defines ISIS authentication key state
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "key"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State))])
                                        self._leafs = OrderedDict()

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "key"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key, [], name, value)

                                    class Config(_Entity_):
                                        """
                                        This container defines ISIS authentication key configuration.
                                        
                                        .. attribute:: auth_password
                                        
                                            Authentication key string
                                        
                                            **type**: str
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.Config, ['auth_password'], name, value)


                                    class State(_Entity_):
                                        """
                                        This container defines ISIS authentication key state.
                                        
                                        .. attribute:: auth_password
                                        
                                            Authentication key string
                                        
                                            **type**: str
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "key"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                            ])
                                            self.auth_password = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Authentication.Key.State, ['auth_password'], name, value)



                                class Keychain(_Entity_):
                                    """
                                    This container defines keychain parameters.
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "keychain"
                                        self.yang_parent_name = "authentication"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "keychain"
                                        self._is_frozen = True



                            class AfiSafi(_Entity_):
                                """
                                This container defines address\-family specific configuration
                                and state information.
                                
                                .. attribute:: af
                                
                                    Address\-family/Subsequent Address\-family list
                                
                                    **type**: list of    :py:class:`Af<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "afi-safi"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("af", ("af", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af))])
                                    self._leafs = OrderedDict()

                                    self.af = YList(self)
                                    self._segment_path = lambda: "afi-safi"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi, [], name, value)

                                class Af(_Entity_):
                                    """
                                    Address\-family/Subsequent Address\-family list.
                                    
                                    .. attribute:: afi_name  (key)
                                    
                                        Reference to address\-family type
                                    
                                        **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                    
                                    .. attribute:: safi_name  (key)
                                    
                                        Reference to subsequent address\-family type
                                    
                                        **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                    
                                    .. attribute:: config
                                    
                                        This container defines AFI\-SAFI configuration parameters. Single topology is the default setting
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config>`
                                    
                                    .. attribute:: state
                                    
                                        This container defines AFI\-SAFI State information
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "af"
                                        self.yang_parent_name = "afi-safi"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['afi_name','safi_name']
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State))])
                                        self._leafs = OrderedDict([
                                            ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                            ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                        ])
                                        self.afi_name = None
                                        self.safi_name = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"
                                        self._segment_path = lambda: "af" + "[afi-name='" + str(self.afi_name) + "']" + "[safi-name='" + str(self.safi_name) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af, ['afi_name', 'safi_name'], name, value)

                                    class Config(_Entity_):
                                        """
                                        This container defines AFI\-SAFI configuration parameters. Single
                                        topology is the default setting.
                                        
                                        .. attribute:: afi_name
                                        
                                            Address\-family type
                                        
                                            **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                        .. attribute:: safi_name
                                        
                                            Subsequent address\-family type
                                        
                                            **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                        .. attribute:: enabled
                                        
                                            When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        
                                            **type**: bool
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.Config, ['afi_name', 'safi_name', 'enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        This container defines AFI\-SAFI State information
                                        
                                        .. attribute:: afi_name
                                        
                                            Address\-family type
                                        
                                            **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: safi_name
                                        
                                            Subsequent address\-family type
                                        
                                            **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: enabled
                                        
                                            When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "af"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.afi_name = None
                                            self.safi_name = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.AfiSafi.Af.State, ['afi_name', 'safi_name', 'enabled'], name, value)




                            class Levels(_Entity_):
                                """
                                This container defines ISIS level specific configuration and
                                state information.
                                
                                .. attribute:: level
                                
                                    Configuration and operational state parameters related to a particular level on an IS\-IS enabled interface
                                
                                    **type**: list of    :py:class:`Level<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level>`
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "levels"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("level", ("level", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level))])
                                    self._leafs = OrderedDict()

                                    self.level = YList(self)
                                    self._segment_path = lambda: "levels"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels, [], name, value)

                                class Level(_Entity_):
                                    """
                                    Configuration and operational state parameters related to a
                                    particular level on an IS\-IS enabled interface.
                                    
                                    .. attribute:: level_number  (key)
                                    
                                        Reference to ISIS level\-number
                                    
                                        **type**: int
                                    
                                            **range:** 1..2
                                    
                                        **refers to**:  :py:class:`level_number<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config>`
                                    
                                    .. attribute:: config
                                    
                                        This container defines interface ISIS level configuration
                                    
                                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config>`
                                    
                                    .. attribute:: state
                                    
                                        This container defines interface ISIS level state information
                                    
                                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: packet_counters
                                    
                                        This container defines ISIS interface packet counters
                                    
                                        **type**:  :py:class:`PacketCounters<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters>`
                                    
                                    .. attribute:: adjacencies
                                    
                                        This container defines ISIS adjacencies
                                    
                                        **type**:  :py:class:`Adjacencies<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: timers
                                    
                                        This container defines ISIS timers
                                    
                                        **type**:  :py:class:`Timers<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers>`
                                    
                                    .. attribute:: afi_safi
                                    
                                        This container defines address\-family specific configuration and state information
                                    
                                        **type**:  :py:class:`AfiSafi<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi>`
                                    
                                    .. attribute:: hello_authentication
                                    
                                        This container defines ISIS authentication
                                    
                                        **type**:  :py:class:`HelloAuthentication<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "level"
                                        self.yang_parent_name = "levels"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['level_number']
                                        self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State)), ("packet-counters", ("packet_counters", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters)), ("adjacencies", ("adjacencies", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies)), ("timers", ("timers", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers)), ("afi-safi", ("afi_safi", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi)), ("hello-authentication", ("hello_authentication", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication))])
                                        self._leafs = OrderedDict([
                                            ('level_number', (YLeaf(YType.str, 'level-number'), ['int'])),
                                        ])
                                        self.level_number = None

                                        self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config()
                                        self.config.parent = self
                                        self._children_name_map["config"] = "config"

                                        self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State()
                                        self.state.parent = self
                                        self._children_name_map["state"] = "state"

                                        self.packet_counters = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters()
                                        self.packet_counters.parent = self
                                        self._children_name_map["packet_counters"] = "packet-counters"

                                        self.adjacencies = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies()
                                        self.adjacencies.parent = self
                                        self._children_name_map["adjacencies"] = "adjacencies"

                                        self.timers = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers()
                                        self.timers.parent = self
                                        self._children_name_map["timers"] = "timers"

                                        self.afi_safi = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi()
                                        self.afi_safi.parent = self
                                        self._children_name_map["afi_safi"] = "afi-safi"

                                        self.hello_authentication = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication()
                                        self.hello_authentication.parent = self
                                        self._children_name_map["hello_authentication"] = "hello-authentication"
                                        self._segment_path = lambda: "level" + "[level-number='" + str(self.level_number) + "']"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level, ['level_number'], name, value)

                                    class Config(_Entity_):
                                        """
                                        This container defines interface ISIS level configuration.
                                        
                                        .. attribute:: level_number
                                        
                                            ISIS level number(level\-1, level\-2)
                                        
                                            **type**: int
                                        
                                                **range:** 1..2
                                        
                                        .. attribute:: passive
                                        
                                            ISIS passive interface admin enable/disable function
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        .. attribute:: priority
                                        
                                            ISIS neighbor priority(LAN hello PDU only)
                                        
                                            **type**: int
                                        
                                                **range:** 0..127
                                        
                                        .. attribute:: enabled
                                        
                                            When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        
                                            **type**: bool
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "config"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('level_number', (YLeaf(YType.uint8, 'level-number'), ['int'])),
                                                ('passive', (YLeaf(YType.boolean, 'passive'), ['bool'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.level_number = None
                                            self.passive = None
                                            self.priority = None
                                            self.enabled = None
                                            self._segment_path = lambda: "config"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Config, ['level_number', 'passive', 'priority', 'enabled'], name, value)


                                    class State(_Entity_):
                                        """
                                        This container defines interface ISIS level state information.
                                        
                                        .. attribute:: level_number
                                        
                                            ISIS level number(level\-1, level\-2)
                                        
                                            **type**: int
                                        
                                                **range:** 1..2
                                        
                                            **config**: False
                                        
                                        .. attribute:: passive
                                        
                                            ISIS passive interface admin enable/disable function
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        .. attribute:: priority
                                        
                                            ISIS neighbor priority(LAN hello PDU only)
                                        
                                            **type**: int
                                        
                                                **range:** 0..127
                                        
                                            **config**: False
                                        
                                        .. attribute:: enabled
                                        
                                            When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                        
                                            **type**: bool
                                        
                                            **config**: False
                                        
                                            **default value**: false
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "state"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('level_number', (YLeaf(YType.uint8, 'level-number'), ['int'])),
                                                ('passive', (YLeaf(YType.boolean, 'passive'), ['bool'])),
                                                ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                            ])
                                            self.level_number = None
                                            self.passive = None
                                            self.priority = None
                                            self.enabled = None
                                            self._segment_path = lambda: "state"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.State, ['level_number', 'passive', 'priority', 'enabled'], name, value)


                                    class PacketCounters(_Entity_):
                                        """
                                        This container defines ISIS interface packet counters.
                                        
                                        .. attribute:: lsp
                                        
                                            This container defines LSP packet counters
                                        
                                            **type**:  :py:class:`Lsp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp>`
                                        
                                        .. attribute:: iih
                                        
                                            This container defines IIH packet counters
                                        
                                            **type**:  :py:class:`Iih<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih>`
                                        
                                        .. attribute:: ish
                                        
                                            This container defines ISH packet counters
                                        
                                            **type**:  :py:class:`Ish<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish>`
                                        
                                        .. attribute:: esh
                                        
                                            This container defines ESH packet counters
                                        
                                            **type**:  :py:class:`Esh<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh>`
                                        
                                        .. attribute:: psnp
                                        
                                            This container defines PSNP packet counters
                                        
                                            **type**:  :py:class:`Psnp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp>`
                                        
                                        .. attribute:: csnp
                                        
                                            Operational state parameters relating to CSNPs
                                        
                                            **type**:  :py:class:`Csnp<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp>`
                                        
                                        .. attribute:: unknown
                                        
                                            Operational state parameters relating to IS\-IS PDUs that are not otherwise classified \- referred to as Unknown PDUs
                                        
                                            **type**:  :py:class:`Unknown<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "packet-counters"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("lsp", ("lsp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp)), ("iih", ("iih", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih)), ("ish", ("ish", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish)), ("esh", ("esh", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh)), ("psnp", ("psnp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp)), ("csnp", ("csnp", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp)), ("unknown", ("unknown", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown))])
                                            self._leafs = OrderedDict()

                                            self.lsp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp()
                                            self.lsp.parent = self
                                            self._children_name_map["lsp"] = "lsp"

                                            self.iih = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih()
                                            self.iih.parent = self
                                            self._children_name_map["iih"] = "iih"

                                            self.ish = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish()
                                            self.ish.parent = self
                                            self._children_name_map["ish"] = "ish"

                                            self.esh = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh()
                                            self.esh.parent = self
                                            self._children_name_map["esh"] = "esh"

                                            self.psnp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp()
                                            self.psnp.parent = self
                                            self._children_name_map["psnp"] = "psnp"

                                            self.csnp = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp()
                                            self.csnp.parent = self
                                            self._children_name_map["csnp"] = "csnp"

                                            self.unknown = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown()
                                            self.unknown.parent = self
                                            self._children_name_map["unknown"] = "unknown"
                                            self._segment_path = lambda: "packet-counters"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters, [], name, value)

                                        class Lsp(_Entity_):
                                            """
                                            This container defines LSP packet counters.
                                            
                                            .. attribute:: state
                                            
                                                This container defines LSP PDU counters
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "lsp"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "lsp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp, [], name, value)

                                            class State(_Entity_):
                                                """
                                                This container defines LSP PDU counters.
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "lsp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Lsp.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)



                                        class Iih(_Entity_):
                                            """
                                            This container defines IIH packet counters.
                                            
                                            .. attribute:: state
                                            
                                                Operational counters relating to IIH PDUs
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "iih"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "iih"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih, [], name, value)

                                            class State(_Entity_):
                                                """
                                                Operational counters relating to IIH PDUs
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "iih"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Iih.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)



                                        class Ish(_Entity_):
                                            """
                                            This container defines ISH packet counters.
                                            
                                            .. attribute:: state
                                            
                                                Operational state relating to ISH PDUs
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "ish"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "ish"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish, [], name, value)

                                            class State(_Entity_):
                                                """
                                                Operational state relating to ISH PDUs.
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "ish"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Ish.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)



                                        class Esh(_Entity_):
                                            """
                                            This container defines ESH packet counters.
                                            
                                            .. attribute:: state
                                            
                                                Operational state relating to ESH PDUs
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "esh"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "esh"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh, [], name, value)

                                            class State(_Entity_):
                                                """
                                                Operational state relating to ESH PDUs
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "esh"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Esh.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)



                                        class Psnp(_Entity_):
                                            """
                                            This container defines PSNP packet counters.
                                            
                                            .. attribute:: state
                                            
                                                Packet counters relating to PSNPs
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "psnp"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "psnp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp, [], name, value)

                                            class State(_Entity_):
                                                """
                                                Packet counters relating to PSNPs.
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "psnp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Psnp.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)



                                        class Csnp(_Entity_):
                                            """
                                            Operational state parameters relating to CSNPs.
                                            
                                            .. attribute:: state
                                            
                                                Packet counters relating to CSNPs
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "csnp"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "csnp"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp, [], name, value)

                                            class State(_Entity_):
                                                """
                                                Packet counters relating to CSNPs.
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "csnp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Csnp.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)



                                        class Unknown(_Entity_):
                                            """
                                            Operational state parameters relating to IS\-IS PDUs that are not
                                            otherwise classified \- referred to as Unknown PDUs.
                                            
                                            .. attribute:: state
                                            
                                                Packet counters relating to unknown PDUs
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "unknown"
                                                self.yang_parent_name = "packet-counters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State))])
                                                self._leafs = OrderedDict()

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "unknown"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown, [], name, value)

                                            class State(_Entity_):
                                                """
                                                Packet counters relating to unknown PDUs.
                                                
                                                .. attribute:: received
                                                
                                                    The number of the specified type of PDU received on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: processed
                                                
                                                    The number of the specified type of PDU received on the interface that have been processed by the local system
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dropped
                                                
                                                    The number of the specified type of PDU received on the interface that have been dropped
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: sent
                                                
                                                    The number of the specified type of PDU that have been sent by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: retransmit
                                                
                                                    The number of the specified type of PDU that that have been retransmitted by the local system on the interface
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "unknown"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received', (YLeaf(YType.uint32, 'received'), ['int'])),
                                                        ('processed', (YLeaf(YType.uint32, 'processed'), ['int'])),
                                                        ('dropped', (YLeaf(YType.uint32, 'dropped'), ['int'])),
                                                        ('sent', (YLeaf(YType.uint32, 'sent'), ['int'])),
                                                        ('retransmit', (YLeaf(YType.uint32, 'retransmit'), ['int'])),
                                                    ])
                                                    self.received = None
                                                    self.processed = None
                                                    self.dropped = None
                                                    self.sent = None
                                                    self.retransmit = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.PacketCounters.Unknown.State, ['received', 'processed', 'dropped', 'sent', 'retransmit'], name, value)




                                    class Adjacencies(_Entity_):
                                        """
                                        This container defines ISIS adjacencies.
                                        
                                        .. attribute:: adjacency
                                        
                                            List of the local system's IS\-IS adjacencies
                                        
                                            **type**: list of    :py:class:`Adjacency<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "adjacencies"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("adjacency", ("adjacency", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency))])
                                            self._leafs = OrderedDict()

                                            self.adjacency = YList(self)
                                            self._segment_path = lambda: "adjacencies"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies, [], name, value)

                                        class Adjacency(_Entity_):
                                            """
                                            List of the local system's IS\-IS adjacencies.
                                            
                                            .. attribute:: system_id  (key)
                                            
                                                Reference to the IS neighbor
                                            
                                                **type**: str
                                            
                                                    **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                            
                                                **refers to**:  :py:class:`system_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: state
                                            
                                                Operational state relating to the IS\-IS adjacency with the remote system
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "adjacency"
                                                self.yang_parent_name = "adjacencies"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['system_id']
                                                self._child_classes = OrderedDict([("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State))])
                                                self._leafs = OrderedDict([
                                                    ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                ])
                                                self.system_id = None

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "adjacency" + "[system-id='" + str(self.system_id) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency, ['system_id'], name, value)

                                            class State(_Entity_):
                                                """
                                                Operational state relating to the IS\-IS adjacency with the
                                                remote system
                                                
                                                .. attribute:: system_id
                                                
                                                    ISIS neighbor system\-id
                                                
                                                    **type**: str
                                                
                                                        **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                
                                                    **config**: False
                                                
                                                .. attribute:: neighbor_ipv4_address
                                                
                                                    ISIS Neighbor IPv4 address
                                                
                                                    **type**: str
                                                
                                                        **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                    **config**: False
                                                
                                                .. attribute:: neighbor_ipv6_address
                                                
                                                    ISIS Neighbor IPv6 address
                                                
                                                    **type**: str
                                                
                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                
                                                    **config**: False
                                                
                                                .. attribute:: neighbor_snpa
                                                
                                                    ISIS neighbor SNPA
                                                
                                                    **type**: str
                                                
                                                        **length:** 0..20
                                                
                                                    **config**: False
                                                
                                                .. attribute:: local_extended_circuit_id
                                                
                                                    Local extended circuit ID
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: neighbor_extended_circuit_id
                                                
                                                    ISIS neighbor extended circuit ID
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: priority
                                                
                                                    Priority of the neighboring IS(LAN Hello only)
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..127
                                                
                                                    **config**: False
                                                
                                                .. attribute:: dis_system_id
                                                
                                                    DIS System ID(LAN hello only)
                                                
                                                    **type**: str
                                                
                                                        **pattern:** ^[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}\\.[0\-9A\-Fa\-f]{4}$
                                                
                                                    **config**: False
                                                
                                                .. attribute:: neighbor_circuit_type
                                                
                                                    Received ISIS circuit type (level\-1, level\-2, level\-1\-2)
                                                
                                                    **type**:  :py:class:`LevelType<ydk.models.openconfig.openconfig_isis_types.LevelType>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: adjacency_type
                                                
                                                    Formed ISIS adjacency type(level\-1, level\-2, level\-1\-2)
                                                
                                                    **type**:  :py:class:`LevelType<ydk.models.openconfig.openconfig_isis_types.LevelType>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: adjacency_state
                                                
                                                    P2P 3\-way ISIS adjacency state(up, down, init, failed)
                                                
                                                    **type**:  :py:class:`IsisInterfaceAdjState<ydk.models.openconfig.openconfig_isis_types.IsisInterfaceAdjState>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: remaining_hold_time
                                                
                                                    Holding time in seconds for adjacency. This value is based on received hello PDUs and the elapsed time since receipt
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..65535
                                                
                                                    **config**: False
                                                
                                                    **units**: seconds
                                                
                                                .. attribute:: up_time
                                                
                                                    Adjacency up time
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                .. attribute:: multi_topology
                                                
                                                    When set to true, ISIS multi\-topology is supported
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                .. attribute:: topology
                                                
                                                    ISIS topology type support(ipv4\-unicast, ipv6\-unicast, ipv4\-multicast, ipv6\-multicast)
                                                
                                                    **type**: list of   :py:class:`AFISAFITYPE<ydk.models.openconfig.openconfig_isis_types.AFISAFITYPE>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_support
                                                
                                                    When set to true, Graceful\-restart signaling is supported
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_suppress
                                                
                                                    When set to true, adjacency is not advertised. The SA bit is used by a starting router to  request that its neighbor suppress advertisement of the adjacency  to the starting router in the neighbor's LSPs
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                .. attribute:: restart_status
                                                
                                                    When set to true, neighbor is being helped. The RR bit is used by a (re)starting router to signal to its neighbors that a (re)start is in progress
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                .. attribute:: area_address
                                                
                                                    List of ISIS area\-address(es)
                                                
                                                    **type**: list of str
                                                
                                                        **pattern:** ^[0\-9A\-Fa\-f]{2}\\.([0\-9A\-Fa\-f]{4}\\.){0,3}$
                                                
                                                    **config**: False
                                                
                                                .. attribute:: nlpid
                                                
                                                    Supported Protocol. IPv4 is defined as (0xcc) and IPv6 \- (0x8e). ISIS reference is TLV 129
                                                
                                                    **type**: list of   :py:class:`Nlpid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State.Nlpid>`
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "adjacency"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('system_id', (YLeaf(YType.str, 'system-id'), ['str'])),
                                                        ('neighbor_ipv4_address', (YLeaf(YType.str, 'neighbor-ipv4-address'), ['str'])),
                                                        ('neighbor_ipv6_address', (YLeaf(YType.str, 'neighbor-ipv6-address'), ['str'])),
                                                        ('neighbor_snpa', (YLeaf(YType.str, 'neighbor-snpa'), ['str'])),
                                                        ('local_extended_circuit_id', (YLeaf(YType.uint32, 'local-extended-circuit-id'), ['int'])),
                                                        ('neighbor_extended_circuit_id', (YLeaf(YType.uint32, 'neighbor-extended-circuit-id'), ['int'])),
                                                        ('priority', (YLeaf(YType.uint8, 'priority'), ['int'])),
                                                        ('dis_system_id', (YLeaf(YType.str, 'dis-system-id'), ['str'])),
                                                        ('neighbor_circuit_type', (YLeaf(YType.enumeration, 'neighbor-circuit-type'), [('ydk.models.openconfig.openconfig_isis_types', 'LevelType', '')])),
                                                        ('adjacency_type', (YLeaf(YType.enumeration, 'adjacency-type'), [('ydk.models.openconfig.openconfig_isis_types', 'LevelType', '')])),
                                                        ('adjacency_state', (YLeaf(YType.enumeration, 'adjacency-state'), [('ydk.models.openconfig.openconfig_isis_types', 'IsisInterfaceAdjState', '')])),
                                                        ('remaining_hold_time', (YLeaf(YType.uint16, 'remaining-hold-time'), ['int'])),
                                                        ('up_time', (YLeaf(YType.uint32, 'up-time'), ['int'])),
                                                        ('multi_topology', (YLeaf(YType.boolean, 'multi-topology'), ['bool'])),
                                                        ('topology', (YLeafList(YType.identityref, 'topology'), [('ydk.models.openconfig.openconfig_isis_types', 'AFISAFITYPE')])),
                                                        ('restart_support', (YLeaf(YType.boolean, 'restart-support'), ['bool'])),
                                                        ('restart_suppress', (YLeaf(YType.boolean, 'restart-suppress'), ['bool'])),
                                                        ('restart_status', (YLeaf(YType.boolean, 'restart-status'), ['bool'])),
                                                        ('area_address', (YLeafList(YType.str, 'area-address'), ['str'])),
                                                        ('nlpid', (YLeafList(YType.enumeration, 'nlpid'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State.Nlpid')])),
                                                    ])
                                                    self.system_id = None
                                                    self.neighbor_ipv4_address = None
                                                    self.neighbor_ipv6_address = None
                                                    self.neighbor_snpa = None
                                                    self.local_extended_circuit_id = None
                                                    self.neighbor_extended_circuit_id = None
                                                    self.priority = None
                                                    self.dis_system_id = None
                                                    self.neighbor_circuit_type = None
                                                    self.adjacency_type = None
                                                    self.adjacency_state = None
                                                    self.remaining_hold_time = None
                                                    self.up_time = None
                                                    self.multi_topology = None
                                                    self.topology = []
                                                    self.restart_support = None
                                                    self.restart_suppress = None
                                                    self.restart_status = None
                                                    self.area_address = []
                                                    self.nlpid = []
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Adjacencies.Adjacency.State, ['system_id', 'neighbor_ipv4_address', 'neighbor_ipv6_address', 'neighbor_snpa', 'local_extended_circuit_id', 'neighbor_extended_circuit_id', 'priority', 'dis_system_id', 'neighbor_circuit_type', 'adjacency_type', 'adjacency_state', 'remaining_hold_time', 'up_time', 'multi_topology', 'topology', 'restart_support', 'restart_suppress', 'restart_status', 'area_address', 'nlpid'], name, value)

                                                class Nlpid(Enum):
                                                    """
                                                    Nlpid (Enum Class)

                                                    .. data:: IPV4 = 0

                                                        IPv4 Address family.

                                                    .. data:: IPV6 = 1

                                                        IPv6 Address family.

                                                    """

                                                    IPV4 = Enum.YLeaf(0, "IPV4")

                                                    IPV6 = Enum.YLeaf(1, "IPV6")





                                    class Timers(_Entity_):
                                        """
                                        This container defines ISIS timers.
                                        
                                        .. attribute:: config
                                        
                                            This container defines ISIS interface hello\-timers configuration
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config>`
                                        
                                        .. attribute:: state
                                        
                                            This container defines ISIS interface hello\-timers state
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State>`
                                        
                                            **config**: False
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "timers"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"
                                            self._segment_path = lambda: "timers"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            This container defines ISIS interface hello\-timers configuration.
                                            
                                            .. attribute:: hello_interval
                                            
                                                ISIS hello\-interval value
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                            .. attribute:: hello_multiplier
                                            
                                                ISIS hello\-multiplier value
                                            
                                                **type**: int
                                            
                                                    **range:** 0..255
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "timers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                                ])
                                                self.hello_interval = None
                                                self.hello_multiplier = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.Config, ['hello_interval', 'hello_multiplier'], name, value)


                                        class State(_Entity_):
                                            """
                                            This container defines ISIS interface hello\-timers state.
                                            
                                            .. attribute:: hello_interval
                                            
                                                ISIS hello\-interval value
                                            
                                                **type**: int
                                            
                                                    **range:** 0..4294967295
                                            
                                                **config**: False
                                            
                                            .. attribute:: hello_multiplier
                                            
                                                ISIS hello\-multiplier value
                                            
                                                **type**: int
                                            
                                                    **range:** 0..255
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "timers"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_interval', (YLeaf(YType.uint32, 'hello-interval'), ['int'])),
                                                    ('hello_multiplier', (YLeaf(YType.uint8, 'hello-multiplier'), ['int'])),
                                                ])
                                                self.hello_interval = None
                                                self.hello_multiplier = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.Timers.State, ['hello_interval', 'hello_multiplier'], name, value)



                                    class AfiSafi(_Entity_):
                                        """
                                        This container defines address\-family specific configuration
                                        and state information.
                                        
                                        .. attribute:: af
                                        
                                            Address\-family/Subsequent Address\-family list
                                        
                                            **type**: list of    :py:class:`Af<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "afi-safi"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("af", ("af", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af))])
                                            self._leafs = OrderedDict()

                                            self.af = YList(self)
                                            self._segment_path = lambda: "afi-safi"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi, [], name, value)

                                        class Af(_Entity_):
                                            """
                                            Address\-family/Subsequent Address\-family list.
                                            
                                            .. attribute:: afi_name  (key)
                                            
                                                Reference to address\-family type
                                            
                                                **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                            
                                            .. attribute:: safi_name  (key)
                                            
                                                Reference to subsequent address\-family type
                                            
                                                **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                            
                                            .. attribute:: config
                                            
                                                This container defines AFI\-SAFI configuration parameters. Single topology is the default setting
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config>`
                                            
                                            .. attribute:: state
                                            
                                                This container defines AFI\-SAFI State information
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State>`
                                            
                                                **config**: False
                                            
                                            .. attribute:: segment_routing
                                            
                                                Configuration and operatioanl state parameters relating to segment routing for an interface within the IGP
                                            
                                                **type**:  :py:class:`SegmentRouting<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting>`
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "af"
                                                self.yang_parent_name = "afi-safi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = ['afi_name','safi_name']
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State)), ("segment-routing", ("segment_routing", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting))])
                                                self._leafs = OrderedDict([
                                                    ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                    ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                                ])
                                                self.afi_name = None
                                                self.safi_name = None

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"

                                                self.segment_routing = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting()
                                                self.segment_routing.parent = self
                                                self._children_name_map["segment_routing"] = "segment-routing"
                                                self._segment_path = lambda: "af" + "[afi-name='" + str(self.afi_name) + "']" + "[safi-name='" + str(self.safi_name) + "']"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af, ['afi_name', 'safi_name'], name, value)

                                            class Config(_Entity_):
                                                """
                                                This container defines AFI\-SAFI configuration parameters. Single
                                                topology is the default setting.
                                                
                                                .. attribute:: afi_name
                                                
                                                    Address\-family type
                                                
                                                    **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                                
                                                .. attribute:: safi_name
                                                
                                                    Subsequent address\-family type
                                                
                                                    **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                                
                                                .. attribute:: metric
                                                
                                                    ISIS metric value(default=10)
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **default value**: 10
                                                
                                                .. attribute:: enabled
                                                
                                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                                
                                                    **type**: bool
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                        ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ])
                                                    self.afi_name = None
                                                    self.safi_name = None
                                                    self.metric = None
                                                    self.enabled = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.Config, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                            class State(_Entity_):
                                                """
                                                This container defines AFI\-SAFI State information
                                                
                                                .. attribute:: afi_name
                                                
                                                    Address\-family type
                                                
                                                    **type**:  :py:class:`AFITYPE<ydk.models.openconfig.openconfig_isis_types.AFITYPE>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: safi_name
                                                
                                                    Subsequent address\-family type
                                                
                                                    **type**:  :py:class:`SAFITYPE<ydk.models.openconfig.openconfig_isis_types.SAFITYPE>`
                                                
                                                    **config**: False
                                                
                                                .. attribute:: metric
                                                
                                                    ISIS metric value(default=10)
                                                
                                                    **type**: int
                                                
                                                        **range:** 0..4294967295
                                                
                                                    **config**: False
                                                
                                                    **default value**: 10
                                                
                                                .. attribute:: enabled
                                                
                                                    When set to true, the functionality within which this leaf is defined is enabled, when set to false it is explicitly disabled
                                                
                                                    **type**: bool
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('afi_name', (YLeaf(YType.identityref, 'afi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'AFITYPE')])),
                                                        ('safi_name', (YLeaf(YType.identityref, 'safi-name'), [('ydk.models.openconfig.openconfig_isis_types', 'SAFITYPE')])),
                                                        ('metric', (YLeaf(YType.uint32, 'metric'), ['int'])),
                                                        ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                                    ])
                                                    self.afi_name = None
                                                    self.safi_name = None
                                                    self.metric = None
                                                    self.enabled = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.State, ['afi_name', 'safi_name', 'metric', 'enabled'], name, value)


                                            class SegmentRouting(_Entity_):
                                                """
                                                Configuration and operatioanl state parameters relating to segment
                                                routing for an interface within the IGP.
                                                
                                                .. attribute:: prefix_sids
                                                
                                                    Configuration and operational state parameters relating to the advertisement of a segment routing IGP\-Prefix SID for this interface
                                                
                                                    **type**:  :py:class:`PrefixSids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids>`
                                                
                                                .. attribute:: adjacency_sids
                                                
                                                    Configuration and operational state parameters relating to the advertisement of a segment routing adjacency SID for this interface
                                                
                                                    **type**:  :py:class:`AdjacencySids<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids>`
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "segment-routing"
                                                    self.yang_parent_name = "af"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("prefix-sids", ("prefix_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids)), ("adjacency-sids", ("adjacency_sids", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids))])
                                                    self._leafs = OrderedDict()

                                                    self.prefix_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids()
                                                    self.prefix_sids.parent = self
                                                    self._children_name_map["prefix_sids"] = "prefix-sids"

                                                    self.adjacency_sids = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids()
                                                    self.adjacency_sids.parent = self
                                                    self._children_name_map["adjacency_sids"] = "adjacency-sids"
                                                    self._segment_path = lambda: "segment-routing"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting, [], name, value)

                                                class PrefixSids(_Entity_):
                                                    """
                                                    Configuration and operational state parameters relating to
                                                    the advertisement of a segment routing IGP\-Prefix SID for this
                                                    interface.
                                                    
                                                    .. attribute:: prefix_sid
                                                    
                                                        An IGP prefix that should have a segment routing IGP\-Prefix SID allocated to it. The value of the SID is specified by the SID ID, as an absolute value. If the absolute value falls within the SRGB, the Global flag should be advertised by the system
                                                    
                                                        **type**: list of    :py:class:`PrefixSid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid>`
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "prefix-sids"
                                                        self.yang_parent_name = "segment-routing"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("prefix-sid", ("prefix_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid))])
                                                        self._leafs = OrderedDict()

                                                        self.prefix_sid = YList(self)
                                                        self._segment_path = lambda: "prefix-sids"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids, [], name, value)

                                                    class PrefixSid(_Entity_):
                                                        """
                                                        An IGP prefix that should have a segment routing IGP\-Prefix SID
                                                        allocated to it. The value of the SID is specified by the SID ID,
                                                        as an absolute value. If the absolute value falls within the SRGB,
                                                        the Global flag should be advertised by the system.
                                                        
                                                        .. attribute:: prefix  (key)
                                                        
                                                            Reference to the prefix for which the IGP\-Prefix SID is to be advertised
                                                        
                                                            **type**: union of the below types:
                                                        
                                                                **type**: str
                                                        
                                                                    **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                        
                                                                **type**: str
                                                        
                                                                    **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                        
                                                            **refers to**:  :py:class:`prefix<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config>`
                                                        
                                                        .. attribute:: config
                                                        
                                                            Configuration parameters for the IGP Prefix SID
                                                        
                                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config>`
                                                        
                                                        .. attribute:: state
                                                        
                                                            Operational state parameters for the IGP\-Prefix SID
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "prefix-sid"
                                                            self.yang_parent_name = "prefix-sids"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['prefix']
                                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State))])
                                                            self._leafs = OrderedDict([
                                                                ('prefix', (YLeaf(YType.str, 'prefix'), ['str'])),
                                                            ])
                                                            self.prefix = None

                                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config()
                                                            self.config.parent = self
                                                            self._children_name_map["config"] = "config"

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._segment_path = lambda: "prefix-sid" + "[prefix='" + str(self.prefix) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid, ['prefix'], name, value)

                                                        class Config(_Entity_):
                                                            """
                                                            Configuration parameters for the IGP Prefix SID.
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                The IP prefix for which the IGP prefix SID should be advertised. The value specified is a local prefix on the interface which is advertised into the IGP
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                                The Segment Identifier to be used when advertising the IGP Prefix SID
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                        **type**: int
                                                            
                                                                            **range:** 16..1048575
                                                            
                                                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            .. attribute:: label_options
                                                            
                                                                The options associated with the IGP prefix SID for MPLS. The value of this leaf specifies the option that the SID should be advertised into the IGP with
                                                            
                                                                **type**:  :py:class:`LabelOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config.LabelOptions>`
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "config"
                                                                self.yang_parent_name = "prefix-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                                                    ('sid_id', (YLeaf(YType.str, 'sid-id'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', ''),'str'])),
                                                                    ('label_options', (YLeaf(YType.enumeration, 'label-options'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config.LabelOptions')])),
                                                                ])
                                                                self.prefix = None
                                                                self.sid_id = None
                                                                self.label_options = None
                                                                self._segment_path = lambda: "config"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.Config, ['prefix', 'sid_id', 'label_options'], name, value)

                                                            class LabelOptions(Enum):
                                                                """
                                                                LabelOptions (Enum Class)

                                                                .. data:: NO_PHP = 0

                                                                    When this value is specified, the penultimate hop must not pop

                                                                    the Prefix-SID label before forwarding it to the local system.

                                                                .. data:: EXPLICIT_NULL = 1

                                                                    When set, the penultimate hop must swap the prefix SID for the

                                                                    relevant explicit null label before forwarding the packet.

                                                                """

                                                                NO_PHP = Enum.YLeaf(0, "NO_PHP")

                                                                EXPLICIT_NULL = Enum.YLeaf(1, "EXPLICIT_NULL")



                                                        class State(_Entity_):
                                                            """
                                                            Operational state parameters for the IGP\-Prefix SID.
                                                            
                                                            .. attribute:: prefix
                                                            
                                                                The IP prefix for which the IGP prefix SID should be advertised. The value specified is a local prefix on the interface which is advertised into the IGP
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])/(([0\-9])\|([1\-2][0\-9])\|(3[0\-2]))
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(/(([0\-9])\|([0\-9]{2})\|(1[0\-1][0\-9])\|(12[0\-8])))
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                                The Segment Identifier to be used when advertising the IGP Prefix SID
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                        **type**: int
                                                            
                                                                            **range:** 16..1048575
                                                            
                                                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: label_options
                                                            
                                                                The options associated with the IGP prefix SID for MPLS. The value of this leaf specifies the option that the SID should be advertised into the IGP with
                                                            
                                                                **type**:  :py:class:`LabelOptions<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State.LabelOptions>`
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "prefix-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('prefix', (YLeaf(YType.str, 'prefix'), ['str','str'])),
                                                                    ('sid_id', (YLeaf(YType.str, 'sid-id'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', ''),'str'])),
                                                                    ('label_options', (YLeaf(YType.enumeration, 'label-options'), [('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State.LabelOptions')])),
                                                                ])
                                                                self.prefix = None
                                                                self.sid_id = None
                                                                self.label_options = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.PrefixSids.PrefixSid.State, ['prefix', 'sid_id', 'label_options'], name, value)

                                                            class LabelOptions(Enum):
                                                                """
                                                                LabelOptions (Enum Class)

                                                                .. data:: NO_PHP = 0

                                                                    When this value is specified, the penultimate hop must not pop

                                                                    the Prefix-SID label before forwarding it to the local system.

                                                                .. data:: EXPLICIT_NULL = 1

                                                                    When set, the penultimate hop must swap the prefix SID for the

                                                                    relevant explicit null label before forwarding the packet.

                                                                """

                                                                NO_PHP = Enum.YLeaf(0, "NO_PHP")

                                                                EXPLICIT_NULL = Enum.YLeaf(1, "EXPLICIT_NULL")





                                                class AdjacencySids(_Entity_):
                                                    """
                                                    Configuration and operational state parameters relating to
                                                    the advertisement of a segment routing adjacency SID for this
                                                    interface.
                                                    
                                                    .. attribute:: adjacency_sid
                                                    
                                                        An Adjacency SID to be advertised for the specified interface. The Adj\-SID's identifier (the SID ID) must be unique, with flags specified indicating the parameters that should be set for the SID. Where a SID value is specified that is allocated from the SRGB, the global flag must be set by the system
                                                    
                                                        **type**: list of    :py:class:`AdjacencySid<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid>`
                                                    
                                                    """
                                                    _prefix = 'oc-netinst'
                                                    _revision = '2017-01-13'

                                                    def __init__(self):
                                                        super().__init__()

                                                        self.yang_name = "adjacency-sids"
                                                        self.yang_parent_name = "segment-routing"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("adjacency-sid", ("adjacency_sid", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid))])
                                                        self._leafs = OrderedDict()

                                                        self.adjacency_sid = YList(self)
                                                        self._segment_path = lambda: "adjacency-sids"
                                                        self._is_frozen = True

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids, [], name, value)

                                                    class AdjacencySid(_Entity_):
                                                        """
                                                        An Adjacency SID to be advertised for the specified interface.
                                                        The Adj\-SID's identifier (the SID ID) must be unique, with flags
                                                        specified indicating the parameters that should be set for the SID.
                                                        Where a SID value is specified that is allocated from the SRGB, the
                                                        global flag must be set by the system.
                                                        
                                                        .. attribute:: neighbor  (key)
                                                        
                                                            Reference to the neighbor with which the Adjacency SID is associated
                                                        
                                                            **type**: union of the below types:
                                                        
                                                                **type**: str
                                                        
                                                                    **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                                **type**: str
                                                        
                                                                    **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                            **refers to**:  :py:class:`neighbor<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config>`
                                                        
                                                        .. attribute:: sid_id  (key)
                                                        
                                                            Reference to the segment identifier to be used by the local system
                                                        
                                                            **type**: union of the below types:
                                                        
                                                                        **type**: int
                                                        
                                                                            **range:** 16..1048575
                                                        
                                                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                        
                                                                    **type**: str
                                                        
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                                **type**:  :py:class:`SidId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId>`
                                                        
                                                            **refers to**:  :py:class:`sid_id<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config>`
                                                        
                                                        .. attribute:: config
                                                        
                                                            Configuraton parameters relating to the AdjSID
                                                        
                                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config>`
                                                        
                                                        .. attribute:: state
                                                        
                                                            Operational state parameters relating to the AdjSID
                                                        
                                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State>`
                                                        
                                                            **config**: False
                                                        
                                                        """
                                                        _prefix = 'oc-netinst'
                                                        _revision = '2017-01-13'

                                                        def __init__(self):
                                                            super().__init__()

                                                            self.yang_name = "adjacency-sid"
                                                            self.yang_parent_name = "adjacency-sids"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = ['neighbor','sid_id']
                                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State))])
                                                            self._leafs = OrderedDict([
                                                                ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str'])),
                                                                ('sid_id', (YLeaf(YType.str, 'sid-id'), ['str'])),
                                                            ])
                                                            self.neighbor = None
                                                            self.sid_id = None

                                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config()
                                                            self.config.parent = self
                                                            self._children_name_map["config"] = "config"

                                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State()
                                                            self.state.parent = self
                                                            self._children_name_map["state"] = "state"
                                                            self._segment_path = lambda: "adjacency-sid" + "[neighbor='" + str(self.neighbor) + "']" + "[sid-id='" + str(self.sid_id) + "']"
                                                            self._is_frozen = True

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid, ['neighbor', 'sid_id'], name, value)

                                                        class Config(_Entity_):
                                                            """
                                                            Configuraton parameters relating to the AdjSID.
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                                The value of the Adj\-SID to be advertised. Where a static SID identifier is specified, this should be advertised directly by the system. Where the DYNAMIC value is specified, this should be treated as a dynamically allocated value. When the MPLS data plane is in use the dynamic value should not fall within a reserved\-label\-block
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                            **type**: int
                                                            
                                                                                **range:** 16..1048575
                                                            
                                                                            **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                                        **type**: str
                                                            
                                                                            **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                                    **type**:  :py:class:`SidId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId>`
                                                            
                                                            .. attribute:: protection_eligible
                                                            
                                                                Whether the Adj\-SID should be considered to be eligible for protection using IP or MPLS FRR during a network failure. When this value is set to true, the B\-flag of the Adj\-SID is set to 1, and the local system should provide FRR paths for the associated label forwarding entry. When it is set to false, the local system must not provide FRR for the specified LFIB entry
                                                            
                                                                **type**: bool
                                                            
                                                                **default value**: true
                                                            
                                                            .. attribute:: group
                                                            
                                                                When set to true, the Adj\-SID is indicated to be part of a group, and the G flag is set to 1 in the corresponding advertisement in the IGP
                                                            
                                                                **type**: bool
                                                            
                                                                **default value**: false
                                                            
                                                            .. attribute:: neighbor
                                                            
                                                                The remote system on the interface with which the Adj\-SID is associated
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "config"
                                                                self.yang_parent_name = "adjacency-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('sid_id', (YLeaf(YType.str, 'sid-id'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', ''),'str',('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId')])),
                                                                    ('protection_eligible', (YLeaf(YType.boolean, 'protection-eligible'), ['bool'])),
                                                                    ('group', (YLeaf(YType.boolean, 'group'), ['bool'])),
                                                                    ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str','str'])),
                                                                ])
                                                                self.sid_id = None
                                                                self.protection_eligible = None
                                                                self.group = None
                                                                self.neighbor = None
                                                                self._segment_path = lambda: "config"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.Config, ['sid_id', 'protection_eligible', 'group', 'neighbor'], name, value)

                                                            class SidId(Enum):
                                                                """
                                                                SidId (Enum Class)

                                                                .. data:: DYNAMIC = 0

                                                                    The SID chosen for the Adjacency SID should be dynamically

                                                                    allocated from the system's dynamic range of Segment

                                                                    Identifiers. For MPLS, this range should be considered to be

                                                                    those labels that do not fall within a reserved label block.

                                                                """

                                                                DYNAMIC = Enum.YLeaf(0, "DYNAMIC")



                                                        class State(_Entity_):
                                                            """
                                                            Operational state parameters relating to the AdjSID.
                                                            
                                                            .. attribute:: sid_id
                                                            
                                                                The value of the Adj\-SID to be advertised. Where a static SID identifier is specified, this should be advertised directly by the system. Where the DYNAMIC value is specified, this should be treated as a dynamically allocated value. When the MPLS data plane is in use the dynamic value should not fall within a reserved\-label\-block
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                            **type**: int
                                                            
                                                                                **range:** 16..1048575
                                                            
                                                                            **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                                        **type**: str
                                                            
                                                                            **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                                    **type**:  :py:class:`SidId<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId>`
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: protection_eligible
                                                            
                                                                Whether the Adj\-SID should be considered to be eligible for protection using IP or MPLS FRR during a network failure. When this value is set to true, the B\-flag of the Adj\-SID is set to 1, and the local system should provide FRR paths for the associated label forwarding entry. When it is set to false, the local system must not provide FRR for the specified LFIB entry
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                                **default value**: true
                                                            
                                                            .. attribute:: group
                                                            
                                                                When set to true, the Adj\-SID is indicated to be part of a group, and the G flag is set to 1 in the corresponding advertisement in the IGP
                                                            
                                                                **type**: bool
                                                            
                                                                **config**: False
                                                            
                                                                **default value**: false
                                                            
                                                            .. attribute:: neighbor
                                                            
                                                                The remote system on the interface with which the Adj\-SID is associated
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                                **config**: False
                                                            
                                                            .. attribute:: allocated_dynamic_local
                                                            
                                                                Where an Adjacency SID with a dynamic value is to be allocated by the system, this leaf reports to the value of the Adj\-SID allocated to this interface
                                                            
                                                                **type**: union of the below types:
                                                            
                                                                        **type**: int
                                                            
                                                                            **range:** 16..1048575
                                                            
                                                                        **type**:  :py:class:`MplsLabel<ydk.models.openconfig.openconfig_segment_routing.MplsLabel>`
                                                            
                                                                    **type**: str
                                                            
                                                                        **pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                            
                                                                **config**: False
                                                            
                                                            """
                                                            _prefix = 'oc-netinst'
                                                            _revision = '2017-01-13'

                                                            def __init__(self):
                                                                super().__init__()

                                                                self.yang_name = "state"
                                                                self.yang_parent_name = "adjacency-sid"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self.ylist_key_names = []
                                                                self._child_classes = OrderedDict([])
                                                                self._leafs = OrderedDict([
                                                                    ('sid_id', (YLeaf(YType.str, 'sid-id'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', ''),'str',('ydk.models.openconfig.openconfig_network_instance', 'NetworkInstances', 'NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State.SidId')])),
                                                                    ('protection_eligible', (YLeaf(YType.boolean, 'protection-eligible'), ['bool'])),
                                                                    ('group', (YLeaf(YType.boolean, 'group'), ['bool'])),
                                                                    ('neighbor', (YLeaf(YType.str, 'neighbor'), ['str','str'])),
                                                                    ('allocated_dynamic_local', (YLeaf(YType.str, 'allocated-dynamic-local'), ['int',('ydk.models.openconfig.openconfig_segment_routing', 'MplsLabel', ''),'str'])),
                                                                ])
                                                                self.sid_id = None
                                                                self.protection_eligible = None
                                                                self.group = None
                                                                self.neighbor = None
                                                                self.allocated_dynamic_local = None
                                                                self._segment_path = lambda: "state"
                                                                self._is_frozen = True

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.AfiSafi.Af.SegmentRouting.AdjacencySids.AdjacencySid.State, ['sid_id', 'protection_eligible', 'group', 'neighbor', 'allocated_dynamic_local'], name, value)

                                                            class SidId(Enum):
                                                                """
                                                                SidId (Enum Class)

                                                                .. data:: DYNAMIC = 0

                                                                    The SID chosen for the Adjacency SID should be dynamically

                                                                    allocated from the system's dynamic range of Segment

                                                                    Identifiers. For MPLS, this range should be considered to be

                                                                    those labels that do not fall within a reserved label block.

                                                                """

                                                                DYNAMIC = Enum.YLeaf(0, "DYNAMIC")








                                    class HelloAuthentication(_Entity_):
                                        """
                                        This container defines ISIS authentication.
                                        
                                        .. attribute:: config
                                        
                                            This container defines ISIS authentication configuration
                                        
                                            **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config>`
                                        
                                        .. attribute:: state
                                        
                                            This container defines ISIS authentication state
                                        
                                            **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State>`
                                        
                                            **config**: False
                                        
                                        .. attribute:: key
                                        
                                            This container defines ISIS authentication key
                                        
                                            **type**:  :py:class:`Key<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key>`
                                        
                                        .. attribute:: keychain
                                        
                                            This container defines keychain parameters
                                        
                                            **type**:  :py:class:`Keychain<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain>`
                                        
                                        """
                                        _prefix = 'oc-netinst'
                                        _revision = '2017-01-13'

                                        def __init__(self):
                                            super().__init__()

                                            self.yang_name = "hello-authentication"
                                            self.yang_parent_name = "level"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State)), ("key", ("key", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key)), ("keychain", ("keychain", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain))])
                                            self._leafs = OrderedDict()

                                            self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config()
                                            self.config.parent = self
                                            self._children_name_map["config"] = "config"

                                            self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State()
                                            self.state.parent = self
                                            self._children_name_map["state"] = "state"

                                            self.key = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key()
                                            self.key.parent = self
                                            self._children_name_map["key"] = "key"

                                            self.keychain = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Keychain()
                                            self.keychain.parent = self
                                            self._children_name_map["keychain"] = "keychain"
                                            self._segment_path = lambda: "hello-authentication"
                                            self._is_frozen = True

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication, [], name, value)

                                        class Config(_Entity_):
                                            """
                                            This container defines ISIS authentication configuration.
                                            
                                            .. attribute:: hello_authentication
                                            
                                                Enabled or disable ISIS Hello authentication
                                            
                                                **type**: bool
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "config"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_authentication', (YLeaf(YType.boolean, 'hello-authentication'), ['bool'])),
                                                ])
                                                self.hello_authentication = None
                                                self._segment_path = lambda: "config"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Config, ['hello_authentication'], name, value)


                                        class State(_Entity_):
                                            """
                                            This container defines ISIS authentication state.
                                            
                                            .. attribute:: hello_authentication
                                            
                                                Enabled or disable ISIS Hello authentication
                                            
                                                **type**: bool
                                            
                                                **config**: False
                                            
                                                **default value**: false
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "state"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('hello_authentication', (YLeaf(YType.boolean, 'hello-authentication'), ['bool'])),
                                                ])
                                                self.hello_authentication = None
                                                self._segment_path = lambda: "state"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.State, ['hello_authentication'], name, value)


                                        class Key(_Entity_):
                                            """
                                            This container defines ISIS authentication key
                                            
                                            .. attribute:: config
                                            
                                                This container defines ISIS authentication key configuration
                                            
                                                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config>`
                                            
                                            .. attribute:: state
                                            
                                                This container defines ISIS authentication key state
                                            
                                                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State>`
                                            
                                                **config**: False
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "key"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State))])
                                                self._leafs = OrderedDict()

                                                self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config()
                                                self.config.parent = self
                                                self._children_name_map["config"] = "config"

                                                self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State()
                                                self.state.parent = self
                                                self._children_name_map["state"] = "state"
                                                self._segment_path = lambda: "key"
                                                self._is_frozen = True

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key, [], name, value)

                                            class Config(_Entity_):
                                                """
                                                This container defines ISIS authentication key configuration.
                                                
                                                .. attribute:: auth_password
                                                
                                                    Authentication key string
                                                
                                                    **type**: str
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "config"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                                    ])
                                                    self.auth_password = None
                                                    self._segment_path = lambda: "config"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.Config, ['auth_password'], name, value)


                                            class State(_Entity_):
                                                """
                                                This container defines ISIS authentication key state.
                                                
                                                .. attribute:: auth_password
                                                
                                                    Authentication key string
                                                
                                                    **type**: str
                                                
                                                    **config**: False
                                                
                                                """
                                                _prefix = 'oc-netinst'
                                                _revision = '2017-01-13'

                                                def __init__(self):
                                                    super().__init__()

                                                    self.yang_name = "state"
                                                    self.yang_parent_name = "key"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('auth_password', (YLeaf(YType.str, 'auth-password'), ['str'])),
                                                    ])
                                                    self.auth_password = None
                                                    self._segment_path = lambda: "state"
                                                    self._is_frozen = True

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Levels.Level.HelloAuthentication.Key.State, ['auth_password'], name, value)



                                        class Keychain(_Entity_):
                                            """
                                            This container defines keychain parameters.
                                            
                                            """
                                            _prefix = 'oc-netinst'
                                            _revision = '2017-01-13'

                                            def __init__(self):
                                                super().__init__()

                                                self.yang_name = "keychain"
                                                self.yang_parent_name = "hello-authentication"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict()
                                                self._segment_path = lambda: "keychain"
                                                self._is_frozen = True





                            class Timers(_Entity_):
                                """
                                This container describes ISIS interface timers configuration
                                
                                .. attribute:: config
                                
                                    Configuration parameters relating to interface timers for IS\-IS
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines state information for ISIS interface timers
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "timers"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "timers"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configuration parameters relating to interface
                                    timers for IS\-IS
                                    
                                    .. attribute:: csnp_interval
                                    
                                        The interval, specified in seconds, at which periodic CSNP packets should be transmitted by the local IS
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **units**: seconds
                                    
                                    .. attribute:: lsp_pacing_interval
                                    
                                        The interval interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **units**: milliseconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_interval', (YLeaf(YType.uint16, 'csnp-interval'), ['int'])),
                                            ('lsp_pacing_interval', (YLeaf(YType.uint64, 'lsp-pacing-interval'), ['int'])),
                                        ])
                                        self.csnp_interval = None
                                        self.lsp_pacing_interval = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.Config, ['csnp_interval', 'lsp_pacing_interval'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines state information for ISIS interface timers.
                                    
                                    .. attribute:: csnp_interval
                                    
                                        The interval, specified in seconds, at which periodic CSNP packets should be transmitted by the local IS
                                    
                                        **type**: int
                                    
                                            **range:** 0..65535
                                    
                                        **config**: False
                                    
                                        **units**: seconds
                                    
                                    .. attribute:: lsp_pacing_interval
                                    
                                        The interval interval in milliseconds between the detection of topology change and when the SPF algorithm runs
                                    
                                        **type**: int
                                    
                                            **range:** 0..18446744073709551615
                                    
                                        **config**: False
                                    
                                        **units**: milliseconds
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "timers"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('csnp_interval', (YLeaf(YType.uint16, 'csnp-interval'), ['int'])),
                                            ('lsp_pacing_interval', (YLeaf(YType.uint64, 'lsp-pacing-interval'), ['int'])),
                                        ])
                                        self.csnp_interval = None
                                        self.lsp_pacing_interval = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Timers.State, ['csnp_interval', 'lsp_pacing_interval'], name, value)



                            class Bfd(_Entity_):
                                """
                                This container defines BFD.
                                
                                .. attribute:: config
                                
                                    This container defines BFD configuration parameters
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config>`
                                
                                .. attribute:: state
                                
                                    This container defines BFD state information
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "bfd"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "bfd"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd, [], name, value)

                                class Config(_Entity_):
                                    """
                                    This container defines BFD configuration parameters.
                                    
                                    .. attribute:: bfd_tlv
                                    
                                        When set to true, BFD TLV is used. This enables support for the IS\-IS BFD TLV options, which specify that a BFD session must be established before an IS\-IS adjacency can transition to the established state. This option should be enabled on all IS\-IS neighbors on a shared interface
                                    
                                        **type**: bool
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_tlv', (YLeaf(YType.boolean, 'bfd-tlv'), ['bool'])),
                                        ])
                                        self.bfd_tlv = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.Config, ['bfd_tlv'], name, value)


                                class State(_Entity_):
                                    """
                                    This container defines BFD state information.
                                    
                                    .. attribute:: bfd_tlv
                                    
                                        When set to true, BFD TLV is used. This enables support for the IS\-IS BFD TLV options, which specify that a BFD session must be established before an IS\-IS adjacency can transition to the established state. This option should be enabled on all IS\-IS neighbors on a shared interface
                                    
                                        **type**: bool
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "bfd"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bfd_tlv', (YLeaf(YType.boolean, 'bfd-tlv'), ['bool'])),
                                        ])
                                        self.bfd_tlv = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.Bfd.State, ['bfd_tlv'], name, value)



                            class InterfaceRef(_Entity_):
                                """
                                Reference to an interface or subinterface
                                
                                .. attribute:: config
                                
                                    Configured reference to interface / subinterface
                                
                                    **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config>`
                                
                                .. attribute:: state
                                
                                    Operational state for interface\-ref
                                
                                    **type**:  :py:class:`State<ydk.models.openconfig.openconfig_network_instance.NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State>`
                                
                                    **config**: False
                                
                                """
                                _prefix = 'oc-netinst'
                                _revision = '2017-01-13'

                                def __init__(self):
                                    super().__init__()

                                    self.yang_name = "interface-ref"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("config", ("config", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config)), ("state", ("state", NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State))])
                                    self._leafs = OrderedDict()

                                    self.config = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config()
                                    self.config.parent = self
                                    self._children_name_map["config"] = "config"

                                    self.state = NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State()
                                    self.state.parent = self
                                    self._children_name_map["state"] = "state"
                                    self._segment_path = lambda: "interface-ref"
                                    self._is_frozen = True

                                def __setattr__(self, name, value):
                                    self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef, [], name, value)

                                class Config(_Entity_):
                                    """
                                    Configured reference to interface / subinterface
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "config"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "config"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.Config, ['interface', 'subinterface'], name, value)


                                class State(_Entity_):
                                    """
                                    Operational state for interface\-ref
                                    
                                    .. attribute:: interface
                                    
                                        Reference to a base interface.  If a reference to a subinterface is required, this leaf must be specified to indicate the base interface
                                    
                                        **type**: str
                                    
                                        **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface>`
                                    
                                        **config**: False
                                    
                                    .. attribute:: subinterface
                                    
                                        Reference to a subinterface \-\- this requires the base interface to be specified using the interface leaf in this container.  If only a reference to a base interface is requuired, this leaf should not be set
                                    
                                        **type**: int
                                    
                                            **range:** 0..4294967295
                                    
                                        **refers to**:  :py:class:`index<ydk.models.openconfig.openconfig_interfaces.Interfaces.Interface.Subinterfaces.Subinterface>`
                                    
                                        **config**: False
                                    
                                    """
                                    _prefix = 'oc-netinst'
                                    _revision = '2017-01-13'

                                    def __init__(self):
                                        super().__init__()

                                        self.yang_name = "state"
                                        self.yang_parent_name = "interface-ref"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('interface', (YLeaf(YType.str, 'interface'), ['str'])),
                                            ('subinterface', (YLeaf(YType.str, 'subinterface'), ['int'])),
                                        ])
                                        self.interface = None
                                        self.subinterface = None
                                        self._segment_path = lambda: "state"
                                        self._is_frozen = True

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(NetworkInstances.NetworkInstance.Protocols.Protocol.Isis.Interfaces.Interface.InterfaceRef.State, ['interface', 'subinterface'], name, value)









    def clone_ptr(self):
        self._top_entity = NetworkInstances()
        return self._top_entity



